#include <assert.h>

#include <aterm2.h>
#include <deprecated.h>
#include "MuASF.h"

/**
 * Converts a string to an ATermList of integers (ASCII values). 
 * \param[in] str An ASCII string
 * \return An ATermList containing the ASCII values of #arg as ATermInts
 */
ATerm MA_stringToChars(const char *str) {
  int len = strlen(str);
  int i;
  ATermList result = ATempty;

  for (i = len - 1; i >= 0; i--) {
    result = ATinsert(result, (ATerm) ATmakeInt(str[i]));
  }

  return (ATerm) result;
}

/**
 * Converts an ASCII char to an ATermInt. 
 * \param[in] ch an ASCII character
 * \return An ATerm representing the ASCII value of #arg
 */
ATerm MA_byteToChar(char ch) {
    return (ATerm) ATmakeInt(ch);
}

/**
 * Converts a list of integers (ASCII values) to a C string. 
 * \param[in] arg An ATermList with ATermInts, such as [32,32,10]
 * \return String containing the characters from #arg as characters
 */
char *MA_charsToString(ATerm arg) {
  ATermList list = (ATermList) arg;
  int len = ATgetLength(list);
  int i;
  char *str;

  str = (char *) malloc(len+1);
  if (str == NULL) {
      return NULL;
  }

  for (i = 0; !ATisEmpty(list); list = ATgetNext(list), i++) {
    str[i] = (char) ATgetInt((ATermInt) ATgetFirst(list));
  }
  str[i] = '\0';

  return str;
}

char MA_charToByte(ATerm arg) {
    return (char) ATgetInt((ATermInt) arg);
}


typedef struct ATerm _MA_OptLayout;
typedef struct ATerm _MA_Layout;
typedef struct ATerm _MA_LexLayoutList;
typedef struct ATerm _MA_TraversalStrategy;
typedef struct ATerm _MA_TraversalType;
typedef struct ATerm _MA_TraversalContinuation;
typedef struct ATerm _MA_FunId;
typedef struct ATerm _MA_VarId;
typedef struct ATerm _MA_ModId;
typedef struct ATerm _MA_Term;
typedef struct ATerm _MA_TermList;
typedef struct ATerm _MA_SigArg;
typedef struct ATerm _MA_FuncDef;
typedef struct ATerm _MA_Annotations;
typedef struct ATerm _MA_SigArgList;
typedef struct ATerm _MA_FuncDefList;
typedef struct ATerm _MA_Rule;
typedef struct ATerm _MA_RuleList;
typedef struct ATerm _MA_CondList;
typedef struct ATerm _MA_Cond;
typedef struct ATerm _MA_SignatureOpt;
typedef struct ATerm _MA_RulesOpt;
typedef struct ATerm _MA_Module;
typedef struct ATerm _MA_TermArgs;
typedef struct ATerm _MA_TermElems;
typedef struct ATerm _MA_SigArgArgs;
typedef struct ATerm _MA_TermAttrs;
typedef struct ATerm _MA_FuncDefDefs;
typedef struct ATerm _MA_RuleRules;
typedef struct ATerm _MA_CondConds;
typedef struct ATerm _MA_LexLayout;
typedef struct ATerm _MA_LexStrChar;
typedef struct ATerm _MA_StrChar;
typedef struct ATerm _MA_LexStrCon;
typedef struct ATerm _MA_StrCon;
typedef struct ATerm _MA_LexStrCharChars;
typedef struct ATerm _MA_LexNatCon;
typedef struct ATerm _MA_NatCon;
typedef struct ATerm _MA_LexIdCon;
typedef struct ATerm _MA_IdCon;


/**
 * Initializes the full API. Forgetting to call this function before using the API will lead to strange behaviour. ATinit() needs to be called before this function.
 */
void _MA_initMuASFApi(void) {
  init_MuASF_dict();

}

/**
 * Protect a MA_OptLayout from the ATerm garbage collector. Every MA_OptLayout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_OptLayout
 */
void _MA_protectOptLayout(MA_OptLayout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_OptLayout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_OptLayout
 */
void _MA_unprotectOptLayout(MA_OptLayout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_Layout from the ATerm garbage collector. Every MA_Layout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_Layout
 */
void _MA_protectLayout(MA_Layout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_Layout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_Layout
 */
void _MA_unprotectLayout(MA_Layout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexLayoutList from the ATerm garbage collector. Every MA_LexLayoutList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexLayoutList
 */
void _MA_protectLexLayoutList(MA_LexLayoutList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexLayoutList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexLayoutList
 */
void _MA_unprotectLexLayoutList(MA_LexLayoutList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TraversalStrategy from the ATerm garbage collector. Every MA_TraversalStrategy that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TraversalStrategy
 */
void _MA_protectTraversalStrategy(MA_TraversalStrategy *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TraversalStrategy from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TraversalStrategy
 */
void _MA_unprotectTraversalStrategy(MA_TraversalStrategy *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TraversalType from the ATerm garbage collector. Every MA_TraversalType that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TraversalType
 */
void _MA_protectTraversalType(MA_TraversalType *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TraversalType from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TraversalType
 */
void _MA_unprotectTraversalType(MA_TraversalType *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TraversalContinuation from the ATerm garbage collector. Every MA_TraversalContinuation that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TraversalContinuation
 */
void _MA_protectTraversalContinuation(MA_TraversalContinuation *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TraversalContinuation from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TraversalContinuation
 */
void _MA_unprotectTraversalContinuation(MA_TraversalContinuation *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_FunId from the ATerm garbage collector. Every MA_FunId that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_FunId
 */
void _MA_protectFunId(MA_FunId *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_FunId from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_FunId
 */
void _MA_unprotectFunId(MA_FunId *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_VarId from the ATerm garbage collector. Every MA_VarId that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_VarId
 */
void _MA_protectVarId(MA_VarId *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_VarId from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_VarId
 */
void _MA_unprotectVarId(MA_VarId *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_ModId from the ATerm garbage collector. Every MA_ModId that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_ModId
 */
void _MA_protectModId(MA_ModId *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_ModId from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_ModId
 */
void _MA_unprotectModId(MA_ModId *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_Term from the ATerm garbage collector. Every MA_Term that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_Term
 */
void _MA_protectTerm(MA_Term *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_Term from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_Term
 */
void _MA_unprotectTerm(MA_Term *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TermList from the ATerm garbage collector. Every MA_TermList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TermList
 */
void _MA_protectTermList(MA_TermList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TermList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TermList
 */
void _MA_unprotectTermList(MA_TermList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_SigArg from the ATerm garbage collector. Every MA_SigArg that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_SigArg
 */
void _MA_protectSigArg(MA_SigArg *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_SigArg from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_SigArg
 */
void _MA_unprotectSigArg(MA_SigArg *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_FuncDef from the ATerm garbage collector. Every MA_FuncDef that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_FuncDef
 */
void _MA_protectFuncDef(MA_FuncDef *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_FuncDef from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_FuncDef
 */
void _MA_unprotectFuncDef(MA_FuncDef *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_Annotations from the ATerm garbage collector. Every MA_Annotations that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_Annotations
 */
void _MA_protectAnnotations(MA_Annotations *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_Annotations from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_Annotations
 */
void _MA_unprotectAnnotations(MA_Annotations *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_SigArgList from the ATerm garbage collector. Every MA_SigArgList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_SigArgList
 */
void _MA_protectSigArgList(MA_SigArgList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_SigArgList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_SigArgList
 */
void _MA_unprotectSigArgList(MA_SigArgList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_FuncDefList from the ATerm garbage collector. Every MA_FuncDefList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_FuncDefList
 */
void _MA_protectFuncDefList(MA_FuncDefList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_FuncDefList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_FuncDefList
 */
void _MA_unprotectFuncDefList(MA_FuncDefList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_Rule from the ATerm garbage collector. Every MA_Rule that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_Rule
 */
void _MA_protectRule(MA_Rule *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_Rule from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_Rule
 */
void _MA_unprotectRule(MA_Rule *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_RuleList from the ATerm garbage collector. Every MA_RuleList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_RuleList
 */
void _MA_protectRuleList(MA_RuleList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_RuleList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_RuleList
 */
void _MA_unprotectRuleList(MA_RuleList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_CondList from the ATerm garbage collector. Every MA_CondList that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_CondList
 */
void _MA_protectCondList(MA_CondList *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_CondList from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_CondList
 */
void _MA_unprotectCondList(MA_CondList *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_Cond from the ATerm garbage collector. Every MA_Cond that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_Cond
 */
void _MA_protectCond(MA_Cond *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_Cond from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_Cond
 */
void _MA_unprotectCond(MA_Cond *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_SignatureOpt from the ATerm garbage collector. Every MA_SignatureOpt that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_SignatureOpt
 */
void _MA_protectSignatureOpt(MA_SignatureOpt *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_SignatureOpt from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_SignatureOpt
 */
void _MA_unprotectSignatureOpt(MA_SignatureOpt *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_RulesOpt from the ATerm garbage collector. Every MA_RulesOpt that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_RulesOpt
 */
void _MA_protectRulesOpt(MA_RulesOpt *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_RulesOpt from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_RulesOpt
 */
void _MA_unprotectRulesOpt(MA_RulesOpt *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_Module from the ATerm garbage collector. Every MA_Module that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_Module
 */
void _MA_protectModule(MA_Module *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_Module from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_Module
 */
void _MA_unprotectModule(MA_Module *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TermArgs from the ATerm garbage collector. Every MA_TermArgs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TermArgs
 */
void _MA_protectTermArgs(MA_TermArgs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TermArgs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TermArgs
 */
void _MA_unprotectTermArgs(MA_TermArgs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TermElems from the ATerm garbage collector. Every MA_TermElems that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TermElems
 */
void _MA_protectTermElems(MA_TermElems *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TermElems from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TermElems
 */
void _MA_unprotectTermElems(MA_TermElems *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_SigArgArgs from the ATerm garbage collector. Every MA_SigArgArgs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_SigArgArgs
 */
void _MA_protectSigArgArgs(MA_SigArgArgs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_SigArgArgs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_SigArgArgs
 */
void _MA_unprotectSigArgArgs(MA_SigArgArgs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_TermAttrs from the ATerm garbage collector. Every MA_TermAttrs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_TermAttrs
 */
void _MA_protectTermAttrs(MA_TermAttrs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_TermAttrs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_TermAttrs
 */
void _MA_unprotectTermAttrs(MA_TermAttrs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_FuncDefDefs from the ATerm garbage collector. Every MA_FuncDefDefs that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_FuncDefDefs
 */
void _MA_protectFuncDefDefs(MA_FuncDefDefs *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_FuncDefDefs from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_FuncDefDefs
 */
void _MA_unprotectFuncDefDefs(MA_FuncDefDefs *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_RuleRules from the ATerm garbage collector. Every MA_RuleRules that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_RuleRules
 */
void _MA_protectRuleRules(MA_RuleRules *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_RuleRules from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_RuleRules
 */
void _MA_unprotectRuleRules(MA_RuleRules *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_CondConds from the ATerm garbage collector. Every MA_CondConds that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_CondConds
 */
void _MA_protectCondConds(MA_CondConds *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_CondConds from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_CondConds
 */
void _MA_unprotectCondConds(MA_CondConds *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexLayout from the ATerm garbage collector. Every MA_LexLayout that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexLayout
 */
void _MA_protectLexLayout(MA_LexLayout *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexLayout from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexLayout
 */
void _MA_unprotectLexLayout(MA_LexLayout *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexStrChar from the ATerm garbage collector. Every MA_LexStrChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexStrChar
 */
void _MA_protectLexStrChar(MA_LexStrChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexStrChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexStrChar
 */
void _MA_unprotectLexStrChar(MA_LexStrChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_StrChar from the ATerm garbage collector. Every MA_StrChar that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_StrChar
 */
void _MA_protectStrChar(MA_StrChar *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_StrChar from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_StrChar
 */
void _MA_unprotectStrChar(MA_StrChar *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexStrCon from the ATerm garbage collector. Every MA_LexStrCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexStrCon
 */
void _MA_protectLexStrCon(MA_LexStrCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexStrCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexStrCon
 */
void _MA_unprotectLexStrCon(MA_LexStrCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_StrCon from the ATerm garbage collector. Every MA_StrCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_StrCon
 */
void _MA_protectStrCon(MA_StrCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_StrCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_StrCon
 */
void _MA_unprotectStrCon(MA_StrCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexStrCharChars from the ATerm garbage collector. Every MA_LexStrCharChars that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexStrCharChars
 */
void _MA_protectLexStrCharChars(MA_LexStrCharChars *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexStrCharChars from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexStrCharChars
 */
void _MA_unprotectLexStrCharChars(MA_LexStrCharChars *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexNatCon from the ATerm garbage collector. Every MA_LexNatCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexNatCon
 */
void _MA_protectLexNatCon(MA_LexNatCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexNatCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexNatCon
 */
void _MA_unprotectLexNatCon(MA_LexNatCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_NatCon from the ATerm garbage collector. Every MA_NatCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_NatCon
 */
void _MA_protectNatCon(MA_NatCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_NatCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_NatCon
 */
void _MA_unprotectNatCon(MA_NatCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_LexIdCon from the ATerm garbage collector. Every MA_LexIdCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_LexIdCon
 */
void _MA_protectLexIdCon(MA_LexIdCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_LexIdCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_LexIdCon
 */
void _MA_unprotectLexIdCon(MA_LexIdCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Protect a MA_IdCon from the ATerm garbage collector. Every MA_IdCon that is not rooted somewhere on the C call stack must be protected. Examples are global variables
 * \param[in] arg pointer to a MA_IdCon
 */
void _MA_protectIdCon(MA_IdCon *arg) {
  ATprotect((ATerm*)((void*) arg));
}

/**
 * Unprotect a MA_IdCon from the ATerm garbage collector. This improves the efficiency of the garbage collector, as well as provide opportunity for reclaiming space
 * \param[in] arg pointer to a MA_IdCon
 */
void _MA_unprotectIdCon(MA_IdCon *arg) {
  ATunprotect((ATerm*)((void*) arg));
}

/**
 * Transforms an ATerm to a MA_OptLayout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_OptLayout that was encoded by \arg
 */
MA_OptLayout _MA_OptLayoutFromTerm(ATerm t) {
  return (MA_OptLayout)t;
}

/**
 * Transforms a MA_OptLayoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_OptLayout to be converted
 * \return ATerm that represents the MA_OptLayout
 */
ATerm _MA_OptLayoutToTerm(MA_OptLayout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_Layout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_Layout that was encoded by \arg
 */
MA_Layout _MA_LayoutFromTerm(ATerm t) {
  return (MA_Layout)t;
}

/**
 * Transforms a MA_Layoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_Layout to be converted
 * \return ATerm that represents the MA_Layout
 */
ATerm _MA_LayoutToTerm(MA_Layout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexLayoutList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexLayoutList that was encoded by \arg
 */
MA_LexLayoutList _MA_LexLayoutListFromTerm(ATerm t) {
  return (MA_LexLayoutList)t;
}

/**
 * Transforms a MA_LexLayoutListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexLayoutList to be converted
 * \return ATerm that represents the MA_LexLayoutList
 */
ATerm _MA_LexLayoutListToTerm(MA_LexLayoutList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TraversalStrategy. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TraversalStrategy that was encoded by \arg
 */
MA_TraversalStrategy _MA_TraversalStrategyFromTerm(ATerm t) {
  return (MA_TraversalStrategy)t;
}

/**
 * Transforms a MA_TraversalStrategyto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TraversalStrategy to be converted
 * \return ATerm that represents the MA_TraversalStrategy
 */
ATerm _MA_TraversalStrategyToTerm(MA_TraversalStrategy arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TraversalType. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TraversalType that was encoded by \arg
 */
MA_TraversalType _MA_TraversalTypeFromTerm(ATerm t) {
  return (MA_TraversalType)t;
}

/**
 * Transforms a MA_TraversalTypeto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TraversalType to be converted
 * \return ATerm that represents the MA_TraversalType
 */
ATerm _MA_TraversalTypeToTerm(MA_TraversalType arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TraversalContinuation. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TraversalContinuation that was encoded by \arg
 */
MA_TraversalContinuation _MA_TraversalContinuationFromTerm(ATerm t) {
  return (MA_TraversalContinuation)t;
}

/**
 * Transforms a MA_TraversalContinuationto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TraversalContinuation to be converted
 * \return ATerm that represents the MA_TraversalContinuation
 */
ATerm _MA_TraversalContinuationToTerm(MA_TraversalContinuation arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_FunId. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_FunId that was encoded by \arg
 */
MA_FunId _MA_FunIdFromTerm(ATerm t) {
  return (MA_FunId)t;
}

/**
 * Transforms a MA_FunIdto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_FunId to be converted
 * \return ATerm that represents the MA_FunId
 */
ATerm _MA_FunIdToTerm(MA_FunId arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_VarId. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_VarId that was encoded by \arg
 */
MA_VarId _MA_VarIdFromTerm(ATerm t) {
  return (MA_VarId)t;
}

/**
 * Transforms a MA_VarIdto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_VarId to be converted
 * \return ATerm that represents the MA_VarId
 */
ATerm _MA_VarIdToTerm(MA_VarId arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_ModId. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_ModId that was encoded by \arg
 */
MA_ModId _MA_ModIdFromTerm(ATerm t) {
  return (MA_ModId)t;
}

/**
 * Transforms a MA_ModIdto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_ModId to be converted
 * \return ATerm that represents the MA_ModId
 */
ATerm _MA_ModIdToTerm(MA_ModId arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_Term. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_Term that was encoded by \arg
 */
MA_Term _MA_TermFromTerm(ATerm t) {
  return (MA_Term)t;
}

/**
 * Transforms a MA_Termto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_Term to be converted
 * \return ATerm that represents the MA_Term
 */
ATerm _MA_TermToTerm(MA_Term arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TermList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TermList that was encoded by \arg
 */
MA_TermList _MA_TermListFromTerm(ATerm t) {
  return (MA_TermList)t;
}

/**
 * Transforms a MA_TermListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TermList to be converted
 * \return ATerm that represents the MA_TermList
 */
ATerm _MA_TermListToTerm(MA_TermList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_SigArg. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_SigArg that was encoded by \arg
 */
MA_SigArg _MA_SigArgFromTerm(ATerm t) {
  return (MA_SigArg)t;
}

/**
 * Transforms a MA_SigArgto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_SigArg to be converted
 * \return ATerm that represents the MA_SigArg
 */
ATerm _MA_SigArgToTerm(MA_SigArg arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_FuncDef. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_FuncDef that was encoded by \arg
 */
MA_FuncDef _MA_FuncDefFromTerm(ATerm t) {
  return (MA_FuncDef)t;
}

/**
 * Transforms a MA_FuncDefto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_FuncDef to be converted
 * \return ATerm that represents the MA_FuncDef
 */
ATerm _MA_FuncDefToTerm(MA_FuncDef arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_Annotations. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_Annotations that was encoded by \arg
 */
MA_Annotations _MA_AnnotationsFromTerm(ATerm t) {
  return (MA_Annotations)t;
}

/**
 * Transforms a MA_Annotationsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_Annotations to be converted
 * \return ATerm that represents the MA_Annotations
 */
ATerm _MA_AnnotationsToTerm(MA_Annotations arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_SigArgList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_SigArgList that was encoded by \arg
 */
MA_SigArgList _MA_SigArgListFromTerm(ATerm t) {
  return (MA_SigArgList)t;
}

/**
 * Transforms a MA_SigArgListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_SigArgList to be converted
 * \return ATerm that represents the MA_SigArgList
 */
ATerm _MA_SigArgListToTerm(MA_SigArgList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_FuncDefList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_FuncDefList that was encoded by \arg
 */
MA_FuncDefList _MA_FuncDefListFromTerm(ATerm t) {
  return (MA_FuncDefList)t;
}

/**
 * Transforms a MA_FuncDefListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_FuncDefList to be converted
 * \return ATerm that represents the MA_FuncDefList
 */
ATerm _MA_FuncDefListToTerm(MA_FuncDefList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_Rule. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_Rule that was encoded by \arg
 */
MA_Rule _MA_RuleFromTerm(ATerm t) {
  return (MA_Rule)t;
}

/**
 * Transforms a MA_Ruleto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_Rule to be converted
 * \return ATerm that represents the MA_Rule
 */
ATerm _MA_RuleToTerm(MA_Rule arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_RuleList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_RuleList that was encoded by \arg
 */
MA_RuleList _MA_RuleListFromTerm(ATerm t) {
  return (MA_RuleList)t;
}

/**
 * Transforms a MA_RuleListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_RuleList to be converted
 * \return ATerm that represents the MA_RuleList
 */
ATerm _MA_RuleListToTerm(MA_RuleList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_CondList. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_CondList that was encoded by \arg
 */
MA_CondList _MA_CondListFromTerm(ATerm t) {
  return (MA_CondList)t;
}

/**
 * Transforms a MA_CondListto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_CondList to be converted
 * \return ATerm that represents the MA_CondList
 */
ATerm _MA_CondListToTerm(MA_CondList arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_Cond. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_Cond that was encoded by \arg
 */
MA_Cond _MA_CondFromTerm(ATerm t) {
  return (MA_Cond)t;
}

/**
 * Transforms a MA_Condto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_Cond to be converted
 * \return ATerm that represents the MA_Cond
 */
ATerm _MA_CondToTerm(MA_Cond arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_SignatureOpt. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_SignatureOpt that was encoded by \arg
 */
MA_SignatureOpt _MA_SignatureOptFromTerm(ATerm t) {
  return (MA_SignatureOpt)t;
}

/**
 * Transforms a MA_SignatureOptto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_SignatureOpt to be converted
 * \return ATerm that represents the MA_SignatureOpt
 */
ATerm _MA_SignatureOptToTerm(MA_SignatureOpt arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_RulesOpt. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_RulesOpt that was encoded by \arg
 */
MA_RulesOpt _MA_RulesOptFromTerm(ATerm t) {
  return (MA_RulesOpt)t;
}

/**
 * Transforms a MA_RulesOptto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_RulesOpt to be converted
 * \return ATerm that represents the MA_RulesOpt
 */
ATerm _MA_RulesOptToTerm(MA_RulesOpt arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_Module. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_Module that was encoded by \arg
 */
MA_Module _MA_ModuleFromTerm(ATerm t) {
  return (MA_Module)t;
}

/**
 * Transforms a MA_Moduleto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_Module to be converted
 * \return ATerm that represents the MA_Module
 */
ATerm _MA_ModuleToTerm(MA_Module arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TermArgs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TermArgs that was encoded by \arg
 */
MA_TermArgs _MA_TermArgsFromTerm(ATerm t) {
  return (MA_TermArgs)t;
}

/**
 * Transforms a MA_TermArgsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TermArgs to be converted
 * \return ATerm that represents the MA_TermArgs
 */
ATerm _MA_TermArgsToTerm(MA_TermArgs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TermElems. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TermElems that was encoded by \arg
 */
MA_TermElems _MA_TermElemsFromTerm(ATerm t) {
  return (MA_TermElems)t;
}

/**
 * Transforms a MA_TermElemsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TermElems to be converted
 * \return ATerm that represents the MA_TermElems
 */
ATerm _MA_TermElemsToTerm(MA_TermElems arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_SigArgArgs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_SigArgArgs that was encoded by \arg
 */
MA_SigArgArgs _MA_SigArgArgsFromTerm(ATerm t) {
  return (MA_SigArgArgs)t;
}

/**
 * Transforms a MA_SigArgArgsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_SigArgArgs to be converted
 * \return ATerm that represents the MA_SigArgArgs
 */
ATerm _MA_SigArgArgsToTerm(MA_SigArgArgs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_TermAttrs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_TermAttrs that was encoded by \arg
 */
MA_TermAttrs _MA_TermAttrsFromTerm(ATerm t) {
  return (MA_TermAttrs)t;
}

/**
 * Transforms a MA_TermAttrsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_TermAttrs to be converted
 * \return ATerm that represents the MA_TermAttrs
 */
ATerm _MA_TermAttrsToTerm(MA_TermAttrs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_FuncDefDefs. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_FuncDefDefs that was encoded by \arg
 */
MA_FuncDefDefs _MA_FuncDefDefsFromTerm(ATerm t) {
  return (MA_FuncDefDefs)t;
}

/**
 * Transforms a MA_FuncDefDefsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_FuncDefDefs to be converted
 * \return ATerm that represents the MA_FuncDefDefs
 */
ATerm _MA_FuncDefDefsToTerm(MA_FuncDefDefs arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_RuleRules. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_RuleRules that was encoded by \arg
 */
MA_RuleRules _MA_RuleRulesFromTerm(ATerm t) {
  return (MA_RuleRules)t;
}

/**
 * Transforms a MA_RuleRulesto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_RuleRules to be converted
 * \return ATerm that represents the MA_RuleRules
 */
ATerm _MA_RuleRulesToTerm(MA_RuleRules arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_CondConds. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_CondConds that was encoded by \arg
 */
MA_CondConds _MA_CondCondsFromTerm(ATerm t) {
  return (MA_CondConds)t;
}

/**
 * Transforms a MA_CondCondsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_CondConds to be converted
 * \return ATerm that represents the MA_CondConds
 */
ATerm _MA_CondCondsToTerm(MA_CondConds arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexLayout. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexLayout that was encoded by \arg
 */
MA_LexLayout _MA_LexLayoutFromTerm(ATerm t) {
  return (MA_LexLayout)t;
}

/**
 * Transforms a MA_LexLayoutto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexLayout to be converted
 * \return ATerm that represents the MA_LexLayout
 */
ATerm _MA_LexLayoutToTerm(MA_LexLayout arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexStrChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexStrChar that was encoded by \arg
 */
MA_LexStrChar _MA_LexStrCharFromTerm(ATerm t) {
  return (MA_LexStrChar)t;
}

/**
 * Transforms a MA_LexStrCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexStrChar to be converted
 * \return ATerm that represents the MA_LexStrChar
 */
ATerm _MA_LexStrCharToTerm(MA_LexStrChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_StrChar. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_StrChar that was encoded by \arg
 */
MA_StrChar _MA_StrCharFromTerm(ATerm t) {
  return (MA_StrChar)t;
}

/**
 * Transforms a MA_StrCharto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_StrChar to be converted
 * \return ATerm that represents the MA_StrChar
 */
ATerm _MA_StrCharToTerm(MA_StrChar arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexStrCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexStrCon that was encoded by \arg
 */
MA_LexStrCon _MA_LexStrConFromTerm(ATerm t) {
  return (MA_LexStrCon)t;
}

/**
 * Transforms a MA_LexStrConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexStrCon to be converted
 * \return ATerm that represents the MA_LexStrCon
 */
ATerm _MA_LexStrConToTerm(MA_LexStrCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_StrCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_StrCon that was encoded by \arg
 */
MA_StrCon _MA_StrConFromTerm(ATerm t) {
  return (MA_StrCon)t;
}

/**
 * Transforms a MA_StrConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_StrCon to be converted
 * \return ATerm that represents the MA_StrCon
 */
ATerm _MA_StrConToTerm(MA_StrCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexStrCharChars. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexStrCharChars that was encoded by \arg
 */
MA_LexStrCharChars _MA_LexStrCharCharsFromTerm(ATerm t) {
  return (MA_LexStrCharChars)t;
}

/**
 * Transforms a MA_LexStrCharCharsto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexStrCharChars to be converted
 * \return ATerm that represents the MA_LexStrCharChars
 */
ATerm _MA_LexStrCharCharsToTerm(MA_LexStrCharChars arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexNatCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexNatCon that was encoded by \arg
 */
MA_LexNatCon _MA_LexNatConFromTerm(ATerm t) {
  return (MA_LexNatCon)t;
}

/**
 * Transforms a MA_LexNatConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexNatCon to be converted
 * \return ATerm that represents the MA_LexNatCon
 */
ATerm _MA_LexNatConToTerm(MA_LexNatCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_NatCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_NatCon that was encoded by \arg
 */
MA_NatCon _MA_NatConFromTerm(ATerm t) {
  return (MA_NatCon)t;
}

/**
 * Transforms a MA_NatConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_NatCon to be converted
 * \return ATerm that represents the MA_NatCon
 */
ATerm _MA_NatConToTerm(MA_NatCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_LexIdCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_LexIdCon that was encoded by \arg
 */
MA_LexIdCon _MA_LexIdConFromTerm(ATerm t) {
  return (MA_LexIdCon)t;
}

/**
 * Transforms a MA_LexIdConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_LexIdCon to be converted
 * \return ATerm that represents the MA_LexIdCon
 */
ATerm _MA_LexIdConToTerm(MA_LexIdCon arg) {
  return (ATerm)arg;
}

/**
 * Transforms an ATerm to a MA_IdCon. This is just a wrapper for a cast, so no structural validation is done!
 * \param[in] t ATerm to be converted
 * \return MA_IdCon that was encoded by \arg
 */
MA_IdCon _MA_IdConFromTerm(ATerm t) {
  return (MA_IdCon)t;
}

/**
 * Transforms a MA_IdConto an ATerm. This is just a wrapper for a cast.
 * \param[in] arg MA_IdCon to be converted
 * \return ATerm that represents the MA_IdCon
 */
ATerm _MA_IdConToTerm(MA_IdCon arg) {
  return (ATerm)arg;
}

/**
 * Retrieve the length of a MA_LexLayoutList. 
 * \param[in] arg input MA_LexLayoutList
 * \return The number of elements in the MA_LexLayoutList
 */
int _MA_getLexLayoutListLength(MA_LexLayoutList arg) {
  return ATgetLength((ATermList) arg);
}

/**
 * Reverse a MA_LexLayoutList. 
 * \param[in] arg MA_LexLayoutList to be reversed
 * \return a reversed #arg
 */
MA_LexLayoutList _MA_reverseLexLayoutList(MA_LexLayoutList arg) {
  return (MA_LexLayoutList) ATreverse((ATermList) arg);
}

/**
 * Append a MA_LexLayout to the end of a MA_LexLayoutList. 
 * \param[in] arg MA_LexLayoutList to append the MA_LexLayout to
 * \param[in] elem MA_LexLayout to be appended
 * \return new MA_LexLayoutList with #elem appended
 */
MA_LexLayoutList _MA_appendLexLayoutList(MA_LexLayoutList arg, MA_LexLayout elem) {
  return (MA_LexLayoutList) ATappend((ATermList) arg, (ATerm) ((ATerm) elem));
}

/**
 * Concatenate two MA_LexLayoutLists. 
 * \param[in] arg0 first MA_LexLayoutList
 * \param[in] arg1 second MA_LexLayoutList
 * \return MA_LexLayoutList with the elements of #arg0 before the elements of #arg1
 */
MA_LexLayoutList _MA_concatLexLayoutList(MA_LexLayoutList arg0, MA_LexLayoutList arg1) {
  return (MA_LexLayoutList) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_LexLayoutList. 
 * \param[in] arg MA_LexLayoutList to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_LexLayoutList with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_LexLayoutList _MA_sliceLexLayoutList(MA_LexLayoutList arg, int start, int end) {
  return (MA_LexLayoutList) ATgetSlice((ATermList) arg, start, end);
}

/**
 * Retrieve the MA_LexLayout at #index from a MA_LexLayoutList. 
 * \param[in] arg MA_LexLayoutList to retrieve the MA_LexLayout from
 * \param[in] index index to use to point in the MA_LexLayoutList
 * \return MA_LexLayout at position #index in #arg
 */
MA_LexLayout _MA_getLexLayoutListLexLayoutAt(MA_LexLayoutList arg, int index) {
 return (MA_LexLayout)ATelementAt((ATermList) arg,index);
}

/**
 * Replace the MA_LexLayout at #index from a MA_LexLayoutList by a new one. 
 * \param[in] arg MA_LexLayoutList to retrieve the MA_LexLayout from
 * \param[in] elem new MA_LexLayout to replace another
 * \param[in] index index to use to point in the MA_LexLayoutList
 * \return A new MA_LexLayoutListwith #elem replaced in #arg at position #index
 */
MA_LexLayoutList _MA_replaceLexLayoutListLexLayoutAt(MA_LexLayoutList arg, MA_LexLayout elem, int index) {
 return (MA_LexLayoutList) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index);
}

/**
 * Builds a MA_LexLayoutList of 2 consecutive elements. 
 * \param[in] elem1 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem2 One MA_LexLayout element of the new MA_LexLayoutList
 * \return A new MA_LexLayoutList consisting of 2 MA_LexLayouts
 */
MA_LexLayoutList _MA_makeLexLayoutList2(MA_LexLayout elem1, MA_LexLayout elem2) {
  return (MA_LexLayoutList) ATmakeList2((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2));
}

/**
 * Builds a MA_LexLayoutList of 3 consecutive elements. 
 * \param[in] elem1 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem2 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem3 One MA_LexLayout element of the new MA_LexLayoutList
 * \return A new MA_LexLayoutList consisting of 3 MA_LexLayouts
 */
MA_LexLayoutList _MA_makeLexLayoutList3(MA_LexLayout elem1, MA_LexLayout elem2, MA_LexLayout elem3) {
  return (MA_LexLayoutList) ATmakeList3((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3));
}

/**
 * Builds a MA_LexLayoutList of 4 consecutive elements. 
 * \param[in] elem1 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem2 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem3 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem4 One MA_LexLayout element of the new MA_LexLayoutList
 * \return A new MA_LexLayoutList consisting of 4 MA_LexLayouts
 */
MA_LexLayoutList _MA_makeLexLayoutList4(MA_LexLayout elem1, MA_LexLayout elem2, MA_LexLayout elem3, MA_LexLayout elem4) {
  return (MA_LexLayoutList) ATmakeList4((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4));
}

/**
 * Builds a MA_LexLayoutList of 5 consecutive elements. 
 * \param[in] elem1 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem2 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem3 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem4 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem5 One MA_LexLayout element of the new MA_LexLayoutList
 * \return A new MA_LexLayoutList consisting of 5 MA_LexLayouts
 */
MA_LexLayoutList _MA_makeLexLayoutList5(MA_LexLayout elem1, MA_LexLayout elem2, MA_LexLayout elem3, MA_LexLayout elem4, MA_LexLayout elem5) {
  return (MA_LexLayoutList) ATmakeList5((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5));
}

/**
 * Builds a MA_LexLayoutList of 6 consecutive elements. 
 * \param[in] elem1 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem2 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem3 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem4 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem5 One MA_LexLayout element of the new MA_LexLayoutList
 * \param[in] elem6 One MA_LexLayout element of the new MA_LexLayoutList
 * \return A new MA_LexLayoutList consisting of 6 MA_LexLayouts
 */
MA_LexLayoutList _MA_makeLexLayoutList6(MA_LexLayout elem1, MA_LexLayout elem2, MA_LexLayout elem3, MA_LexLayout elem4, MA_LexLayout elem5, MA_LexLayout elem6) {
  return (MA_LexLayoutList) ATmakeList6((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5), (ATerm) ((ATerm) elem6));
}

/**
 * Retrieve the number of elements in a MA_TermArgs. 
 * \param[in] arg input MA_TermArgs
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getTermArgsLength(MA_TermArgs arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_TermArgs. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_TermArgs to be reversed
 * \return #arg reversed
 */
MA_TermArgs MA_reverseTermArgs(MA_TermArgs arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_TermArgs) result;
}

/**
 * Append a MA_Term to the end of a MA_TermArgs. 
 * \param[in] arg MA_TermArgs to append the MA_Term to
 * \param[in] elem MA_Term to be appended
 * \return new MA_TermArgs with #elem appended after the separators
 */
MA_TermArgs MA_appendTermArgs(MA_TermArgs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term arg1) {
  return MA_concatTermArgs(arg0, wsAfterHead, wsAfterSep, MA_makeTermArgsSingle(arg1));
}

/**
 * Concatenate two MA_TermArgss. 
 * \param[in] arg0 first MA_TermArgs
 * \param[in] arg1 second MA_TermArgs
 * \return MA_TermArgs with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_TermArgs MA_concatTermArgs(MA_TermArgs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_TermArgs arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeTermArgsMany((MA_Term)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_TermArgs) ATgetNext((ATermList) arg1);
  return (MA_TermArgs) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_TermArgs. 
 * \param[in] arg MA_TermArgs to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_TermArgs with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_TermArgs _MA_sliceTermArgs(MA_TermArgs arg, int start, int end) {
  return (MA_TermArgs) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_Term at #index from a MA_TermArgs. 
 * \param[in] arg MA_TermArgs to retrieve the MA_Term from
 * \param[in] index index to use to point in the MA_TermArgs
 * \return MA_Term at position #index in #arg
 */
MA_Term _MA_getTermArgsTermAt(MA_TermArgs arg, int index) {
 return (MA_Term)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_Term at #index from a MA_TermArgs by a new one. 
 * \param[in] arg MA_TermArgs to retrieve the MA_Term from
 * \param[in] elem new MA_Term to replace another
 * \param[in] index index to use to point in the MA_TermArgs
 * \return A new MA_TermArgswith #elem replaced in #arg at position #index
 */
MA_TermArgs _MA_replaceTermArgsTermAt(MA_TermArgs arg, MA_Term elem, int index) {
 return (MA_TermArgs) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_TermArgs of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermArgs
 * \param[in] elem2 One MA_Term element of the new MA_TermArgs
 * \return A new MA_TermArgs consisting of 2 MA_Terms
 */
MA_TermArgs MA_makeTermArgs2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2) {
  return MA_makeTermArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermArgsSingle(elem2));
}

/**
 * Builds a MA_TermArgs of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermArgs
 * \param[in] elem2 One MA_Term element of the new MA_TermArgs
 * \param[in] elem3 One MA_Term element of the new MA_TermArgs
 * \return A new MA_TermArgs consisting of 3 MA_Terms
 */
MA_TermArgs MA_makeTermArgs3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3) {
  return MA_makeTermArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermArgs2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_TermArgs of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermArgs
 * \param[in] elem2 One MA_Term element of the new MA_TermArgs
 * \param[in] elem3 One MA_Term element of the new MA_TermArgs
 * \param[in] elem4 One MA_Term element of the new MA_TermArgs
 * \return A new MA_TermArgs consisting of 4 MA_Terms
 */
MA_TermArgs MA_makeTermArgs4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4) {
  return MA_makeTermArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermArgs3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_TermArgs of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermArgs
 * \param[in] elem2 One MA_Term element of the new MA_TermArgs
 * \param[in] elem3 One MA_Term element of the new MA_TermArgs
 * \param[in] elem4 One MA_Term element of the new MA_TermArgs
 * \param[in] elem5 One MA_Term element of the new MA_TermArgs
 * \return A new MA_TermArgs consisting of 5 MA_Terms
 */
MA_TermArgs MA_makeTermArgs5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4, MA_Term elem5) {
  return MA_makeTermArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermArgs4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_TermArgs of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermArgs
 * \param[in] elem2 One MA_Term element of the new MA_TermArgs
 * \param[in] elem3 One MA_Term element of the new MA_TermArgs
 * \param[in] elem4 One MA_Term element of the new MA_TermArgs
 * \param[in] elem5 One MA_Term element of the new MA_TermArgs
 * \param[in] elem6 One MA_Term element of the new MA_TermArgs
 * \return A new MA_TermArgs consisting of 6 MA_Terms
 */
MA_TermArgs MA_makeTermArgs6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4, MA_Term elem5, MA_Term elem6) {
  return MA_makeTermArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermArgs5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a MA_TermElems. 
 * \param[in] arg input MA_TermElems
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getTermElemsLength(MA_TermElems arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_TermElems. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_TermElems to be reversed
 * \return #arg reversed
 */
MA_TermElems MA_reverseTermElems(MA_TermElems arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_TermElems) result;
}

/**
 * Append a MA_Term to the end of a MA_TermElems. 
 * \param[in] arg MA_TermElems to append the MA_Term to
 * \param[in] elem MA_Term to be appended
 * \return new MA_TermElems with #elem appended after the separators
 */
MA_TermElems MA_appendTermElems(MA_TermElems arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term arg1) {
  return MA_concatTermElems(arg0, wsAfterHead, wsAfterSep, MA_makeTermElemsSingle(arg1));
}

/**
 * Concatenate two MA_TermElemss. 
 * \param[in] arg0 first MA_TermElems
 * \param[in] arg1 second MA_TermElems
 * \return MA_TermElems with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_TermElems MA_concatTermElems(MA_TermElems arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_TermElems arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeTermElemsMany((MA_Term)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_TermElems) ATgetNext((ATermList) arg1);
  return (MA_TermElems) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_TermElems. 
 * \param[in] arg MA_TermElems to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_TermElems with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_TermElems _MA_sliceTermElems(MA_TermElems arg, int start, int end) {
  return (MA_TermElems) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_Term at #index from a MA_TermElems. 
 * \param[in] arg MA_TermElems to retrieve the MA_Term from
 * \param[in] index index to use to point in the MA_TermElems
 * \return MA_Term at position #index in #arg
 */
MA_Term _MA_getTermElemsTermAt(MA_TermElems arg, int index) {
 return (MA_Term)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_Term at #index from a MA_TermElems by a new one. 
 * \param[in] arg MA_TermElems to retrieve the MA_Term from
 * \param[in] elem new MA_Term to replace another
 * \param[in] index index to use to point in the MA_TermElems
 * \return A new MA_TermElemswith #elem replaced in #arg at position #index
 */
MA_TermElems _MA_replaceTermElemsTermAt(MA_TermElems arg, MA_Term elem, int index) {
 return (MA_TermElems) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_TermElems of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermElems
 * \param[in] elem2 One MA_Term element of the new MA_TermElems
 * \return A new MA_TermElems consisting of 2 MA_Terms
 */
MA_TermElems MA_makeTermElems2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2) {
  return MA_makeTermElemsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermElemsSingle(elem2));
}

/**
 * Builds a MA_TermElems of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermElems
 * \param[in] elem2 One MA_Term element of the new MA_TermElems
 * \param[in] elem3 One MA_Term element of the new MA_TermElems
 * \return A new MA_TermElems consisting of 3 MA_Terms
 */
MA_TermElems MA_makeTermElems3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3) {
  return MA_makeTermElemsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermElems2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_TermElems of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermElems
 * \param[in] elem2 One MA_Term element of the new MA_TermElems
 * \param[in] elem3 One MA_Term element of the new MA_TermElems
 * \param[in] elem4 One MA_Term element of the new MA_TermElems
 * \return A new MA_TermElems consisting of 4 MA_Terms
 */
MA_TermElems MA_makeTermElems4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4) {
  return MA_makeTermElemsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermElems3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_TermElems of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermElems
 * \param[in] elem2 One MA_Term element of the new MA_TermElems
 * \param[in] elem3 One MA_Term element of the new MA_TermElems
 * \param[in] elem4 One MA_Term element of the new MA_TermElems
 * \param[in] elem5 One MA_Term element of the new MA_TermElems
 * \return A new MA_TermElems consisting of 5 MA_Terms
 */
MA_TermElems MA_makeTermElems5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4, MA_Term elem5) {
  return MA_makeTermElemsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermElems4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_TermElems of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermElems
 * \param[in] elem2 One MA_Term element of the new MA_TermElems
 * \param[in] elem3 One MA_Term element of the new MA_TermElems
 * \param[in] elem4 One MA_Term element of the new MA_TermElems
 * \param[in] elem5 One MA_Term element of the new MA_TermElems
 * \param[in] elem6 One MA_Term element of the new MA_TermElems
 * \return A new MA_TermElems consisting of 6 MA_Terms
 */
MA_TermElems MA_makeTermElems6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4, MA_Term elem5, MA_Term elem6) {
  return MA_makeTermElemsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermElems5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a MA_SigArgArgs. 
 * \param[in] arg input MA_SigArgArgs
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getSigArgArgsLength(MA_SigArgArgs arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_SigArgArgs. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_SigArgArgs to be reversed
 * \return #arg reversed
 */
MA_SigArgArgs MA_reverseSigArgArgs(MA_SigArgArgs arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_SigArgArgs) result;
}

/**
 * Append a MA_SigArg to the end of a MA_SigArgArgs. 
 * \param[in] arg MA_SigArgArgs to append the MA_SigArg to
 * \param[in] elem MA_SigArg to be appended
 * \return new MA_SigArgArgs with #elem appended after the separators
 */
MA_SigArgArgs MA_appendSigArgArgs(MA_SigArgArgs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArg arg1) {
  return MA_concatSigArgArgs(arg0, wsAfterHead, wsAfterSep, MA_makeSigArgArgsSingle(arg1));
}

/**
 * Concatenate two MA_SigArgArgss. 
 * \param[in] arg0 first MA_SigArgArgs
 * \param[in] arg1 second MA_SigArgArgs
 * \return MA_SigArgArgs with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_SigArgArgs MA_concatSigArgArgs(MA_SigArgArgs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArgArgs arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeSigArgArgsMany((MA_SigArg)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_SigArgArgs) ATgetNext((ATermList) arg1);
  return (MA_SigArgArgs) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_SigArgArgs. 
 * \param[in] arg MA_SigArgArgs to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_SigArgArgs with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_SigArgArgs _MA_sliceSigArgArgs(MA_SigArgArgs arg, int start, int end) {
  return (MA_SigArgArgs) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_SigArg at #index from a MA_SigArgArgs. 
 * \param[in] arg MA_SigArgArgs to retrieve the MA_SigArg from
 * \param[in] index index to use to point in the MA_SigArgArgs
 * \return MA_SigArg at position #index in #arg
 */
MA_SigArg _MA_getSigArgArgsSigArgAt(MA_SigArgArgs arg, int index) {
 return (MA_SigArg)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_SigArg at #index from a MA_SigArgArgs by a new one. 
 * \param[in] arg MA_SigArgArgs to retrieve the MA_SigArg from
 * \param[in] elem new MA_SigArg to replace another
 * \param[in] index index to use to point in the MA_SigArgArgs
 * \return A new MA_SigArgArgswith #elem replaced in #arg at position #index
 */
MA_SigArgArgs _MA_replaceSigArgArgsSigArgAt(MA_SigArgArgs arg, MA_SigArg elem, int index) {
 return (MA_SigArgArgs) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_SigArgArgs of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem2 One MA_SigArg element of the new MA_SigArgArgs
 * \return A new MA_SigArgArgs consisting of 2 MA_SigArgs
 */
MA_SigArgArgs MA_makeSigArgArgs2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArg elem1, MA_SigArg elem2) {
  return MA_makeSigArgArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeSigArgArgsSingle(elem2));
}

/**
 * Builds a MA_SigArgArgs of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem2 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem3 One MA_SigArg element of the new MA_SigArgArgs
 * \return A new MA_SigArgArgs consisting of 3 MA_SigArgs
 */
MA_SigArgArgs MA_makeSigArgArgs3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArg elem1, MA_SigArg elem2, MA_SigArg elem3) {
  return MA_makeSigArgArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeSigArgArgs2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_SigArgArgs of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem2 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem3 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem4 One MA_SigArg element of the new MA_SigArgArgs
 * \return A new MA_SigArgArgs consisting of 4 MA_SigArgs
 */
MA_SigArgArgs MA_makeSigArgArgs4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArg elem1, MA_SigArg elem2, MA_SigArg elem3, MA_SigArg elem4) {
  return MA_makeSigArgArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeSigArgArgs3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_SigArgArgs of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem2 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem3 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem4 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem5 One MA_SigArg element of the new MA_SigArgArgs
 * \return A new MA_SigArgArgs consisting of 5 MA_SigArgs
 */
MA_SigArgArgs MA_makeSigArgArgs5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArg elem1, MA_SigArg elem2, MA_SigArg elem3, MA_SigArg elem4, MA_SigArg elem5) {
  return MA_makeSigArgArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeSigArgArgs4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_SigArgArgs of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem2 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem3 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem4 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem5 One MA_SigArg element of the new MA_SigArgArgs
 * \param[in] elem6 One MA_SigArg element of the new MA_SigArgArgs
 * \return A new MA_SigArgArgs consisting of 6 MA_SigArgs
 */
MA_SigArgArgs MA_makeSigArgArgs6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArg elem1, MA_SigArg elem2, MA_SigArg elem3, MA_SigArg elem4, MA_SigArg elem5, MA_SigArg elem6) {
  return MA_makeSigArgArgsMany(elem1, wsAfterHead, wsAfterSep, MA_makeSigArgArgs5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a MA_TermAttrs. 
 * \param[in] arg input MA_TermAttrs
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getTermAttrsLength(MA_TermAttrs arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_TermAttrs. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_TermAttrs to be reversed
 * \return #arg reversed
 */
MA_TermAttrs MA_reverseTermAttrs(MA_TermAttrs arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_TermAttrs) result;
}

/**
 * Append a MA_Term to the end of a MA_TermAttrs. 
 * \param[in] arg MA_TermAttrs to append the MA_Term to
 * \param[in] elem MA_Term to be appended
 * \return new MA_TermAttrs with #elem appended after the separators
 */
MA_TermAttrs MA_appendTermAttrs(MA_TermAttrs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term arg1) {
  return MA_concatTermAttrs(arg0, wsAfterHead, wsAfterSep, MA_makeTermAttrsSingle(arg1));
}

/**
 * Concatenate two MA_TermAttrss. 
 * \param[in] arg0 first MA_TermAttrs
 * \param[in] arg1 second MA_TermAttrs
 * \return MA_TermAttrs with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_TermAttrs MA_concatTermAttrs(MA_TermAttrs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_TermAttrs arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeTermAttrsMany((MA_Term)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_TermAttrs) ATgetNext((ATermList) arg1);
  return (MA_TermAttrs) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_TermAttrs. 
 * \param[in] arg MA_TermAttrs to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_TermAttrs with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_TermAttrs _MA_sliceTermAttrs(MA_TermAttrs arg, int start, int end) {
  return (MA_TermAttrs) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_Term at #index from a MA_TermAttrs. 
 * \param[in] arg MA_TermAttrs to retrieve the MA_Term from
 * \param[in] index index to use to point in the MA_TermAttrs
 * \return MA_Term at position #index in #arg
 */
MA_Term _MA_getTermAttrsTermAt(MA_TermAttrs arg, int index) {
 return (MA_Term)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_Term at #index from a MA_TermAttrs by a new one. 
 * \param[in] arg MA_TermAttrs to retrieve the MA_Term from
 * \param[in] elem new MA_Term to replace another
 * \param[in] index index to use to point in the MA_TermAttrs
 * \return A new MA_TermAttrswith #elem replaced in #arg at position #index
 */
MA_TermAttrs _MA_replaceTermAttrsTermAt(MA_TermAttrs arg, MA_Term elem, int index) {
 return (MA_TermAttrs) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_TermAttrs of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem2 One MA_Term element of the new MA_TermAttrs
 * \return A new MA_TermAttrs consisting of 2 MA_Terms
 */
MA_TermAttrs MA_makeTermAttrs2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2) {
  return MA_makeTermAttrsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermAttrsSingle(elem2));
}

/**
 * Builds a MA_TermAttrs of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem2 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem3 One MA_Term element of the new MA_TermAttrs
 * \return A new MA_TermAttrs consisting of 3 MA_Terms
 */
MA_TermAttrs MA_makeTermAttrs3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3) {
  return MA_makeTermAttrsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermAttrs2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_TermAttrs of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem2 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem3 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem4 One MA_Term element of the new MA_TermAttrs
 * \return A new MA_TermAttrs consisting of 4 MA_Terms
 */
MA_TermAttrs MA_makeTermAttrs4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4) {
  return MA_makeTermAttrsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermAttrs3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_TermAttrs of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem2 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem3 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem4 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem5 One MA_Term element of the new MA_TermAttrs
 * \return A new MA_TermAttrs consisting of 5 MA_Terms
 */
MA_TermAttrs MA_makeTermAttrs5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4, MA_Term elem5) {
  return MA_makeTermAttrsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermAttrs4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_TermAttrs of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem2 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem3 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem4 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem5 One MA_Term element of the new MA_TermAttrs
 * \param[in] elem6 One MA_Term element of the new MA_TermAttrs
 * \return A new MA_TermAttrs consisting of 6 MA_Terms
 */
MA_TermAttrs MA_makeTermAttrs6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Term elem1, MA_Term elem2, MA_Term elem3, MA_Term elem4, MA_Term elem5, MA_Term elem6) {
  return MA_makeTermAttrsMany(elem1, wsAfterHead, wsAfterSep, MA_makeTermAttrs5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a MA_FuncDefDefs. 
 * \param[in] arg input MA_FuncDefDefs
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getFuncDefDefsLength(MA_FuncDefDefs arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_FuncDefDefs. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_FuncDefDefs to be reversed
 * \return #arg reversed
 */
MA_FuncDefDefs MA_reverseFuncDefDefs(MA_FuncDefDefs arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_FuncDefDefs) result;
}

/**
 * Append a MA_FuncDef to the end of a MA_FuncDefDefs. 
 * \param[in] arg MA_FuncDefDefs to append the MA_FuncDef to
 * \param[in] elem MA_FuncDef to be appended
 * \return new MA_FuncDefDefs with #elem appended after the separators
 */
MA_FuncDefDefs MA_appendFuncDefDefs(MA_FuncDefDefs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDef arg1) {
  return MA_concatFuncDefDefs(arg0, wsAfterHead, wsAfterSep, MA_makeFuncDefDefsSingle(arg1));
}

/**
 * Concatenate two MA_FuncDefDefss. 
 * \param[in] arg0 first MA_FuncDefDefs
 * \param[in] arg1 second MA_FuncDefDefs
 * \return MA_FuncDefDefs with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_FuncDefDefs MA_concatFuncDefDefs(MA_FuncDefDefs arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDefDefs arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeFuncDefDefsMany((MA_FuncDef)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_FuncDefDefs) ATgetNext((ATermList) arg1);
  return (MA_FuncDefDefs) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_FuncDefDefs. 
 * \param[in] arg MA_FuncDefDefs to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_FuncDefDefs with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_FuncDefDefs _MA_sliceFuncDefDefs(MA_FuncDefDefs arg, int start, int end) {
  return (MA_FuncDefDefs) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_FuncDef at #index from a MA_FuncDefDefs. 
 * \param[in] arg MA_FuncDefDefs to retrieve the MA_FuncDef from
 * \param[in] index index to use to point in the MA_FuncDefDefs
 * \return MA_FuncDef at position #index in #arg
 */
MA_FuncDef _MA_getFuncDefDefsFuncDefAt(MA_FuncDefDefs arg, int index) {
 return (MA_FuncDef)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_FuncDef at #index from a MA_FuncDefDefs by a new one. 
 * \param[in] arg MA_FuncDefDefs to retrieve the MA_FuncDef from
 * \param[in] elem new MA_FuncDef to replace another
 * \param[in] index index to use to point in the MA_FuncDefDefs
 * \return A new MA_FuncDefDefswith #elem replaced in #arg at position #index
 */
MA_FuncDefDefs _MA_replaceFuncDefDefsFuncDefAt(MA_FuncDefDefs arg, MA_FuncDef elem, int index) {
 return (MA_FuncDefDefs) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_FuncDefDefs of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem2 One MA_FuncDef element of the new MA_FuncDefDefs
 * \return A new MA_FuncDefDefs consisting of 2 MA_FuncDefs
 */
MA_FuncDefDefs MA_makeFuncDefDefs2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDef elem1, MA_FuncDef elem2) {
  return MA_makeFuncDefDefsMany(elem1, wsAfterHead, wsAfterSep, MA_makeFuncDefDefsSingle(elem2));
}

/**
 * Builds a MA_FuncDefDefs of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem2 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem3 One MA_FuncDef element of the new MA_FuncDefDefs
 * \return A new MA_FuncDefDefs consisting of 3 MA_FuncDefs
 */
MA_FuncDefDefs MA_makeFuncDefDefs3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDef elem1, MA_FuncDef elem2, MA_FuncDef elem3) {
  return MA_makeFuncDefDefsMany(elem1, wsAfterHead, wsAfterSep, MA_makeFuncDefDefs2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_FuncDefDefs of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem2 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem3 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem4 One MA_FuncDef element of the new MA_FuncDefDefs
 * \return A new MA_FuncDefDefs consisting of 4 MA_FuncDefs
 */
MA_FuncDefDefs MA_makeFuncDefDefs4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDef elem1, MA_FuncDef elem2, MA_FuncDef elem3, MA_FuncDef elem4) {
  return MA_makeFuncDefDefsMany(elem1, wsAfterHead, wsAfterSep, MA_makeFuncDefDefs3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_FuncDefDefs of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem2 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem3 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem4 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem5 One MA_FuncDef element of the new MA_FuncDefDefs
 * \return A new MA_FuncDefDefs consisting of 5 MA_FuncDefs
 */
MA_FuncDefDefs MA_makeFuncDefDefs5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDef elem1, MA_FuncDef elem2, MA_FuncDef elem3, MA_FuncDef elem4, MA_FuncDef elem5) {
  return MA_makeFuncDefDefsMany(elem1, wsAfterHead, wsAfterSep, MA_makeFuncDefDefs4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_FuncDefDefs of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem2 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem3 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem4 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem5 One MA_FuncDef element of the new MA_FuncDefDefs
 * \param[in] elem6 One MA_FuncDef element of the new MA_FuncDefDefs
 * \return A new MA_FuncDefDefs consisting of 6 MA_FuncDefs
 */
MA_FuncDefDefs MA_makeFuncDefDefs6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDef elem1, MA_FuncDef elem2, MA_FuncDef elem3, MA_FuncDef elem4, MA_FuncDef elem5, MA_FuncDef elem6) {
  return MA_makeFuncDefDefsMany(elem1, wsAfterHead, wsAfterSep, MA_makeFuncDefDefs5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a MA_RuleRules. 
 * \param[in] arg input MA_RuleRules
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getRuleRulesLength(MA_RuleRules arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_RuleRules. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_RuleRules to be reversed
 * \return #arg reversed
 */
MA_RuleRules MA_reverseRuleRules(MA_RuleRules arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_RuleRules) result;
}

/**
 * Append a MA_Rule to the end of a MA_RuleRules. 
 * \param[in] arg MA_RuleRules to append the MA_Rule to
 * \param[in] elem MA_Rule to be appended
 * \return new MA_RuleRules with #elem appended after the separators
 */
MA_RuleRules MA_appendRuleRules(MA_RuleRules arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Rule arg1) {
  return MA_concatRuleRules(arg0, wsAfterHead, wsAfterSep, MA_makeRuleRulesSingle(arg1));
}

/**
 * Concatenate two MA_RuleRuless. 
 * \param[in] arg0 first MA_RuleRules
 * \param[in] arg1 second MA_RuleRules
 * \return MA_RuleRules with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_RuleRules MA_concatRuleRules(MA_RuleRules arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_RuleRules arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeRuleRulesMany((MA_Rule)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_RuleRules) ATgetNext((ATermList) arg1);
  return (MA_RuleRules) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_RuleRules. 
 * \param[in] arg MA_RuleRules to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_RuleRules with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_RuleRules _MA_sliceRuleRules(MA_RuleRules arg, int start, int end) {
  return (MA_RuleRules) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_Rule at #index from a MA_RuleRules. 
 * \param[in] arg MA_RuleRules to retrieve the MA_Rule from
 * \param[in] index index to use to point in the MA_RuleRules
 * \return MA_Rule at position #index in #arg
 */
MA_Rule _MA_getRuleRulesRuleAt(MA_RuleRules arg, int index) {
 return (MA_Rule)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_Rule at #index from a MA_RuleRules by a new one. 
 * \param[in] arg MA_RuleRules to retrieve the MA_Rule from
 * \param[in] elem new MA_Rule to replace another
 * \param[in] index index to use to point in the MA_RuleRules
 * \return A new MA_RuleRuleswith #elem replaced in #arg at position #index
 */
MA_RuleRules _MA_replaceRuleRulesRuleAt(MA_RuleRules arg, MA_Rule elem, int index) {
 return (MA_RuleRules) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_RuleRules of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem2 One MA_Rule element of the new MA_RuleRules
 * \return A new MA_RuleRules consisting of 2 MA_Rules
 */
MA_RuleRules MA_makeRuleRules2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Rule elem1, MA_Rule elem2) {
  return MA_makeRuleRulesMany(elem1, wsAfterHead, wsAfterSep, MA_makeRuleRulesSingle(elem2));
}

/**
 * Builds a MA_RuleRules of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem2 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem3 One MA_Rule element of the new MA_RuleRules
 * \return A new MA_RuleRules consisting of 3 MA_Rules
 */
MA_RuleRules MA_makeRuleRules3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Rule elem1, MA_Rule elem2, MA_Rule elem3) {
  return MA_makeRuleRulesMany(elem1, wsAfterHead, wsAfterSep, MA_makeRuleRules2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_RuleRules of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem2 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem3 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem4 One MA_Rule element of the new MA_RuleRules
 * \return A new MA_RuleRules consisting of 4 MA_Rules
 */
MA_RuleRules MA_makeRuleRules4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Rule elem1, MA_Rule elem2, MA_Rule elem3, MA_Rule elem4) {
  return MA_makeRuleRulesMany(elem1, wsAfterHead, wsAfterSep, MA_makeRuleRules3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_RuleRules of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem2 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem3 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem4 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem5 One MA_Rule element of the new MA_RuleRules
 * \return A new MA_RuleRules consisting of 5 MA_Rules
 */
MA_RuleRules MA_makeRuleRules5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Rule elem1, MA_Rule elem2, MA_Rule elem3, MA_Rule elem4, MA_Rule elem5) {
  return MA_makeRuleRulesMany(elem1, wsAfterHead, wsAfterSep, MA_makeRuleRules4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_RuleRules of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem2 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem3 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem4 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem5 One MA_Rule element of the new MA_RuleRules
 * \param[in] elem6 One MA_Rule element of the new MA_RuleRules
 * \return A new MA_RuleRules consisting of 6 MA_Rules
 */
MA_RuleRules MA_makeRuleRules6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Rule elem1, MA_Rule elem2, MA_Rule elem3, MA_Rule elem4, MA_Rule elem5, MA_Rule elem6) {
  return MA_makeRuleRulesMany(elem1, wsAfterHead, wsAfterSep, MA_makeRuleRules5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the number of elements in a MA_CondConds. 
 * \param[in] arg input MA_CondConds
 * \return The number of elements in #arg, excluding any separators
 */
int _MA_getCondCondsLength(MA_CondConds arg) {
  if (ATisEmpty((ATermList) arg)) {
    return 0;
  }
  return (ATgetLength((ATermList) arg) / 4) + 1;
}

/**
 * Reverses the elements of a MA_CondConds. Note that separators are reversed with the list, but the order in which each set of separators inbetween two elements occurs does not change
 * \param[in] arg MA_CondConds to be reversed
 * \return #arg reversed
 */
MA_CondConds MA_reverseCondConds(MA_CondConds arg) {
  ATermList list = (ATermList) arg;
  ATerm head;
  ATerm sep0;
  ATerm sep1;
  ATerm sep2;
  ATermList result;

 if (ATisEmpty(list) || ATgetLength(list) == 1) {
    return arg;
  }

  result = ATmakeList1(ATgetFirst(list));
      list = ATgetNext(list);
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);

  while (!ATisEmpty(list)) {
    result = ATinsert(result, sep2);
    result = ATinsert(result, sep1);
    result = ATinsert(result, sep0);

   head = ATgetFirst(list);
   result = ATinsert(result, head);
    list = ATgetNext(list);

   if (!ATisEmpty(list)) {
  sep0 = ATgetFirst(list);
  list = ATgetNext(list);
  sep1 = ATgetFirst(list);
  list = ATgetNext(list);
  sep2 = ATgetFirst(list);
  list = ATgetNext(list);
   }
  }

  return (MA_CondConds) result;
}

/**
 * Append a MA_Cond to the end of a MA_CondConds. 
 * \param[in] arg MA_CondConds to append the MA_Cond to
 * \param[in] elem MA_Cond to be appended
 * \return new MA_CondConds with #elem appended after the separators
 */
MA_CondConds MA_appendCondConds(MA_CondConds arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Cond arg1) {
  return MA_concatCondConds(arg0, wsAfterHead, wsAfterSep, MA_makeCondCondsSingle(arg1));
}

/**
 * Concatenate two MA_CondCondss. 
 * \param[in] arg0 first MA_CondConds
 * \param[in] arg1 second MA_CondConds
 * \return MA_CondConds with the elements of #arg0 before the elements of #arg1, with the separators in between.
 */
MA_CondConds MA_concatCondConds(MA_CondConds arg0, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_CondConds arg1) {
  if (ATisEmpty((ATermList) arg0)) {
    return arg1;
  }
  arg1 = MA_makeCondCondsMany((MA_Cond)ATgetFirst((ATermList) arg0), wsAfterHead, wsAfterSep,  arg1);
  arg1 = (MA_CondConds) ATgetNext((ATermList) arg1);
  return (MA_CondConds) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_CondConds. 
 * \param[in] arg MA_CondConds to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_CondConds with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_CondConds _MA_sliceCondConds(MA_CondConds arg, int start, int end) {
  return (MA_CondConds) ATgetSlice((ATermList) arg, start * 4, end * 4);
}

/**
 * Retrieve the MA_Cond at #index from a MA_CondConds. 
 * \param[in] arg MA_CondConds to retrieve the MA_Cond from
 * \param[in] index index to use to point in the MA_CondConds
 * \return MA_Cond at position #index in #arg
 */
MA_Cond _MA_getCondCondsCondAt(MA_CondConds arg, int index) {
 return (MA_Cond)ATelementAt((ATermList) arg,index * 4);
}

/**
 * Replace the MA_Cond at #index from a MA_CondConds by a new one. 
 * \param[in] arg MA_CondConds to retrieve the MA_Cond from
 * \param[in] elem new MA_Cond to replace another
 * \param[in] index index to use to point in the MA_CondConds
 * \return A new MA_CondCondswith #elem replaced in #arg at position #index
 */
MA_CondConds _MA_replaceCondCondsCondAt(MA_CondConds arg, MA_Cond elem, int index) {
 return (MA_CondConds) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index * 4);
}

/**
 * Builds a MA_CondConds of 2 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Cond element of the new MA_CondConds
 * \param[in] elem2 One MA_Cond element of the new MA_CondConds
 * \return A new MA_CondConds consisting of 2 MA_Conds
 */
MA_CondConds MA_makeCondConds2(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Cond elem1, MA_Cond elem2) {
  return MA_makeCondCondsMany(elem1, wsAfterHead, wsAfterSep, MA_makeCondCondsSingle(elem2));
}

/**
 * Builds a MA_CondConds of 3 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Cond element of the new MA_CondConds
 * \param[in] elem2 One MA_Cond element of the new MA_CondConds
 * \param[in] elem3 One MA_Cond element of the new MA_CondConds
 * \return A new MA_CondConds consisting of 3 MA_Conds
 */
MA_CondConds MA_makeCondConds3(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Cond elem1, MA_Cond elem2, MA_Cond elem3) {
  return MA_makeCondCondsMany(elem1, wsAfterHead, wsAfterSep, MA_makeCondConds2(wsAfterHead, wsAfterSep, elem2, elem3));
}

/**
 * Builds a MA_CondConds of 4 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Cond element of the new MA_CondConds
 * \param[in] elem2 One MA_Cond element of the new MA_CondConds
 * \param[in] elem3 One MA_Cond element of the new MA_CondConds
 * \param[in] elem4 One MA_Cond element of the new MA_CondConds
 * \return A new MA_CondConds consisting of 4 MA_Conds
 */
MA_CondConds MA_makeCondConds4(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Cond elem1, MA_Cond elem2, MA_Cond elem3, MA_Cond elem4) {
  return MA_makeCondCondsMany(elem1, wsAfterHead, wsAfterSep, MA_makeCondConds3(wsAfterHead, wsAfterSep, elem2, elem3, elem4));
}

/**
 * Builds a MA_CondConds of 5 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Cond element of the new MA_CondConds
 * \param[in] elem2 One MA_Cond element of the new MA_CondConds
 * \param[in] elem3 One MA_Cond element of the new MA_CondConds
 * \param[in] elem4 One MA_Cond element of the new MA_CondConds
 * \param[in] elem5 One MA_Cond element of the new MA_CondConds
 * \return A new MA_CondConds consisting of 5 MA_Conds
 */
MA_CondConds MA_makeCondConds5(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Cond elem1, MA_Cond elem2, MA_Cond elem3, MA_Cond elem4, MA_Cond elem5) {
  return MA_makeCondCondsMany(elem1, wsAfterHead, wsAfterSep, MA_makeCondConds4(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5));
}

/**
 * Builds a MA_CondConds of 6 consecutive elements. The elements are separated.
 * \param[in] elem1 One MA_Cond element of the new MA_CondConds
 * \param[in] elem2 One MA_Cond element of the new MA_CondConds
 * \param[in] elem3 One MA_Cond element of the new MA_CondConds
 * \param[in] elem4 One MA_Cond element of the new MA_CondConds
 * \param[in] elem5 One MA_Cond element of the new MA_CondConds
 * \param[in] elem6 One MA_Cond element of the new MA_CondConds
 * \return A new MA_CondConds consisting of 6 MA_Conds
 */
MA_CondConds MA_makeCondConds6(MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_Cond elem1, MA_Cond elem2, MA_Cond elem3, MA_Cond elem4, MA_Cond elem5, MA_Cond elem6) {
  return MA_makeCondCondsMany(elem1, wsAfterHead, wsAfterSep, MA_makeCondConds5(wsAfterHead, wsAfterSep, elem2, elem3, elem4, elem5, elem6));
}

/**
 * Retrieve the length of a MA_LexStrCharChars. 
 * \param[in] arg input MA_LexStrCharChars
 * \return The number of elements in the MA_LexStrCharChars
 */
int _MA_getLexStrCharCharsLength(MA_LexStrCharChars arg) {
  return ATgetLength((ATermList) arg);
}

/**
 * Reverse a MA_LexStrCharChars. 
 * \param[in] arg MA_LexStrCharChars to be reversed
 * \return a reversed #arg
 */
MA_LexStrCharChars _MA_reverseLexStrCharChars(MA_LexStrCharChars arg) {
  return (MA_LexStrCharChars) ATreverse((ATermList) arg);
}

/**
 * Append a MA_LexStrChar to the end of a MA_LexStrCharChars. 
 * \param[in] arg MA_LexStrCharChars to append the MA_LexStrChar to
 * \param[in] elem MA_LexStrChar to be appended
 * \return new MA_LexStrCharChars with #elem appended
 */
MA_LexStrCharChars _MA_appendLexStrCharChars(MA_LexStrCharChars arg, MA_LexStrChar elem) {
  return (MA_LexStrCharChars) ATappend((ATermList) arg, (ATerm) ((ATerm) elem));
}

/**
 * Concatenate two MA_LexStrCharCharss. 
 * \param[in] arg0 first MA_LexStrCharChars
 * \param[in] arg1 second MA_LexStrCharChars
 * \return MA_LexStrCharChars with the elements of #arg0 before the elements of #arg1
 */
MA_LexStrCharChars _MA_concatLexStrCharChars(MA_LexStrCharChars arg0, MA_LexStrCharChars arg1) {
  return (MA_LexStrCharChars) ATconcat((ATermList) arg0, (ATermList) arg1);
}

/**
 * Extract a sublist from a MA_LexStrCharChars. 
 * \param[in] arg MA_LexStrCharChars to extract a slice from
 * \param[in] start inclusive start index of the sublist
 * \param[in] end exclusive end index of the sublist
 * \return new MA_LexStrCharChars with a first element the element at index #start from #arg, and as last element the element at index (#end - 1).
 */
MA_LexStrCharChars _MA_sliceLexStrCharChars(MA_LexStrCharChars arg, int start, int end) {
  return (MA_LexStrCharChars) ATgetSlice((ATermList) arg, start, end);
}

/**
 * Retrieve the MA_LexStrChar at #index from a MA_LexStrCharChars. 
 * \param[in] arg MA_LexStrCharChars to retrieve the MA_LexStrChar from
 * \param[in] index index to use to point in the MA_LexStrCharChars
 * \return MA_LexStrChar at position #index in #arg
 */
MA_LexStrChar _MA_getLexStrCharCharsLexStrCharAt(MA_LexStrCharChars arg, int index) {
 return (MA_LexStrChar)ATelementAt((ATermList) arg,index);
}

/**
 * Replace the MA_LexStrChar at #index from a MA_LexStrCharChars by a new one. 
 * \param[in] arg MA_LexStrCharChars to retrieve the MA_LexStrChar from
 * \param[in] elem new MA_LexStrChar to replace another
 * \param[in] index index to use to point in the MA_LexStrCharChars
 * \return A new MA_LexStrCharCharswith #elem replaced in #arg at position #index
 */
MA_LexStrCharChars _MA_replaceLexStrCharCharsLexStrCharAt(MA_LexStrCharChars arg, MA_LexStrChar elem, int index) {
 return (MA_LexStrCharChars) ATreplace((ATermList) arg, (ATerm) ((ATerm) elem), index);
}

/**
 * Builds a MA_LexStrCharChars of 2 consecutive elements. 
 * \param[in] elem1 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem2 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \return A new MA_LexStrCharChars consisting of 2 MA_LexStrChars
 */
MA_LexStrCharChars _MA_makeLexStrCharChars2(MA_LexStrChar elem1, MA_LexStrChar elem2) {
  return (MA_LexStrCharChars) ATmakeList2((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2));
}

/**
 * Builds a MA_LexStrCharChars of 3 consecutive elements. 
 * \param[in] elem1 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem2 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem3 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \return A new MA_LexStrCharChars consisting of 3 MA_LexStrChars
 */
MA_LexStrCharChars _MA_makeLexStrCharChars3(MA_LexStrChar elem1, MA_LexStrChar elem2, MA_LexStrChar elem3) {
  return (MA_LexStrCharChars) ATmakeList3((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3));
}

/**
 * Builds a MA_LexStrCharChars of 4 consecutive elements. 
 * \param[in] elem1 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem2 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem3 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem4 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \return A new MA_LexStrCharChars consisting of 4 MA_LexStrChars
 */
MA_LexStrCharChars _MA_makeLexStrCharChars4(MA_LexStrChar elem1, MA_LexStrChar elem2, MA_LexStrChar elem3, MA_LexStrChar elem4) {
  return (MA_LexStrCharChars) ATmakeList4((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4));
}

/**
 * Builds a MA_LexStrCharChars of 5 consecutive elements. 
 * \param[in] elem1 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem2 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem3 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem4 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem5 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \return A new MA_LexStrCharChars consisting of 5 MA_LexStrChars
 */
MA_LexStrCharChars _MA_makeLexStrCharChars5(MA_LexStrChar elem1, MA_LexStrChar elem2, MA_LexStrChar elem3, MA_LexStrChar elem4, MA_LexStrChar elem5) {
  return (MA_LexStrCharChars) ATmakeList5((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5));
}

/**
 * Builds a MA_LexStrCharChars of 6 consecutive elements. 
 * \param[in] elem1 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem2 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem3 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem4 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem5 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \param[in] elem6 One MA_LexStrChar element of the new MA_LexStrCharChars
 * \return A new MA_LexStrCharChars consisting of 6 MA_LexStrChars
 */
MA_LexStrCharChars _MA_makeLexStrCharChars6(MA_LexStrChar elem1, MA_LexStrChar elem2, MA_LexStrChar elem3, MA_LexStrChar elem4, MA_LexStrChar elem5, MA_LexStrChar elem6) {
  return (MA_LexStrCharChars) ATmakeList6((ATerm) ((ATerm) elem1), (ATerm) ((ATerm) elem2), (ATerm) ((ATerm) elem3), (ATerm) ((ATerm) elem4), (ATerm) ((ATerm) elem5), (ATerm) ((ATerm) elem6));
}

/**
 * Constructs a Absent of type MA_OptLayout. Like all ATerm types, MA_OptLayouts are maximally shared.
 * \return A pointer to a Absent, either newly constructed or shared
 */
MA_OptLayout MA_makeOptLayoutAbsent(void) {
  return (MA_OptLayout)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATempty);
}
/**
 * Constructs a Present of type MA_OptLayout. Like all ATerm types, MA_OptLayouts are maximally shared.
 * \param[in] layout a child of the new Present
 * \return A pointer to a Present, either newly constructed or shared
 */
MA_OptLayout MA_makeOptLayoutPresent(MA_Layout layout) {
  return (MA_OptLayout)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl0(MA_afun4))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm) layout));
}
/**
 * Constructs a Lex-to-cf of type MA_Layout. Like all ATerm types, MA_Layouts are maximally shared.
 * \param[in] list a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
MA_Layout MA_makeLayoutLexToCf(MA_LexLayoutList list) {
  return (MA_Layout)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun7, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl0(MA_afun4)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun7, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm) list)));
}
/**
 * Constructs a empty of type MA_LexLayoutList. Like all ATerm types, MA_LexLayoutLists are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_LexLayoutList MA_makeLexLayoutListEmpty(void) {
  return (MA_LexLayoutList)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_LexLayoutList. Like all ATerm types, MA_LexLayoutLists are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_LexLayoutList MA_makeLexLayoutListSingle(MA_LexLayout head) {
  return (MA_LexLayoutList)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_LexLayoutList. Like all ATerm types, MA_LexLayoutLists are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_LexLayoutList MA_makeLexLayoutListMany(MA_LexLayout head, MA_LexLayoutList tail) {
  return (MA_LexLayoutList)(ATerm)ATinsert((ATermList)tail, (ATerm) head);
}
/**
 * Constructs a bottom-up of type MA_TraversalStrategy. Like all ATerm types, MA_TraversalStrategys are maximally shared.
 * \return A pointer to a bottom-up, either newly constructed or shared
 */
MA_TraversalStrategy MA_makeTraversalStrategyBottomUp(void) {
  return (MA_TraversalStrategy)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun10))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun12))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun10)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(98)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun10)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(109)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(98)))));
}
/**
 * Constructs a top-down of type MA_TraversalStrategy. Like all ATerm types, MA_TraversalStrategys are maximally shared.
 * \return A pointer to a top-down, either newly constructed or shared
 */
MA_TraversalStrategy MA_makeTraversalStrategyTopDown(void) {
  return (MA_TraversalStrategy)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun17))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun12))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun17)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(119)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(112)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun17)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(119)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(100)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(112)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(116)))));
}
/**
 * Constructs a trafo of type MA_TraversalType. Like all ATerm types, MA_TraversalTypes are maximally shared.
 * \return A pointer to a trafo, either newly constructed or shared
 */
MA_TraversalType MA_makeTraversalTypeTrafo(void) {
  return (MA_TraversalType)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun18))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun19))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun18)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun18)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(116)))));
}
/**
 * Constructs a accu of type MA_TraversalType. Like all ATerm types, MA_TraversalTypes are maximally shared.
 * \return A pointer to a accu, either newly constructed or shared
 */
MA_TraversalType MA_makeTraversalTypeAccu(void) {
  return (MA_TraversalType)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun20))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun19))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun20)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun20)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a accutrafo of type MA_TraversalType. Like all ATerm types, MA_TraversalTypes are maximally shared.
 * \return A pointer to a accutrafo, either newly constructed or shared
 */
MA_TraversalType MA_makeTraversalTypeAccutrafo(void) {
  return (MA_TraversalType)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun21))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun19))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun21)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun21)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(99)), (ATerm)ATmakeInt(97)))));
}
/**
 * Constructs a break of type MA_TraversalContinuation. Like all ATerm types, MA_TraversalContinuations are maximally shared.
 * \return A pointer to a break, either newly constructed or shared
 */
MA_TraversalContinuation MA_makeTraversalContinuationBreak(void) {
  return (MA_TraversalContinuation)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun22))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun23))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun22)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(107)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(98)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun22)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(107)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(98)))));
}
/**
 * Constructs a continue of type MA_TraversalContinuation. Like all ATerm types, MA_TraversalContinuations are maximally shared.
 * \return A pointer to a continue, either newly constructed or shared
 */
MA_TraversalContinuation MA_makeTraversalContinuationContinue(void) {
  return (MA_TraversalContinuation)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun24))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun23))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun24)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(99)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun24)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(99)))));
}
/**
 * Constructs a character of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] NatCon a child of the new character
 * \return A pointer to a character, either newly constructed or shared
 */
MA_FunId MA_makeFunIdCharacter(MA_NatCon NatCon) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun25)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun27)))))), (ATerm)ATmakeList1((ATerm) NatCon));
}
/**
 * Constructs a unquoted of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] IdCon a child of the new unquoted
 * \return A pointer to a unquoted, either newly constructed or shared
 */
MA_FunId MA_makeFunIdUnquoted(MA_IdCon IdCon) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun28)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl0(MA_afun29)), (ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun30)))))), (ATerm)ATmakeList1((ATerm) IdCon));
}
/**
 * Constructs a quoted of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] StrCon a child of the new quoted
 * \return A pointer to a quoted, either newly constructed or shared
 */
MA_FunId MA_makeFunIdQuoted(MA_StrCon StrCon) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun31)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun32)))))), (ATerm)ATmakeList1((ATerm) StrCon));
}
/**
 * Constructs a returns-list of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new returns-list
 * \param[in] FunId a child of the new returns-list
 * \param[in] wsAfterFunId a child of the new returns-list
 * \return A pointer to a returns-list, either newly constructed or shared
 */
MA_FunId MA_makeFunIdReturnsList(MA_OptLayout wsAfterBracketOpen, MA_FunId FunId, MA_OptLayout wsAfterFunId) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun35)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterFunId), (ATerm) FunId), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a list of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] wsAfterBraceOpen a child of the new list
 * \param[in] FunId a child of the new list
 * \param[in] wsAfterFunId a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
MA_FunId MA_makeFunIdList(MA_OptLayout wsAfterBraceOpen, MA_FunId FunId, MA_OptLayout wsAfterFunId) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun36))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun37))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun38)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun36)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm) wsAfterFunId), (ATerm) FunId), (ATerm) wsAfterBraceOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun37)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))));
}
/**
 * Constructs a sep-list of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] wsAfterBraceOpen a child of the new sep-list
 * \param[in] FunId a child of the new sep-list
 * \param[in] wsAfterFunId a child of the new sep-list
 * \param[in] seps a child of the new sep-list
 * \param[in] wsAfterSeps a child of the new sep-list
 * \return A pointer to a sep-list, either newly constructed or shared
 */
MA_FunId MA_makeFunIdSepList(MA_OptLayout wsAfterBraceOpen, MA_FunId FunId, MA_OptLayout wsAfterFunId, MA_NatCon seps, MA_OptLayout wsAfterSeps) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun36))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun25)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun37))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun39)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun36)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm) wsAfterSeps), (ATerm) seps), (ATerm) wsAfterFunId), (ATerm) FunId), (ATerm) wsAfterBraceOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun37)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))));
}
/**
 * Constructs a ignored of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] wsAfterIGNORE a child of the new ignored
 * \param[in] wsAfterBracketOpen a child of the new ignored
 * \param[in] FunId a child of the new ignored
 * \param[in] wsAfterFunId a child of the new ignored
 * \return A pointer to a ignored, either newly constructed or shared
 */
MA_FunId MA_makeFunIdIgnored(MA_OptLayout wsAfterIGNORE, MA_OptLayout wsAfterBracketOpen, MA_FunId FunId, MA_OptLayout wsAfterFunId) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun40))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun41)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterFunId), (ATerm) FunId), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm) wsAfterIGNORE), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(69)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(82)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(79)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(78)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(71)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(73)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun40)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(69)), (ATerm)ATmakeInt(82)), (ATerm)ATmakeInt(79)), (ATerm)ATmakeInt(78)), (ATerm)ATmakeInt(71)), (ATerm)ATmakeInt(73)))));
}
/**
 * Constructs a translate of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] wsAfterTRANSLATE a child of the new translate
 * \param[in] wsAfterBracketOpen a child of the new translate
 * \param[in] FunId a child of the new translate
 * \param[in] wsAfterFunId a child of the new translate
 * \return A pointer to a translate, either newly constructed or shared
 */
MA_FunId MA_makeFunIdTranslate(MA_OptLayout wsAfterTRANSLATE, MA_OptLayout wsAfterBracketOpen, MA_FunId FunId, MA_OptLayout wsAfterFunId) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun42))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun43)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterFunId), (ATerm) FunId), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm) wsAfterTRANSLATE), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(69)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(84)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(65)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(76)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(83)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(78)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(65)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(82)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(84)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun42)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(69)), (ATerm)ATmakeInt(84)), (ATerm)ATmakeInt(65)), (ATerm)ATmakeInt(76)), (ATerm)ATmakeInt(83)), (ATerm)ATmakeInt(78)), (ATerm)ATmakeInt(65)), (ATerm)ATmakeInt(82)), (ATerm)ATmakeInt(84)))));
}
/**
 * Constructs a traversal of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] wsAfterBar a child of the new traversal
 * \param[in] FunId a child of the new traversal
 * \param[in] wsAfterFunId a child of the new traversal
 * \param[in] TraversalType a child of the new traversal
 * \param[in] wsAfterTraversalType a child of the new traversal
 * \param[in] TraversalStrategy a child of the new traversal
 * \param[in] wsAfterTraversalStrategy a child of the new traversal
 * \param[in] TraversalContinuation a child of the new traversal
 * \param[in] wsAfterTraversalContinuation a child of the new traversal
 * \return A pointer to a traversal, either newly constructed or shared
 */
MA_FunId MA_makeFunIdTraversal(MA_OptLayout wsAfterBar, MA_FunId FunId, MA_OptLayout wsAfterFunId, MA_TraversalType TraversalType, MA_OptLayout wsAfterTraversalType, MA_TraversalStrategy TraversalStrategy, MA_OptLayout wsAfterTraversalStrategy, MA_TraversalContinuation TraversalContinuation, MA_OptLayout wsAfterTraversalContinuation) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun44))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun23)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun12)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun19)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun44))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun45)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(124)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun44)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(124)))), (ATerm) wsAfterTraversalContinuation), (ATerm) TraversalContinuation), (ATerm) wsAfterTraversalStrategy), (ATerm) TraversalStrategy), (ATerm) wsAfterTraversalType), (ATerm) TraversalType), (ATerm) wsAfterFunId), (ATerm) FunId), (ATerm) wsAfterBar), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(124)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun44)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(124)))));
}
/**
 * Constructs a concat of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] lhs a child of the new concat
 * \param[in] wsAfterLhs a child of the new concat
 * \param[in] wsAfterConc a child of the new concat
 * \param[in] rhs a child of the new concat
 * \return A pointer to a concat, either newly constructed or shared
 */
MA_FunId MA_makeFunIdConcat(MA_FunId lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterConc, MA_FunId rhs) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun46))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl0(MA_afun47))), (ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun48)))), (ATerm)ATmakeAppl1(MA_afun49, (ATerm)ATmakeAppl0(MA_afun50))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterConc), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun46)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(43)), (ATerm)ATmakeInt(43)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a concat-dash of type MA_FunId. Like all ATerm types, MA_FunIds are maximally shared.
 * \param[in] lhs a child of the new concat-dash
 * \param[in] wsAfterLhs a child of the new concat-dash
 * \param[in] wsAfterConc2 a child of the new concat-dash
 * \param[in] rhs a child of the new concat-dash
 * \return A pointer to a concat-dash, either newly constructed or shared
 */
MA_FunId MA_makeFunIdConcatDash(MA_FunId lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterConc2, MA_FunId rhs) {
  return (MA_FunId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun51))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl0(MA_afun47))), (ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun52)))), (ATerm)ATmakeAppl1(MA_afun49, (ATerm)ATmakeAppl0(MA_afun50))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterConc2), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(45)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun51)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(43)), (ATerm)ATmakeInt(45)), (ATerm)ATmakeInt(43)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a normal of type MA_VarId. Like all ATerm types, MA_VarIds are maximally shared.
 * \param[in] wsAfterDollar a child of the new normal
 * \param[in] FunId a child of the new normal
 * \return A pointer to a normal, either newly constructed or shared
 */
MA_VarId MA_makeVarIdNormal(MA_OptLayout wsAfterDollar, MA_FunId FunId) {
  return (MA_VarId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun53))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun54))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun55)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) FunId), (ATerm) wsAfterDollar), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(36)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun53)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(36)))));
}
/**
 * Constructs a plus of type MA_VarId. Like all ATerm types, MA_VarIds are maximally shared.
 * \param[in] wsAfterDollarPlus a child of the new plus
 * \param[in] FunId a child of the new plus
 * \return A pointer to a plus, either newly constructed or shared
 */
MA_VarId MA_makeVarIdPlus(MA_OptLayout wsAfterDollarPlus, MA_FunId FunId) {
  return (MA_VarId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun56))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun54))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun57)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) FunId), (ATerm) wsAfterDollarPlus), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(36)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun56)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(43)), (ATerm)ATmakeInt(36)))));
}
/**
 * Constructs a star of type MA_VarId. Like all ATerm types, MA_VarIds are maximally shared.
 * \param[in] wsAfterDollarStar a child of the new star
 * \param[in] FunId a child of the new star
 * \return A pointer to a star, either newly constructed or shared
 */
MA_VarId MA_makeVarIdStar(MA_OptLayout wsAfterDollarStar, MA_FunId FunId) {
  return (MA_VarId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun58))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun54))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun59)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) FunId), (ATerm) wsAfterDollarStar), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(42)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(36)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun58)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(42)), (ATerm)ATmakeInt(36)))));
}
/**
 * Constructs a Default of type MA_ModId. Like all ATerm types, MA_ModIds are maximally shared.
 * \param[in] IdCon a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_ModId MA_makeModIdDefault(MA_IdCon IdCon) {
  return (MA_ModId)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun28)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun60))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm) IdCon));
}
/**
 * Constructs a var of type MA_Term. Like all ATerm types, MA_Terms are maximally shared.
 * \param[in] VarId a child of the new var
 * \return A pointer to a var, either newly constructed or shared
 */
MA_Term MA_makeTermVar(MA_VarId VarId) {
  return (MA_Term)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun54)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun62)))))), (ATerm)ATmakeList1((ATerm) VarId));
}
/**
 * Constructs a constant of type MA_Term. Like all ATerm types, MA_Terms are maximally shared.
 * \param[in] FunId a child of the new constant
 * \return A pointer to a constant, either newly constructed or shared
 */
MA_Term MA_makeTermConstant(MA_FunId FunId) {
  return (MA_Term)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun63)))))), (ATerm)ATmakeList1((ATerm) FunId));
}
/**
 * Constructs a func of type MA_Term. Like all ATerm types, MA_Terms are maximally shared.
 * \param[in] FunId a child of the new func
 * \param[in] wsAfterFunId a child of the new func
 * \param[in] wsAfterParenOpen a child of the new func
 * \param[in] args a child of the new func
 * \param[in] wsAfterArgs a child of the new func
 * \return A pointer to a func, either newly constructed or shared
 */
MA_Term MA_makeTermFunc(MA_FunId FunId, MA_OptLayout wsAfterFunId, MA_OptLayout wsAfterParenOpen, MA_TermArgs args, MA_OptLayout wsAfterArgs) {
  return (MA_Term)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun64))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun67))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun68)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun64)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterArgs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm) args)), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun67)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterFunId), (ATerm) FunId));
}
/**
 * Constructs a list of type MA_Term. Like all ATerm types, MA_Terms are maximally shared.
 * \param[in] wsAfterBracketOpen a child of the new list
 * \param[in] TermList a child of the new list
 * \param[in] wsAfterTermList a child of the new list
 * \return A pointer to a list, either newly constructed or shared
 */
MA_Term MA_makeTermList(MA_OptLayout wsAfterBracketOpen, MA_TermList TermList, MA_OptLayout wsAfterTermList) {
  return (MA_Term)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun69)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun38)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun33)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(93)))), (ATerm) wsAfterTermList), (ATerm) TermList), (ATerm) wsAfterBracketOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun34)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(91)))));
}
/**
 * Constructs a typed of type MA_Term. Like all ATerm types, MA_Terms are maximally shared.
 * \param[in] Term a child of the new typed
 * \param[in] wsAfterTerm a child of the new typed
 * \param[in] wsAfterColon a child of the new typed
 * \param[in] type a child of the new typed
 * \return A pointer to a typed, either newly constructed or shared
 */
MA_Term MA_makeTermTyped(MA_Term Term, MA_OptLayout wsAfterTerm, MA_OptLayout wsAfterColon, MA_Term type) {
  return (MA_Term)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun70))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun71)))), (ATerm)ATmakeAppl1(MA_afun49, (ATerm)ATmakeAppl0(MA_afun72))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) type), (ATerm) wsAfterColon), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun70)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm) wsAfterTerm), (ATerm) Term));
}
/**
 * Constructs a Default of type MA_TermList. Like all ATerm types, MA_TermLists are maximally shared.
 * \param[in] elems a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_TermList MA_makeTermListDefault(MA_TermElems elems) {
  return (MA_TermList)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun69))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm) elems)));
}
/**
 * Constructs a normal of type MA_SigArg. Like all ATerm types, MA_SigArgs are maximally shared.
 * \return A pointer to a normal, either newly constructed or shared
 */
MA_SigArg MA_makeSigArgNormal(void) {
  return (MA_SigArg)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun74))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun55)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun74)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))));
}
/**
 * Constructs a star of type MA_SigArg. Like all ATerm types, MA_SigArgs are maximally shared.
 * \param[in] wsAfterUnderscore a child of the new star
 * \return A pointer to a star, either newly constructed or shared
 */
MA_SigArg MA_makeSigArgStar(MA_OptLayout wsAfterUnderscore) {
  return (MA_SigArg)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun76))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun74))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun59)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(42)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun76)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(42)))), (ATerm) wsAfterUnderscore), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun74)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))));
}
/**
 * Constructs a plus of type MA_SigArg. Like all ATerm types, MA_SigArgs are maximally shared.
 * \param[in] wsAfterUnderscore a child of the new plus
 * \return A pointer to a plus, either newly constructed or shared
 */
MA_SigArg MA_makeSigArgPlus(MA_OptLayout wsAfterUnderscore) {
  return (MA_SigArg)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun77))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun74))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun57)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun77)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(43)))), (ATerm) wsAfterUnderscore), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun74)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(95)))));
}
/**
 * Constructs a constant-no-annos of type MA_FuncDef. Like all ATerm types, MA_FuncDefs are maximally shared.
 * \param[in] FunId a child of the new constant-no-annos
 * \return A pointer to a constant-no-annos, either newly constructed or shared
 */
MA_FuncDef MA_makeFuncDefConstantNoAnnos(MA_FunId FunId) {
  return (MA_FuncDef)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun78))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun79)))))), (ATerm)ATmakeList1((ATerm) FunId));
}
/**
 * Constructs a constant-with-annos of type MA_FuncDef. Like all ATerm types, MA_FuncDefs are maximally shared.
 * \param[in] FunId a child of the new constant-with-annos
 * \param[in] wsAfterFunId a child of the new constant-with-annos
 * \param[in] Annotations a child of the new constant-with-annos
 * \return A pointer to a constant-with-annos, either newly constructed or shared
 */
MA_FuncDef MA_makeFuncDefConstantWithAnnos(MA_FunId FunId, MA_OptLayout wsAfterFunId, MA_Annotations Annotations) {
  return (MA_FuncDef)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun80)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun78))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun81)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) Annotations), (ATerm) wsAfterFunId), (ATerm) FunId));
}
/**
 * Constructs a func-no-annos of type MA_FuncDef. Like all ATerm types, MA_FuncDefs are maximally shared.
 * \param[in] FunId a child of the new func-no-annos
 * \param[in] wsAfterFunId a child of the new func-no-annos
 * \param[in] wsAfterParenOpen a child of the new func-no-annos
 * \param[in] args a child of the new func-no-annos
 * \param[in] wsAfterArgs a child of the new func-no-annos
 * \return A pointer to a func-no-annos, either newly constructed or shared
 */
MA_FuncDef MA_makeFuncDefFuncNoAnnos(MA_FunId FunId, MA_OptLayout wsAfterFunId, MA_OptLayout wsAfterParenOpen, MA_SigArgArgs args, MA_OptLayout wsAfterArgs) {
  return (MA_FuncDef)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun64))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun67))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun78))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun82)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun64)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterArgs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm) args)), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun67)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterFunId), (ATerm) FunId));
}
/**
 * Constructs a func-with-annos of type MA_FuncDef. Like all ATerm types, MA_FuncDefs are maximally shared.
 * \param[in] FunId a child of the new func-with-annos
 * \param[in] wsAfterFunId a child of the new func-with-annos
 * \param[in] wsAfterParenOpen a child of the new func-with-annos
 * \param[in] args a child of the new func-with-annos
 * \param[in] wsAfterArgs a child of the new func-with-annos
 * \param[in] wsAfterParenClose a child of the new func-with-annos
 * \param[in] Annotations a child of the new func-with-annos
 * \return A pointer to a func-with-annos, either newly constructed or shared
 */
MA_FuncDef MA_makeFuncDefFuncWithAnnos(MA_FunId FunId, MA_OptLayout wsAfterFunId, MA_OptLayout wsAfterParenOpen, MA_SigArgArgs args, MA_OptLayout wsAfterArgs, MA_OptLayout wsAfterParenClose, MA_Annotations Annotations) {
  return (MA_FuncDef)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun80)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun64))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun67))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun26)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun78))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun83)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) Annotations), (ATerm) wsAfterParenClose), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun64)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(41)))), (ATerm) wsAfterArgs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm) args)), (ATerm) wsAfterParenOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun67)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(40)))), (ATerm) wsAfterFunId), (ATerm) FunId));
}
/**
 * Constructs a Default of type MA_Annotations. Like all ATerm types, MA_Annotationss are maximally shared.
 * \param[in] wsAfterBraceOpen a child of the new Default
 * \param[in] attrs a child of the new Default
 * \param[in] wsAfterAttrs a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_Annotations MA_makeAnnotationsDefault(MA_OptLayout wsAfterBraceOpen, MA_TermAttrs attrs, MA_OptLayout wsAfterAttrs) {
  return (MA_Annotations)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun36))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun37))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun80))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun36)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(125)))), (ATerm) wsAfterAttrs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm) attrs)), (ATerm) wsAfterBraceOpen), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun37)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(123)))));
}
/**
 * Constructs a Default of type MA_SigArgList. Like all ATerm types, MA_SigArgLists are maximally shared.
 * \param[in] args a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_SigArgList MA_makeSigArgListDefault(MA_SigArgArgs args) {
  return (MA_SigArgList)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun84))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun65, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun75)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66))))), (ATerm) args)));
}
/**
 * Constructs a Default of type MA_FuncDefList. Like all ATerm types, MA_FuncDefLists are maximally shared.
 * \param[in] defs a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_FuncDefList MA_makeFuncDefListDefault(MA_FuncDefDefs defs) {
  return (MA_FuncDefList)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun78)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun85))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun86))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun78)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun85))))), (ATerm) defs)));
}
/**
 * Constructs a no-conds of type MA_Rule. Like all ATerm types, MA_Rules are maximally shared.
 * \param[in] lhs a child of the new no-conds
 * \param[in] wsAfterLhs a child of the new no-conds
 * \param[in] wsAfterIs a child of the new no-conds
 * \param[in] rhs a child of the new no-conds
 * \return A pointer to a no-conds, either newly constructed or shared
 */
MA_Rule MA_makeRuleNoConds(MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterIs, MA_Term rhs) {
  return (MA_Rule)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun88))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun89)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterIs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a default-no-conds of type MA_Rule. Like all ATerm types, MA_Rules are maximally shared.
 * \param[in] wsAfterDefaultColon a child of the new default-no-conds
 * \param[in] lhs a child of the new default-no-conds
 * \param[in] wsAfterLhs a child of the new default-no-conds
 * \param[in] wsAfterIs a child of the new default-no-conds
 * \param[in] rhs a child of the new default-no-conds
 * \return A pointer to a default-no-conds, either newly constructed or shared
 */
MA_Rule MA_makeRuleDefaultNoConds(MA_OptLayout wsAfterDefaultColon, MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterIs, MA_Term rhs) {
  return (MA_Rule)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun90))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun88))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun91)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterIs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs), (ATerm) wsAfterDefaultColon), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun90)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(58)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(100)))));
}
/**
 * Constructs a with-conds of type MA_Rule. Like all ATerm types, MA_Rules are maximally shared.
 * \param[in] conds a child of the new with-conds
 * \param[in] wsAfterConds a child of the new with-conds
 * \param[in] wsAfterEqualsEqualsGreaterThan a child of the new with-conds
 * \param[in] lhs a child of the new with-conds
 * \param[in] wsAfterLhs a child of the new with-conds
 * \param[in] wsAfterIs a child of the new with-conds
 * \param[in] rhs a child of the new with-conds
 * \return A pointer to a with-conds, either newly constructed or shared
 */
MA_Rule MA_makeRuleWithConds(MA_CondList conds, MA_OptLayout wsAfterConds, MA_OptLayout wsAfterEqualsEqualsGreaterThan, MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterIs, MA_Term rhs) {
  return (MA_Rule)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun92))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun93)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun88))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun94)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterIs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs), (ATerm) wsAfterEqualsEqualsGreaterThan), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(62)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun92)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(62)), (ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(61)))), (ATerm) wsAfterConds), (ATerm) conds));
}
/**
 * Constructs a default-with-conds of type MA_Rule. Like all ATerm types, MA_Rules are maximally shared.
 * \param[in] wsAfterDefaultColon a child of the new default-with-conds
 * \param[in] conds a child of the new default-with-conds
 * \param[in] wsAfterConds a child of the new default-with-conds
 * \param[in] wsAfterEqualsEqualsGreaterThan a child of the new default-with-conds
 * \param[in] lhs a child of the new default-with-conds
 * \param[in] wsAfterLhs a child of the new default-with-conds
 * \param[in] wsAfterIs a child of the new default-with-conds
 * \param[in] rhs a child of the new default-with-conds
 * \return A pointer to a default-with-conds, either newly constructed or shared
 */
MA_Rule MA_makeRuleDefaultWithConds(MA_OptLayout wsAfterDefaultColon, MA_CondList conds, MA_OptLayout wsAfterConds, MA_OptLayout wsAfterEqualsEqualsGreaterThan, MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterIs, MA_Term rhs) {
  return (MA_Rule)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun92))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun93)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun90))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun88))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun95)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterIs), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun87)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs), (ATerm) wsAfterEqualsEqualsGreaterThan), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(62)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun92)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(62)), (ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(61)))), (ATerm) wsAfterConds), (ATerm) conds), (ATerm) wsAfterDefaultColon), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(102)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun90)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(58)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(102)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(100)))));
}
/**
 * Constructs a Default of type MA_RuleList. Like all ATerm types, MA_RuleLists are maximally shared.
 * \param[in] rules a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_RuleList MA_makeRuleListDefault(MA_RuleRules rules) {
  return (MA_RuleList)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun88)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun85))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun96))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun88)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun85))))), (ATerm) rules)));
}
/**
 * Constructs a Default of type MA_CondList. Like all ATerm types, MA_CondLists are maximally shared.
 * \param[in] conds a child of the new Default
 * \return A pointer to a Default, either newly constructed or shared
 */
MA_CondList MA_makeCondListDefault(MA_CondConds conds) {
  return (MA_CondList)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun97)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun98))))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun93))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl2(MA_afun73, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun97)), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun98))))), (ATerm) conds)));
}
/**
 * Constructs a assign of type MA_Cond. Like all ATerm types, MA_Conds are maximally shared.
 * \param[in] lhs a child of the new assign
 * \param[in] wsAfterLhs a child of the new assign
 * \param[in] wsAfterBecomes a child of the new assign
 * \param[in] rhs a child of the new assign
 * \return A pointer to a assign, either newly constructed or shared
 */
MA_Cond MA_makeCondAssign(MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterBecomes, MA_Term rhs) {
  return (MA_Cond)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun99))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun97))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun100)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterBecomes), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun99)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(58)), (ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a no-assign of type MA_Cond. Like all ATerm types, MA_Conds are maximally shared.
 * \param[in] lhs a child of the new no-assign
 * \param[in] wsAfterLhs a child of the new no-assign
 * \param[in] wsAfterNotBecomes a child of the new no-assign
 * \param[in] rhs a child of the new no-assign
 * \return A pointer to a no-assign, either newly constructed or shared
 */
MA_Cond MA_makeCondNoAssign(MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterNotBecomes, MA_Term rhs) {
  return (MA_Cond)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun101))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun97))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun102)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterNotBecomes), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(33)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(58)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun101)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(33)), (ATerm)ATmakeInt(58)), (ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a equal of type MA_Cond. Like all ATerm types, MA_Conds are maximally shared.
 * \param[in] lhs a child of the new equal
 * \param[in] wsAfterLhs a child of the new equal
 * \param[in] wsAfterEquals a child of the new equal
 * \param[in] rhs a child of the new equal
 * \return A pointer to a equal, either newly constructed or shared
 */
MA_Cond MA_makeCondEqual(MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterEquals, MA_Term rhs) {
  return (MA_Cond)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun103))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun97))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun104)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterEquals), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun103)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(61)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a unequal of type MA_Cond. Like all ATerm types, MA_Conds are maximally shared.
 * \param[in] lhs a child of the new unequal
 * \param[in] wsAfterLhs a child of the new unequal
 * \param[in] wsAfterNotEquals a child of the new unequal
 * \param[in] rhs a child of the new unequal
 * \return A pointer to a unequal, either newly constructed or shared
 */
MA_Cond MA_makeCondUnequal(MA_Term lhs, MA_OptLayout wsAfterLhs, MA_OptLayout wsAfterNotEquals, MA_Term rhs) {
  return (MA_Cond)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun105))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun61)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun97))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun106)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) rhs), (ATerm) wsAfterNotEquals), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(61)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(33)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun105)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(61)), (ATerm)ATmakeInt(33)))), (ATerm) wsAfterLhs), (ATerm) lhs));
}
/**
 * Constructs a absent of type MA_SignatureOpt. Like all ATerm types, MA_SignatureOpts are maximally shared.
 * \return A pointer to a absent, either newly constructed or shared
 */
MA_SignatureOpt MA_makeSignatureOptAbsent(void) {
  return (MA_SignatureOpt)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun107))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun108)))))), (ATerm)ATempty);
}
/**
 * Constructs a present of type MA_SignatureOpt. Like all ATerm types, MA_SignatureOpts are maximally shared.
 * \param[in] wsAfterSignature a child of the new present
 * \param[in] FuncDefList a child of the new present
 * \return A pointer to a present, either newly constructed or shared
 */
MA_SignatureOpt MA_makeSignatureOptPresent(MA_OptLayout wsAfterSignature, MA_FuncDefList FuncDefList) {
  return (MA_SignatureOpt)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun86)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun109))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun107))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun110)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) FuncDefList), (ATerm) wsAfterSignature), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(97)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(103)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(105)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun109)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(114)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(97)), (ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(103)), (ATerm)ATmakeInt(105)), (ATerm)ATmakeInt(115)))));
}
/**
 * Constructs a absent of type MA_RulesOpt. Like all ATerm types, MA_RulesOpts are maximally shared.
 * \return A pointer to a absent, either newly constructed or shared
 */
MA_RulesOpt MA_makeRulesOptAbsent(void) {
  return (MA_RulesOpt)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATempty, (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun111))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun108)))))), (ATerm)ATempty);
}
/**
 * Constructs a present of type MA_RulesOpt. Like all ATerm types, MA_RulesOpts are maximally shared.
 * \param[in] wsAfterRules a child of the new present
 * \param[in] RuleList a child of the new present
 * \return A pointer to a present, either newly constructed or shared
 */
MA_RulesOpt MA_makeRulesOptPresent(MA_OptLayout wsAfterRules, MA_RuleList RuleList) {
  return (MA_RulesOpt)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun96)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun112))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun111))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun110)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm) RuleList), (ATerm) wsAfterRules), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(115)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(114)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun112)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(115)), (ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(114)))));
}
/**
 * Constructs a module of type MA_Module. Like all ATerm types, MA_Modules are maximally shared.
 * \param[in] wsAfterModule a child of the new module
 * \param[in] ModId a child of the new module
 * \param[in] wsAfterModId a child of the new module
 * \param[in] SignatureOpt a child of the new module
 * \param[in] wsAfterSignatureOpt a child of the new module
 * \param[in] RulesOpt a child of the new module
 * \return A pointer to a module, either newly constructed or shared
 */
MA_Module MA_makeModuleModule(MA_OptLayout wsAfterModule, MA_ModId ModId, MA_OptLayout wsAfterModId, MA_SignatureOpt SignatureOpt, MA_OptLayout wsAfterSignatureOpt, MA_RulesOpt RulesOpt) {
  return (MA_Module)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun111)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun107)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun60)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun3, (ATerm)ATmakeAppl0(MA_afun4)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun113))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun114))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun113)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) RulesOpt), (ATerm) wsAfterSignatureOpt), (ATerm) SignatureOpt), (ATerm) wsAfterModId), (ATerm) ModId), (ATerm) wsAfterModule), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(101)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(108)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(117)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(100)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(111)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(109)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun113)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATinsert(ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(101)), (ATerm)ATmakeInt(108)), (ATerm)ATmakeInt(117)), (ATerm)ATmakeInt(100)), (ATerm)ATmakeInt(111)), (ATerm)ATmakeInt(109)))));
}
/**
 * Constructs a empty of type MA_TermArgs. Like all ATerm types, MA_TermArgss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_TermArgs MA_makeTermArgsEmpty(void) {
  return (MA_TermArgs)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_TermArgs. Like all ATerm types, MA_TermArgss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_TermArgs MA_makeTermArgsSingle(MA_Term head) {
  return (MA_TermArgs)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_TermArgs. Like all ATerm types, MA_TermArgss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_TermArgs MA_makeTermArgsMany(MA_Term head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_TermArgs tail) {
  if (MA_isTermArgsEmpty(tail)) {
    return MA_makeTermArgsSingle(head);
  }
  return (MA_TermArgs)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type MA_TermElems. Like all ATerm types, MA_TermElemss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_TermElems MA_makeTermElemsEmpty(void) {
  return (MA_TermElems)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_TermElems. Like all ATerm types, MA_TermElemss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_TermElems MA_makeTermElemsSingle(MA_Term head) {
  return (MA_TermElems)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_TermElems. Like all ATerm types, MA_TermElemss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_TermElems MA_makeTermElemsMany(MA_Term head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_TermElems tail) {
  if (MA_isTermElemsEmpty(tail)) {
    return MA_makeTermElemsSingle(head);
  }
  return (MA_TermElems)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type MA_SigArgArgs. Like all ATerm types, MA_SigArgArgss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_SigArgArgs MA_makeSigArgArgsEmpty(void) {
  return (MA_SigArgArgs)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_SigArgArgs. Like all ATerm types, MA_SigArgArgss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_SigArgArgs MA_makeSigArgArgsSingle(MA_SigArg head) {
  return (MA_SigArgArgs)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_SigArgArgs. Like all ATerm types, MA_SigArgArgss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_SigArgArgs MA_makeSigArgArgsMany(MA_SigArg head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_SigArgArgs tail) {
  if (MA_isSigArgArgsEmpty(tail)) {
    return MA_makeSigArgArgsSingle(head);
  }
  return (MA_SigArgArgs)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type MA_TermAttrs. Like all ATerm types, MA_TermAttrss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_TermAttrs MA_makeTermAttrsEmpty(void) {
  return (MA_TermAttrs)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_TermAttrs. Like all ATerm types, MA_TermAttrss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_TermAttrs MA_makeTermAttrsSingle(MA_Term head) {
  return (MA_TermAttrs)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_TermAttrs. Like all ATerm types, MA_TermAttrss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_TermAttrs MA_makeTermAttrsMany(MA_Term head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_TermAttrs tail) {
  if (MA_isTermAttrsEmpty(tail)) {
    return MA_makeTermAttrsSingle(head);
  }
  return (MA_TermAttrs)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun66)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(44)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type MA_FuncDefDefs. Like all ATerm types, MA_FuncDefDefss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_FuncDefDefs MA_makeFuncDefDefsEmpty(void) {
  return (MA_FuncDefDefs)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_FuncDefDefs. Like all ATerm types, MA_FuncDefDefss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_FuncDefDefs MA_makeFuncDefDefsSingle(MA_FuncDef head) {
  return (MA_FuncDefDefs)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_FuncDefDefs. Like all ATerm types, MA_FuncDefDefss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_FuncDefDefs MA_makeFuncDefDefsMany(MA_FuncDef head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_FuncDefDefs tail) {
  if (MA_isFuncDefDefsEmpty(tail)) {
    return MA_makeFuncDefDefsSingle(head);
  }
  return (MA_FuncDefDefs)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(59)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun85)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(59)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type MA_RuleRules. Like all ATerm types, MA_RuleRuless are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_RuleRules MA_makeRuleRulesEmpty(void) {
  return (MA_RuleRules)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_RuleRules. Like all ATerm types, MA_RuleRuless are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_RuleRules MA_makeRuleRulesSingle(MA_Rule head) {
  return (MA_RuleRules)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_RuleRules. Like all ATerm types, MA_RuleRuless are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_RuleRules MA_makeRuleRulesMany(MA_Rule head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_RuleRules tail) {
  if (MA_isRuleRulesEmpty(tail)) {
    return MA_makeRuleRulesSingle(head);
  }
  return (MA_RuleRules)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(59)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun85)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(59)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a empty of type MA_CondConds. Like all ATerm types, MA_CondCondss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_CondConds MA_makeCondCondsEmpty(void) {
  return (MA_CondConds)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_CondConds. Like all ATerm types, MA_CondCondss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_CondConds MA_makeCondCondsSingle(MA_Cond head) {
  return (MA_CondConds)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_CondConds. Like all ATerm types, MA_CondCondss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] wsAfterHead a child of the new many
 * \param[in] wsAfterSep a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_CondConds MA_makeCondCondsMany(MA_Cond head, MA_OptLayout wsAfterHead, MA_OptLayout wsAfterSep, MA_CondConds tail) {
  if (MA_isCondCondsEmpty(tail)) {
    return MA_makeCondCondsSingle(head);
  }
  return (MA_CondConds)(ATerm)ATinsert(ATinsert(ATinsert(ATinsert((ATermList)tail, (ATerm) wsAfterSep), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(38)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun98)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(38)))), (ATerm) wsAfterHead), (ATerm) head);
}
/**
 * Constructs a whitespace of type MA_LexLayout. Like all ATerm types, MA_LexLayouts are maximally shared.
 * \param[in] ch a child of the new whitespace
 * \return A pointer to a whitespace, either newly constructed or shared
 */
MA_LexLayout MA_makeLexLayoutWhitespace(char ch) {
  return (MA_LexLayout)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(32)), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(9), (ATerm)ATmakeInt(13))))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl0(MA_afun4)), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun116)))))), (ATerm)ATmakeList1((ATerm) ((ATerm) MA_byteToChar(ch))));
}
/**
 * Constructs a newline of type MA_LexStrChar. Like all ATerm types, MA_LexStrChars are maximally shared.
 * \return A pointer to a newline, either newly constructed or shared
 */
MA_LexStrChar MA_makeLexStrCharNewline(void) {
  return (MA_LexStrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun117))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun119)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(110)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun117)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(110)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a tab of type MA_LexStrChar. Like all ATerm types, MA_LexStrChars are maximally shared.
 * \return A pointer to a tab, either newly constructed or shared
 */
MA_LexStrChar MA_makeLexStrCharTab(void) {
  return (MA_LexStrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun120))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun121)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(116)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun120)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(116)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a quote of type MA_LexStrChar. Like all ATerm types, MA_LexStrChars are maximally shared.
 * \return A pointer to a quote, either newly constructed or shared
 */
MA_LexStrChar MA_makeLexStrCharQuote(void) {
  return (MA_LexStrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun122))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun123)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun122)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(34)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a backslash of type MA_LexStrChar. Like all ATerm types, MA_LexStrChars are maximally shared.
 * \return A pointer to a backslash, either newly constructed or shared
 */
MA_LexStrChar MA_makeLexStrCharBackslash(void) {
  return (MA_LexStrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun124))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun125)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun124)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeInt(92)), (ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a decimal of type MA_LexStrChar. Like all ATerm types, MA_LexStrChars are maximally shared.
 * \param[in] a a child of the new decimal
 * \param[in] b a child of the new decimal
 * \param[in] c a child of the new decimal
 * \return A pointer to a decimal, either newly constructed or shared
 */
MA_LexStrChar MA_makeLexStrCharDecimal(char a, char b, char c) {
  return (MA_LexStrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun126))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun127)))))), (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm) ((ATerm) MA_byteToChar(c))), (ATerm) ((ATerm) MA_byteToChar(b))), (ATerm) ((ATerm) MA_byteToChar(a))), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))), (ATerm)ATmakeAppl1(MA_afun9, (ATerm)ATmakeAppl0(MA_afun126)), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm)ATmakeInt(92)))));
}
/**
 * Constructs a normal of type MA_LexStrChar. Like all ATerm types, MA_LexStrChars are maximally shared.
 * \param[in] ch a child of the new normal
 * \return A pointer to a normal, either newly constructed or shared
 */
MA_LexStrChar MA_makeLexStrCharNormal(char ch) {
  return (MA_LexStrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(93), (ATerm)ATmakeInt(255))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(35), (ATerm)ATmakeInt(91))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(32), (ATerm)ATmakeInt(33))))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun55)))))), (ATerm)ATmakeList1((ATerm) ((ATerm) MA_byteToChar(ch))));
}
/**
 * Constructs a Lex-to-cf of type MA_StrChar. Like all ATerm types, MA_StrChars are maximally shared.
 * \param[in] StrChar a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
MA_StrChar MA_makeStrCharLexToCf(MA_LexStrChar StrChar) {
  return (MA_StrChar)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm) StrChar));
}
/**
 * Constructs a default of type MA_LexStrCon. Like all ATerm types, MA_LexStrCons are maximally shared.
 * \param[in] chars a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
MA_LexStrCon MA_makeLexStrConDefault(MA_LexStrCharChars chars) {
  return (MA_LexStrCon)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun128, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeInt(34)))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun31))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun129)))))), (ATerm)ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeInt(34)), (ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun128, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun118))))), (ATerm) chars)), (ATerm)ATmakeInt(34)));
}
/**
 * Constructs a Lex-to-cf of type MA_StrCon. Like all ATerm types, MA_StrCons are maximally shared.
 * \param[in] StrCon a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
MA_StrCon MA_makeStrConLexToCf(MA_LexStrCon StrCon) {
  return (MA_StrCon)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun31)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun31))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm) StrCon));
}
/**
 * Constructs a empty of type MA_LexStrCharChars. Like all ATerm types, MA_LexStrCharCharss are maximally shared.
 * \return A pointer to a empty, either newly constructed or shared
 */
MA_LexStrCharChars MA_makeLexStrCharCharsEmpty(void) {
  return (MA_LexStrCharChars)(ATerm)ATempty;
}
/**
 * Constructs a single of type MA_LexStrCharChars. Like all ATerm types, MA_LexStrCharCharss are maximally shared.
 * \param[in] head a child of the new single
 * \return A pointer to a single, either newly constructed or shared
 */
MA_LexStrCharChars MA_makeLexStrCharCharsSingle(MA_LexStrChar head) {
  return (MA_LexStrCharChars)(ATerm)ATmakeList1((ATerm) head);
}
/**
 * Constructs a many of type MA_LexStrCharChars. Like all ATerm types, MA_LexStrCharCharss are maximally shared.
 * \param[in] head a child of the new many
 * \param[in] tail a child of the new many
 * \return A pointer to a many, either newly constructed or shared
 */
MA_LexStrCharChars MA_makeLexStrCharCharsMany(MA_LexStrChar head, MA_LexStrCharChars tail) {
  return (MA_LexStrCharChars)(ATerm)ATinsert((ATermList)tail, (ATerm) head);
}
/**
 * Constructs a digits of type MA_LexNatCon. Like all ATerm types, MA_LexNatCons are maximally shared.
 * \param[in] list a child of the new digits
 * \return A pointer to a digits, either newly constructed or shared
 */
MA_LexNatCon MA_makeLexNatConDigits(const char* list) {
  return (MA_LexNatCon)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun7, (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun25))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun130)))))), (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun7, (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))))))), (ATerm) ((ATerm) MA_stringToChars(list)))));
}
/**
 * Constructs a Lex-to-cf of type MA_NatCon. Like all ATerm types, MA_NatCons are maximally shared.
 * \param[in] NatCon a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
MA_NatCon MA_makeNatConLexToCf(MA_LexNatCon NatCon) {
  return (MA_NatCon)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun25)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun25))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm) NatCon));
}
/**
 * Constructs a default of type MA_LexIdCon. Like all ATerm types, MA_LexIdCons are maximally shared.
 * \param[in] head a child of the new default
 * \param[in] tail a child of the new default
 * \return A pointer to a default, either newly constructed or shared
 */
MA_LexIdCon MA_makeLexIdConDefault(char head, const char* tail) {
  return (MA_LexIdCon)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun128, (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(45)))))), (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))))), (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun28))), (ATerm)ATmakeAppl1(MA_afun13, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun14, (ATerm)ATmakeAppl1(MA_afun15, (ATerm)ATmakeAppl0(MA_afun129)))))), (ATerm)ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl1(MA_afun8, (ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun128, (ATerm)ATmakeAppl1(MA_afun16, (ATerm)ATinsert(ATinsert(ATinsert(ATmakeList1((ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(97), (ATerm)ATmakeInt(122))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(65), (ATerm)ATmakeInt(90))), (ATerm)ATmakeAppl2(MA_afun115, (ATerm)ATmakeInt(48), (ATerm)ATmakeInt(57))), (ATerm)ATmakeInt(45)))))), (ATerm) ((ATerm) MA_stringToChars(tail)))), (ATerm) ((ATerm) MA_byteToChar(head))));
}
/**
 * Constructs a Lex-to-cf of type MA_IdCon. Like all ATerm types, MA_IdCons are maximally shared.
 * \param[in] IdCon a child of the new Lex-to-cf
 * \return A pointer to a Lex-to-cf, either newly constructed or shared
 */
MA_IdCon MA_makeIdConLexToCf(MA_LexIdCon IdCon) {
  return (MA_IdCon)(ATerm)ATmakeAppl2(MA_afun0, (ATerm)ATmakeAppl3(MA_afun1, (ATerm)ATmakeList1((ATerm)ATmakeAppl1(MA_afun6, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun28)))), (ATerm)ATmakeAppl1(MA_afun2, (ATerm)ATmakeAppl1(MA_afun11, (ATerm)ATmakeAppl0(MA_afun28))), (ATerm)ATmakeAppl0(MA_afun5)), (ATerm)ATmakeList1((ATerm) IdCon));
}

/**
 * Tests equality of two MA_OptLayouts. A constant time operation.
 * \param[in] arg0 first MA_OptLayout to be compared
 * \param[in] arg1 second MA_OptLayout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualOptLayout(MA_OptLayout arg0, MA_OptLayout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_Layouts. A constant time operation.
 * \param[in] arg0 first MA_Layout to be compared
 * \param[in] arg1 second MA_Layout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLayout(MA_Layout arg0, MA_Layout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexLayoutLists. A constant time operation.
 * \param[in] arg0 first MA_LexLayoutList to be compared
 * \param[in] arg1 second MA_LexLayoutList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexLayoutList(MA_LexLayoutList arg0, MA_LexLayoutList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TraversalStrategys. A constant time operation.
 * \param[in] arg0 first MA_TraversalStrategy to be compared
 * \param[in] arg1 second MA_TraversalStrategy to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTraversalStrategy(MA_TraversalStrategy arg0, MA_TraversalStrategy arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TraversalTypes. A constant time operation.
 * \param[in] arg0 first MA_TraversalType to be compared
 * \param[in] arg1 second MA_TraversalType to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTraversalType(MA_TraversalType arg0, MA_TraversalType arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TraversalContinuations. A constant time operation.
 * \param[in] arg0 first MA_TraversalContinuation to be compared
 * \param[in] arg1 second MA_TraversalContinuation to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTraversalContinuation(MA_TraversalContinuation arg0, MA_TraversalContinuation arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_FunIds. A constant time operation.
 * \param[in] arg0 first MA_FunId to be compared
 * \param[in] arg1 second MA_FunId to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualFunId(MA_FunId arg0, MA_FunId arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_VarIds. A constant time operation.
 * \param[in] arg0 first MA_VarId to be compared
 * \param[in] arg1 second MA_VarId to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualVarId(MA_VarId arg0, MA_VarId arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_ModIds. A constant time operation.
 * \param[in] arg0 first MA_ModId to be compared
 * \param[in] arg1 second MA_ModId to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualModId(MA_ModId arg0, MA_ModId arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_Terms. A constant time operation.
 * \param[in] arg0 first MA_Term to be compared
 * \param[in] arg1 second MA_Term to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTerm(MA_Term arg0, MA_Term arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TermLists. A constant time operation.
 * \param[in] arg0 first MA_TermList to be compared
 * \param[in] arg1 second MA_TermList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTermList(MA_TermList arg0, MA_TermList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_SigArgs. A constant time operation.
 * \param[in] arg0 first MA_SigArg to be compared
 * \param[in] arg1 second MA_SigArg to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualSigArg(MA_SigArg arg0, MA_SigArg arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_FuncDefs. A constant time operation.
 * \param[in] arg0 first MA_FuncDef to be compared
 * \param[in] arg1 second MA_FuncDef to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualFuncDef(MA_FuncDef arg0, MA_FuncDef arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_Annotationss. A constant time operation.
 * \param[in] arg0 first MA_Annotations to be compared
 * \param[in] arg1 second MA_Annotations to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualAnnotations(MA_Annotations arg0, MA_Annotations arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_SigArgLists. A constant time operation.
 * \param[in] arg0 first MA_SigArgList to be compared
 * \param[in] arg1 second MA_SigArgList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualSigArgList(MA_SigArgList arg0, MA_SigArgList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_FuncDefLists. A constant time operation.
 * \param[in] arg0 first MA_FuncDefList to be compared
 * \param[in] arg1 second MA_FuncDefList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualFuncDefList(MA_FuncDefList arg0, MA_FuncDefList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_Rules. A constant time operation.
 * \param[in] arg0 first MA_Rule to be compared
 * \param[in] arg1 second MA_Rule to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualRule(MA_Rule arg0, MA_Rule arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_RuleLists. A constant time operation.
 * \param[in] arg0 first MA_RuleList to be compared
 * \param[in] arg1 second MA_RuleList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualRuleList(MA_RuleList arg0, MA_RuleList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_CondLists. A constant time operation.
 * \param[in] arg0 first MA_CondList to be compared
 * \param[in] arg1 second MA_CondList to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualCondList(MA_CondList arg0, MA_CondList arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_Conds. A constant time operation.
 * \param[in] arg0 first MA_Cond to be compared
 * \param[in] arg1 second MA_Cond to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualCond(MA_Cond arg0, MA_Cond arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_SignatureOpts. A constant time operation.
 * \param[in] arg0 first MA_SignatureOpt to be compared
 * \param[in] arg1 second MA_SignatureOpt to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualSignatureOpt(MA_SignatureOpt arg0, MA_SignatureOpt arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_RulesOpts. A constant time operation.
 * \param[in] arg0 first MA_RulesOpt to be compared
 * \param[in] arg1 second MA_RulesOpt to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualRulesOpt(MA_RulesOpt arg0, MA_RulesOpt arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_Modules. A constant time operation.
 * \param[in] arg0 first MA_Module to be compared
 * \param[in] arg1 second MA_Module to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualModule(MA_Module arg0, MA_Module arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TermArgss. A constant time operation.
 * \param[in] arg0 first MA_TermArgs to be compared
 * \param[in] arg1 second MA_TermArgs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTermArgs(MA_TermArgs arg0, MA_TermArgs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TermElemss. A constant time operation.
 * \param[in] arg0 first MA_TermElems to be compared
 * \param[in] arg1 second MA_TermElems to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTermElems(MA_TermElems arg0, MA_TermElems arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_SigArgArgss. A constant time operation.
 * \param[in] arg0 first MA_SigArgArgs to be compared
 * \param[in] arg1 second MA_SigArgArgs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualSigArgArgs(MA_SigArgArgs arg0, MA_SigArgArgs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_TermAttrss. A constant time operation.
 * \param[in] arg0 first MA_TermAttrs to be compared
 * \param[in] arg1 second MA_TermAttrs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualTermAttrs(MA_TermAttrs arg0, MA_TermAttrs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_FuncDefDefss. A constant time operation.
 * \param[in] arg0 first MA_FuncDefDefs to be compared
 * \param[in] arg1 second MA_FuncDefDefs to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualFuncDefDefs(MA_FuncDefDefs arg0, MA_FuncDefDefs arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_RuleRuless. A constant time operation.
 * \param[in] arg0 first MA_RuleRules to be compared
 * \param[in] arg1 second MA_RuleRules to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualRuleRules(MA_RuleRules arg0, MA_RuleRules arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_CondCondss. A constant time operation.
 * \param[in] arg0 first MA_CondConds to be compared
 * \param[in] arg1 second MA_CondConds to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualCondConds(MA_CondConds arg0, MA_CondConds arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexLayouts. A constant time operation.
 * \param[in] arg0 first MA_LexLayout to be compared
 * \param[in] arg1 second MA_LexLayout to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexLayout(MA_LexLayout arg0, MA_LexLayout arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexStrChars. A constant time operation.
 * \param[in] arg0 first MA_LexStrChar to be compared
 * \param[in] arg1 second MA_LexStrChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexStrChar(MA_LexStrChar arg0, MA_LexStrChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_StrChars. A constant time operation.
 * \param[in] arg0 first MA_StrChar to be compared
 * \param[in] arg1 second MA_StrChar to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualStrChar(MA_StrChar arg0, MA_StrChar arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexStrCons. A constant time operation.
 * \param[in] arg0 first MA_LexStrCon to be compared
 * \param[in] arg1 second MA_LexStrCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexStrCon(MA_LexStrCon arg0, MA_LexStrCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_StrCons. A constant time operation.
 * \param[in] arg0 first MA_StrCon to be compared
 * \param[in] arg1 second MA_StrCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualStrCon(MA_StrCon arg0, MA_StrCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexStrCharCharss. A constant time operation.
 * \param[in] arg0 first MA_LexStrCharChars to be compared
 * \param[in] arg1 second MA_LexStrCharChars to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexStrCharChars(MA_LexStrCharChars arg0, MA_LexStrCharChars arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexNatCons. A constant time operation.
 * \param[in] arg0 first MA_LexNatCon to be compared
 * \param[in] arg1 second MA_LexNatCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexNatCon(MA_LexNatCon arg0, MA_LexNatCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_NatCons. A constant time operation.
 * \param[in] arg0 first MA_NatCon to be compared
 * \param[in] arg1 second MA_NatCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualNatCon(MA_NatCon arg0, MA_NatCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_LexIdCons. A constant time operation.
 * \param[in] arg0 first MA_LexIdCon to be compared
 * \param[in] arg1 second MA_LexIdCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualLexIdCon(MA_LexIdCon arg0, MA_LexIdCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Tests equality of two MA_IdCons. A constant time operation.
 * \param[in] arg0 first MA_IdCon to be compared
 * \param[in] arg1 second MA_IdCon to be compared
 * \return ATtrue if #arg0 was equal to #arg1, ATfalse otherwise
 */
ATbool _MA_isEqualIdCon(MA_IdCon arg0, MA_IdCon arg1) {
  return ATisEqual((ATerm)arg0, (ATerm)arg1);
}

/**
 * Assert whether a MA_OptLayout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_OptLayout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidOptLayout(MA_OptLayout arg) {
  if (MA_isOptLayoutAbsent(arg)) {
    return ATtrue;
  }
  else if (MA_isOptLayoutPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_OptLayout is a Absent by checking against the following ATerm pattern: appl(prod([],cf(opt(layout)),no-attrs),[]). May not be used to assert correctness of the MA_OptLayout
 * \param[in] arg input MA_OptLayout
 * \return ATtrue if #arg corresponds to the signature of a Absent, or ATfalse otherwise
 */
inline ATbool MA_isOptLayoutAbsent(MA_OptLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: opt */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun3) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: layout */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun4) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: no-attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                ATerm arg_arg1 = ATgetArgument(arg, 1);
                if (ATisEmpty((ATermList)arg_arg1)) {
                  return ATtrue;
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_OptLayout is a Present by checking against the following ATerm pattern: appl(prod([cf(layout)],cf(opt(layout)),no-attrs),[<"layout"("Layout")>]). May not be used to assert correctness of the MA_OptLayout
 * \param[in] arg input MA_OptLayout
 * \return ATtrue if #arg corresponds to the signature of a Present, or ATfalse otherwise
 */
inline ATbool MA_isOptLayoutPresent(MA_OptLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: layout */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun4) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun4) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: no-attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                        arg_arg1_list = ATgetNext(arg_arg1_list);
                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                          return ATtrue;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_OptLayout has a layout. 
 * \param[in] arg input MA_OptLayout
 * \return ATtrue if the MA_OptLayout had a layout, or ATfalse otherwise
 */
ATbool MA_hasOptLayoutLayout(MA_OptLayout arg) {
  if (MA_isOptLayoutPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the layout MA_Layout of a MA_OptLayout. Note that the precondition is that this MA_OptLayout actually has a layout
 * \param[in] arg input MA_OptLayout
 * \return the layout of #arg, if it exist or an undefined value if it does not
 */
MA_Layout MA_getOptLayoutLayout(MA_OptLayout arg) {
  
    return (MA_Layout)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the layout of a MA_OptLayout. The precondition being that this MA_OptLayout actually has a layout
 * \param[in] arg input MA_OptLayout
 * \param[in] layout new MA_Layout to set in #arg
 * \return A new MA_OptLayout with layout at the right place, or a core dump if #arg did not have a layout
 */
MA_OptLayout MA_setOptLayoutLayout(MA_OptLayout arg, MA_Layout layout) {
  if (MA_isOptLayoutPresent(arg)) {
    return (MA_OptLayout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) layout), 0), 1);
  }

  ATabort("OptLayout has no Layout: %t\n", arg);
  return (MA_OptLayout)NULL;
}

/**
 * Assert whether a MA_Layout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_Layout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLayout(MA_Layout arg) {
  if (MA_isLayoutLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Layout is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(iter(layout))],cf(layout),no-attrs),[appl(list(lex(iter(layout))),<"list"("Lex-Layout-list")>)]). Always returns ATtrue
 * \param[in] arg input MA_Layout
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool MA_isLayoutLexToCf(MA_Layout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun7) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: layout */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun4) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: no-attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                        ATerm arg_arg1_head;
                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                        arg_arg1_list = ATgetNext(arg_arg1_list);
                        /* checking for: appl */
                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                          /* checking for: list */
                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                            /* checking for: lex */
                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun6) {
                              ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                              /* checking for: iter */
                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun7) {
                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun4) {
                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                    return ATtrue;
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Layout has a list. 
 * \param[in] arg input MA_Layout
 * \return ATtrue if the MA_Layout had a list, or ATfalse otherwise
 */
ATbool MA_hasLayoutList(MA_Layout arg) {
  if (MA_isLayoutLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list MA_LexLayoutList of a MA_Layout. Note that the precondition is that this MA_Layout actually has a list
 * \param[in] arg input MA_Layout
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
MA_LexLayoutList MA_getLayoutList(MA_Layout arg) {
  
    return (MA_LexLayoutList)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the list of a MA_Layout. The precondition being that this MA_Layout actually has a list
 * \param[in] arg input MA_Layout
 * \param[in] list new MA_LexLayoutList to set in #arg
 * \return A new MA_Layout with list at the right place, or a core dump if #arg did not have a list
 */
MA_Layout MA_setLayoutList(MA_Layout arg, MA_LexLayoutList list) {
  if (MA_isLayoutLexToCf(arg)) {
    return (MA_Layout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) list), 1), 0), 1);
  }

  ATabort("Layout has no List: %t\n", arg);
  return (MA_Layout)NULL;
}

/**
 * Assert whether a MA_LexLayoutList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexLayoutList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexLayoutList(MA_LexLayoutList arg) {
  if (MA_isLexLayoutListEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isLexLayoutListSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayoutList is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_LexLayoutList
 * \param[in] arg input MA_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isLexLayoutListEmpty(MA_LexLayoutList arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayoutList is a single by checking against the following ATerm pattern: [<head(Lex-Layout)>]. May not be used to assert correctness of the MA_LexLayoutList
 * \param[in] arg input MA_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isLexLayoutListSingle(MA_LexLayoutList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayoutList is a many by checking against the following ATerm pattern: [<head(Lex-Layout)>,<[tail(Lex-Layout-list)]>]. May not be used to assert correctness of the MA_LexLayoutList
 * \param[in] arg input MA_LexLayoutList
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isLexLayoutListMany(MA_LexLayoutList arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayoutList has a head. 
 * \param[in] arg input MA_LexLayoutList
 * \return ATtrue if the MA_LexLayoutList had a head, or ATfalse otherwise
 */
ATbool MA_hasLexLayoutListHead(MA_LexLayoutList arg) {
  if (MA_isLexLayoutListSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayoutList has a tail. 
 * \param[in] arg input MA_LexLayoutList
 * \return ATtrue if the MA_LexLayoutList had a tail, or ATfalse otherwise
 */
ATbool MA_hasLexLayoutListTail(MA_LexLayoutList arg) {
  if (MA_isLexLayoutListMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head MA_LexLayout of a MA_LexLayoutList. Note that the precondition is that this MA_LexLayoutList actually has a head
 * \param[in] arg input MA_LexLayoutList
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_LexLayout MA_getLexLayoutListHead(MA_LexLayoutList arg) {
  if (MA_isLexLayoutListSingle(arg)) {
    return (MA_LexLayout)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_LexLayout)ATgetFirst((ATermList)arg);
}

/**
 * Get the tail MA_LexLayoutList of a MA_LexLayoutList. Note that the precondition is that this MA_LexLayoutList actually has a tail
 * \param[in] arg input MA_LexLayoutList
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
MA_LexLayoutList MA_getLexLayoutListTail(MA_LexLayoutList arg) {
  
    return (MA_LexLayoutList)ATgetNext((ATermList)arg);
}

/**
 * Set the head of a MA_LexLayoutList. The precondition being that this MA_LexLayoutList actually has a head
 * \param[in] arg input MA_LexLayoutList
 * \param[in] head new MA_LexLayout to set in #arg
 * \return A new MA_LexLayoutList with head at the right place, or a core dump if #arg did not have a head
 */
MA_LexLayoutList MA_setLexLayoutListHead(MA_LexLayoutList arg, MA_LexLayout head) {
  if (MA_isLexLayoutListSingle(arg)) {
    return (MA_LexLayoutList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isLexLayoutListMany(arg)) {
    return (MA_LexLayoutList)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("LexLayoutList has no Head: %t\n", arg);
  return (MA_LexLayoutList)NULL;
}

/**
 * Set the tail of a MA_LexLayoutList. The precondition being that this MA_LexLayoutList actually has a tail
 * \param[in] arg input MA_LexLayoutList
 * \param[in] tail new MA_LexLayoutList to set in #arg
 * \return A new MA_LexLayoutList with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_LexLayoutList MA_setLexLayoutListTail(MA_LexLayoutList arg, MA_LexLayoutList tail) {
  if (MA_isLexLayoutListMany(arg)) {
    return (MA_LexLayoutList)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 1);
  }

  ATabort("LexLayoutList has no Tail: %t\n", arg);
  return (MA_LexLayoutList)NULL;
}

/**
 * Assert whether a MA_TraversalStrategy is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TraversalStrategy
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTraversalStrategy(MA_TraversalStrategy arg) {
  if (MA_isTraversalStrategyBottomUp(arg)) {
    return ATtrue;
  }
  else if (MA_isTraversalStrategyTopDown(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalStrategy is a bottom-up by checking against the following ATerm pattern: appl(prod([lit("bottom-up")],cf(sort("TraversalStrategy")),attrs([term(cons("bottom-up"))])),[appl(prod([char-class([98]),char-class([111]),char-class([116]),char-class([116]),char-class([111]),char-class([109]),char-class([45]),char-class([117]),char-class([112])],lit("bottom-up"),no-attrs),[98,111,116,116,111,109,45,117,112])]). May not be used to assert correctness of the MA_TraversalStrategy
 * \param[in] arg input MA_TraversalStrategy
 * \return ATtrue if #arg corresponds to the signature of a bottom-up, or ATfalse otherwise
 */
inline ATbool MA_isTraversalStrategyBottomUp(MA_TraversalStrategy arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: bottom-up */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun10) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalStrategy */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun12) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: bottom-up */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun10) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 98) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                        /* checking for: char-class */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                  /* checking for: lit */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                    /* checking for: bottom-up */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun10) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 98) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                return ATtrue;
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalStrategy is a top-down by checking against the following ATerm pattern: appl(prod([lit("top-down")],cf(sort("TraversalStrategy")),attrs([term(cons("top-down"))])),[appl(prod([char-class([116]),char-class([111]),char-class([112]),char-class([45]),char-class([100]),char-class([111]),char-class([119]),char-class([110])],lit("top-down"),no-attrs),[116,111,112,45,100,111,119,110])]). May not be used to assert correctness of the MA_TraversalStrategy
 * \param[in] arg input MA_TraversalStrategy
 * \return ATtrue if #arg corresponds to the signature of a top-down, or ATfalse otherwise
 */
inline ATbool MA_isTraversalStrategyTopDown(MA_TraversalStrategy arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: top-down */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun17) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalStrategy */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun12) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: top-down */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun17) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 112) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 119) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                        /* checking for: lit */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                          /* checking for: top-down */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun17) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                            /* checking for: no-attrs */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 112) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 119) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                  return ATtrue;
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalType is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TraversalType
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTraversalType(MA_TraversalType arg) {
  if (MA_isTraversalTypeTrafo(arg)) {
    return ATtrue;
  }
  else if (MA_isTraversalTypeAccu(arg)) {
    return ATtrue;
  }
  else if (MA_isTraversalTypeAccutrafo(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalType is a trafo by checking against the following ATerm pattern: appl(prod([lit("trafo")],cf(sort("TraversalType")),attrs([term(cons("trafo"))])),[appl(prod([char-class([116]),char-class([114]),char-class([97]),char-class([102]),char-class([111])],lit("trafo"),no-attrs),[116,114,97,102,111])]). May not be used to assert correctness of the MA_TraversalType
 * \param[in] arg input MA_TraversalType
 * \return ATtrue if #arg corresponds to the signature of a trafo, or ATfalse otherwise
 */
inline ATbool MA_isTraversalTypeTrafo(MA_TraversalType arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: trafo */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun18) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalType */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun19) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: trafo */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun18) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                          /* checking for: lit */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                            /* checking for: trafo */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun18) {
                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                              /* checking for: no-attrs */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                        return ATtrue;
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalType is a accu by checking against the following ATerm pattern: appl(prod([lit("accu")],cf(sort("TraversalType")),attrs([term(cons("accu"))])),[appl(prod([char-class([97]),char-class([99]),char-class([99]),char-class([117])],lit("accu"),no-attrs),[97,99,99,117])]). May not be used to assert correctness of the MA_TraversalType
 * \param[in] arg input MA_TraversalType
 * \return ATtrue if #arg corresponds to the signature of a accu, or ATfalse otherwise
 */
inline ATbool MA_isTraversalTypeAccu(MA_TraversalType arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: accu */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun20) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalType */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun19) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: accu */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun20) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: accu */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun20) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                          return ATtrue;
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalType is a accutrafo by checking against the following ATerm pattern: appl(prod([lit("accutrafo")],cf(sort("TraversalType")),attrs([term(cons("accutrafo"))])),[appl(prod([char-class([97]),char-class([99]),char-class([99]),char-class([117]),char-class([116]),char-class([114]),char-class([97]),char-class([102]),char-class([111])],lit("accutrafo"),no-attrs),[97,99,99,117,116,114,97,102,111])]). May not be used to assert correctness of the MA_TraversalType
 * \param[in] arg input MA_TraversalType
 * \return ATtrue if #arg corresponds to the signature of a accutrafo, or ATfalse otherwise
 */
inline ATbool MA_isTraversalTypeAccutrafo(MA_TraversalType arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: accutrafo */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun21) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalType */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun19) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: accutrafo */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun21) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                        /* checking for: char-class */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                  /* checking for: lit */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                    /* checking for: accutrafo */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun21) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                return ATtrue;
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalContinuation is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TraversalContinuation
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTraversalContinuation(MA_TraversalContinuation arg) {
  if (MA_isTraversalContinuationBreak(arg)) {
    return ATtrue;
  }
  else if (MA_isTraversalContinuationContinue(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalContinuation is a break by checking against the following ATerm pattern: appl(prod([lit("break")],cf(sort("TraversalContinuation")),attrs([term(cons("break"))])),[appl(prod([char-class([98]),char-class([114]),char-class([101]),char-class([97]),char-class([107])],lit("break"),no-attrs),[98,114,101,97,107])]). May not be used to assert correctness of the MA_TraversalContinuation
 * \param[in] arg input MA_TraversalContinuation
 * \return ATtrue if #arg corresponds to the signature of a break, or ATfalse otherwise
 */
inline ATbool MA_isTraversalContinuationBreak(MA_TraversalContinuation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: break */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun22) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalContinuation */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun23) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: break */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun22) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 98) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 107) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                          /* checking for: lit */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                            /* checking for: break */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun22) {
                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                              /* checking for: no-attrs */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 98) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 107) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                        return ATtrue;
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TraversalContinuation is a continue by checking against the following ATerm pattern: appl(prod([lit("continue")],cf(sort("TraversalContinuation")),attrs([term(cons("continue"))])),[appl(prod([char-class([99]),char-class([111]),char-class([110]),char-class([116]),char-class([105]),char-class([110]),char-class([117]),char-class([101])],lit("continue"),no-attrs),[99,111,110,116,105,110,117,101])]). May not be used to assert correctness of the MA_TraversalContinuation
 * \param[in] arg input MA_TraversalContinuation
 * \return ATtrue if #arg corresponds to the signature of a continue, or ATfalse otherwise
 */
inline ATbool MA_isTraversalContinuationContinue(MA_TraversalContinuation arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: continue */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun24) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: TraversalContinuation */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun23) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: continue */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun24) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 99) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                            /* checking for: char-class */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                /* checking for: char-class */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                          /* checking for: char-class */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                              /* checking for: char-class */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                        /* checking for: lit */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                          /* checking for: continue */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun24) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                            /* checking for: no-attrs */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 99) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                  return ATtrue;
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidFunId(MA_FunId arg) {
  if (MA_isFunIdCharacter(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdUnquoted(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdQuoted(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdReturnsList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdSepList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdIgnored(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTranslate(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdConcat(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a character by checking against the following ATerm pattern: appl(prod([cf(sort("NatCon"))],cf(sort("FunId")),attrs([term(cons("character"))])),[<"NatCon"("NatCon")>]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a character, or ATfalse otherwise
 */
inline ATbool MA_isFunIdCharacter(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NatCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun25) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: FunId */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: character */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun27) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a unquoted by checking against the following ATerm pattern: appl(prod([cf(sort("IdCon"))],cf(sort("FunId")),attrs([term(cons("unquoted")),avoid])),[<"IdCon"("IdCon")>]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a unquoted, or ATfalse otherwise
 */
inline ATbool MA_isFunIdUnquoted(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IdCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun28) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: FunId */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: unquoted */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun30) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                  /* checking for: avoid */
                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun29) {
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                          return ATtrue;
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a quoted by checking against the following ATerm pattern: appl(prod([cf(sort("StrCon"))],cf(sort("FunId")),attrs([term(cons("quoted"))])),[<"StrCon"("StrCon")>]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a quoted, or ATfalse otherwise
 */
inline ATbool MA_isFunIdQuoted(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: StrCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun31) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: FunId */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: quoted */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun32) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a returns-list by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(sort("FunId")),cf(opt(layout)),lit("]")],cf(sort("FunId")),attrs([term(cons("returns-list"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a returns-list, or ATfalse otherwise
 */
inline ATbool MA_isFunIdReturnsList(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun34) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: ] */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun33) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                              /* checking for: sort */
                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                /* checking for: FunId */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                  /* checking for: attrs */
                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                      ATerm arg_arg0_arg2_arg0_head;
                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                      /* checking for: term */
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                        /* checking for: cons */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                          /* checking for: returns-list */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun35) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                ATerm arg_arg1_head;
                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                /* checking for: appl */
                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                  /* checking for: prod */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: [ */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun34) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    /* checking for: appl */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                      /* checking for: prod */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                    /* checking for: lit */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                      /* checking for: ] */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun33) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                        /* checking for: no-attrs */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                  return ATtrue;
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a list by checking against the following ATerm pattern: appl(prod([lit("{"),cf(opt(layout)),cf(sort("FunId")),cf(opt(layout)),lit("}")],cf(sort("FunId")),attrs([term(cons("list"))])),[appl(prod([char-class([123])],lit("{"),no-attrs),[123]),<"ws-after-{"("OptLayout")>,<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([125])],lit("}"),no-attrs),[125])]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool MA_isFunIdList(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: { */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun37) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: } */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun36) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                              /* checking for: sort */
                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                /* checking for: FunId */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                  /* checking for: attrs */
                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                      ATerm arg_arg0_arg2_arg0_head;
                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                      /* checking for: term */
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                        /* checking for: cons */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                          /* checking for: list */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun38) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                ATerm arg_arg1_head;
                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                /* checking for: appl */
                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                  /* checking for: prod */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 123) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: { */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun37) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 123) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    /* checking for: appl */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                      /* checking for: prod */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 125) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                    /* checking for: lit */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                      /* checking for: } */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun36) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                        /* checking for: no-attrs */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 125) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                  return ATtrue;
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a sep-list by checking against the following ATerm pattern: appl(prod([lit("{"),cf(opt(layout)),cf(sort("FunId")),cf(opt(layout)),cf(sort("NatCon")),cf(opt(layout)),lit("}")],cf(sort("FunId")),attrs([term(cons("sep-list"))])),[appl(prod([char-class([123])],lit("{"),no-attrs),[123]),<"ws-after-{"("OptLayout")>,<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,<"seps"("NatCon")>,<"ws-after-seps"("OptLayout")>,appl(prod([char-class([125])],lit("}"),no-attrs),[125])]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a sep-list, or ATfalse otherwise
 */
inline ATbool MA_isFunIdSepList(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: { */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun37) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: NatCon */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun25) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: lit */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: } */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun36) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                            /* checking for: cf */
                                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                              /* checking for: sort */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                /* checking for: FunId */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                  /* checking for: attrs */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                      ATerm arg_arg0_arg2_arg0_head;
                                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                      /* checking for: term */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                        /* checking for: cons */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                          /* checking for: sep-list */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun39) {
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                ATerm arg_arg1_head;
                                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                /* checking for: appl */
                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                  /* checking for: prod */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 123) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: { */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun37) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 123) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        /* checking for: appl */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                          /* checking for: prod */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 125) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                        /* checking for: lit */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                          /* checking for: } */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun36) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 125) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                      return ATtrue;
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a ignored by checking against the following ATerm pattern: appl(prod([lit("IGNORE"),cf(opt(layout)),lit("["),cf(opt(layout)),cf(sort("FunId")),cf(opt(layout)),lit("]")],cf(sort("FunId")),attrs([term(cons("ignored"))])),[appl(prod([char-class([73]),char-class([71]),char-class([78]),char-class([79]),char-class([82]),char-class([69])],lit("IGNORE"),no-attrs),[73,71,78,79,82,69]),<"ws-after-IGNORE"("OptLayout")>,appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a ignored, or ATfalse otherwise
 */
inline ATbool MA_isFunIdIgnored(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: IGNORE */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun40) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: [ */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun34) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: FunId */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ] */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun33) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: FunId */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: ignored */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun41) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 73) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 71) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 78) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 79) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 82) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 69) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                /* checking for: lit */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                  /* checking for: IGNORE */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun40) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 73) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 71) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 78) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 79) {

                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 82) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 69) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                      /* checking for: [ */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun34) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                        /* checking for: appl */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                          /* checking for: prod */
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                          /* checking for: ] */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun33) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                      return ATtrue;
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a translate by checking against the following ATerm pattern: appl(prod([lit("TRANSLATE"),cf(opt(layout)),lit("["),cf(opt(layout)),cf(sort("FunId")),cf(opt(layout)),lit("]")],cf(sort("FunId")),attrs([term(cons("translate"))])),[appl(prod([char-class([84]),char-class([82]),char-class([65]),char-class([78]),char-class([83]),char-class([76]),char-class([65]),char-class([84]),char-class([69])],lit("TRANSLATE"),no-attrs),[84,82,65,78,83,76,65,84,69]),<"ws-after-TRANSLATE"("OptLayout")>,appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a translate, or ATfalse otherwise
 */
inline ATbool MA_isFunIdTranslate(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: TRANSLATE */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun42) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: [ */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun34) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              /* checking for: opt */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                /* checking for: layout */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: sort */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: FunId */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: lit */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: ] */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun33) {
                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                          /* checking for: cf */
                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                            /* checking for: sort */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                              /* checking for: FunId */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                /* checking for: attrs */
                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                    /* checking for: term */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                      /* checking for: cons */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                        /* checking for: translate */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun43) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              /* checking for: appl */
                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                /* checking for: prod */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                    /* checking for: char-class */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 84) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                              /* checking for: char-class */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 82) {

                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                        /* checking for: char-class */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 65) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                  /* checking for: char-class */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 78) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                            /* checking for: char-class */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 83) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                      /* checking for: char-class */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 76) {

                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                /* checking for: char-class */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 65) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 84) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 69) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                /* checking for: TRANSLATE */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun42) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 84) {

                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 82) {

                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 65) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 78) {

                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 83) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 76) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 65) {

                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 84) {

                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 69) {

                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                              /* checking for: appl */
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                /* checking for: [ */
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun34) {
                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                  /* checking for: appl */
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                    /* checking for: prod */
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                        /* checking for: char-class */
                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                  /* checking for: lit */
                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                    /* checking for: ] */
                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun33) {
                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                return ATtrue;
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a traversal by checking against the following ATerm pattern: appl(prod([lit("|"),cf(opt(layout)),cf(sort("FunId")),cf(opt(layout)),cf(sort("TraversalType")),cf(opt(layout)),cf(sort("TraversalStrategy")),cf(opt(layout)),cf(sort("TraversalContinuation")),cf(opt(layout)),lit("|")],cf(sort("FunId")),attrs([term(cons("traversal"))])),[appl(prod([char-class([124])],lit("|"),no-attrs),[124]),<"ws-after-|"("OptLayout")>,<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,<"TraversalType"("TraversalType")>,<"ws-after-TraversalType"("OptLayout")>,<"TraversalStrategy"("TraversalStrategy")>,<"ws-after-TraversalStrategy"("OptLayout")>,<"TraversalContinuation"("TraversalContinuation")>,<"ws-after-TraversalContinuation"("OptLayout")>,appl(prod([char-class([124])],lit("|"),no-attrs),[124])]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a traversal, or ATfalse otherwise
 */
inline ATbool MA_isFunIdTraversal(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: | */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun44) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: TraversalType */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun19) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: cf */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: sort */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                          /* checking for: TraversalStrategy */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun12) {
                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                              /* checking for: cf */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                /* checking for: opt */
                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                  /* checking for: layout */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                      /* checking for: cf */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                        /* checking for: sort */
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                          /* checking for: TraversalContinuation */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun23) {
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                              /* checking for: cf */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                /* checking for: opt */
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                  /* checking for: layout */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                        /* checking for: | */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun44) {
                                                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                            /* checking for: cf */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                              /* checking for: sort */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                                /* checking for: FunId */
                                                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                                  /* checking for: attrs */
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head;
                                                                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                      /* checking for: term */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                        /* checking for: cons */
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                          /* checking for: traversal */
                                                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun45) {
                                                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                                ATerm arg_arg1_head;
                                                                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                /* checking for: appl */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                  /* checking for: prod */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                      /* checking for: char-class */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 124) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                /* checking for: lit */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                  /* checking for: | */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun44) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 124) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                /* checking for: appl */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                  /* checking for: prod */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 124) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                /* checking for: lit */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                  /* checking for: | */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun44) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 124) {

                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                              return ATtrue;
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a concat by checking against the following ATerm pattern: appl(prod([cf(sort("FunId")),cf(opt(layout)),lit("++"),cf(opt(layout)),cf(sort("FunId"))],cf(sort("FunId")),attrs([assoc(left),term(cons("concat")),term(complete)])),[<"lhs"("FunId")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([43]),char-class([43])],lit("++"),no-attrs),[43,43]),<"ws-after-conc"("OptLayout")>,<"rhs"("FunId")>]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a concat, or ATfalse otherwise
 */
inline ATbool MA_isFunIdConcat(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ++ */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun46) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: FunId */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: FunId */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: assoc */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun49) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: left */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun50) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                              /* checking for: term */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                /* checking for: cons */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                  /* checking for: concat */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun48) {
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                      /* checking for: term */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                        /* checking for: complete */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun47) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  /* checking for: appl */
                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                    /* checking for: prod */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                        /* checking for: char-class */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                  /* checking for: char-class */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                            /* checking for: lit */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                              /* checking for: ++ */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun46) {
                                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                /* checking for: no-attrs */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                  return ATtrue;
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId is a concat-dash by checking against the following ATerm pattern: appl(prod([cf(sort("FunId")),cf(opt(layout)),lit("+-+"),cf(opt(layout)),cf(sort("FunId"))],cf(sort("FunId")),attrs([assoc(left),term(cons("concat-dash")),term(complete)])),[<"lhs"("FunId")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([43]),char-class([45]),char-class([43])],lit("+-+"),no-attrs),[43,45,43]),<"ws-after-conc2"("OptLayout")>,<"rhs"("FunId")>]). May not be used to assert correctness of the MA_FunId
 * \param[in] arg input MA_FunId
 * \return ATtrue if #arg corresponds to the signature of a concat-dash, or ATfalse otherwise
 */
inline ATbool MA_isFunIdConcatDash(MA_FunId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: +-+ */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun51) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: FunId */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: FunId */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun26) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: assoc */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun49) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: left */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun50) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                              /* checking for: term */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                /* checking for: cons */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                  /* checking for: concat-dash */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun52) {
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                      /* checking for: term */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                        /* checking for: complete */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun47) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                              ATerm arg_arg1_head;
                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  /* checking for: appl */
                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                    /* checking for: prod */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                        /* checking for: char-class */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                  /* checking for: char-class */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 45) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                            /* checking for: char-class */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                      /* checking for: lit */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                        /* checking for: +-+ */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun51) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                          /* checking for: no-attrs */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 45) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                return ATtrue;
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a NatCon. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a NatCon, or ATfalse otherwise
 */
ATbool MA_hasFunIdNatCon(MA_FunId arg) {
  if (MA_isFunIdCharacter(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a IdCon. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a IdCon, or ATfalse otherwise
 */
ATbool MA_hasFunIdIdCon(MA_FunId arg) {
  if (MA_isFunIdUnquoted(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a StrCon. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a StrCon, or ATfalse otherwise
 */
ATbool MA_hasFunIdStrCon(MA_FunId arg) {
  if (MA_isFunIdQuoted(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-[. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-[, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterBracketOpen(MA_FunId arg) {
  if (MA_isFunIdReturnsList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdIgnored(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTranslate(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a FunId. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a FunId, or ATfalse otherwise
 */
ATbool MA_hasFunIdFunId(MA_FunId arg) {
  if (MA_isFunIdReturnsList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdSepList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdIgnored(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTranslate(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-FunId. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-FunId, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterFunId(MA_FunId arg) {
  if (MA_isFunIdReturnsList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdSepList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdIgnored(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTranslate(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-{. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-{, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterBraceOpen(MA_FunId arg) {
  if (MA_isFunIdList(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdSepList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a seps. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a seps, or ATfalse otherwise
 */
ATbool MA_hasFunIdSeps(MA_FunId arg) {
  if (MA_isFunIdSepList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-seps. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-seps, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterSeps(MA_FunId arg) {
  if (MA_isFunIdSepList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-IGNORE. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-IGNORE, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterIGNORE(MA_FunId arg) {
  if (MA_isFunIdIgnored(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-TRANSLATE. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-TRANSLATE, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterTRANSLATE(MA_FunId arg) {
  if (MA_isFunIdTranslate(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-|. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-|, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterBar(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a TraversalType. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a TraversalType, or ATfalse otherwise
 */
ATbool MA_hasFunIdTraversalType(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-TraversalType. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-TraversalType, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterTraversalType(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a TraversalStrategy. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a TraversalStrategy, or ATfalse otherwise
 */
ATbool MA_hasFunIdTraversalStrategy(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-TraversalStrategy. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-TraversalStrategy, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterTraversalStrategy(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a TraversalContinuation. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a TraversalContinuation, or ATfalse otherwise
 */
ATbool MA_hasFunIdTraversalContinuation(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-TraversalContinuation. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-TraversalContinuation, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterTraversalContinuation(MA_FunId arg) {
  if (MA_isFunIdTraversal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a lhs. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a lhs, or ATfalse otherwise
 */
ATbool MA_hasFunIdLhs(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-lhs. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-lhs, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterLhs(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-conc. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-conc, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterConc(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a rhs. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a rhs, or ATfalse otherwise
 */
ATbool MA_hasFunIdRhs(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return ATtrue;
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FunId has a ws-after-conc2. 
 * \param[in] arg input MA_FunId
 * \return ATtrue if the MA_FunId had a ws-after-conc2, or ATfalse otherwise
 */
ATbool MA_hasFunIdWsAfterConc2(MA_FunId arg) {
  if (MA_isFunIdConcatDash(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the NatCon MA_NatCon of a MA_FunId. Note that the precondition is that this MA_FunId actually has a NatCon
 * \param[in] arg input MA_FunId
 * \return the NatCon of #arg, if it exist or an undefined value if it does not
 */
MA_NatCon MA_getFunIdNatCon(MA_FunId arg) {
  
    return (MA_NatCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the IdCon MA_IdCon of a MA_FunId. Note that the precondition is that this MA_FunId actually has a IdCon
 * \param[in] arg input MA_FunId
 * \return the IdCon of #arg, if it exist or an undefined value if it does not
 */
MA_IdCon MA_getFunIdIdCon(MA_FunId arg) {
  
    return (MA_IdCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the StrCon MA_StrCon of a MA_FunId. Note that the precondition is that this MA_FunId actually has a StrCon
 * \param[in] arg input MA_FunId
 * \return the StrCon of #arg, if it exist or an undefined value if it does not
 */
MA_StrCon MA_getFunIdStrCon(MA_FunId arg) {
  
    return (MA_StrCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-[ MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-[
 * \param[in] arg input MA_FunId
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterBracketOpen(MA_FunId arg) {
  if (MA_isFunIdReturnsList(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (MA_isFunIdIgnored(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the FunId MA_FunId of a MA_FunId. Note that the precondition is that this MA_FunId actually has a FunId
 * \param[in] arg input MA_FunId
 * \return the FunId of #arg, if it exist or an undefined value if it does not
 */
MA_FunId MA_getFunIdFunId(MA_FunId arg) {
  if (MA_isFunIdReturnsList(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (MA_isFunIdList(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (MA_isFunIdSepList(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (MA_isFunIdIgnored(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (MA_isFunIdTranslate(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-FunId MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-FunId
 * \param[in] arg input MA_FunId
 * \return the ws-after-FunId of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterFunId(MA_FunId arg) {
  if (MA_isFunIdReturnsList(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (MA_isFunIdList(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (MA_isFunIdSepList(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (MA_isFunIdIgnored(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (MA_isFunIdTranslate(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-{ MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-{
 * \param[in] arg input MA_FunId
 * \return the ws-after-{ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterBraceOpen(MA_FunId arg) {
  if (MA_isFunIdList(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the seps MA_NatCon of a MA_FunId. Note that the precondition is that this MA_FunId actually has a seps
 * \param[in] arg input MA_FunId
 * \return the seps of #arg, if it exist or an undefined value if it does not
 */
MA_NatCon MA_getFunIdSeps(MA_FunId arg) {
  
    return (MA_NatCon)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-seps MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-seps
 * \param[in] arg input MA_FunId
 * \return the ws-after-seps of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterSeps(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-IGNORE MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-IGNORE
 * \param[in] arg input MA_FunId
 * \return the ws-after-IGNORE of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterIGNORE(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-TRANSLATE MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-TRANSLATE
 * \param[in] arg input MA_FunId
 * \return the ws-after-TRANSLATE of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterTRANSLATE(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-| MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-|
 * \param[in] arg input MA_FunId
 * \return the ws-after-| of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterBar(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the TraversalType MA_TraversalType of a MA_FunId. Note that the precondition is that this MA_FunId actually has a TraversalType
 * \param[in] arg input MA_FunId
 * \return the TraversalType of #arg, if it exist or an undefined value if it does not
 */
MA_TraversalType MA_getFunIdTraversalType(MA_FunId arg) {
  
    return (MA_TraversalType)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-TraversalType MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-TraversalType
 * \param[in] arg input MA_FunId
 * \return the ws-after-TraversalType of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterTraversalType(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the TraversalStrategy MA_TraversalStrategy of a MA_FunId. Note that the precondition is that this MA_FunId actually has a TraversalStrategy
 * \param[in] arg input MA_FunId
 * \return the TraversalStrategy of #arg, if it exist or an undefined value if it does not
 */
MA_TraversalStrategy MA_getFunIdTraversalStrategy(MA_FunId arg) {
  
    return (MA_TraversalStrategy)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
}

/**
 * Get the ws-after-TraversalStrategy MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-TraversalStrategy
 * \param[in] arg input MA_FunId
 * \return the ws-after-TraversalStrategy of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterTraversalStrategy(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the TraversalContinuation MA_TraversalContinuation of a MA_FunId. Note that the precondition is that this MA_FunId actually has a TraversalContinuation
 * \param[in] arg input MA_FunId
 * \return the TraversalContinuation of #arg, if it exist or an undefined value if it does not
 */
MA_TraversalContinuation MA_getFunIdTraversalContinuation(MA_FunId arg) {
  
    return (MA_TraversalContinuation)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-TraversalContinuation MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-TraversalContinuation
 * \param[in] arg input MA_FunId
 * \return the ws-after-TraversalContinuation of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterTraversalContinuation(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Get the lhs MA_FunId of a MA_FunId. Note that the precondition is that this MA_FunId actually has a lhs
 * \param[in] arg input MA_FunId
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
MA_FunId MA_getFunIdLhs(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-lhs MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-lhs
 * \param[in] arg input MA_FunId
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterLhs(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-conc MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-conc
 * \param[in] arg input MA_FunId
 * \return the ws-after-conc of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterConc(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the rhs MA_FunId of a MA_FunId. Note that the precondition is that this MA_FunId actually has a rhs
 * \param[in] arg input MA_FunId
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
MA_FunId MA_getFunIdRhs(MA_FunId arg) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-conc2 MA_OptLayout of a MA_FunId. Note that the precondition is that this MA_FunId actually has a ws-after-conc2
 * \param[in] arg input MA_FunId
 * \return the ws-after-conc2 of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFunIdWsAfterConc2(MA_FunId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the NatCon of a MA_FunId. The precondition being that this MA_FunId actually has a NatCon
 * \param[in] arg input MA_FunId
 * \param[in] NatCon new MA_NatCon to set in #arg
 * \return A new MA_FunId with NatCon at the right place, or a core dump if #arg did not have a NatCon
 */
MA_FunId MA_setFunIdNatCon(MA_FunId arg, MA_NatCon NatCon) {
  if (MA_isFunIdCharacter(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NatCon), 0), 1);
  }

  ATabort("FunId has no NatCon: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the IdCon of a MA_FunId. The precondition being that this MA_FunId actually has a IdCon
 * \param[in] arg input MA_FunId
 * \param[in] IdCon new MA_IdCon to set in #arg
 * \return A new MA_FunId with IdCon at the right place, or a core dump if #arg did not have a IdCon
 */
MA_FunId MA_setFunIdIdCon(MA_FunId arg, MA_IdCon IdCon) {
  if (MA_isFunIdUnquoted(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IdCon), 0), 1);
  }

  ATabort("FunId has no IdCon: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the StrCon of a MA_FunId. The precondition being that this MA_FunId actually has a StrCon
 * \param[in] arg input MA_FunId
 * \param[in] StrCon new MA_StrCon to set in #arg
 * \return A new MA_FunId with StrCon at the right place, or a core dump if #arg did not have a StrCon
 */
MA_FunId MA_setFunIdStrCon(MA_FunId arg, MA_StrCon StrCon) {
  if (MA_isFunIdQuoted(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) StrCon), 0), 1);
  }

  ATabort("FunId has no StrCon: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-[ of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-[
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterBracketOpen new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
MA_FunId MA_setFunIdWsAfterBracketOpen(MA_FunId arg, MA_OptLayout wsAfterBracketOpen) {
  if (MA_isFunIdReturnsList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }
  else if (MA_isFunIdIgnored(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 3), 1);
  }
  else if (MA_isFunIdTranslate(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 3), 1);
  }

  ATabort("FunId has no WsAfterBracketOpen: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the FunId of a MA_FunId. The precondition being that this MA_FunId actually has a FunId
 * \param[in] arg input MA_FunId
 * \param[in] FunId new MA_FunId to set in #arg
 * \return A new MA_FunId with FunId at the right place, or a core dump if #arg did not have a FunId
 */
MA_FunId MA_setFunIdFunId(MA_FunId arg, MA_FunId FunId) {
  if (MA_isFunIdReturnsList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }
  else if (MA_isFunIdList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }
  else if (MA_isFunIdSepList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }
  else if (MA_isFunIdIgnored(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 4), 1);
  }
  else if (MA_isFunIdTranslate(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 4), 1);
  }
  else if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }

  ATabort("FunId has no FunId: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-FunId of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-FunId
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterFunId new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterFunId at the right place, or a core dump if #arg did not have a wsAfterFunId
 */
MA_FunId MA_setFunIdWsAfterFunId(MA_FunId arg, MA_OptLayout wsAfterFunId) {
  if (MA_isFunIdReturnsList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 3), 1);
  }
  else if (MA_isFunIdList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 3), 1);
  }
  else if (MA_isFunIdSepList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 3), 1);
  }
  else if (MA_isFunIdIgnored(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 5), 1);
  }
  else if (MA_isFunIdTranslate(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 5), 1);
  }
  else if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 3), 1);
  }

  ATabort("FunId has no WsAfterFunId: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-{ of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-{
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterBraceOpen new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterBraceOpen at the right place, or a core dump if #arg did not have a wsAfterBraceOpen
 */
MA_FunId MA_setFunIdWsAfterBraceOpen(MA_FunId arg, MA_OptLayout wsAfterBraceOpen) {
  if (MA_isFunIdList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBraceOpen), 1), 1);
  }
  else if (MA_isFunIdSepList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBraceOpen), 1), 1);
  }

  ATabort("FunId has no WsAfterBraceOpen: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the seps of a MA_FunId. The precondition being that this MA_FunId actually has a seps
 * \param[in] arg input MA_FunId
 * \param[in] seps new MA_NatCon to set in #arg
 * \return A new MA_FunId with seps at the right place, or a core dump if #arg did not have a seps
 */
MA_FunId MA_setFunIdSeps(MA_FunId arg, MA_NatCon seps) {
  if (MA_isFunIdSepList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) seps), 4), 1);
  }

  ATabort("FunId has no Seps: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-seps of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-seps
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterSeps new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterSeps at the right place, or a core dump if #arg did not have a wsAfterSeps
 */
MA_FunId MA_setFunIdWsAfterSeps(MA_FunId arg, MA_OptLayout wsAfterSeps) {
  if (MA_isFunIdSepList(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSeps), 5), 1);
  }

  ATabort("FunId has no WsAfterSeps: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-IGNORE of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-IGNORE
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterIGNORE new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterIGNORE at the right place, or a core dump if #arg did not have a wsAfterIGNORE
 */
MA_FunId MA_setFunIdWsAfterIGNORE(MA_FunId arg, MA_OptLayout wsAfterIGNORE) {
  if (MA_isFunIdIgnored(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIGNORE), 1), 1);
  }

  ATabort("FunId has no WsAfterIGNORE: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-TRANSLATE of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-TRANSLATE
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterTRANSLATE new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterTRANSLATE at the right place, or a core dump if #arg did not have a wsAfterTRANSLATE
 */
MA_FunId MA_setFunIdWsAfterTRANSLATE(MA_FunId arg, MA_OptLayout wsAfterTRANSLATE) {
  if (MA_isFunIdTranslate(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTRANSLATE), 1), 1);
  }

  ATabort("FunId has no WsAfterTRANSLATE: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-| of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-|
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterBar new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterBar at the right place, or a core dump if #arg did not have a wsAfterBar
 */
MA_FunId MA_setFunIdWsAfterBar(MA_FunId arg, MA_OptLayout wsAfterBar) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBar), 1), 1);
  }

  ATabort("FunId has no WsAfterBar: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the TraversalType of a MA_FunId. The precondition being that this MA_FunId actually has a TraversalType
 * \param[in] arg input MA_FunId
 * \param[in] TraversalType new MA_TraversalType to set in #arg
 * \return A new MA_FunId with TraversalType at the right place, or a core dump if #arg did not have a TraversalType
 */
MA_FunId MA_setFunIdTraversalType(MA_FunId arg, MA_TraversalType TraversalType) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) TraversalType), 4), 1);
  }

  ATabort("FunId has no TraversalType: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-TraversalType of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-TraversalType
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterTraversalType new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterTraversalType at the right place, or a core dump if #arg did not have a wsAfterTraversalType
 */
MA_FunId MA_setFunIdWsAfterTraversalType(MA_FunId arg, MA_OptLayout wsAfterTraversalType) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTraversalType), 5), 1);
  }

  ATabort("FunId has no WsAfterTraversalType: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the TraversalStrategy of a MA_FunId. The precondition being that this MA_FunId actually has a TraversalStrategy
 * \param[in] arg input MA_FunId
 * \param[in] TraversalStrategy new MA_TraversalStrategy to set in #arg
 * \return A new MA_FunId with TraversalStrategy at the right place, or a core dump if #arg did not have a TraversalStrategy
 */
MA_FunId MA_setFunIdTraversalStrategy(MA_FunId arg, MA_TraversalStrategy TraversalStrategy) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) TraversalStrategy), 6), 1);
  }

  ATabort("FunId has no TraversalStrategy: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-TraversalStrategy of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-TraversalStrategy
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterTraversalStrategy new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterTraversalStrategy at the right place, or a core dump if #arg did not have a wsAfterTraversalStrategy
 */
MA_FunId MA_setFunIdWsAfterTraversalStrategy(MA_FunId arg, MA_OptLayout wsAfterTraversalStrategy) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTraversalStrategy), 7), 1);
  }

  ATabort("FunId has no WsAfterTraversalStrategy: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the TraversalContinuation of a MA_FunId. The precondition being that this MA_FunId actually has a TraversalContinuation
 * \param[in] arg input MA_FunId
 * \param[in] TraversalContinuation new MA_TraversalContinuation to set in #arg
 * \return A new MA_FunId with TraversalContinuation at the right place, or a core dump if #arg did not have a TraversalContinuation
 */
MA_FunId MA_setFunIdTraversalContinuation(MA_FunId arg, MA_TraversalContinuation TraversalContinuation) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) TraversalContinuation), 8), 1);
  }

  ATabort("FunId has no TraversalContinuation: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-TraversalContinuation of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-TraversalContinuation
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterTraversalContinuation new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterTraversalContinuation at the right place, or a core dump if #arg did not have a wsAfterTraversalContinuation
 */
MA_FunId MA_setFunIdWsAfterTraversalContinuation(MA_FunId arg, MA_OptLayout wsAfterTraversalContinuation) {
  if (MA_isFunIdTraversal(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTraversalContinuation), 9), 1);
  }

  ATabort("FunId has no WsAfterTraversalContinuation: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the lhs of a MA_FunId. The precondition being that this MA_FunId actually has a lhs
 * \param[in] arg input MA_FunId
 * \param[in] lhs new MA_FunId to set in #arg
 * \return A new MA_FunId with lhs at the right place, or a core dump if #arg did not have a lhs
 */
MA_FunId MA_setFunIdLhs(MA_FunId arg, MA_FunId lhs) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }

  ATabort("FunId has no Lhs: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-lhs of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-lhs
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterLhs new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
MA_FunId MA_setFunIdWsAfterLhs(MA_FunId arg, MA_OptLayout wsAfterLhs) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }

  ATabort("FunId has no WsAfterLhs: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-conc of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-conc
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterConc new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterConc at the right place, or a core dump if #arg did not have a wsAfterConc
 */
MA_FunId MA_setFunIdWsAfterConc(MA_FunId arg, MA_OptLayout wsAfterConc) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterConc), 3), 1);
  }

  ATabort("FunId has no WsAfterConc: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the rhs of a MA_FunId. The precondition being that this MA_FunId actually has a rhs
 * \param[in] arg input MA_FunId
 * \param[in] rhs new MA_FunId to set in #arg
 * \return A new MA_FunId with rhs at the right place, or a core dump if #arg did not have a rhs
 */
MA_FunId MA_setFunIdRhs(MA_FunId arg, MA_FunId rhs) {
  if (MA_isFunIdConcat(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (MA_isFunIdConcatDash(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }

  ATabort("FunId has no Rhs: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Set the ws-after-conc2 of a MA_FunId. The precondition being that this MA_FunId actually has a ws-after-conc2
 * \param[in] arg input MA_FunId
 * \param[in] wsAfterConc2 new MA_OptLayout to set in #arg
 * \return A new MA_FunId with wsAfterConc2 at the right place, or a core dump if #arg did not have a wsAfterConc2
 */
MA_FunId MA_setFunIdWsAfterConc2(MA_FunId arg, MA_OptLayout wsAfterConc2) {
  if (MA_isFunIdConcatDash(arg)) {
    return (MA_FunId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterConc2), 3), 1);
  }

  ATabort("FunId has no WsAfterConc2: %t\n", arg);
  return (MA_FunId)NULL;
}

/**
 * Assert whether a MA_VarId is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_VarId
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidVarId(MA_VarId arg) {
  if (MA_isVarIdNormal(arg)) {
    return ATtrue;
  }
  else if (MA_isVarIdPlus(arg)) {
    return ATtrue;
  }
  else if (MA_isVarIdStar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId is a normal by checking against the following ATerm pattern: appl(prod([lit("$"),cf(opt(layout)),cf(sort("FunId"))],cf(sort("VarId")),attrs([term(cons("normal"))])),[appl(prod([char-class([36])],lit("$"),no-attrs),[36]),<"ws-after-$"("OptLayout")>,<"FunId"("FunId")>]). May not be used to assert correctness of the MA_VarId
 * \param[in] arg input MA_VarId
 * \return ATtrue if #arg corresponds to the signature of a normal, or ATfalse otherwise
 */
inline ATbool MA_isVarIdNormal(MA_VarId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: $ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun53) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: VarId */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun54) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: normal */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun55) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 36) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                  /* checking for: lit */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                    /* checking for: $ */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun53) {
                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                      /* checking for: no-attrs */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg1_head;
                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 36) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                    return ATtrue;
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId is a plus by checking against the following ATerm pattern: appl(prod([lit("$+"),cf(opt(layout)),cf(sort("FunId"))],cf(sort("VarId")),attrs([term(cons("plus"))])),[appl(prod([char-class([36]),char-class([43])],lit("$+"),no-attrs),[36,43]),<"ws-after-$+"("OptLayout")>,<"FunId"("FunId")>]). May not be used to assert correctness of the MA_VarId
 * \param[in] arg input MA_VarId
 * \return ATtrue if #arg corresponds to the signature of a plus, or ATfalse otherwise
 */
inline ATbool MA_isVarIdPlus(MA_VarId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: $+ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun56) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: VarId */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun54) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: plus */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun57) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 36) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                  /* checking for: char-class */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                            /* checking for: lit */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                              /* checking for: $+ */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun56) {
                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                /* checking for: no-attrs */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 36) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                  return ATtrue;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId is a star by checking against the following ATerm pattern: appl(prod([lit("$*"),cf(opt(layout)),cf(sort("FunId"))],cf(sort("VarId")),attrs([term(cons("star"))])),[appl(prod([char-class([36]),char-class([42])],lit("$*"),no-attrs),[36,42]),<"ws-after-$*"("OptLayout")>,<"FunId"("FunId")>]). May not be used to assert correctness of the MA_VarId
 * \param[in] arg input MA_VarId
 * \return ATtrue if #arg corresponds to the signature of a star, or ATfalse otherwise
 */
inline ATbool MA_isVarIdStar(MA_VarId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: $* */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun58) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FunId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: VarId */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun54) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: star */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun59) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 36) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                  /* checking for: char-class */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 42) {

                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                            /* checking for: lit */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                              /* checking for: $* */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun58) {
                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                /* checking for: no-attrs */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 36) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 42) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                  return ATtrue;
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId has a ws-after-$. 
 * \param[in] arg input MA_VarId
 * \return ATtrue if the MA_VarId had a ws-after-$, or ATfalse otherwise
 */
ATbool MA_hasVarIdWsAfterDollar(MA_VarId arg) {
  if (MA_isVarIdNormal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId has a FunId. 
 * \param[in] arg input MA_VarId
 * \return ATtrue if the MA_VarId had a FunId, or ATfalse otherwise
 */
ATbool MA_hasVarIdFunId(MA_VarId arg) {
  if (MA_isVarIdNormal(arg)) {
    return ATtrue;
  }
  else if (MA_isVarIdPlus(arg)) {
    return ATtrue;
  }
  else if (MA_isVarIdStar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId has a ws-after-$+. 
 * \param[in] arg input MA_VarId
 * \return ATtrue if the MA_VarId had a ws-after-$+, or ATfalse otherwise
 */
ATbool MA_hasVarIdWsAfterDollarPlus(MA_VarId arg) {
  if (MA_isVarIdPlus(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_VarId has a ws-after-$*. 
 * \param[in] arg input MA_VarId
 * \return ATtrue if the MA_VarId had a ws-after-$*, or ATfalse otherwise
 */
ATbool MA_hasVarIdWsAfterDollarStar(MA_VarId arg) {
  if (MA_isVarIdStar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-$ MA_OptLayout of a MA_VarId. Note that the precondition is that this MA_VarId actually has a ws-after-$
 * \param[in] arg input MA_VarId
 * \return the ws-after-$ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getVarIdWsAfterDollar(MA_VarId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the FunId MA_FunId of a MA_VarId. Note that the precondition is that this MA_VarId actually has a FunId
 * \param[in] arg input MA_VarId
 * \return the FunId of #arg, if it exist or an undefined value if it does not
 */
MA_FunId MA_getVarIdFunId(MA_VarId arg) {
  if (MA_isVarIdNormal(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (MA_isVarIdPlus(arg)) {
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else 
    return (MA_FunId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-$+ MA_OptLayout of a MA_VarId. Note that the precondition is that this MA_VarId actually has a ws-after-$+
 * \param[in] arg input MA_VarId
 * \return the ws-after-$+ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getVarIdWsAfterDollarPlus(MA_VarId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-$* MA_OptLayout of a MA_VarId. Note that the precondition is that this MA_VarId actually has a ws-after-$*
 * \param[in] arg input MA_VarId
 * \return the ws-after-$* of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getVarIdWsAfterDollarStar(MA_VarId arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Set the ws-after-$ of a MA_VarId. The precondition being that this MA_VarId actually has a ws-after-$
 * \param[in] arg input MA_VarId
 * \param[in] wsAfterDollar new MA_OptLayout to set in #arg
 * \return A new MA_VarId with wsAfterDollar at the right place, or a core dump if #arg did not have a wsAfterDollar
 */
MA_VarId MA_setVarIdWsAfterDollar(MA_VarId arg, MA_OptLayout wsAfterDollar) {
  if (MA_isVarIdNormal(arg)) {
    return (MA_VarId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterDollar), 1), 1);
  }

  ATabort("VarId has no WsAfterDollar: %t\n", arg);
  return (MA_VarId)NULL;
}

/**
 * Set the FunId of a MA_VarId. The precondition being that this MA_VarId actually has a FunId
 * \param[in] arg input MA_VarId
 * \param[in] FunId new MA_FunId to set in #arg
 * \return A new MA_VarId with FunId at the right place, or a core dump if #arg did not have a FunId
 */
MA_VarId MA_setVarIdFunId(MA_VarId arg, MA_FunId FunId) {
  if (MA_isVarIdNormal(arg)) {
    return (MA_VarId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }
  else if (MA_isVarIdPlus(arg)) {
    return (MA_VarId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }
  else if (MA_isVarIdStar(arg)) {
    return (MA_VarId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 2), 1);
  }

  ATabort("VarId has no FunId: %t\n", arg);
  return (MA_VarId)NULL;
}

/**
 * Set the ws-after-$+ of a MA_VarId. The precondition being that this MA_VarId actually has a ws-after-$+
 * \param[in] arg input MA_VarId
 * \param[in] wsAfterDollarPlus new MA_OptLayout to set in #arg
 * \return A new MA_VarId with wsAfterDollarPlus at the right place, or a core dump if #arg did not have a wsAfterDollarPlus
 */
MA_VarId MA_setVarIdWsAfterDollarPlus(MA_VarId arg, MA_OptLayout wsAfterDollarPlus) {
  if (MA_isVarIdPlus(arg)) {
    return (MA_VarId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterDollarPlus), 1), 1);
  }

  ATabort("VarId has no WsAfterDollarPlus: %t\n", arg);
  return (MA_VarId)NULL;
}

/**
 * Set the ws-after-$* of a MA_VarId. The precondition being that this MA_VarId actually has a ws-after-$*
 * \param[in] arg input MA_VarId
 * \param[in] wsAfterDollarStar new MA_OptLayout to set in #arg
 * \return A new MA_VarId with wsAfterDollarStar at the right place, or a core dump if #arg did not have a wsAfterDollarStar
 */
MA_VarId MA_setVarIdWsAfterDollarStar(MA_VarId arg, MA_OptLayout wsAfterDollarStar) {
  if (MA_isVarIdStar(arg)) {
    return (MA_VarId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterDollarStar), 1), 1);
  }

  ATabort("VarId has no WsAfterDollarStar: %t\n", arg);
  return (MA_VarId)NULL;
}

/**
 * Assert whether a MA_ModId is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_ModId
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidModId(MA_ModId arg) {
  if (MA_isModIdDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_ModId is a Default by checking against the following ATerm pattern: appl(prod([cf(sort("IdCon"))],cf(sort("ModId")),no-attrs),[<"IdCon"("IdCon")>]). Always returns ATtrue
 * \param[in] arg input MA_ModId
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isModIdDefault(MA_ModId arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IdCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun28) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: ModId */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun60) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_ModId has a IdCon. 
 * \param[in] arg input MA_ModId
 * \return ATtrue if the MA_ModId had a IdCon, or ATfalse otherwise
 */
ATbool MA_hasModIdIdCon(MA_ModId arg) {
  if (MA_isModIdDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the IdCon MA_IdCon of a MA_ModId. Note that the precondition is that this MA_ModId actually has a IdCon
 * \param[in] arg input MA_ModId
 * \return the IdCon of #arg, if it exist or an undefined value if it does not
 */
MA_IdCon MA_getModIdIdCon(MA_ModId arg) {
  
    return (MA_IdCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the IdCon of a MA_ModId. The precondition being that this MA_ModId actually has a IdCon
 * \param[in] arg input MA_ModId
 * \param[in] IdCon new MA_IdCon to set in #arg
 * \return A new MA_ModId with IdCon at the right place, or a core dump if #arg did not have a IdCon
 */
MA_ModId MA_setModIdIdCon(MA_ModId arg, MA_IdCon IdCon) {
  if (MA_isModIdDefault(arg)) {
    return (MA_ModId)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IdCon), 0), 1);
  }

  ATabort("ModId has no IdCon: %t\n", arg);
  return (MA_ModId)NULL;
}

/**
 * Assert whether a MA_Term is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_Term
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTerm(MA_Term arg) {
  if (MA_isTermVar(arg)) {
    return ATtrue;
  }
  else if (MA_isTermConstant(arg)) {
    return ATtrue;
  }
  else if (MA_isTermFunc(arg)) {
    return ATtrue;
  }
  else if (MA_isTermList(arg)) {
    return ATtrue;
  }
  else if (MA_isTermTyped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term is a var by checking against the following ATerm pattern: appl(prod([cf(sort("VarId"))],cf(sort("Term")),attrs([term(cons("var"))])),[<"VarId"("VarId")>]). May not be used to assert correctness of the MA_Term
 * \param[in] arg input MA_Term
 * \return ATtrue if #arg corresponds to the signature of a var, or ATfalse otherwise
 */
inline ATbool MA_isTermVar(MA_Term arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: VarId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun54) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: Term */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun61) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: var */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun62) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term is a constant by checking against the following ATerm pattern: appl(prod([cf(sort("FunId"))],cf(sort("Term")),attrs([term(cons("constant"))])),[<"FunId"("FunId")>]). May not be used to assert correctness of the MA_Term
 * \param[in] arg input MA_Term
 * \return ATtrue if #arg corresponds to the signature of a constant, or ATfalse otherwise
 */
inline ATbool MA_isTermConstant(MA_Term arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: Term */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun61) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: constant */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun63) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term is a func by checking against the following ATerm pattern: appl(prod([cf(sort("FunId")),cf(opt(layout)),lit("("),cf(opt(layout)),cf(iter-sep(sort("Term"),lit(","))),cf(opt(layout)),lit(")")],cf(sort("Term")),attrs([term(cons("func"))])),[<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,appl(list(cf(iter-sep(sort("Term"),lit(",")))),<"args"("Term-args")>),<"ws-after-args"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the MA_Term
 * \param[in] arg input MA_Term
 * \return ATtrue if #arg corresponds to the signature of a func, or ATfalse otherwise
 */
inline ATbool MA_isTermFunc(MA_Term arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ( */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun67) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: iter-sep */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun65) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                            /* checking for: Term */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun61) {
                                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                                              /* checking for: lit */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                                /* checking for: , */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun66) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: cf */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: opt */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                        /* checking for: layout */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                              /* checking for: ) */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun64) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                      /* checking for: Term */
                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun61) {
                                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                        /* checking for: attrs */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                            ATerm arg_arg0_arg2_arg0_head;
                                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                            /* checking for: term */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                              /* checking for: cons */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                /* checking for: func */
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun68) {
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                      ATerm arg_arg1_head;
                                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          /* checking for: appl */
                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                            /* checking for: prod */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                          /* checking for: lit */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                            /* checking for: ( */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun67) {
                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                              /* checking for: no-attrs */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: list */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              /* checking for: cf */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                /* checking for: iter-sep */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun65) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                  /* checking for: sort */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                    /* checking for: Term */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun61) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                                      /* checking for: lit */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                                        /* checking for: , */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun66) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                              /* checking for: appl */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                /* checking for: prod */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                              /* checking for: lit */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun64) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                            return ATtrue;
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term is a list by checking against the following ATerm pattern: appl(prod([lit("["),cf(opt(layout)),cf(sort("TermList")),cf(opt(layout)),lit("]")],cf(sort("Term")),attrs([term(cons("list"))])),[appl(prod([char-class([91])],lit("["),no-attrs),[91]),<"ws-after-["("OptLayout")>,<"TermList"("TermList")>,<"ws-after-TermList"("OptLayout")>,appl(prod([char-class([93])],lit("]"),no-attrs),[93])]). May not be used to assert correctness of the MA_Term
 * \param[in] arg input MA_Term
 * \return ATtrue if #arg corresponds to the signature of a list, or ATfalse otherwise
 */
inline ATbool MA_isTermList(MA_Term arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: [ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun34) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: TermList */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun69) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: ] */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun33) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                              /* checking for: sort */
                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                /* checking for: Term */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun61) {
                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                  /* checking for: attrs */
                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                      ATerm arg_arg0_arg2_arg0_head;
                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                      /* checking for: term */
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                        /* checking for: cons */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                          /* checking for: list */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun38) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                ATerm arg_arg1_head;
                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                /* checking for: appl */
                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                  /* checking for: prod */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                      /* checking for: char-class */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 91) {

                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                /* checking for: lit */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                  /* checking for: [ */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun34) {
                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                    /* checking for: no-attrs */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 91) {

                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    /* checking for: appl */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                      /* checking for: prod */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 93) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                    /* checking for: lit */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                      /* checking for: ] */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun33) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                        /* checking for: no-attrs */
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 93) {

                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                  return ATtrue;
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term is a typed by checking against the following ATerm pattern: appl(prod([cf(sort("Term")),cf(opt(layout)),lit(":"),cf(opt(layout)),cf(sort("Term"))],cf(sort("Term")),attrs([assoc(assoc),term(cons("typed"))])),[<"Term"("Term")>,<"ws-after-Term"("OptLayout")>,appl(prod([char-class([58])],lit(":"),no-attrs),[58]),<"ws-after-:"("OptLayout")>,<"type"("Term")>]). May not be used to assert correctness of the MA_Term
 * \param[in] arg input MA_Term
 * \return ATtrue if #arg corresponds to the signature of a typed, or ATfalse otherwise
 */
inline ATbool MA_isTermTyped(MA_Term arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Term */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: : */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun70) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: Term */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun61) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: assoc */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun49) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: assoc */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun72) {
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATfalse) {
                                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                              /* checking for: term */
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                /* checking for: cons */
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                  /* checking for: typed */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun71) {
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                        ATerm arg_arg1_head;
                                                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                            /* checking for: appl */
                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                              /* checking for: prod */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                  /* checking for: char-class */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                            /* checking for: lit */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                              /* checking for: : */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun70) {
                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                /* checking for: no-attrs */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a VarId. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a VarId, or ATfalse otherwise
 */
ATbool MA_hasTermVarId(MA_Term arg) {
  if (MA_isTermVar(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a FunId. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a FunId, or ATfalse otherwise
 */
ATbool MA_hasTermFunId(MA_Term arg) {
  if (MA_isTermConstant(arg)) {
    return ATtrue;
  }
  else if (MA_isTermFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-FunId. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-FunId, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterFunId(MA_Term arg) {
  if (MA_isTermFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-(. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-(, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterParenOpen(MA_Term arg) {
  if (MA_isTermFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a args. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a args, or ATfalse otherwise
 */
ATbool MA_hasTermArgs(MA_Term arg) {
  if (MA_isTermFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-args. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-args, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterArgs(MA_Term arg) {
  if (MA_isTermFunc(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-[. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-[, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterBracketOpen(MA_Term arg) {
  if (MA_isTermList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a TermList. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a TermList, or ATfalse otherwise
 */
ATbool MA_hasTermTermList(MA_Term arg) {
  if (MA_isTermList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-TermList. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-TermList, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterTermList(MA_Term arg) {
  if (MA_isTermList(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a Term. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a Term, or ATfalse otherwise
 */
ATbool MA_hasTermTerm(MA_Term arg) {
  if (MA_isTermTyped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-Term. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-Term, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterTerm(MA_Term arg) {
  if (MA_isTermTyped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a ws-after-:. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a ws-after-:, or ATfalse otherwise
 */
ATbool MA_hasTermWsAfterColon(MA_Term arg) {
  if (MA_isTermTyped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Term has a type. 
 * \param[in] arg input MA_Term
 * \return ATtrue if the MA_Term had a type, or ATfalse otherwise
 */
ATbool MA_hasTermType(MA_Term arg) {
  if (MA_isTermTyped(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the VarId MA_VarId of a MA_Term. Note that the precondition is that this MA_Term actually has a VarId
 * \param[in] arg input MA_Term
 * \return the VarId of #arg, if it exist or an undefined value if it does not
 */
MA_VarId MA_getTermVarId(MA_Term arg) {
  
    return (MA_VarId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the FunId MA_FunId of a MA_Term. Note that the precondition is that this MA_Term actually has a FunId
 * \param[in] arg input MA_Term
 * \return the FunId of #arg, if it exist or an undefined value if it does not
 */
MA_FunId MA_getTermFunId(MA_Term arg) {
  if (MA_isTermConstant(arg)) {
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-FunId MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-FunId
 * \param[in] arg input MA_Term
 * \return the ws-after-FunId of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterFunId(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-( MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-(
 * \param[in] arg input MA_Term
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterParenOpen(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the args MA_TermArgs of a MA_Term. Note that the precondition is that this MA_Term actually has a args
 * \param[in] arg input MA_Term
 * \return the args of #arg, if it exist or an undefined value if it does not
 */
MA_TermArgs MA_getTermArgs(MA_Term arg) {
  
    return (MA_TermArgs)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), 1);
}

/**
 * Get the ws-after-args MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-args
 * \param[in] arg input MA_Term
 * \return the ws-after-args of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterArgs(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-[ MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-[
 * \param[in] arg input MA_Term
 * \return the ws-after-[ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterBracketOpen(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the TermList MA_TermList of a MA_Term. Note that the precondition is that this MA_Term actually has a TermList
 * \param[in] arg input MA_Term
 * \return the TermList of #arg, if it exist or an undefined value if it does not
 */
MA_TermList MA_getTermTermList(MA_Term arg) {
  
    return (MA_TermList)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-TermList MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-TermList
 * \param[in] arg input MA_Term
 * \return the ws-after-TermList of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterTermList(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the Term MA_Term of a MA_Term. Note that the precondition is that this MA_Term actually has a Term
 * \param[in] arg input MA_Term
 * \return the Term of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getTermTerm(MA_Term arg) {
  
    return (MA_Term)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-Term MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-Term
 * \param[in] arg input MA_Term
 * \return the ws-after-Term of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterTerm(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-: MA_OptLayout of a MA_Term. Note that the precondition is that this MA_Term actually has a ws-after-:
 * \param[in] arg input MA_Term
 * \return the ws-after-: of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermWsAfterColon(MA_Term arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the type MA_Term of a MA_Term. Note that the precondition is that this MA_Term actually has a type
 * \param[in] arg input MA_Term
 * \return the type of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getTermType(MA_Term arg) {
  
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Set the VarId of a MA_Term. The precondition being that this MA_Term actually has a VarId
 * \param[in] arg input MA_Term
 * \param[in] VarId new MA_VarId to set in #arg
 * \return A new MA_Term with VarId at the right place, or a core dump if #arg did not have a VarId
 */
MA_Term MA_setTermVarId(MA_Term arg, MA_VarId VarId) {
  if (MA_isTermVar(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) VarId), 0), 1);
  }

  ATabort("Term has no VarId: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the FunId of a MA_Term. The precondition being that this MA_Term actually has a FunId
 * \param[in] arg input MA_Term
 * \param[in] FunId new MA_FunId to set in #arg
 * \return A new MA_Term with FunId at the right place, or a core dump if #arg did not have a FunId
 */
MA_Term MA_setTermFunId(MA_Term arg, MA_FunId FunId) {
  if (MA_isTermConstant(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 0), 1);
  }
  else if (MA_isTermFunc(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 0), 1);
  }

  ATabort("Term has no FunId: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-FunId of a MA_Term. The precondition being that this MA_Term actually has a ws-after-FunId
 * \param[in] arg input MA_Term
 * \param[in] wsAfterFunId new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterFunId at the right place, or a core dump if #arg did not have a wsAfterFunId
 */
MA_Term MA_setTermWsAfterFunId(MA_Term arg, MA_OptLayout wsAfterFunId) {
  if (MA_isTermFunc(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 1), 1);
  }

  ATabort("Term has no WsAfterFunId: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-( of a MA_Term. The precondition being that this MA_Term actually has a ws-after-(
 * \param[in] arg input MA_Term
 * \param[in] wsAfterParenOpen new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
MA_Term MA_setTermWsAfterParenOpen(MA_Term arg, MA_OptLayout wsAfterParenOpen) {
  if (MA_isTermFunc(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("Term has no WsAfterParenOpen: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the args of a MA_Term. The precondition being that this MA_Term actually has a args
 * \param[in] arg input MA_Term
 * \param[in] args new MA_TermArgs to set in #arg
 * \return A new MA_Term with args at the right place, or a core dump if #arg did not have a args
 */
MA_Term MA_setTermArgs(MA_Term arg, MA_TermArgs args) {
  if (MA_isTermFunc(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), (ATerm)((ATerm) args), 1), 4), 1);
  }

  ATabort("Term has no Args: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-args of a MA_Term. The precondition being that this MA_Term actually has a ws-after-args
 * \param[in] arg input MA_Term
 * \param[in] wsAfterArgs new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterArgs at the right place, or a core dump if #arg did not have a wsAfterArgs
 */
MA_Term MA_setTermWsAfterArgs(MA_Term arg, MA_OptLayout wsAfterArgs) {
  if (MA_isTermFunc(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterArgs), 5), 1);
  }

  ATabort("Term has no WsAfterArgs: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-[ of a MA_Term. The precondition being that this MA_Term actually has a ws-after-[
 * \param[in] arg input MA_Term
 * \param[in] wsAfterBracketOpen new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterBracketOpen at the right place, or a core dump if #arg did not have a wsAfterBracketOpen
 */
MA_Term MA_setTermWsAfterBracketOpen(MA_Term arg, MA_OptLayout wsAfterBracketOpen) {
  if (MA_isTermList(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBracketOpen), 1), 1);
  }

  ATabort("Term has no WsAfterBracketOpen: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the TermList of a MA_Term. The precondition being that this MA_Term actually has a TermList
 * \param[in] arg input MA_Term
 * \param[in] TermList new MA_TermList to set in #arg
 * \return A new MA_Term with TermList at the right place, or a core dump if #arg did not have a TermList
 */
MA_Term MA_setTermTermList(MA_Term arg, MA_TermList TermList) {
  if (MA_isTermList(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) TermList), 2), 1);
  }

  ATabort("Term has no TermList: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-TermList of a MA_Term. The precondition being that this MA_Term actually has a ws-after-TermList
 * \param[in] arg input MA_Term
 * \param[in] wsAfterTermList new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterTermList at the right place, or a core dump if #arg did not have a wsAfterTermList
 */
MA_Term MA_setTermWsAfterTermList(MA_Term arg, MA_OptLayout wsAfterTermList) {
  if (MA_isTermList(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTermList), 3), 1);
  }

  ATabort("Term has no WsAfterTermList: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the Term of a MA_Term. The precondition being that this MA_Term actually has a Term
 * \param[in] arg input MA_Term
 * \param[in] Term new MA_Term to set in #arg
 * \return A new MA_Term with Term at the right place, or a core dump if #arg did not have a Term
 */
MA_Term MA_setTermTerm(MA_Term arg, MA_Term Term) {
  if (MA_isTermTyped(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) Term), 0), 1);
  }

  ATabort("Term has no Term: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-Term of a MA_Term. The precondition being that this MA_Term actually has a ws-after-Term
 * \param[in] arg input MA_Term
 * \param[in] wsAfterTerm new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterTerm at the right place, or a core dump if #arg did not have a wsAfterTerm
 */
MA_Term MA_setTermWsAfterTerm(MA_Term arg, MA_OptLayout wsAfterTerm) {
  if (MA_isTermTyped(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterTerm), 1), 1);
  }

  ATabort("Term has no WsAfterTerm: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the ws-after-: of a MA_Term. The precondition being that this MA_Term actually has a ws-after-:
 * \param[in] arg input MA_Term
 * \param[in] wsAfterColon new MA_OptLayout to set in #arg
 * \return A new MA_Term with wsAfterColon at the right place, or a core dump if #arg did not have a wsAfterColon
 */
MA_Term MA_setTermWsAfterColon(MA_Term arg, MA_OptLayout wsAfterColon) {
  if (MA_isTermTyped(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterColon), 3), 1);
  }

  ATabort("Term has no WsAfterColon: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Set the type of a MA_Term. The precondition being that this MA_Term actually has a type
 * \param[in] arg input MA_Term
 * \param[in] type new MA_Term to set in #arg
 * \return A new MA_Term with type at the right place, or a core dump if #arg did not have a type
 */
MA_Term MA_setTermType(MA_Term arg, MA_Term type) {
  if (MA_isTermTyped(arg)) {
    return (MA_Term)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) type), 4), 1);
  }

  ATabort("Term has no Type: %t\n", arg);
  return (MA_Term)NULL;
}

/**
 * Assert whether a MA_TermList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TermList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTermList(MA_TermList arg) {
  if (MA_isTermListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermList is a Default by checking against the following ATerm pattern: appl(prod([cf(iter-star-sep(sort("Term"),lit(",")))],cf(sort("TermList")),no-attrs),[appl(list(cf(iter-star-sep(sort("Term"),lit(",")))),<"elems"("Term-elems")>)]). Always returns ATtrue
 * \param[in] arg input MA_TermList
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isTermListDefault(MA_TermList arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun73) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: Term */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun61) {
                ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                /* checking for: lit */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                  ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                  /* checking for: , */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun66) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                          /* checking for: TermList */
                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun69) {
                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                ATerm arg_arg1_head;
                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                /* checking for: appl */
                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                  /* checking for: list */
                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                      /* checking for: iter-star-sep */
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun73) {
                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun61) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                              /* checking for: , */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun66) {
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermList has a elems. 
 * \param[in] arg input MA_TermList
 * \return ATtrue if the MA_TermList had a elems, or ATfalse otherwise
 */
ATbool MA_hasTermListElems(MA_TermList arg) {
  if (MA_isTermListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the elems MA_TermElems of a MA_TermList. Note that the precondition is that this MA_TermList actually has a elems
 * \param[in] arg input MA_TermList
 * \return the elems of #arg, if it exist or an undefined value if it does not
 */
MA_TermElems MA_getTermListElems(MA_TermList arg) {
  
    return (MA_TermElems)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the elems of a MA_TermList. The precondition being that this MA_TermList actually has a elems
 * \param[in] arg input MA_TermList
 * \param[in] elems new MA_TermElems to set in #arg
 * \return A new MA_TermList with elems at the right place, or a core dump if #arg did not have a elems
 */
MA_TermList MA_setTermListElems(MA_TermList arg, MA_TermElems elems) {
  if (MA_isTermListDefault(arg)) {
    return (MA_TermList)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) elems), 1), 0), 1);
  }

  ATabort("TermList has no Elems: %t\n", arg);
  return (MA_TermList)NULL;
}

/**
 * Assert whether a MA_SigArg is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_SigArg
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidSigArg(MA_SigArg arg) {
  if (MA_isSigArgNormal(arg)) {
    return ATtrue;
  }
  else if (MA_isSigArgStar(arg)) {
    return ATtrue;
  }
  else if (MA_isSigArgPlus(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArg is a normal by checking against the following ATerm pattern: appl(prod([lit("_")],cf(sort("SigArg")),attrs([term(cons("normal"))])),[appl(prod([char-class([95])],lit("_"),no-attrs),[95])]). May not be used to assert correctness of the MA_SigArg
 * \param[in] arg input MA_SigArg
 * \return ATtrue if #arg corresponds to the signature of a normal, or ATfalse otherwise
 */
inline ATbool MA_isSigArgNormal(MA_SigArg arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: _ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun74) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: SigArg */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun75) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: normal */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun55) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 95) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                  /* checking for: lit */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                    /* checking for: _ */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun74) {
                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                      /* checking for: no-attrs */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head_arg1_head;
                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 95) {

                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                return ATtrue;
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArg is a star by checking against the following ATerm pattern: appl(prod([lit("_"),cf(opt(layout)),lit("*")],cf(sort("SigArg")),attrs([term(cons("star"))])),[appl(prod([char-class([95])],lit("_"),no-attrs),[95]),<"ws-after-_"("OptLayout")>,appl(prod([char-class([42])],lit("*"),no-attrs),[42])]). May not be used to assert correctness of the MA_SigArg
 * \param[in] arg input MA_SigArg
 * \return ATtrue if #arg corresponds to the signature of a star, or ATfalse otherwise
 */
inline ATbool MA_isSigArgStar(MA_SigArg arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: _ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun74) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: * */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun76) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                              /* checking for: sort */
                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                /* checking for: SigArg */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun75) {
                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                  /* checking for: attrs */
                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg2_arg0_head;
                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                      /* checking for: term */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                        /* checking for: cons */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                          /* checking for: star */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun59) {
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                ATerm arg_arg1_head;
                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                /* checking for: appl */
                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                  /* checking for: prod */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                      /* checking for: char-class */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 95) {

                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                /* checking for: lit */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                  /* checking for: _ */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun74) {
                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                    /* checking for: no-attrs */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg1_head;
                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 95) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                /* checking for: appl */
                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                  /* checking for: prod */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 42) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: * */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun76) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 42) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArg is a plus by checking against the following ATerm pattern: appl(prod([lit("_"),cf(opt(layout)),lit("+")],cf(sort("SigArg")),attrs([term(cons("plus"))])),[appl(prod([char-class([95])],lit("_"),no-attrs),[95]),<"ws-after-_"("OptLayout")>,appl(prod([char-class([43])],lit("+"),no-attrs),[43])]). May not be used to assert correctness of the MA_SigArg
 * \param[in] arg input MA_SigArg
 * \return ATtrue if #arg corresponds to the signature of a plus, or ATfalse otherwise
 */
inline ATbool MA_isSigArgPlus(MA_SigArg arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: _ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun74) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: lit */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: + */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun77) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                            /* checking for: cf */
                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                              /* checking for: sort */
                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                /* checking for: SigArg */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun75) {
                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                  /* checking for: attrs */
                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg2_arg0_head;
                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                      /* checking for: term */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                        /* checking for: cons */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                          /* checking for: plus */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun57) {
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                ATerm arg_arg1_head;
                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                /* checking for: appl */
                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                  /* checking for: prod */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                      /* checking for: char-class */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 95) {

                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                /* checking for: lit */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                  /* checking for: _ */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun74) {
                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                    /* checking for: no-attrs */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                        ATerm arg_arg1_head_arg1_head;
                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 95) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                /* checking for: appl */
                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                  /* checking for: prod */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 43) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: + */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun77) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 43) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                              return ATtrue;
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArg has a ws-after-_. 
 * \param[in] arg input MA_SigArg
 * \return ATtrue if the MA_SigArg had a ws-after-_, or ATfalse otherwise
 */
ATbool MA_hasSigArgWsAfterUnderscore(MA_SigArg arg) {
  if (MA_isSigArgStar(arg)) {
    return ATtrue;
  }
  else if (MA_isSigArgPlus(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-_ MA_OptLayout of a MA_SigArg. Note that the precondition is that this MA_SigArg actually has a ws-after-_
 * \param[in] arg input MA_SigArg
 * \return the ws-after-_ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getSigArgWsAfterUnderscore(MA_SigArg arg) {
  if (MA_isSigArgStar(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Set the ws-after-_ of a MA_SigArg. The precondition being that this MA_SigArg actually has a ws-after-_
 * \param[in] arg input MA_SigArg
 * \param[in] wsAfterUnderscore new MA_OptLayout to set in #arg
 * \return A new MA_SigArg with wsAfterUnderscore at the right place, or a core dump if #arg did not have a wsAfterUnderscore
 */
MA_SigArg MA_setSigArgWsAfterUnderscore(MA_SigArg arg, MA_OptLayout wsAfterUnderscore) {
  if (MA_isSigArgStar(arg)) {
    return (MA_SigArg)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterUnderscore), 1), 1);
  }
  else if (MA_isSigArgPlus(arg)) {
    return (MA_SigArg)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterUnderscore), 1), 1);
  }

  ATabort("SigArg has no WsAfterUnderscore: %t\n", arg);
  return (MA_SigArg)NULL;
}

/**
 * Assert whether a MA_FuncDef is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidFuncDef(MA_FuncDef arg) {
  if (MA_isFuncDefConstantNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefConstantWithAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef is a constant-no-annos by checking against the following ATerm pattern: appl(prod([cf(sort("FunId"))],cf(sort("FuncDef")),attrs([term(cons("constant-no-annos"))])),[<"FunId"("FunId")>]). May not be used to assert correctness of the MA_FuncDef
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if #arg corresponds to the signature of a constant-no-annos, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefConstantNoAnnos(MA_FuncDef arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: FuncDef */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun78) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                          ATerm arg_arg0_arg2_arg0_head;
                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                          /* checking for: term */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                            /* checking for: cons */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                              /* checking for: constant-no-annos */
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun79) {
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef is a constant-with-annos by checking against the following ATerm pattern: appl(prod([cf(sort("FunId")),cf(opt(layout)),cf(sort("Annotations"))],cf(sort("FuncDef")),attrs([term(cons("constant-with-annos"))])),[<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,<"Annotations"("Annotations")>]). May not be used to assert correctness of the MA_FuncDef
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if #arg corresponds to the signature of a constant-with-annos, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefConstantWithAnnos(MA_FuncDef arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: cf */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                            /* checking for: Annotations */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun80) {
                              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                /* checking for: cf */
                                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                  /* checking for: sort */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                    /* checking for: FuncDef */
                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun78) {
                                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                      /* checking for: attrs */
                                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                        ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                          ATerm arg_arg0_arg2_arg0_head;
                                          ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                          arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                          arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                          /* checking for: term */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                            /* checking for: cons */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                              ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                              /* checking for: constant-with-annos */
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun81) {
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                  ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                  if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                    ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                          return ATtrue;
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef is a func-no-annos by checking against the following ATerm pattern: appl(prod([cf(sort("FunId")),cf(opt(layout)),lit("("),cf(opt(layout)),cf(iter-sep(sort("SigArg"),lit(","))),cf(opt(layout)),lit(")")],cf(sort("FuncDef")),attrs([term(cons("func-no-annos"))])),[<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,appl(list(cf(iter-sep(sort("SigArg"),lit(",")))),<"args"("SigArg-args")>),<"ws-after-args"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41])]). May not be used to assert correctness of the MA_FuncDef
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if #arg corresponds to the signature of a func-no-annos, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefFuncNoAnnos(MA_FuncDef arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ( */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun67) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: iter-sep */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun65) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                            /* checking for: SigArg */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun75) {
                                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                                              /* checking for: lit */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                                /* checking for: , */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun66) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: cf */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: opt */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                        /* checking for: layout */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                              /* checking for: ) */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun64) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                    /* checking for: sort */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                      /* checking for: FuncDef */
                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun78) {
                                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                        /* checking for: attrs */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                            ATerm arg_arg0_arg2_arg0_head;
                                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                            /* checking for: term */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                              /* checking for: cons */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                /* checking for: func-no-annos */
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun82) {
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                      ATerm arg_arg1_head;
                                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          /* checking for: appl */
                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                            /* checking for: prod */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                          /* checking for: lit */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                            /* checking for: ( */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun67) {
                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                              /* checking for: no-attrs */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                          /* checking for: appl */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                            /* checking for: list */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                              /* checking for: cf */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                /* checking for: iter-sep */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun65) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                  /* checking for: sort */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                    /* checking for: SigArg */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun75) {
                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                                      /* checking for: lit */
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                                        /* checking for: , */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun66) {
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                              /* checking for: appl */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                /* checking for: prod */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                              /* checking for: lit */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun64) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                            return ATtrue;
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef is a func-with-annos by checking against the following ATerm pattern: appl(prod([cf(sort("FunId")),cf(opt(layout)),lit("("),cf(opt(layout)),cf(iter-sep(sort("SigArg"),lit(","))),cf(opt(layout)),lit(")"),cf(opt(layout)),cf(sort("Annotations"))],cf(sort("FuncDef")),attrs([term(cons("func-with-annos"))])),[<"FunId"("FunId")>,<"ws-after-FunId"("OptLayout")>,appl(prod([char-class([40])],lit("("),no-attrs),[40]),<"ws-after-("("OptLayout")>,appl(list(cf(iter-sep(sort("SigArg"),lit(",")))),<"args"("SigArg-args")>),<"ws-after-args"("OptLayout")>,appl(prod([char-class([41])],lit(")"),no-attrs),[41]),<"ws-after-)"("OptLayout")>,<"Annotations"("Annotations")>]). May not be used to assert correctness of the MA_FuncDef
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if #arg corresponds to the signature of a func-with-annos, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefFuncWithAnnos(MA_FuncDef arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: FunId */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun26) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ( */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun67) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: iter-sep */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun65) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: sort */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                            /* checking for: SigArg */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun75) {
                                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                                              /* checking for: lit */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                                /* checking for: , */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun66) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: cf */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: opt */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                        /* checking for: layout */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                              /* checking for: ) */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun64) {
                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                  /* checking for: cf */
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                    /* checking for: opt */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                      /* checking for: layout */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: sort */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: Annotations */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun80) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                  /* checking for: cf */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                    /* checking for: sort */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                      /* checking for: FuncDef */
                                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun78) {
                                                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                        /* checking for: attrs */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                                          ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                            ATerm arg_arg0_arg2_arg0_head;
                                                                                            ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                            arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                            arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                            /* checking for: term */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                                              ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                              /* checking for: cons */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                                ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                /* checking for: func-with-annos */
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun83) {
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                    ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                    if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                      ATerm arg_arg1_head;
                                                                                                      ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          /* checking for: appl */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                            /* checking for: prod */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                /* checking for: char-class */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 40) {

                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                          /* checking for: lit */
                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                            /* checking for: ( */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun67) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                              /* checking for: no-attrs */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 40) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          /* checking for: appl */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                            ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                            /* checking for: list */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                              /* checking for: cf */
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                                                                /* checking for: iter-sep */
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun65) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                                                                  /* checking for: sort */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                                                                    /* checking for: SigArg */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun75) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                                                                      /* checking for: lit */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                                                                        /* checking for: , */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun66) {
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                              /* checking for: appl */
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                /* checking for: prod */
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 41) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                              /* checking for: lit */
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                /* checking for: ) */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun64) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                  /* checking for: no-attrs */
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                      ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 41) {

                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                return ATtrue;
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a FunId. 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a FunId, or ATfalse otherwise
 */
ATbool MA_hasFuncDefFunId(MA_FuncDef arg) {
  if (MA_isFuncDefConstantNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefConstantWithAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a ws-after-FunId. 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a ws-after-FunId, or ATfalse otherwise
 */
ATbool MA_hasFuncDefWsAfterFunId(MA_FuncDef arg) {
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a Annotations. 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a Annotations, or ATfalse otherwise
 */
ATbool MA_hasFuncDefAnnotations(MA_FuncDef arg) {
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a ws-after-(. 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a ws-after-(, or ATfalse otherwise
 */
ATbool MA_hasFuncDefWsAfterParenOpen(MA_FuncDef arg) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a args. 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a args, or ATfalse otherwise
 */
ATbool MA_hasFuncDefArgs(MA_FuncDef arg) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a ws-after-args. 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a ws-after-args, or ATfalse otherwise
 */
ATbool MA_hasFuncDefWsAfterArgs(MA_FuncDef arg) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDef has a ws-after-). 
 * \param[in] arg input MA_FuncDef
 * \return ATtrue if the MA_FuncDef had a ws-after-), or ATfalse otherwise
 */
ATbool MA_hasFuncDefWsAfterParenClose(MA_FuncDef arg) {
  if (MA_isFuncDefFuncWithAnnos(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the FunId MA_FunId of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a FunId
 * \param[in] arg input MA_FuncDef
 * \return the FunId of #arg, if it exist or an undefined value if it does not
 */
MA_FunId MA_getFuncDefFunId(MA_FuncDef arg) {
  if (MA_isFuncDefConstantNoAnnos(arg)) {
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (MA_isFuncDefConstantWithAnnos(arg)) {
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (MA_FunId)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-FunId MA_OptLayout of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a ws-after-FunId
 * \param[in] arg input MA_FuncDef
 * \return the ws-after-FunId of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFuncDefWsAfterFunId(MA_FuncDef arg) {
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the Annotations MA_Annotations of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a Annotations
 * \param[in] arg input MA_FuncDef
 * \return the Annotations of #arg, if it exist or an undefined value if it does not
 */
MA_Annotations MA_getFuncDefAnnotations(MA_FuncDef arg) {
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return (MA_Annotations)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else 
    return (MA_Annotations)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
}

/**
 * Get the ws-after-( MA_OptLayout of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a ws-after-(
 * \param[in] arg input MA_FuncDef
 * \return the ws-after-( of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFuncDefWsAfterParenOpen(MA_FuncDef arg) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the args MA_SigArgArgs of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a args
 * \param[in] arg input MA_FuncDef
 * \return the args of #arg, if it exist or an undefined value if it does not
 */
MA_SigArgArgs MA_getFuncDefArgs(MA_FuncDef arg) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_SigArgArgs)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), 1);
  }
  else 
    return (MA_SigArgArgs)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), 1);
}

/**
 * Get the ws-after-args MA_OptLayout of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a ws-after-args
 * \param[in] arg input MA_FuncDef
 * \return the ws-after-args of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFuncDefWsAfterArgs(MA_FuncDef arg) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the ws-after-) MA_OptLayout of a MA_FuncDef. Note that the precondition is that this MA_FuncDef actually has a ws-after-)
 * \param[in] arg input MA_FuncDef
 * \return the ws-after-) of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFuncDefWsAfterParenClose(MA_FuncDef arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Set the FunId of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a FunId
 * \param[in] arg input MA_FuncDef
 * \param[in] FunId new MA_FunId to set in #arg
 * \return A new MA_FuncDef with FunId at the right place, or a core dump if #arg did not have a FunId
 */
MA_FuncDef MA_setFuncDefFunId(MA_FuncDef arg, MA_FunId FunId) {
  if (MA_isFuncDefConstantNoAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 0), 1);
  }
  else if (MA_isFuncDefConstantWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 0), 1);
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 0), 1);
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FunId), 0), 1);
  }

  ATabort("FuncDef has no FunId: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Set the ws-after-FunId of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a ws-after-FunId
 * \param[in] arg input MA_FuncDef
 * \param[in] wsAfterFunId new MA_OptLayout to set in #arg
 * \return A new MA_FuncDef with wsAfterFunId at the right place, or a core dump if #arg did not have a wsAfterFunId
 */
MA_FuncDef MA_setFuncDefWsAfterFunId(MA_FuncDef arg, MA_OptLayout wsAfterFunId) {
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 1), 1);
  }
  else if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 1), 1);
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterFunId), 1), 1);
  }

  ATabort("FuncDef has no WsAfterFunId: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Set the Annotations of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a Annotations
 * \param[in] arg input MA_FuncDef
 * \param[in] Annotations new MA_Annotations to set in #arg
 * \return A new MA_FuncDef with Annotations at the right place, or a core dump if #arg did not have a Annotations
 */
MA_FuncDef MA_setFuncDefAnnotations(MA_FuncDef arg, MA_Annotations Annotations) {
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) Annotations), 2), 1);
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) Annotations), 8), 1);
  }

  ATabort("FuncDef has no Annotations: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Set the ws-after-( of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a ws-after-(
 * \param[in] arg input MA_FuncDef
 * \param[in] wsAfterParenOpen new MA_OptLayout to set in #arg
 * \return A new MA_FuncDef with wsAfterParenOpen at the right place, or a core dump if #arg did not have a wsAfterParenOpen
 */
MA_FuncDef MA_setFuncDefWsAfterParenOpen(MA_FuncDef arg, MA_OptLayout wsAfterParenOpen) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenOpen), 3), 1);
  }

  ATabort("FuncDef has no WsAfterParenOpen: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Set the args of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a args
 * \param[in] arg input MA_FuncDef
 * \param[in] args new MA_SigArgArgs to set in #arg
 * \return A new MA_FuncDef with args at the right place, or a core dump if #arg did not have a args
 */
MA_FuncDef MA_setFuncDefArgs(MA_FuncDef arg, MA_SigArgArgs args) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), (ATerm)((ATerm) args), 1), 4), 1);
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4), (ATerm)((ATerm) args), 1), 4), 1);
  }

  ATabort("FuncDef has no Args: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Set the ws-after-args of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a ws-after-args
 * \param[in] arg input MA_FuncDef
 * \param[in] wsAfterArgs new MA_OptLayout to set in #arg
 * \return A new MA_FuncDef with wsAfterArgs at the right place, or a core dump if #arg did not have a wsAfterArgs
 */
MA_FuncDef MA_setFuncDefWsAfterArgs(MA_FuncDef arg, MA_OptLayout wsAfterArgs) {
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterArgs), 5), 1);
  }
  else if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterArgs), 5), 1);
  }

  ATabort("FuncDef has no WsAfterArgs: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Set the ws-after-) of a MA_FuncDef. The precondition being that this MA_FuncDef actually has a ws-after-)
 * \param[in] arg input MA_FuncDef
 * \param[in] wsAfterParenClose new MA_OptLayout to set in #arg
 * \return A new MA_FuncDef with wsAfterParenClose at the right place, or a core dump if #arg did not have a wsAfterParenClose
 */
MA_FuncDef MA_setFuncDefWsAfterParenClose(MA_FuncDef arg, MA_OptLayout wsAfterParenClose) {
  if (MA_isFuncDefFuncWithAnnos(arg)) {
    return (MA_FuncDef)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterParenClose), 7), 1);
  }

  ATabort("FuncDef has no WsAfterParenClose: %t\n", arg);
  return (MA_FuncDef)NULL;
}

/**
 * Assert whether a MA_Annotations is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_Annotations
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidAnnotations(MA_Annotations arg) {
  if (MA_isAnnotationsDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Annotations is a Default by checking against the following ATerm pattern: appl(prod([lit("{"),cf(opt(layout)),cf(iter-sep(sort("Term"),lit(","))),cf(opt(layout)),lit("}")],cf(sort("Annotations")),no-attrs),[appl(prod([char-class([123])],lit("{"),no-attrs),[123]),<"ws-after-{"("OptLayout")>,appl(list(cf(iter-sep(sort("Term"),lit(",")))),<"attrs"("Term-attrs")>),<"ws-after-attrs"("OptLayout")>,appl(prod([char-class([125])],lit("}"),no-attrs),[125])]). Always returns ATtrue
 * \param[in] arg input MA_Annotations
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isAnnotationsDefault(MA_Annotations arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: { */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun37) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: iter-sep */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun65) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: sort */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                            /* checking for: Term */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun61) {
                              ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                              /* checking for: lit */
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                                ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                                /* checking for: , */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun66) {
                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                      /* checking for: opt */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                        /* checking for: layout */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: } */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun36) {
                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                  ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                  /* checking for: cf */
                                                  if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                    ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                    /* checking for: sort */
                                                    if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                      ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                      /* checking for: Annotations */
                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun80) {
                                                        ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                        /* checking for: no-attrs */
                                                        if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                            ATerm arg_arg1_head;
                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                            /* checking for: appl */
                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                              /* checking for: prod */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                  /* checking for: char-class */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 123) {

                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                            /* checking for: lit */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                              /* checking for: { */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun37) {
                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                /* checking for: no-attrs */
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 123) {

                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                            /* checking for: appl */
                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                              /* checking for: list */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                /* checking for: cf */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                  /* checking for: iter-sep */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun65) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                    /* checking for: sort */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                      /* checking for: Term */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun61) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                                                                                        /* checking for: lit */
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                                                                                          /* checking for: , */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun66) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                /* checking for: appl */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                  /* checking for: prod */
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                      /* checking for: char-class */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 125) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                /* checking for: lit */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                  /* checking for: } */
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun36) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                    /* checking for: no-attrs */
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 125) {

                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                              return ATtrue;
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Annotations has a ws-after-{. 
 * \param[in] arg input MA_Annotations
 * \return ATtrue if the MA_Annotations had a ws-after-{, or ATfalse otherwise
 */
ATbool MA_hasAnnotationsWsAfterBraceOpen(MA_Annotations arg) {
  if (MA_isAnnotationsDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Annotations has a attrs. 
 * \param[in] arg input MA_Annotations
 * \return ATtrue if the MA_Annotations had a attrs, or ATfalse otherwise
 */
ATbool MA_hasAnnotationsAttrs(MA_Annotations arg) {
  if (MA_isAnnotationsDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Annotations has a ws-after-attrs. 
 * \param[in] arg input MA_Annotations
 * \return ATtrue if the MA_Annotations had a ws-after-attrs, or ATfalse otherwise
 */
ATbool MA_hasAnnotationsWsAfterAttrs(MA_Annotations arg) {
  if (MA_isAnnotationsDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-{ MA_OptLayout of a MA_Annotations. Note that the precondition is that this MA_Annotations actually has a ws-after-{
 * \param[in] arg input MA_Annotations
 * \return the ws-after-{ of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getAnnotationsWsAfterBraceOpen(MA_Annotations arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the attrs MA_TermAttrs of a MA_Annotations. Note that the precondition is that this MA_Annotations actually has a attrs
 * \param[in] arg input MA_Annotations
 * \return the attrs of #arg, if it exist or an undefined value if it does not
 */
MA_TermAttrs MA_getAnnotationsAttrs(MA_Annotations arg) {
  
    return (MA_TermAttrs)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), 1);
}

/**
 * Get the ws-after-attrs MA_OptLayout of a MA_Annotations. Note that the precondition is that this MA_Annotations actually has a ws-after-attrs
 * \param[in] arg input MA_Annotations
 * \return the ws-after-attrs of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getAnnotationsWsAfterAttrs(MA_Annotations arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the ws-after-{ of a MA_Annotations. The precondition being that this MA_Annotations actually has a ws-after-{
 * \param[in] arg input MA_Annotations
 * \param[in] wsAfterBraceOpen new MA_OptLayout to set in #arg
 * \return A new MA_Annotations with wsAfterBraceOpen at the right place, or a core dump if #arg did not have a wsAfterBraceOpen
 */
MA_Annotations MA_setAnnotationsWsAfterBraceOpen(MA_Annotations arg, MA_OptLayout wsAfterBraceOpen) {
  if (MA_isAnnotationsDefault(arg)) {
    return (MA_Annotations)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBraceOpen), 1), 1);
  }

  ATabort("Annotations has no WsAfterBraceOpen: %t\n", arg);
  return (MA_Annotations)NULL;
}

/**
 * Set the attrs of a MA_Annotations. The precondition being that this MA_Annotations actually has a attrs
 * \param[in] arg input MA_Annotations
 * \param[in] attrs new MA_TermAttrs to set in #arg
 * \return A new MA_Annotations with attrs at the right place, or a core dump if #arg did not have a attrs
 */
MA_Annotations MA_setAnnotationsAttrs(MA_Annotations arg, MA_TermAttrs attrs) {
  if (MA_isAnnotationsDefault(arg)) {
    return (MA_Annotations)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2), (ATerm)((ATerm) attrs), 1), 2), 1);
  }

  ATabort("Annotations has no Attrs: %t\n", arg);
  return (MA_Annotations)NULL;
}

/**
 * Set the ws-after-attrs of a MA_Annotations. The precondition being that this MA_Annotations actually has a ws-after-attrs
 * \param[in] arg input MA_Annotations
 * \param[in] wsAfterAttrs new MA_OptLayout to set in #arg
 * \return A new MA_Annotations with wsAfterAttrs at the right place, or a core dump if #arg did not have a wsAfterAttrs
 */
MA_Annotations MA_setAnnotationsWsAfterAttrs(MA_Annotations arg, MA_OptLayout wsAfterAttrs) {
  if (MA_isAnnotationsDefault(arg)) {
    return (MA_Annotations)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterAttrs), 3), 1);
  }

  ATabort("Annotations has no WsAfterAttrs: %t\n", arg);
  return (MA_Annotations)NULL;
}

/**
 * Assert whether a MA_SigArgList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_SigArgList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidSigArgList(MA_SigArgList arg) {
  if (MA_isSigArgListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgList is a Default by checking against the following ATerm pattern: appl(prod([cf(iter-sep(sort("SigArg"),lit(",")))],cf(sort("SigArgList")),no-attrs),[appl(list(cf(iter-sep(sort("SigArg"),lit(",")))),<"args"("SigArg-args")>)]). Always returns ATtrue
 * \param[in] arg input MA_SigArgList
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isSigArgListDefault(MA_SigArgList arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun65) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: SigArg */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun75) {
                ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                /* checking for: lit */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                  ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                  /* checking for: , */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun66) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                          /* checking for: SigArgList */
                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun84) {
                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                ATerm arg_arg1_head;
                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                /* checking for: appl */
                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                  /* checking for: list */
                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                      /* checking for: iter-sep */
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun65) {
                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                          /* checking for: SigArg */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun75) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                              /* checking for: , */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun66) {
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgList has a args. 
 * \param[in] arg input MA_SigArgList
 * \return ATtrue if the MA_SigArgList had a args, or ATfalse otherwise
 */
ATbool MA_hasSigArgListArgs(MA_SigArgList arg) {
  if (MA_isSigArgListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the args MA_SigArgArgs of a MA_SigArgList. Note that the precondition is that this MA_SigArgList actually has a args
 * \param[in] arg input MA_SigArgList
 * \return the args of #arg, if it exist or an undefined value if it does not
 */
MA_SigArgArgs MA_getSigArgListArgs(MA_SigArgList arg) {
  
    return (MA_SigArgArgs)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the args of a MA_SigArgList. The precondition being that this MA_SigArgList actually has a args
 * \param[in] arg input MA_SigArgList
 * \param[in] args new MA_SigArgArgs to set in #arg
 * \return A new MA_SigArgList with args at the right place, or a core dump if #arg did not have a args
 */
MA_SigArgList MA_setSigArgListArgs(MA_SigArgList arg, MA_SigArgArgs args) {
  if (MA_isSigArgListDefault(arg)) {
    return (MA_SigArgList)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) args), 1), 0), 1);
  }

  ATabort("SigArgList has no Args: %t\n", arg);
  return (MA_SigArgList)NULL;
}

/**
 * Assert whether a MA_FuncDefList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_FuncDefList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidFuncDefList(MA_FuncDefList arg) {
  if (MA_isFuncDefListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefList is a Default by checking against the following ATerm pattern: appl(prod([cf(iter-star-sep(sort("FuncDef"),lit(";")))],cf(sort("FuncDefList")),no-attrs),[appl(list(cf(iter-star-sep(sort("FuncDef"),lit(";")))),<"defs"("FuncDef-defs")>)]). Always returns ATtrue
 * \param[in] arg input MA_FuncDefList
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefListDefault(MA_FuncDefList arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun73) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: FuncDef */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun78) {
                ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                /* checking for: lit */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                  ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                  /* checking for: ; */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun85) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                          /* checking for: FuncDefList */
                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun86) {
                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                ATerm arg_arg1_head;
                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                /* checking for: appl */
                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                  /* checking for: list */
                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                      /* checking for: iter-star-sep */
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun73) {
                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                          /* checking for: FuncDef */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun78) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                              /* checking for: ; */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun85) {
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefList has a defs. 
 * \param[in] arg input MA_FuncDefList
 * \return ATtrue if the MA_FuncDefList had a defs, or ATfalse otherwise
 */
ATbool MA_hasFuncDefListDefs(MA_FuncDefList arg) {
  if (MA_isFuncDefListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the defs MA_FuncDefDefs of a MA_FuncDefList. Note that the precondition is that this MA_FuncDefList actually has a defs
 * \param[in] arg input MA_FuncDefList
 * \return the defs of #arg, if it exist or an undefined value if it does not
 */
MA_FuncDefDefs MA_getFuncDefListDefs(MA_FuncDefList arg) {
  
    return (MA_FuncDefDefs)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the defs of a MA_FuncDefList. The precondition being that this MA_FuncDefList actually has a defs
 * \param[in] arg input MA_FuncDefList
 * \param[in] defs new MA_FuncDefDefs to set in #arg
 * \return A new MA_FuncDefList with defs at the right place, or a core dump if #arg did not have a defs
 */
MA_FuncDefList MA_setFuncDefListDefs(MA_FuncDefList arg, MA_FuncDefDefs defs) {
  if (MA_isFuncDefListDefault(arg)) {
    return (MA_FuncDefList)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) defs), 1), 0), 1);
  }

  ATabort("FuncDefList has no Defs: %t\n", arg);
  return (MA_FuncDefList)NULL;
}

/**
 * Assert whether a MA_Rule is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_Rule
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidRule(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule is a no-conds by checking against the following ATerm pattern: appl(prod([cf(sort("Term")),cf(opt(layout)),lit("="),cf(opt(layout)),cf(sort("Term"))],cf(sort("Rule")),attrs([term(cons("no-conds"))])),[<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61])],lit("="),no-attrs),[61]),<"ws-after-is"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Rule
 * \param[in] arg input MA_Rule
 * \return ATtrue if #arg corresponds to the signature of a no-conds, or ATfalse otherwise
 */
inline ATbool MA_isRuleNoConds(MA_Rule arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Term */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: = */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun87) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: Rule */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun88) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: term */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: cons */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                            /* checking for: no-conds */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun89) {
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                  ATerm arg_arg1_head;
                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                      /* checking for: lit */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                        /* checking for: = */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun87) {
                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                          /* checking for: no-attrs */
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                        return ATtrue;
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule is a default-no-conds by checking against the following ATerm pattern: appl(prod([lit("default:"),cf(opt(layout)),cf(sort("Term")),cf(opt(layout)),lit("="),cf(opt(layout)),cf(sort("Term"))],cf(sort("Rule")),attrs([term(cons("default-no-conds"))])),[appl(prod([char-class([100]),char-class([101]),char-class([102]),char-class([97]),char-class([117]),char-class([108]),char-class([116]),char-class([58])],lit("default:"),no-attrs),[100,101,102,97,117,108,116,58]),<"ws-after-default:"("OptLayout")>,<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61])],lit("="),no-attrs),[61]),<"ws-after-is"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Rule
 * \param[in] arg input MA_Rule
 * \return ATtrue if #arg corresponds to the signature of a default-no-conds, or ATfalse otherwise
 */
inline ATbool MA_isRuleDefaultNoConds(MA_Rule arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: default: */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun90) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: Term */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: = */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun87) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: cf */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: sort */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                        /* checking for: Term */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                            /* checking for: cf */
                                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                              /* checking for: sort */
                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                /* checking for: Rule */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun88) {
                                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                  /* checking for: attrs */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                      ATerm arg_arg0_arg2_arg0_head;
                                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                      /* checking for: term */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                        /* checking for: cons */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                          /* checking for: default-no-conds */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun91) {
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                ATerm arg_arg1_head;
                                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                /* checking for: appl */
                                                                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                  /* checking for: prod */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                    /* checking for: char-class */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                        /* checking for: char-class */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                        /* checking for: default: */
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun90) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                      /* checking for: appl */
                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                        /* checking for: prod */
                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                      /* checking for: lit */
                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                        /* checking for: = */
                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun87) {
                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                          /* checking for: no-attrs */
                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                        return ATtrue;
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule is a with-conds by checking against the following ATerm pattern: appl(prod([cf(sort("CondList")),cf(opt(layout)),lit("==>"),cf(opt(layout)),cf(sort("Term")),cf(opt(layout)),lit("="),cf(opt(layout)),cf(sort("Term"))],cf(sort("Rule")),attrs([term(cons("with-conds"))])),[<"conds"("CondList")>,<"ws-after-conds"("OptLayout")>,appl(prod([char-class([61]),char-class([61]),char-class([62])],lit("==>"),no-attrs),[61,61,62]),<"ws-after-==>"("OptLayout")>,<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61])],lit("="),no-attrs),[61]),<"ws-after-is"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Rule
 * \param[in] arg input MA_Rule
 * \return ATtrue if #arg corresponds to the signature of a with-conds, or ATfalse otherwise
 */
inline ATbool MA_isRuleWithConds(MA_Rule arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: CondList */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun93) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: ==> */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun92) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: lit */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: = */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun87) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                            /* checking for: cf */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                              /* checking for: opt */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                /* checking for: layout */
                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                    /* checking for: cf */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                      /* checking for: sort */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                        /* checking for: Term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                            ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                            /* checking for: cf */
                                                                            if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                              ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                              /* checking for: sort */
                                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                                ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                /* checking for: Rule */
                                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun88) {
                                                                                  ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                  /* checking for: attrs */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                                    ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                      ATerm arg_arg0_arg2_arg0_head;
                                                                                      ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                      arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                      arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                      /* checking for: term */
                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                                        ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                        /* checking for: cons */
                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                          ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                          /* checking for: with-conds */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun94) {
                                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                ATerm arg_arg1_head;
                                                                                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                    /* checking for: appl */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                      /* checking for: prod */
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                    /* checking for: char-class */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 62) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                        /* checking for: lit */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                          /* checking for: ==> */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun92) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 62) {

                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                      /* checking for: = */
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun87) {
                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                      return ATtrue;
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule is a default-with-conds by checking against the following ATerm pattern: appl(prod([lit("default:"),cf(opt(layout)),cf(sort("CondList")),cf(opt(layout)),lit("==>"),cf(opt(layout)),cf(sort("Term")),cf(opt(layout)),lit("="),cf(opt(layout)),cf(sort("Term"))],cf(sort("Rule")),attrs([term(cons("default-with-conds"))])),[appl(prod([char-class([100]),char-class([101]),char-class([102]),char-class([97]),char-class([117]),char-class([108]),char-class([116]),char-class([58])],lit("default:"),no-attrs),[100,101,102,97,117,108,116,58]),<"ws-after-default:"("OptLayout")>,<"conds"("CondList")>,<"ws-after-conds"("OptLayout")>,appl(prod([char-class([61]),char-class([61]),char-class([62])],lit("==>"),no-attrs),[61,61,62]),<"ws-after-==>"("OptLayout")>,<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61])],lit("="),no-attrs),[61]),<"ws-after-is"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Rule
 * \param[in] arg input MA_Rule
 * \return ATtrue if #arg corresponds to the signature of a default-with-conds, or ATfalse otherwise
 */
inline ATbool MA_isRuleDefaultWithConds(MA_Rule arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: default: */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun90) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: CondList */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun93) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: lit */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: ==> */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun92) {
                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                            /* checking for: cf */
                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                              /* checking for: opt */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                /* checking for: layout */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                    /* checking for: cf */
                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                      /* checking for: sort */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                        ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                        /* checking for: Term */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                            /* checking for: cf */
                                                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                              /* checking for: opt */
                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                                ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                /* checking for: layout */
                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                    arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                    arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                    /* checking for: lit */
                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                                                                      ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                      /* checking for: = */
                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun87) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                          /* checking for: cf */
                                                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                            /* checking for: opt */
                                                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                                              ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                              /* checking for: layout */
                                                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                                                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                                                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                                                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                                                  /* checking for: cf */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                                                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                                                    /* checking for: sort */
                                                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                                                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                                                      /* checking for: Term */
                                                                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                                                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                                          /* checking for: cf */
                                                                                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                                            /* checking for: sort */
                                                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                                              /* checking for: Rule */
                                                                                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun88) {
                                                                                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                                                /* checking for: attrs */
                                                                                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg0_arg2_arg0_head;
                                                                                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                                                    /* checking for: term */
                                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                                      /* checking for: cons */
                                                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                                        /* checking for: default-with-conds */
                                                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun95) {
                                                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                                              ATerm arg_arg1_head;
                                                                                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                              /* checking for: appl */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                /* checking for: prod */
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                    ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                    /* checking for: char-class */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                        /* checking for: char-class */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 102) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                  /* checking for: char-class */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                            /* checking for: char-class */
                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                      /* checking for: char-class */
                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                /* checking for: char-class */
                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                      /* checking for: default: */
                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun90) {
                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 102) {

                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                    /* checking for: char-class */
                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                              /* checking for: char-class */
                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 62) {

                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                        /* checking for: lit */
                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                          /* checking for: ==> */
                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun92) {
                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                            /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 62) {

                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                    arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                    /* checking for: appl */
                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                                                                                                                                                                                                                                                      /* checking for: prod */
                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head;
                                                                                                                                                                                                                                                                                                                          ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                                                                                                                                                                                                          /* checking for: char-class */
                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                                                                                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                                                                                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                                                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                                                                                                                                                                                                    /* checking for: lit */
                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                                                                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                                                                                                                                                                                                      /* checking for: = */
                                                                                                                                                                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun87) {
                                                                                                                                                                                                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                                                                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                                                                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                                                                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                                                                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                                                                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                                                                                                                                                                      return ATtrue;
                                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                                }
                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                      }
                                                                                                                                                                                                                                    }
                                                                                                                                                                                                                                  }
                                                                                                                                                                                                                                }
                                                                                                                                                                                                                              }
                                                                                                                                                                                                                            }
                                                                                                                                                                                                                          }
                                                                                                                                                                                                                        }
                                                                                                                                                                                                                      }
                                                                                                                                                                                                                    }
                                                                                                                                                                                                                  }
                                                                                                                                                                                                                }
                                                                                                                                                                                                              }
                                                                                                                                                                                                            }
                                                                                                                                                                                                          }
                                                                                                                                                                                                        }
                                                                                                                                                                                                      }
                                                                                                                                                                                                    }
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a lhs. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a lhs, or ATfalse otherwise
 */
ATbool MA_hasRuleLhs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a ws-after-lhs. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a ws-after-lhs, or ATfalse otherwise
 */
ATbool MA_hasRuleWsAfterLhs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a ws-after-is. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a ws-after-is, or ATfalse otherwise
 */
ATbool MA_hasRuleWsAfterIs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a rhs. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a rhs, or ATfalse otherwise
 */
ATbool MA_hasRuleRhs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a ws-after-default:. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a ws-after-default:, or ATfalse otherwise
 */
ATbool MA_hasRuleWsAfterDefaultColon(MA_Rule arg) {
  if (MA_isRuleDefaultNoConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a conds. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a conds, or ATfalse otherwise
 */
ATbool MA_hasRuleConds(MA_Rule arg) {
  if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a ws-after-conds. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a ws-after-conds, or ATfalse otherwise
 */
ATbool MA_hasRuleWsAfterConds(MA_Rule arg) {
  if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Rule has a ws-after-==>. 
 * \param[in] arg input MA_Rule
 * \return ATtrue if the MA_Rule had a ws-after-==>, or ATfalse otherwise
 */
ATbool MA_hasRuleWsAfterEqualsEqualsGreaterThan(MA_Rule arg) {
  if (MA_isRuleWithConds(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the lhs MA_Term of a MA_Rule. Note that the precondition is that this MA_Rule actually has a lhs
 * \param[in] arg input MA_Rule
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getRuleLhs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_Term)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
}

/**
 * Get the ws-after-lhs MA_OptLayout of a MA_Rule. Note that the precondition is that this MA_Rule actually has a ws-after-lhs
 * \param[in] arg input MA_Rule
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleWsAfterLhs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
}

/**
 * Get the ws-after-is MA_OptLayout of a MA_Rule. Note that the precondition is that this MA_Rule actually has a ws-after-is
 * \param[in] arg input MA_Rule
 * \return the ws-after-is of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleWsAfterIs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 7);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 9);
}

/**
 * Get the rhs MA_Term of a MA_Rule. Note that the precondition is that this MA_Rule actually has a rhs
 * \param[in] arg input MA_Rule
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getRuleRhs(MA_Rule arg) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 8);
  }
  else 
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 10);
}

/**
 * Get the ws-after-default: MA_OptLayout of a MA_Rule. Note that the precondition is that this MA_Rule actually has a ws-after-default:
 * \param[in] arg input MA_Rule
 * \return the ws-after-default: of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleWsAfterDefaultColon(MA_Rule arg) {
  if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the conds MA_CondList of a MA_Rule. Note that the precondition is that this MA_Rule actually has a conds
 * \param[in] arg input MA_Rule
 * \return the conds of #arg, if it exist or an undefined value if it does not
 */
MA_CondList MA_getRuleConds(MA_Rule arg) {
  if (MA_isRuleWithConds(arg)) {
    return (MA_CondList)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (MA_CondList)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-conds MA_OptLayout of a MA_Rule. Note that the precondition is that this MA_Rule actually has a ws-after-conds
 * \param[in] arg input MA_Rule
 * \return the ws-after-conds of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleWsAfterConds(MA_Rule arg) {
  if (MA_isRuleWithConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-==> MA_OptLayout of a MA_Rule. Note that the precondition is that this MA_Rule actually has a ws-after-==>
 * \param[in] arg input MA_Rule
 * \return the ws-after-==> of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleWsAfterEqualsEqualsGreaterThan(MA_Rule arg) {
  if (MA_isRuleWithConds(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Set the lhs of a MA_Rule. The precondition being that this MA_Rule actually has a lhs
 * \param[in] arg input MA_Rule
 * \param[in] lhs new MA_Term to set in #arg
 * \return A new MA_Rule with lhs at the right place, or a core dump if #arg did not have a lhs
 */
MA_Rule MA_setRuleLhs(MA_Rule arg, MA_Term lhs) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 2), 1);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 4), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 6), 1);
  }

  ATabort("Rule has no Lhs: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the ws-after-lhs of a MA_Rule. The precondition being that this MA_Rule actually has a ws-after-lhs
 * \param[in] arg input MA_Rule
 * \param[in] wsAfterLhs new MA_OptLayout to set in #arg
 * \return A new MA_Rule with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
MA_Rule MA_setRuleWsAfterLhs(MA_Rule arg, MA_OptLayout wsAfterLhs) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 3), 1);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 5), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 7), 1);
  }

  ATabort("Rule has no WsAfterLhs: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the ws-after-is of a MA_Rule. The precondition being that this MA_Rule actually has a ws-after-is
 * \param[in] arg input MA_Rule
 * \param[in] wsAfterIs new MA_OptLayout to set in #arg
 * \return A new MA_Rule with wsAfterIs at the right place, or a core dump if #arg did not have a wsAfterIs
 */
MA_Rule MA_setRuleWsAfterIs(MA_Rule arg, MA_OptLayout wsAfterIs) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIs), 3), 1);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIs), 5), 1);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIs), 7), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterIs), 9), 1);
  }

  ATabort("Rule has no WsAfterIs: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the rhs of a MA_Rule. The precondition being that this MA_Rule actually has a rhs
 * \param[in] arg input MA_Rule
 * \param[in] rhs new MA_Term to set in #arg
 * \return A new MA_Rule with rhs at the right place, or a core dump if #arg did not have a rhs
 */
MA_Rule MA_setRuleRhs(MA_Rule arg, MA_Term rhs) {
  if (MA_isRuleNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 6), 1);
  }
  else if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 8), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 10), 1);
  }

  ATabort("Rule has no Rhs: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the ws-after-default: of a MA_Rule. The precondition being that this MA_Rule actually has a ws-after-default:
 * \param[in] arg input MA_Rule
 * \param[in] wsAfterDefaultColon new MA_OptLayout to set in #arg
 * \return A new MA_Rule with wsAfterDefaultColon at the right place, or a core dump if #arg did not have a wsAfterDefaultColon
 */
MA_Rule MA_setRuleWsAfterDefaultColon(MA_Rule arg, MA_OptLayout wsAfterDefaultColon) {
  if (MA_isRuleDefaultNoConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterDefaultColon), 1), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterDefaultColon), 1), 1);
  }

  ATabort("Rule has no WsAfterDefaultColon: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the conds of a MA_Rule. The precondition being that this MA_Rule actually has a conds
 * \param[in] arg input MA_Rule
 * \param[in] conds new MA_CondList to set in #arg
 * \return A new MA_Rule with conds at the right place, or a core dump if #arg did not have a conds
 */
MA_Rule MA_setRuleConds(MA_Rule arg, MA_CondList conds) {
  if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) conds), 0), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) conds), 2), 1);
  }

  ATabort("Rule has no Conds: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the ws-after-conds of a MA_Rule. The precondition being that this MA_Rule actually has a ws-after-conds
 * \param[in] arg input MA_Rule
 * \param[in] wsAfterConds new MA_OptLayout to set in #arg
 * \return A new MA_Rule with wsAfterConds at the right place, or a core dump if #arg did not have a wsAfterConds
 */
MA_Rule MA_setRuleWsAfterConds(MA_Rule arg, MA_OptLayout wsAfterConds) {
  if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterConds), 1), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterConds), 3), 1);
  }

  ATabort("Rule has no WsAfterConds: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Set the ws-after-==> of a MA_Rule. The precondition being that this MA_Rule actually has a ws-after-==>
 * \param[in] arg input MA_Rule
 * \param[in] wsAfterEqualsEqualsGreaterThan new MA_OptLayout to set in #arg
 * \return A new MA_Rule with wsAfterEqualsEqualsGreaterThan at the right place, or a core dump if #arg did not have a wsAfterEqualsEqualsGreaterThan
 */
MA_Rule MA_setRuleWsAfterEqualsEqualsGreaterThan(MA_Rule arg, MA_OptLayout wsAfterEqualsEqualsGreaterThan) {
  if (MA_isRuleWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEqualsEqualsGreaterThan), 3), 1);
  }
  else if (MA_isRuleDefaultWithConds(arg)) {
    return (MA_Rule)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEqualsEqualsGreaterThan), 5), 1);
  }

  ATabort("Rule has no WsAfterEqualsEqualsGreaterThan: %t\n", arg);
  return (MA_Rule)NULL;
}

/**
 * Assert whether a MA_RuleList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_RuleList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidRuleList(MA_RuleList arg) {
  if (MA_isRuleListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleList is a Default by checking against the following ATerm pattern: appl(prod([cf(iter-star-sep(sort("Rule"),lit(";")))],cf(sort("RuleList")),no-attrs),[appl(list(cf(iter-star-sep(sort("Rule"),lit(";")))),<"rules"("Rule-rules")>)]). Always returns ATtrue
 * \param[in] arg input MA_RuleList
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isRuleListDefault(MA_RuleList arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun73) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: Rule */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun88) {
                ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                /* checking for: lit */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                  ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                  /* checking for: ; */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun85) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                          /* checking for: RuleList */
                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun96) {
                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                ATerm arg_arg1_head;
                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                /* checking for: appl */
                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                  /* checking for: list */
                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                      /* checking for: iter-star-sep */
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun73) {
                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                          /* checking for: Rule */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun88) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                              /* checking for: ; */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun85) {
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleList has a rules. 
 * \param[in] arg input MA_RuleList
 * \return ATtrue if the MA_RuleList had a rules, or ATfalse otherwise
 */
ATbool MA_hasRuleListRules(MA_RuleList arg) {
  if (MA_isRuleListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the rules MA_RuleRules of a MA_RuleList. Note that the precondition is that this MA_RuleList actually has a rules
 * \param[in] arg input MA_RuleList
 * \return the rules of #arg, if it exist or an undefined value if it does not
 */
MA_RuleRules MA_getRuleListRules(MA_RuleList arg) {
  
    return (MA_RuleRules)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the rules of a MA_RuleList. The precondition being that this MA_RuleList actually has a rules
 * \param[in] arg input MA_RuleList
 * \param[in] rules new MA_RuleRules to set in #arg
 * \return A new MA_RuleList with rules at the right place, or a core dump if #arg did not have a rules
 */
MA_RuleList MA_setRuleListRules(MA_RuleList arg, MA_RuleRules rules) {
  if (MA_isRuleListDefault(arg)) {
    return (MA_RuleList)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) rules), 1), 0), 1);
  }

  ATabort("RuleList has no Rules: %t\n", arg);
  return (MA_RuleList)NULL;
}

/**
 * Assert whether a MA_CondList is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_CondList
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidCondList(MA_CondList arg) {
  if (MA_isCondListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondList is a Default by checking against the following ATerm pattern: appl(prod([cf(iter-star-sep(sort("Cond"),lit("&")))],cf(sort("CondList")),no-attrs),[appl(list(cf(iter-star-sep(sort("Cond"),lit("&")))),<"conds"("Cond-conds")>)]). Always returns ATtrue
 * \param[in] arg input MA_CondList
 * \return ATtrue if #arg corresponds to the signature of a Default, or ATfalse otherwise
 */
inline ATbool MA_isCondListDefault(MA_CondList arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter-star-sep */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun73) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: sort */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              /* checking for: Cond */
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun97) {
                ATerm arg_arg0_arg0_head_arg0_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0, 1);
                /* checking for: lit */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1) == MA_afun9) {
                  ATerm arg_arg0_arg0_head_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg1, 0);
                  /* checking for: & */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg1_arg0) == MA_afun98) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                          /* checking for: CondList */
                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun93) {
                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                              ATerm arg_arg1 = ATgetArgument(arg, 1);
                              if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                ATerm arg_arg1_head;
                                ATermList arg_arg1_list = (ATermList)arg_arg1;
                                arg_arg1_head = ATgetFirst(arg_arg1_list);
                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                /* checking for: appl */
                                if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                  ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                  /* checking for: list */
                                  if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                    ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                    /* checking for: cf */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun2) {
                                      ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                      /* checking for: iter-star-sep */
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun73) {
                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                          /* checking for: Cond */
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun97) {
                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 1);
                                            /* checking for: lit */
                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1) == MA_afun9) {
                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg1, 0);
                                              /* checking for: & */
                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg1_arg0) == MA_afun98) {
                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                  return ATtrue;
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondList has a conds. 
 * \param[in] arg input MA_CondList
 * \return ATtrue if the MA_CondList had a conds, or ATfalse otherwise
 */
ATbool MA_hasCondListConds(MA_CondList arg) {
  if (MA_isCondListDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the conds MA_CondConds of a MA_CondList. Note that the precondition is that this MA_CondList actually has a conds
 * \param[in] arg input MA_CondList
 * \return the conds of #arg, if it exist or an undefined value if it does not
 */
MA_CondConds MA_getCondListConds(MA_CondList arg) {
  
    return (MA_CondConds)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1);
}

/**
 * Set the conds of a MA_CondList. The precondition being that this MA_CondList actually has a conds
 * \param[in] arg input MA_CondList
 * \param[in] conds new MA_CondConds to set in #arg
 * \return A new MA_CondList with conds at the right place, or a core dump if #arg did not have a conds
 */
MA_CondList MA_setCondListConds(MA_CondList arg, MA_CondConds conds) {
  if (MA_isCondListDefault(arg)) {
    return (MA_CondList)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) conds), 1), 0), 1);
  }

  ATabort("CondList has no Conds: %t\n", arg);
  return (MA_CondList)NULL;
}

/**
 * Assert whether a MA_Cond is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_Cond
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidCond(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondNoAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondEqual(arg)) {
    return ATtrue;
  }
  else if (MA_isCondUnequal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond is a assign by checking against the following ATerm pattern: appl(prod([cf(sort("Term")),cf(opt(layout)),lit("=:"),cf(opt(layout)),cf(sort("Term"))],cf(sort("Cond")),attrs([term(cons("assign"))])),[<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61]),char-class([58])],lit("=:"),no-attrs),[61,58]),<"ws-after-becomes"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Cond
 * \param[in] arg input MA_Cond
 * \return ATtrue if #arg corresponds to the signature of a assign, or ATfalse otherwise
 */
inline ATbool MA_isCondAssign(MA_Cond arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Term */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: =: */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun99) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: Cond */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun97) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: term */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: cons */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                            /* checking for: assign */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun100) {
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                  ATerm arg_arg1_head;
                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: =: */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun99) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                      return ATtrue;
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond is a no-assign by checking against the following ATerm pattern: appl(prod([cf(sort("Term")),cf(opt(layout)),lit("=:!"),cf(opt(layout)),cf(sort("Term"))],cf(sort("Cond")),attrs([term(cons("no-assign"))])),[<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61]),char-class([58]),char-class([33])],lit("=:!"),no-attrs),[61,58,33]),<"ws-after-not-becomes"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Cond
 * \param[in] arg input MA_Cond
 * \return ATtrue if #arg corresponds to the signature of a no-assign, or ATfalse otherwise
 */
inline ATbool MA_isCondNoAssign(MA_Cond arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Term */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: =:! */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun101) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: Cond */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun97) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: term */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: cons */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                            /* checking for: no-assign */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun102) {
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                  ATerm arg_arg1_head;
                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 58) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 33) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                          /* checking for: lit */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                            /* checking for: =:! */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun101) {
                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                              /* checking for: no-attrs */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 58) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 33) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                    return ATtrue;
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond is a equal by checking against the following ATerm pattern: appl(prod([cf(sort("Term")),cf(opt(layout)),lit("=="),cf(opt(layout)),cf(sort("Term"))],cf(sort("Cond")),attrs([term(cons("equal"))])),[<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([61]),char-class([61])],lit("=="),no-attrs),[61,61]),<"ws-after-equals"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Cond
 * \param[in] arg input MA_Cond
 * \return ATtrue if #arg corresponds to the signature of a equal, or ATfalse otherwise
 */
inline ATbool MA_isCondEqual(MA_Cond arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Term */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: == */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun103) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: Cond */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun97) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: term */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: cons */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                            /* checking for: equal */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun104) {
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                  ATerm arg_arg1_head;
                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: == */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun103) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                      return ATtrue;
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond is a unequal by checking against the following ATerm pattern: appl(prod([cf(sort("Term")),cf(opt(layout)),lit("!="),cf(opt(layout)),cf(sort("Term"))],cf(sort("Cond")),attrs([term(cons("unequal"))])),[<"lhs"("Term")>,<"ws-after-lhs"("OptLayout")>,appl(prod([char-class([33]),char-class([61])],lit("!="),no-attrs),[33,61]),<"ws-after-not-equals"("OptLayout")>,<"rhs"("Term")>]). May not be used to assert correctness of the MA_Cond
 * \param[in] arg input MA_Cond
 * \return ATtrue if #arg corresponds to the signature of a unequal, or ATfalse otherwise
 */
inline ATbool MA_isCondUnequal(MA_Cond arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: Term */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                  ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                  /* checking for: opt */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                    ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                    /* checking for: layout */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
                          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                          /* checking for: != */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun105) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: Term */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun61) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                /* checking for: sort */
                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                  /* checking for: Cond */
                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun97) {
                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                    /* checking for: attrs */
                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                        ATerm arg_arg0_arg2_arg0_head;
                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                        /* checking for: term */
                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                          /* checking for: cons */
                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                            /* checking for: unequal */
                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun106) {
                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                  ATerm arg_arg1_head;
                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                      arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                      /* checking for: appl */
                                                                      if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                        ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                        /* checking for: prod */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                          ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                            ATerm arg_arg1_head_arg0_arg0_head;
                                                                            ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 33) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 61) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                /* checking for: lit */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                  ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                  /* checking for: != */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun105) {
                                                                                                    ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                    /* checking for: no-attrs */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                      ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg1_head;
                                                                                                        ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 33) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 61) {

                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                    arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                      return ATtrue;
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a lhs. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a lhs, or ATfalse otherwise
 */
ATbool MA_hasCondLhs(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondNoAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondEqual(arg)) {
    return ATtrue;
  }
  else if (MA_isCondUnequal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a ws-after-lhs. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a ws-after-lhs, or ATfalse otherwise
 */
ATbool MA_hasCondWsAfterLhs(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondNoAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondEqual(arg)) {
    return ATtrue;
  }
  else if (MA_isCondUnequal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a ws-after-becomes. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a ws-after-becomes, or ATfalse otherwise
 */
ATbool MA_hasCondWsAfterBecomes(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a rhs. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a rhs, or ATfalse otherwise
 */
ATbool MA_hasCondRhs(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondNoAssign(arg)) {
    return ATtrue;
  }
  else if (MA_isCondEqual(arg)) {
    return ATtrue;
  }
  else if (MA_isCondUnequal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a ws-after-not-becomes. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a ws-after-not-becomes, or ATfalse otherwise
 */
ATbool MA_hasCondWsAfterNotBecomes(MA_Cond arg) {
  if (MA_isCondNoAssign(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a ws-after-equals. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a ws-after-equals, or ATfalse otherwise
 */
ATbool MA_hasCondWsAfterEquals(MA_Cond arg) {
  if (MA_isCondEqual(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Cond has a ws-after-not-equals. 
 * \param[in] arg input MA_Cond
 * \return ATtrue if the MA_Cond had a ws-after-not-equals, or ATfalse otherwise
 */
ATbool MA_hasCondWsAfterNotEquals(MA_Cond arg) {
  if (MA_isCondUnequal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the lhs MA_Term of a MA_Cond. Note that the precondition is that this MA_Cond actually has a lhs
 * \param[in] arg input MA_Cond
 * \return the lhs of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getCondLhs(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return (MA_Term)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (MA_isCondNoAssign(arg)) {
    return (MA_Term)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else if (MA_isCondEqual(arg)) {
    return (MA_Term)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
  }
  else 
    return (MA_Term)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Get the ws-after-lhs MA_OptLayout of a MA_Cond. Note that the precondition is that this MA_Cond actually has a ws-after-lhs
 * \param[in] arg input MA_Cond
 * \return the ws-after-lhs of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondWsAfterLhs(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (MA_isCondNoAssign(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else if (MA_isCondEqual(arg)) {
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
  }
  else 
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ws-after-becomes MA_OptLayout of a MA_Cond. Note that the precondition is that this MA_Cond actually has a ws-after-becomes
 * \param[in] arg input MA_Cond
 * \return the ws-after-becomes of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondWsAfterBecomes(MA_Cond arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the rhs MA_Term of a MA_Cond. Note that the precondition is that this MA_Cond actually has a rhs
 * \param[in] arg input MA_Cond
 * \return the rhs of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getCondRhs(MA_Cond arg) {
  if (MA_isCondAssign(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (MA_isCondNoAssign(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else if (MA_isCondEqual(arg)) {
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
  }
  else 
    return (MA_Term)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-not-becomes MA_OptLayout of a MA_Cond. Note that the precondition is that this MA_Cond actually has a ws-after-not-becomes
 * \param[in] arg input MA_Cond
 * \return the ws-after-not-becomes of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondWsAfterNotBecomes(MA_Cond arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-equals MA_OptLayout of a MA_Cond. Note that the precondition is that this MA_Cond actually has a ws-after-equals
 * \param[in] arg input MA_Cond
 * \return the ws-after-equals of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondWsAfterEquals(MA_Cond arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the ws-after-not-equals MA_OptLayout of a MA_Cond. Note that the precondition is that this MA_Cond actually has a ws-after-not-equals
 * \param[in] arg input MA_Cond
 * \return the ws-after-not-equals of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondWsAfterNotEquals(MA_Cond arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Set the lhs of a MA_Cond. The precondition being that this MA_Cond actually has a lhs
 * \param[in] arg input MA_Cond
 * \param[in] lhs new MA_Term to set in #arg
 * \return A new MA_Cond with lhs at the right place, or a core dump if #arg did not have a lhs
 */
MA_Cond MA_setCondLhs(MA_Cond arg, MA_Term lhs) {
  if (MA_isCondAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (MA_isCondNoAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (MA_isCondEqual(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }
  else if (MA_isCondUnequal(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) lhs), 0), 1);
  }

  ATabort("Cond has no Lhs: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Set the ws-after-lhs of a MA_Cond. The precondition being that this MA_Cond actually has a ws-after-lhs
 * \param[in] arg input MA_Cond
 * \param[in] wsAfterLhs new MA_OptLayout to set in #arg
 * \return A new MA_Cond with wsAfterLhs at the right place, or a core dump if #arg did not have a wsAfterLhs
 */
MA_Cond MA_setCondWsAfterLhs(MA_Cond arg, MA_OptLayout wsAfterLhs) {
  if (MA_isCondAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (MA_isCondNoAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (MA_isCondEqual(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }
  else if (MA_isCondUnequal(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterLhs), 1), 1);
  }

  ATabort("Cond has no WsAfterLhs: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Set the ws-after-becomes of a MA_Cond. The precondition being that this MA_Cond actually has a ws-after-becomes
 * \param[in] arg input MA_Cond
 * \param[in] wsAfterBecomes new MA_OptLayout to set in #arg
 * \return A new MA_Cond with wsAfterBecomes at the right place, or a core dump if #arg did not have a wsAfterBecomes
 */
MA_Cond MA_setCondWsAfterBecomes(MA_Cond arg, MA_OptLayout wsAfterBecomes) {
  if (MA_isCondAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterBecomes), 3), 1);
  }

  ATabort("Cond has no WsAfterBecomes: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Set the rhs of a MA_Cond. The precondition being that this MA_Cond actually has a rhs
 * \param[in] arg input MA_Cond
 * \param[in] rhs new MA_Term to set in #arg
 * \return A new MA_Cond with rhs at the right place, or a core dump if #arg did not have a rhs
 */
MA_Cond MA_setCondRhs(MA_Cond arg, MA_Term rhs) {
  if (MA_isCondAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (MA_isCondNoAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (MA_isCondEqual(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }
  else if (MA_isCondUnequal(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) rhs), 4), 1);
  }

  ATabort("Cond has no Rhs: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Set the ws-after-not-becomes of a MA_Cond. The precondition being that this MA_Cond actually has a ws-after-not-becomes
 * \param[in] arg input MA_Cond
 * \param[in] wsAfterNotBecomes new MA_OptLayout to set in #arg
 * \return A new MA_Cond with wsAfterNotBecomes at the right place, or a core dump if #arg did not have a wsAfterNotBecomes
 */
MA_Cond MA_setCondWsAfterNotBecomes(MA_Cond arg, MA_OptLayout wsAfterNotBecomes) {
  if (MA_isCondNoAssign(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterNotBecomes), 3), 1);
  }

  ATabort("Cond has no WsAfterNotBecomes: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Set the ws-after-equals of a MA_Cond. The precondition being that this MA_Cond actually has a ws-after-equals
 * \param[in] arg input MA_Cond
 * \param[in] wsAfterEquals new MA_OptLayout to set in #arg
 * \return A new MA_Cond with wsAfterEquals at the right place, or a core dump if #arg did not have a wsAfterEquals
 */
MA_Cond MA_setCondWsAfterEquals(MA_Cond arg, MA_OptLayout wsAfterEquals) {
  if (MA_isCondEqual(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterEquals), 3), 1);
  }

  ATabort("Cond has no WsAfterEquals: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Set the ws-after-not-equals of a MA_Cond. The precondition being that this MA_Cond actually has a ws-after-not-equals
 * \param[in] arg input MA_Cond
 * \param[in] wsAfterNotEquals new MA_OptLayout to set in #arg
 * \return A new MA_Cond with wsAfterNotEquals at the right place, or a core dump if #arg did not have a wsAfterNotEquals
 */
MA_Cond MA_setCondWsAfterNotEquals(MA_Cond arg, MA_OptLayout wsAfterNotEquals) {
  if (MA_isCondUnequal(arg)) {
    return (MA_Cond)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterNotEquals), 3), 1);
  }

  ATabort("Cond has no WsAfterNotEquals: %t\n", arg);
  return (MA_Cond)NULL;
}

/**
 * Assert whether a MA_SignatureOpt is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_SignatureOpt
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidSignatureOpt(MA_SignatureOpt arg) {
  if (MA_isSignatureOptAbsent(arg)) {
    return ATtrue;
  }
  else if (MA_isSignatureOptPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SignatureOpt is a absent by checking against the following ATerm pattern: appl(prod([],cf(sort("SignatureOpt")),attrs([term(cons("absent"))])),[]). May not be used to assert correctness of the MA_SignatureOpt
 * \param[in] arg input MA_SignatureOpt
 * \return ATtrue if #arg corresponds to the signature of a absent, or ATfalse otherwise
 */
inline ATbool MA_isSignatureOptAbsent(MA_SignatureOpt arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: SignatureOpt */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun107) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                  ATerm arg_arg0_arg2_arg0_head;
                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                  /* checking for: term */
                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                    /* checking for: cons */
                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                      /* checking for: absent */
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun108) {
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                          if (ATisEmpty((ATermList)arg_arg1)) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SignatureOpt is a present by checking against the following ATerm pattern: appl(prod([lit("signature"),cf(opt(layout)),cf(sort("FuncDefList"))],cf(sort("SignatureOpt")),attrs([term(cons("present"))])),[appl(prod([char-class([115]),char-class([105]),char-class([103]),char-class([110]),char-class([97]),char-class([116]),char-class([117]),char-class([114]),char-class([101])],lit("signature"),no-attrs),[115,105,103,110,97,116,117,114,101]),<"ws-after-signature"("OptLayout")>,<"FuncDefList"("FuncDefList")>]). May not be used to assert correctness of the MA_SignatureOpt
 * \param[in] arg input MA_SignatureOpt
 * \return ATtrue if #arg corresponds to the signature of a present, or ATfalse otherwise
 */
inline ATbool MA_isSignatureOptPresent(MA_SignatureOpt arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: signature */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun109) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: FuncDefList */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun86) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: SignatureOpt */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun107) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: present */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun110) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                  /* checking for: char-class */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 105) {

                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 103) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 97) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                          /* checking for: char-class */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                    /* checking for: char-class */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                        ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                              arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                              /* checking for: char-class */
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                  ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                        /* checking for: char-class */
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                  ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                  /* checking for: lit */
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                    /* checking for: signature */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun109) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                      /* checking for: no-attrs */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                        ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                          ATerm arg_arg1_head_arg1_head;
                                                                                                                                                          ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 105) {

                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 103) {

                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 97) {

                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                    return ATtrue;
                                                                                                                                                                                                  }
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SignatureOpt has a ws-after-signature. 
 * \param[in] arg input MA_SignatureOpt
 * \return ATtrue if the MA_SignatureOpt had a ws-after-signature, or ATfalse otherwise
 */
ATbool MA_hasSignatureOptWsAfterSignature(MA_SignatureOpt arg) {
  if (MA_isSignatureOptPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SignatureOpt has a FuncDefList. 
 * \param[in] arg input MA_SignatureOpt
 * \return ATtrue if the MA_SignatureOpt had a FuncDefList, or ATfalse otherwise
 */
ATbool MA_hasSignatureOptFuncDefList(MA_SignatureOpt arg) {
  if (MA_isSignatureOptPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-signature MA_OptLayout of a MA_SignatureOpt. Note that the precondition is that this MA_SignatureOpt actually has a ws-after-signature
 * \param[in] arg input MA_SignatureOpt
 * \return the ws-after-signature of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getSignatureOptWsAfterSignature(MA_SignatureOpt arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the FuncDefList MA_FuncDefList of a MA_SignatureOpt. Note that the precondition is that this MA_SignatureOpt actually has a FuncDefList
 * \param[in] arg input MA_SignatureOpt
 * \return the FuncDefList of #arg, if it exist or an undefined value if it does not
 */
MA_FuncDefList MA_getSignatureOptFuncDefList(MA_SignatureOpt arg) {
  
    return (MA_FuncDefList)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Set the ws-after-signature of a MA_SignatureOpt. The precondition being that this MA_SignatureOpt actually has a ws-after-signature
 * \param[in] arg input MA_SignatureOpt
 * \param[in] wsAfterSignature new MA_OptLayout to set in #arg
 * \return A new MA_SignatureOpt with wsAfterSignature at the right place, or a core dump if #arg did not have a wsAfterSignature
 */
MA_SignatureOpt MA_setSignatureOptWsAfterSignature(MA_SignatureOpt arg, MA_OptLayout wsAfterSignature) {
  if (MA_isSignatureOptPresent(arg)) {
    return (MA_SignatureOpt)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSignature), 1), 1);
  }

  ATabort("SignatureOpt has no WsAfterSignature: %t\n", arg);
  return (MA_SignatureOpt)NULL;
}

/**
 * Set the FuncDefList of a MA_SignatureOpt. The precondition being that this MA_SignatureOpt actually has a FuncDefList
 * \param[in] arg input MA_SignatureOpt
 * \param[in] FuncDefList new MA_FuncDefList to set in #arg
 * \return A new MA_SignatureOpt with FuncDefList at the right place, or a core dump if #arg did not have a FuncDefList
 */
MA_SignatureOpt MA_setSignatureOptFuncDefList(MA_SignatureOpt arg, MA_FuncDefList FuncDefList) {
  if (MA_isSignatureOptPresent(arg)) {
    return (MA_SignatureOpt)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) FuncDefList), 2), 1);
  }

  ATabort("SignatureOpt has no FuncDefList: %t\n", arg);
  return (MA_SignatureOpt)NULL;
}

/**
 * Assert whether a MA_RulesOpt is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_RulesOpt
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidRulesOpt(MA_RulesOpt arg) {
  if (MA_isRulesOptAbsent(arg)) {
    return ATtrue;
  }
  else if (MA_isRulesOptPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RulesOpt is a absent by checking against the following ATerm pattern: appl(prod([],cf(sort("RulesOpt")),attrs([term(cons("absent"))])),[]). May not be used to assert correctness of the MA_RulesOpt
 * \param[in] arg input MA_RulesOpt
 * \return ATtrue if #arg corresponds to the signature of a absent, or ATfalse otherwise
 */
inline ATbool MA_isRulesOptAbsent(MA_RulesOpt arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATisEmpty((ATermList)arg_arg0_arg0)) {
        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
        /* checking for: cf */
        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
            /* checking for: RulesOpt */
            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun111) {
              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
              /* checking for: attrs */
              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                  ATerm arg_arg0_arg2_arg0_head;
                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                  /* checking for: term */
                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                    /* checking for: cons */
                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                      /* checking for: absent */
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun108) {
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                          if (ATisEmpty((ATermList)arg_arg1)) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RulesOpt is a present by checking against the following ATerm pattern: appl(prod([lit("rules"),cf(opt(layout)),cf(sort("RuleList"))],cf(sort("RulesOpt")),attrs([term(cons("present"))])),[appl(prod([char-class([114]),char-class([117]),char-class([108]),char-class([101]),char-class([115])],lit("rules"),no-attrs),[114,117,108,101,115]),<"ws-after-rules"("OptLayout")>,<"RuleList"("RuleList")>]). May not be used to assert correctness of the MA_RulesOpt
 * \param[in] arg input MA_RulesOpt
 * \return ATtrue if #arg corresponds to the signature of a present, or ATfalse otherwise
 */
inline ATbool MA_isRulesOptPresent(MA_RulesOpt arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: rules */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun112) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: RuleList */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun96) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                /* checking for: sort */
                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                  /* checking for: RulesOpt */
                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun111) {
                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                    /* checking for: attrs */
                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                        ATerm arg_arg0_arg2_arg0_head;
                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                        /* checking for: term */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                          /* checking for: cons */
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                            /* checking for: present */
                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun110) {
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                  ATerm arg_arg1_head;
                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                  /* checking for: appl */
                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                    /* checking for: prod */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                        /* checking for: char-class */
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 114) {

                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                  /* checking for: char-class */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                            /* checking for: char-class */
                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                      /* checking for: char-class */
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                /* checking for: char-class */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 115) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                          ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                          /* checking for: lit */
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                            ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                            /* checking for: rules */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun112) {
                                                                                                              ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                              /* checking for: no-attrs */
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                  ATerm arg_arg1_head_arg1_head;
                                                                                                                  ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 114) {

                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                      arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                      arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                          arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                          arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                              arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                              arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                  arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                  arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                  if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 115) {

                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                            return ATtrue;
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RulesOpt has a ws-after-rules. 
 * \param[in] arg input MA_RulesOpt
 * \return ATtrue if the MA_RulesOpt had a ws-after-rules, or ATfalse otherwise
 */
ATbool MA_hasRulesOptWsAfterRules(MA_RulesOpt arg) {
  if (MA_isRulesOptPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RulesOpt has a RuleList. 
 * \param[in] arg input MA_RulesOpt
 * \return ATtrue if the MA_RulesOpt had a RuleList, or ATfalse otherwise
 */
ATbool MA_hasRulesOptRuleList(MA_RulesOpt arg) {
  if (MA_isRulesOptPresent(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-rules MA_OptLayout of a MA_RulesOpt. Note that the precondition is that this MA_RulesOpt actually has a ws-after-rules
 * \param[in] arg input MA_RulesOpt
 * \return the ws-after-rules of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRulesOptWsAfterRules(MA_RulesOpt arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the RuleList MA_RuleList of a MA_RulesOpt. Note that the precondition is that this MA_RulesOpt actually has a RuleList
 * \param[in] arg input MA_RulesOpt
 * \return the RuleList of #arg, if it exist or an undefined value if it does not
 */
MA_RuleList MA_getRulesOptRuleList(MA_RulesOpt arg) {
  
    return (MA_RuleList)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Set the ws-after-rules of a MA_RulesOpt. The precondition being that this MA_RulesOpt actually has a ws-after-rules
 * \param[in] arg input MA_RulesOpt
 * \param[in] wsAfterRules new MA_OptLayout to set in #arg
 * \return A new MA_RulesOpt with wsAfterRules at the right place, or a core dump if #arg did not have a wsAfterRules
 */
MA_RulesOpt MA_setRulesOptWsAfterRules(MA_RulesOpt arg, MA_OptLayout wsAfterRules) {
  if (MA_isRulesOptPresent(arg)) {
    return (MA_RulesOpt)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterRules), 1), 1);
  }

  ATabort("RulesOpt has no WsAfterRules: %t\n", arg);
  return (MA_RulesOpt)NULL;
}

/**
 * Set the RuleList of a MA_RulesOpt. The precondition being that this MA_RulesOpt actually has a RuleList
 * \param[in] arg input MA_RulesOpt
 * \param[in] RuleList new MA_RuleList to set in #arg
 * \return A new MA_RulesOpt with RuleList at the right place, or a core dump if #arg did not have a RuleList
 */
MA_RulesOpt MA_setRulesOptRuleList(MA_RulesOpt arg, MA_RuleList RuleList) {
  if (MA_isRulesOptPresent(arg)) {
    return (MA_RulesOpt)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) RuleList), 2), 1);
  }

  ATabort("RulesOpt has no RuleList: %t\n", arg);
  return (MA_RulesOpt)NULL;
}

/**
 * Assert whether a MA_Module is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_Module
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidModule(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module is a module by checking against the following ATerm pattern: appl(prod([lit("module"),cf(opt(layout)),cf(sort("ModId")),cf(opt(layout)),cf(sort("SignatureOpt")),cf(opt(layout)),cf(sort("RulesOpt"))],cf(sort("Module")),attrs([term(cons("module"))])),[appl(prod([char-class([109]),char-class([111]),char-class([100]),char-class([117]),char-class([108]),char-class([101])],lit("module"),no-attrs),[109,111,100,117,108,101]),<"ws-after-module"("OptLayout")>,<"ModId"("ModId")>,<"ws-after-ModId"("OptLayout")>,<"SignatureOpt"("SignatureOpt")>,<"ws-after-SignatureOpt"("OptLayout")>,<"RulesOpt"("RulesOpt")>]). Always returns ATtrue
 * \param[in] arg input MA_Module
 * \return ATtrue if #arg corresponds to the signature of a module, or ATfalse otherwise
 */
inline ATbool MA_isModuleModule(MA_Module arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: module */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun113) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: cf */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                /* checking for: opt */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                  /* checking for: layout */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                      /* checking for: cf */
                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                        /* checking for: sort */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                          /* checking for: ModId */
                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun60) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: cf */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: opt */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: layout */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                      /* checking for: cf */
                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                          /* checking for: SignatureOpt */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun107) {
                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                              /* checking for: cf */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                /* checking for: opt */
                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun3) {
                                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                  /* checking for: layout */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun4) {
                                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                                      arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                                      arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                                      /* checking for: cf */
                                                      if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun2) {
                                                        ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                                        /* checking for: sort */
                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
                                                          ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                                          /* checking for: RulesOpt */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun111) {
                                                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                              /* checking for: cf */
                                                              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                                                                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                /* checking for: sort */
                                                                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                  /* checking for: Module */
                                                                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun114) {
                                                                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                    /* checking for: attrs */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                        ATerm arg_arg0_arg2_arg0_head;
                                                                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                        /* checking for: term */
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                          /* checking for: cons */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                            /* checking for: module */
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun113) {
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                  ATerm arg_arg1_head;
                                                                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                  /* checking for: appl */
                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                    /* checking for: prod */
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                        ATerm arg_arg1_head_arg0_arg0_head;
                                                                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                        /* checking for: char-class */
                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 109) {

                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                  /* checking for: char-class */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 111) {

                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                            /* checking for: char-class */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 100) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                      arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                      arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                      /* checking for: char-class */
                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                        ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                          ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                          ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                          if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 117) {

                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                /* checking for: char-class */
                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                  ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                    ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 108) {

                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                                                                                                          arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                                                                          arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                                                                          /* checking for: char-class */
                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                                                                            ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                                                                              ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                                                                              ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                              arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 101) {

                                                                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                                                                                    ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                                                                                    /* checking for: lit */
                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                                                                                      ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                                                                                      /* checking for: module */
                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun113) {
                                                                                                                                                        ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                                                                        /* checking for: no-attrs */
                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                                                                          ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                                                                            ATerm arg_arg1_head_arg1_head;
                                                                                                                                                            ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 109) {

                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 111) {

                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 100) {

                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 117) {

                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                            arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                            arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 108) {

                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                                                                                                                                arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                                                                                                arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 101) {

                                                                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                      arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                                                                                                arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                                                                                  return ATtrue;
                                                                                                                                                                                                }
                                                                                                                                                                                              }
                                                                                                                                                                                            }
                                                                                                                                                                                          }
                                                                                                                                                                                        }
                                                                                                                                                                                      }
                                                                                                                                                                                    }
                                                                                                                                                                                  }
                                                                                                                                                                                }
                                                                                                                                                                              }
                                                                                                                                                                            }
                                                                                                                                                                          }
                                                                                                                                                                        }
                                                                                                                                                                      }
                                                                                                                                                                    }
                                                                                                                                                                  }
                                                                                                                                                                }
                                                                                                                                                              }
                                                                                                                                                            }
                                                                                                                                                          }
                                                                                                                                                        }
                                                                                                                                                      }
                                                                                                                                                    }
                                                                                                                                                  }
                                                                                                                                                }
                                                                                                                                              }
                                                                                                                                            }
                                                                                                                                          }
                                                                                                                                        }
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module has a ws-after-module. 
 * \param[in] arg input MA_Module
 * \return ATtrue if the MA_Module had a ws-after-module, or ATfalse otherwise
 */
ATbool MA_hasModuleWsAfterModule(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module has a ModId. 
 * \param[in] arg input MA_Module
 * \return ATtrue if the MA_Module had a ModId, or ATfalse otherwise
 */
ATbool MA_hasModuleModId(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module has a ws-after-ModId. 
 * \param[in] arg input MA_Module
 * \return ATtrue if the MA_Module had a ws-after-ModId, or ATfalse otherwise
 */
ATbool MA_hasModuleWsAfterModId(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module has a SignatureOpt. 
 * \param[in] arg input MA_Module
 * \return ATtrue if the MA_Module had a SignatureOpt, or ATfalse otherwise
 */
ATbool MA_hasModuleSignatureOpt(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module has a ws-after-SignatureOpt. 
 * \param[in] arg input MA_Module
 * \return ATtrue if the MA_Module had a ws-after-SignatureOpt, or ATfalse otherwise
 */
ATbool MA_hasModuleWsAfterSignatureOpt(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_Module has a RulesOpt. 
 * \param[in] arg input MA_Module
 * \return ATtrue if the MA_Module had a RulesOpt, or ATfalse otherwise
 */
ATbool MA_hasModuleRulesOpt(MA_Module arg) {
  if (MA_isModuleModule(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ws-after-module MA_OptLayout of a MA_Module. Note that the precondition is that this MA_Module actually has a ws-after-module
 * \param[in] arg input MA_Module
 * \return the ws-after-module of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getModuleWsAfterModule(MA_Module arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1);
}

/**
 * Get the ModId MA_ModId of a MA_Module. Note that the precondition is that this MA_Module actually has a ModId
 * \param[in] arg input MA_Module
 * \return the ModId of #arg, if it exist or an undefined value if it does not
 */
MA_ModId MA_getModuleModId(MA_Module arg) {
  
    return (MA_ModId)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2);
}

/**
 * Get the ws-after-ModId MA_OptLayout of a MA_Module. Note that the precondition is that this MA_Module actually has a ws-after-ModId
 * \param[in] arg input MA_Module
 * \return the ws-after-ModId of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getModuleWsAfterModId(MA_Module arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3);
}

/**
 * Get the SignatureOpt MA_SignatureOpt of a MA_Module. Note that the precondition is that this MA_Module actually has a SignatureOpt
 * \param[in] arg input MA_Module
 * \return the SignatureOpt of #arg, if it exist or an undefined value if it does not
 */
MA_SignatureOpt MA_getModuleSignatureOpt(MA_Module arg) {
  
    return (MA_SignatureOpt)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 4);
}

/**
 * Get the ws-after-SignatureOpt MA_OptLayout of a MA_Module. Note that the precondition is that this MA_Module actually has a ws-after-SignatureOpt
 * \param[in] arg input MA_Module
 * \return the ws-after-SignatureOpt of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getModuleWsAfterSignatureOpt(MA_Module arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 5);
}

/**
 * Get the RulesOpt MA_RulesOpt of a MA_Module. Note that the precondition is that this MA_Module actually has a RulesOpt
 * \param[in] arg input MA_Module
 * \return the RulesOpt of #arg, if it exist or an undefined value if it does not
 */
MA_RulesOpt MA_getModuleRulesOpt(MA_Module arg) {
  
    return (MA_RulesOpt)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 6);
}

/**
 * Set the ws-after-module of a MA_Module. The precondition being that this MA_Module actually has a ws-after-module
 * \param[in] arg input MA_Module
 * \param[in] wsAfterModule new MA_OptLayout to set in #arg
 * \return A new MA_Module with wsAfterModule at the right place, or a core dump if #arg did not have a wsAfterModule
 */
MA_Module MA_setModuleWsAfterModule(MA_Module arg, MA_OptLayout wsAfterModule) {
  if (MA_isModuleModule(arg)) {
    return (MA_Module)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterModule), 1), 1);
  }

  ATabort("Module has no WsAfterModule: %t\n", arg);
  return (MA_Module)NULL;
}

/**
 * Set the ModId of a MA_Module. The precondition being that this MA_Module actually has a ModId
 * \param[in] arg input MA_Module
 * \param[in] ModId new MA_ModId to set in #arg
 * \return A new MA_Module with ModId at the right place, or a core dump if #arg did not have a ModId
 */
MA_Module MA_setModuleModId(MA_Module arg, MA_ModId ModId) {
  if (MA_isModuleModule(arg)) {
    return (MA_Module)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ModId), 2), 1);
  }

  ATabort("Module has no ModId: %t\n", arg);
  return (MA_Module)NULL;
}

/**
 * Set the ws-after-ModId of a MA_Module. The precondition being that this MA_Module actually has a ws-after-ModId
 * \param[in] arg input MA_Module
 * \param[in] wsAfterModId new MA_OptLayout to set in #arg
 * \return A new MA_Module with wsAfterModId at the right place, or a core dump if #arg did not have a wsAfterModId
 */
MA_Module MA_setModuleWsAfterModId(MA_Module arg, MA_OptLayout wsAfterModId) {
  if (MA_isModuleModule(arg)) {
    return (MA_Module)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterModId), 3), 1);
  }

  ATabort("Module has no WsAfterModId: %t\n", arg);
  return (MA_Module)NULL;
}

/**
 * Set the SignatureOpt of a MA_Module. The precondition being that this MA_Module actually has a SignatureOpt
 * \param[in] arg input MA_Module
 * \param[in] SignatureOpt new MA_SignatureOpt to set in #arg
 * \return A new MA_Module with SignatureOpt at the right place, or a core dump if #arg did not have a SignatureOpt
 */
MA_Module MA_setModuleSignatureOpt(MA_Module arg, MA_SignatureOpt SignatureOpt) {
  if (MA_isModuleModule(arg)) {
    return (MA_Module)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) SignatureOpt), 4), 1);
  }

  ATabort("Module has no SignatureOpt: %t\n", arg);
  return (MA_Module)NULL;
}

/**
 * Set the ws-after-SignatureOpt of a MA_Module. The precondition being that this MA_Module actually has a ws-after-SignatureOpt
 * \param[in] arg input MA_Module
 * \param[in] wsAfterSignatureOpt new MA_OptLayout to set in #arg
 * \return A new MA_Module with wsAfterSignatureOpt at the right place, or a core dump if #arg did not have a wsAfterSignatureOpt
 */
MA_Module MA_setModuleWsAfterSignatureOpt(MA_Module arg, MA_OptLayout wsAfterSignatureOpt) {
  if (MA_isModuleModule(arg)) {
    return (MA_Module)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) wsAfterSignatureOpt), 5), 1);
  }

  ATabort("Module has no WsAfterSignatureOpt: %t\n", arg);
  return (MA_Module)NULL;
}

/**
 * Set the RulesOpt of a MA_Module. The precondition being that this MA_Module actually has a RulesOpt
 * \param[in] arg input MA_Module
 * \param[in] RulesOpt new MA_RulesOpt to set in #arg
 * \return A new MA_Module with RulesOpt at the right place, or a core dump if #arg did not have a RulesOpt
 */
MA_Module MA_setModuleRulesOpt(MA_Module arg, MA_RulesOpt RulesOpt) {
  if (MA_isModuleModule(arg)) {
    return (MA_Module)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) RulesOpt), 6), 1);
  }

  ATabort("Module has no RulesOpt: %t\n", arg);
  return (MA_Module)NULL;
}

/**
 * Assert whether a MA_TermArgs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTermArgs(MA_TermArgs arg) {
  if (MA_isTermArgsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isTermArgsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isTermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_TermArgs
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isTermArgsEmpty(MA_TermArgs arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs is a single by checking against the following ATerm pattern: [<head(Term)>]. May not be used to assert correctness of the MA_TermArgs
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isTermArgsSingle(MA_TermArgs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs is a many by checking against the following ATerm pattern: [<head(Term)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Term-args)]>]. May not be used to assert correctness of the MA_TermArgs
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isTermArgsMany(MA_TermArgs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun66) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs has a head. 
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if the MA_TermArgs had a head, or ATfalse otherwise
 */
ATbool MA_hasTermArgsHead(MA_TermArgs arg) {
  if (MA_isTermArgsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isTermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs has a ws-after-head. 
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if the MA_TermArgs had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasTermArgsWsAfterHead(MA_TermArgs arg) {
  if (MA_isTermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs has a ws-after-sep. 
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if the MA_TermArgs had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasTermArgsWsAfterSep(MA_TermArgs arg) {
  if (MA_isTermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermArgs has a tail. 
 * \param[in] arg input MA_TermArgs
 * \return ATtrue if the MA_TermArgs had a tail, or ATfalse otherwise
 */
ATbool MA_hasTermArgsTail(MA_TermArgs arg) {
  if (MA_isTermArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_TermArgs. 
 * \param[in] arg input MA_TermArgs
 * \return A new MA_TermArgs, without the first element and the separator(s) just after it.)
 */
MA_TermArgs MA_getTermArgsTail(MA_TermArgs arg) {
  assert(!MA_isTermArgsEmpty(arg) && "getTail on an empty list");
  if (MA_isTermArgsSingle(arg)) {
    return (MA_TermArgs) MA_makeTermArgsEmpty();
  }
  else {
  
    return (MA_TermArgs)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_Term of a MA_TermArgs. Note that the precondition is that this MA_TermArgs actually has a head
 * \param[in] arg input MA_TermArgs
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getTermArgsHead(MA_TermArgs arg) {
  if (MA_isTermArgsSingle(arg)) {
    return (MA_Term)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_Term)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_TermArgs. Note that the precondition is that this MA_TermArgs actually has a ws-after-head
 * \param[in] arg input MA_TermArgs
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermArgsWsAfterHead(MA_TermArgs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_TermArgs. Note that the precondition is that this MA_TermArgs actually has a ws-after-sep
 * \param[in] arg input MA_TermArgs
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermArgsWsAfterSep(MA_TermArgs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_TermArgs. The precondition being that this MA_TermArgs actually has a head
 * \param[in] arg input MA_TermArgs
 * \param[in] head new MA_Term to set in #arg
 * \return A new MA_TermArgs with head at the right place, or a core dump if #arg did not have a head
 */
MA_TermArgs MA_setTermArgsHead(MA_TermArgs arg, MA_Term head) {
  if (MA_isTermArgsSingle(arg)) {
    return (MA_TermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isTermArgsMany(arg)) {
    return (MA_TermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("TermArgs has no Head: %t\n", arg);
  return (MA_TermArgs)NULL;
}

/**
 * Set the ws-after-head of a MA_TermArgs. The precondition being that this MA_TermArgs actually has a ws-after-head
 * \param[in] arg input MA_TermArgs
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_TermArgs with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_TermArgs MA_setTermArgsWsAfterHead(MA_TermArgs arg, MA_OptLayout wsAfterHead) {
  if (MA_isTermArgsMany(arg)) {
    return (MA_TermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("TermArgs has no WsAfterHead: %t\n", arg);
  return (MA_TermArgs)NULL;
}

/**
 * Set the ws-after-sep of a MA_TermArgs. The precondition being that this MA_TermArgs actually has a ws-after-sep
 * \param[in] arg input MA_TermArgs
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_TermArgs with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_TermArgs MA_setTermArgsWsAfterSep(MA_TermArgs arg, MA_OptLayout wsAfterSep) {
  if (MA_isTermArgsMany(arg)) {
    return (MA_TermArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("TermArgs has no WsAfterSep: %t\n", arg);
  return (MA_TermArgs)NULL;
}

/**
 * Set the tail of a MA_TermArgs. The precondition being that this MA_TermArgs actually has a tail
 * \param[in] arg input MA_TermArgs
 * \param[in] tail new MA_TermArgs to set in #arg
 * \return A new MA_TermArgs with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_TermArgs MA_setTermArgsTail(MA_TermArgs arg, MA_TermArgs tail) {
  if (MA_isTermArgsMany(arg)) {
    return (MA_TermArgs)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("TermArgs has no Tail: %t\n", arg);
  return (MA_TermArgs)NULL;
}

/**
 * Assert whether a MA_TermElems is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TermElems
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTermElems(MA_TermElems arg) {
  if (MA_isTermElemsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isTermElemsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isTermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_TermElems
 * \param[in] arg input MA_TermElems
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isTermElemsEmpty(MA_TermElems arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems is a single by checking against the following ATerm pattern: [<head(Term)>]. May not be used to assert correctness of the MA_TermElems
 * \param[in] arg input MA_TermElems
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isTermElemsSingle(MA_TermElems arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems is a many by checking against the following ATerm pattern: [<head(Term)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Term-elems)]>]. May not be used to assert correctness of the MA_TermElems
 * \param[in] arg input MA_TermElems
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isTermElemsMany(MA_TermElems arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun66) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems has a head. 
 * \param[in] arg input MA_TermElems
 * \return ATtrue if the MA_TermElems had a head, or ATfalse otherwise
 */
ATbool MA_hasTermElemsHead(MA_TermElems arg) {
  if (MA_isTermElemsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isTermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems has a ws-after-head. 
 * \param[in] arg input MA_TermElems
 * \return ATtrue if the MA_TermElems had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasTermElemsWsAfterHead(MA_TermElems arg) {
  if (MA_isTermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems has a ws-after-sep. 
 * \param[in] arg input MA_TermElems
 * \return ATtrue if the MA_TermElems had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasTermElemsWsAfterSep(MA_TermElems arg) {
  if (MA_isTermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermElems has a tail. 
 * \param[in] arg input MA_TermElems
 * \return ATtrue if the MA_TermElems had a tail, or ATfalse otherwise
 */
ATbool MA_hasTermElemsTail(MA_TermElems arg) {
  if (MA_isTermElemsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_TermElems. 
 * \param[in] arg input MA_TermElems
 * \return A new MA_TermElems, without the first element and the separator(s) just after it.)
 */
MA_TermElems MA_getTermElemsTail(MA_TermElems arg) {
  assert(!MA_isTermElemsEmpty(arg) && "getTail on an empty list");
  if (MA_isTermElemsSingle(arg)) {
    return (MA_TermElems) MA_makeTermElemsEmpty();
  }
  else {
  
    return (MA_TermElems)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_Term of a MA_TermElems. Note that the precondition is that this MA_TermElems actually has a head
 * \param[in] arg input MA_TermElems
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getTermElemsHead(MA_TermElems arg) {
  if (MA_isTermElemsSingle(arg)) {
    return (MA_Term)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_Term)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_TermElems. Note that the precondition is that this MA_TermElems actually has a ws-after-head
 * \param[in] arg input MA_TermElems
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermElemsWsAfterHead(MA_TermElems arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_TermElems. Note that the precondition is that this MA_TermElems actually has a ws-after-sep
 * \param[in] arg input MA_TermElems
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermElemsWsAfterSep(MA_TermElems arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_TermElems. The precondition being that this MA_TermElems actually has a head
 * \param[in] arg input MA_TermElems
 * \param[in] head new MA_Term to set in #arg
 * \return A new MA_TermElems with head at the right place, or a core dump if #arg did not have a head
 */
MA_TermElems MA_setTermElemsHead(MA_TermElems arg, MA_Term head) {
  if (MA_isTermElemsSingle(arg)) {
    return (MA_TermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isTermElemsMany(arg)) {
    return (MA_TermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("TermElems has no Head: %t\n", arg);
  return (MA_TermElems)NULL;
}

/**
 * Set the ws-after-head of a MA_TermElems. The precondition being that this MA_TermElems actually has a ws-after-head
 * \param[in] arg input MA_TermElems
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_TermElems with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_TermElems MA_setTermElemsWsAfterHead(MA_TermElems arg, MA_OptLayout wsAfterHead) {
  if (MA_isTermElemsMany(arg)) {
    return (MA_TermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("TermElems has no WsAfterHead: %t\n", arg);
  return (MA_TermElems)NULL;
}

/**
 * Set the ws-after-sep of a MA_TermElems. The precondition being that this MA_TermElems actually has a ws-after-sep
 * \param[in] arg input MA_TermElems
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_TermElems with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_TermElems MA_setTermElemsWsAfterSep(MA_TermElems arg, MA_OptLayout wsAfterSep) {
  if (MA_isTermElemsMany(arg)) {
    return (MA_TermElems)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("TermElems has no WsAfterSep: %t\n", arg);
  return (MA_TermElems)NULL;
}

/**
 * Set the tail of a MA_TermElems. The precondition being that this MA_TermElems actually has a tail
 * \param[in] arg input MA_TermElems
 * \param[in] tail new MA_TermElems to set in #arg
 * \return A new MA_TermElems with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_TermElems MA_setTermElemsTail(MA_TermElems arg, MA_TermElems tail) {
  if (MA_isTermElemsMany(arg)) {
    return (MA_TermElems)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("TermElems has no Tail: %t\n", arg);
  return (MA_TermElems)NULL;
}

/**
 * Assert whether a MA_SigArgArgs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidSigArgArgs(MA_SigArgArgs arg) {
  if (MA_isSigArgArgsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isSigArgArgsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isSigArgArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_SigArgArgs
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isSigArgArgsEmpty(MA_SigArgArgs arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs is a single by checking against the following ATerm pattern: [<head(SigArg)>]. May not be used to assert correctness of the MA_SigArgArgs
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isSigArgArgsSingle(MA_SigArgArgs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs is a many by checking against the following ATerm pattern: [<head(SigArg)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(SigArg-args)]>]. May not be used to assert correctness of the MA_SigArgArgs
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isSigArgArgsMany(MA_SigArgArgs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun66) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs has a head. 
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if the MA_SigArgArgs had a head, or ATfalse otherwise
 */
ATbool MA_hasSigArgArgsHead(MA_SigArgArgs arg) {
  if (MA_isSigArgArgsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isSigArgArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs has a ws-after-head. 
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if the MA_SigArgArgs had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasSigArgArgsWsAfterHead(MA_SigArgArgs arg) {
  if (MA_isSigArgArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs has a ws-after-sep. 
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if the MA_SigArgArgs had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasSigArgArgsWsAfterSep(MA_SigArgArgs arg) {
  if (MA_isSigArgArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_SigArgArgs has a tail. 
 * \param[in] arg input MA_SigArgArgs
 * \return ATtrue if the MA_SigArgArgs had a tail, or ATfalse otherwise
 */
ATbool MA_hasSigArgArgsTail(MA_SigArgArgs arg) {
  if (MA_isSigArgArgsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_SigArgArgs. 
 * \param[in] arg input MA_SigArgArgs
 * \return A new MA_SigArgArgs, without the first element and the separator(s) just after it.)
 */
MA_SigArgArgs MA_getSigArgArgsTail(MA_SigArgArgs arg) {
  assert(!MA_isSigArgArgsEmpty(arg) && "getTail on an empty list");
  if (MA_isSigArgArgsSingle(arg)) {
    return (MA_SigArgArgs) MA_makeSigArgArgsEmpty();
  }
  else {
  
    return (MA_SigArgArgs)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_SigArg of a MA_SigArgArgs. Note that the precondition is that this MA_SigArgArgs actually has a head
 * \param[in] arg input MA_SigArgArgs
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_SigArg MA_getSigArgArgsHead(MA_SigArgArgs arg) {
  if (MA_isSigArgArgsSingle(arg)) {
    return (MA_SigArg)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_SigArg)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_SigArgArgs. Note that the precondition is that this MA_SigArgArgs actually has a ws-after-head
 * \param[in] arg input MA_SigArgArgs
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getSigArgArgsWsAfterHead(MA_SigArgArgs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_SigArgArgs. Note that the precondition is that this MA_SigArgArgs actually has a ws-after-sep
 * \param[in] arg input MA_SigArgArgs
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getSigArgArgsWsAfterSep(MA_SigArgArgs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_SigArgArgs. The precondition being that this MA_SigArgArgs actually has a head
 * \param[in] arg input MA_SigArgArgs
 * \param[in] head new MA_SigArg to set in #arg
 * \return A new MA_SigArgArgs with head at the right place, or a core dump if #arg did not have a head
 */
MA_SigArgArgs MA_setSigArgArgsHead(MA_SigArgArgs arg, MA_SigArg head) {
  if (MA_isSigArgArgsSingle(arg)) {
    return (MA_SigArgArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isSigArgArgsMany(arg)) {
    return (MA_SigArgArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("SigArgArgs has no Head: %t\n", arg);
  return (MA_SigArgArgs)NULL;
}

/**
 * Set the ws-after-head of a MA_SigArgArgs. The precondition being that this MA_SigArgArgs actually has a ws-after-head
 * \param[in] arg input MA_SigArgArgs
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_SigArgArgs with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_SigArgArgs MA_setSigArgArgsWsAfterHead(MA_SigArgArgs arg, MA_OptLayout wsAfterHead) {
  if (MA_isSigArgArgsMany(arg)) {
    return (MA_SigArgArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("SigArgArgs has no WsAfterHead: %t\n", arg);
  return (MA_SigArgArgs)NULL;
}

/**
 * Set the ws-after-sep of a MA_SigArgArgs. The precondition being that this MA_SigArgArgs actually has a ws-after-sep
 * \param[in] arg input MA_SigArgArgs
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_SigArgArgs with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_SigArgArgs MA_setSigArgArgsWsAfterSep(MA_SigArgArgs arg, MA_OptLayout wsAfterSep) {
  if (MA_isSigArgArgsMany(arg)) {
    return (MA_SigArgArgs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("SigArgArgs has no WsAfterSep: %t\n", arg);
  return (MA_SigArgArgs)NULL;
}

/**
 * Set the tail of a MA_SigArgArgs. The precondition being that this MA_SigArgArgs actually has a tail
 * \param[in] arg input MA_SigArgArgs
 * \param[in] tail new MA_SigArgArgs to set in #arg
 * \return A new MA_SigArgArgs with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_SigArgArgs MA_setSigArgArgsTail(MA_SigArgArgs arg, MA_SigArgArgs tail) {
  if (MA_isSigArgArgsMany(arg)) {
    return (MA_SigArgArgs)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("SigArgArgs has no Tail: %t\n", arg);
  return (MA_SigArgArgs)NULL;
}

/**
 * Assert whether a MA_TermAttrs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidTermAttrs(MA_TermAttrs arg) {
  if (MA_isTermAttrsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isTermAttrsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isTermAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_TermAttrs
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isTermAttrsEmpty(MA_TermAttrs arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs is a single by checking against the following ATerm pattern: [<head(Term)>]. May not be used to assert correctness of the MA_TermAttrs
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isTermAttrsSingle(MA_TermAttrs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs is a many by checking against the following ATerm pattern: [<head(Term)>,<ws-after-head("OptLayout")>,appl(prod([char-class([44])],lit(","),no-attrs),[44]),<ws-after-sep("OptLayout")>,<[tail(Term-attrs)]>]. May not be used to assert correctness of the MA_TermAttrs
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isTermAttrsMany(MA_TermAttrs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 44) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: , */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun66) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 44) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs has a head. 
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if the MA_TermAttrs had a head, or ATfalse otherwise
 */
ATbool MA_hasTermAttrsHead(MA_TermAttrs arg) {
  if (MA_isTermAttrsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isTermAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs has a ws-after-head. 
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if the MA_TermAttrs had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasTermAttrsWsAfterHead(MA_TermAttrs arg) {
  if (MA_isTermAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs has a ws-after-sep. 
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if the MA_TermAttrs had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasTermAttrsWsAfterSep(MA_TermAttrs arg) {
  if (MA_isTermAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_TermAttrs has a tail. 
 * \param[in] arg input MA_TermAttrs
 * \return ATtrue if the MA_TermAttrs had a tail, or ATfalse otherwise
 */
ATbool MA_hasTermAttrsTail(MA_TermAttrs arg) {
  if (MA_isTermAttrsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_TermAttrs. 
 * \param[in] arg input MA_TermAttrs
 * \return A new MA_TermAttrs, without the first element and the separator(s) just after it.)
 */
MA_TermAttrs MA_getTermAttrsTail(MA_TermAttrs arg) {
  assert(!MA_isTermAttrsEmpty(arg) && "getTail on an empty list");
  if (MA_isTermAttrsSingle(arg)) {
    return (MA_TermAttrs) MA_makeTermAttrsEmpty();
  }
  else {
  
    return (MA_TermAttrs)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_Term of a MA_TermAttrs. Note that the precondition is that this MA_TermAttrs actually has a head
 * \param[in] arg input MA_TermAttrs
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_Term MA_getTermAttrsHead(MA_TermAttrs arg) {
  if (MA_isTermAttrsSingle(arg)) {
    return (MA_Term)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_Term)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_TermAttrs. Note that the precondition is that this MA_TermAttrs actually has a ws-after-head
 * \param[in] arg input MA_TermAttrs
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermAttrsWsAfterHead(MA_TermAttrs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_TermAttrs. Note that the precondition is that this MA_TermAttrs actually has a ws-after-sep
 * \param[in] arg input MA_TermAttrs
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getTermAttrsWsAfterSep(MA_TermAttrs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_TermAttrs. The precondition being that this MA_TermAttrs actually has a head
 * \param[in] arg input MA_TermAttrs
 * \param[in] head new MA_Term to set in #arg
 * \return A new MA_TermAttrs with head at the right place, or a core dump if #arg did not have a head
 */
MA_TermAttrs MA_setTermAttrsHead(MA_TermAttrs arg, MA_Term head) {
  if (MA_isTermAttrsSingle(arg)) {
    return (MA_TermAttrs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isTermAttrsMany(arg)) {
    return (MA_TermAttrs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("TermAttrs has no Head: %t\n", arg);
  return (MA_TermAttrs)NULL;
}

/**
 * Set the ws-after-head of a MA_TermAttrs. The precondition being that this MA_TermAttrs actually has a ws-after-head
 * \param[in] arg input MA_TermAttrs
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_TermAttrs with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_TermAttrs MA_setTermAttrsWsAfterHead(MA_TermAttrs arg, MA_OptLayout wsAfterHead) {
  if (MA_isTermAttrsMany(arg)) {
    return (MA_TermAttrs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("TermAttrs has no WsAfterHead: %t\n", arg);
  return (MA_TermAttrs)NULL;
}

/**
 * Set the ws-after-sep of a MA_TermAttrs. The precondition being that this MA_TermAttrs actually has a ws-after-sep
 * \param[in] arg input MA_TermAttrs
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_TermAttrs with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_TermAttrs MA_setTermAttrsWsAfterSep(MA_TermAttrs arg, MA_OptLayout wsAfterSep) {
  if (MA_isTermAttrsMany(arg)) {
    return (MA_TermAttrs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("TermAttrs has no WsAfterSep: %t\n", arg);
  return (MA_TermAttrs)NULL;
}

/**
 * Set the tail of a MA_TermAttrs. The precondition being that this MA_TermAttrs actually has a tail
 * \param[in] arg input MA_TermAttrs
 * \param[in] tail new MA_TermAttrs to set in #arg
 * \return A new MA_TermAttrs with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_TermAttrs MA_setTermAttrsTail(MA_TermAttrs arg, MA_TermAttrs tail) {
  if (MA_isTermAttrsMany(arg)) {
    return (MA_TermAttrs)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("TermAttrs has no Tail: %t\n", arg);
  return (MA_TermAttrs)NULL;
}

/**
 * Assert whether a MA_FuncDefDefs is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidFuncDefDefs(MA_FuncDefDefs arg) {
  if (MA_isFuncDefDefsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefDefsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefDefsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_FuncDefDefs
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefDefsEmpty(MA_FuncDefDefs arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs is a single by checking against the following ATerm pattern: [<head(FuncDef)>]. May not be used to assert correctness of the MA_FuncDefDefs
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefDefsSingle(MA_FuncDefDefs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs is a many by checking against the following ATerm pattern: [<head(FuncDef)>,<ws-after-head("OptLayout")>,appl(prod([char-class([59])],lit(";"),no-attrs),[59]),<ws-after-sep("OptLayout")>,<[tail(FuncDef-defs)]>]. May not be used to assert correctness of the MA_FuncDefDefs
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isFuncDefDefsMany(MA_FuncDefDefs arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 59) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: ; */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun85) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 59) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs has a head. 
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if the MA_FuncDefDefs had a head, or ATfalse otherwise
 */
ATbool MA_hasFuncDefDefsHead(MA_FuncDefDefs arg) {
  if (MA_isFuncDefDefsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isFuncDefDefsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs has a ws-after-head. 
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if the MA_FuncDefDefs had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasFuncDefDefsWsAfterHead(MA_FuncDefDefs arg) {
  if (MA_isFuncDefDefsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs has a ws-after-sep. 
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if the MA_FuncDefDefs had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasFuncDefDefsWsAfterSep(MA_FuncDefDefs arg) {
  if (MA_isFuncDefDefsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_FuncDefDefs has a tail. 
 * \param[in] arg input MA_FuncDefDefs
 * \return ATtrue if the MA_FuncDefDefs had a tail, or ATfalse otherwise
 */
ATbool MA_hasFuncDefDefsTail(MA_FuncDefDefs arg) {
  if (MA_isFuncDefDefsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_FuncDefDefs. 
 * \param[in] arg input MA_FuncDefDefs
 * \return A new MA_FuncDefDefs, without the first element and the separator(s) just after it.)
 */
MA_FuncDefDefs MA_getFuncDefDefsTail(MA_FuncDefDefs arg) {
  assert(!MA_isFuncDefDefsEmpty(arg) && "getTail on an empty list");
  if (MA_isFuncDefDefsSingle(arg)) {
    return (MA_FuncDefDefs) MA_makeFuncDefDefsEmpty();
  }
  else {
  
    return (MA_FuncDefDefs)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_FuncDef of a MA_FuncDefDefs. Note that the precondition is that this MA_FuncDefDefs actually has a head
 * \param[in] arg input MA_FuncDefDefs
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_FuncDef MA_getFuncDefDefsHead(MA_FuncDefDefs arg) {
  if (MA_isFuncDefDefsSingle(arg)) {
    return (MA_FuncDef)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_FuncDef)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_FuncDefDefs. Note that the precondition is that this MA_FuncDefDefs actually has a ws-after-head
 * \param[in] arg input MA_FuncDefDefs
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFuncDefDefsWsAfterHead(MA_FuncDefDefs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_FuncDefDefs. Note that the precondition is that this MA_FuncDefDefs actually has a ws-after-sep
 * \param[in] arg input MA_FuncDefDefs
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getFuncDefDefsWsAfterSep(MA_FuncDefDefs arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_FuncDefDefs. The precondition being that this MA_FuncDefDefs actually has a head
 * \param[in] arg input MA_FuncDefDefs
 * \param[in] head new MA_FuncDef to set in #arg
 * \return A new MA_FuncDefDefs with head at the right place, or a core dump if #arg did not have a head
 */
MA_FuncDefDefs MA_setFuncDefDefsHead(MA_FuncDefDefs arg, MA_FuncDef head) {
  if (MA_isFuncDefDefsSingle(arg)) {
    return (MA_FuncDefDefs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isFuncDefDefsMany(arg)) {
    return (MA_FuncDefDefs)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("FuncDefDefs has no Head: %t\n", arg);
  return (MA_FuncDefDefs)NULL;
}

/**
 * Set the ws-after-head of a MA_FuncDefDefs. The precondition being that this MA_FuncDefDefs actually has a ws-after-head
 * \param[in] arg input MA_FuncDefDefs
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_FuncDefDefs with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_FuncDefDefs MA_setFuncDefDefsWsAfterHead(MA_FuncDefDefs arg, MA_OptLayout wsAfterHead) {
  if (MA_isFuncDefDefsMany(arg)) {
    return (MA_FuncDefDefs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("FuncDefDefs has no WsAfterHead: %t\n", arg);
  return (MA_FuncDefDefs)NULL;
}

/**
 * Set the ws-after-sep of a MA_FuncDefDefs. The precondition being that this MA_FuncDefDefs actually has a ws-after-sep
 * \param[in] arg input MA_FuncDefDefs
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_FuncDefDefs with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_FuncDefDefs MA_setFuncDefDefsWsAfterSep(MA_FuncDefDefs arg, MA_OptLayout wsAfterSep) {
  if (MA_isFuncDefDefsMany(arg)) {
    return (MA_FuncDefDefs)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("FuncDefDefs has no WsAfterSep: %t\n", arg);
  return (MA_FuncDefDefs)NULL;
}

/**
 * Set the tail of a MA_FuncDefDefs. The precondition being that this MA_FuncDefDefs actually has a tail
 * \param[in] arg input MA_FuncDefDefs
 * \param[in] tail new MA_FuncDefDefs to set in #arg
 * \return A new MA_FuncDefDefs with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_FuncDefDefs MA_setFuncDefDefsTail(MA_FuncDefDefs arg, MA_FuncDefDefs tail) {
  if (MA_isFuncDefDefsMany(arg)) {
    return (MA_FuncDefDefs)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("FuncDefDefs has no Tail: %t\n", arg);
  return (MA_FuncDefDefs)NULL;
}

/**
 * Assert whether a MA_RuleRules is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidRuleRules(MA_RuleRules arg) {
  if (MA_isRuleRulesEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleRulesSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleRulesMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_RuleRules
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isRuleRulesEmpty(MA_RuleRules arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules is a single by checking against the following ATerm pattern: [<head(Rule)>]. May not be used to assert correctness of the MA_RuleRules
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isRuleRulesSingle(MA_RuleRules arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules is a many by checking against the following ATerm pattern: [<head(Rule)>,<ws-after-head("OptLayout")>,appl(prod([char-class([59])],lit(";"),no-attrs),[59]),<ws-after-sep("OptLayout")>,<[tail(Rule-rules)]>]. May not be used to assert correctness of the MA_RuleRules
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isRuleRulesMany(MA_RuleRules arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 59) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: ; */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun85) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 59) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules has a head. 
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if the MA_RuleRules had a head, or ATfalse otherwise
 */
ATbool MA_hasRuleRulesHead(MA_RuleRules arg) {
  if (MA_isRuleRulesSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isRuleRulesMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules has a ws-after-head. 
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if the MA_RuleRules had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasRuleRulesWsAfterHead(MA_RuleRules arg) {
  if (MA_isRuleRulesMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules has a ws-after-sep. 
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if the MA_RuleRules had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasRuleRulesWsAfterSep(MA_RuleRules arg) {
  if (MA_isRuleRulesMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_RuleRules has a tail. 
 * \param[in] arg input MA_RuleRules
 * \return ATtrue if the MA_RuleRules had a tail, or ATfalse otherwise
 */
ATbool MA_hasRuleRulesTail(MA_RuleRules arg) {
  if (MA_isRuleRulesMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_RuleRules. 
 * \param[in] arg input MA_RuleRules
 * \return A new MA_RuleRules, without the first element and the separator(s) just after it.)
 */
MA_RuleRules MA_getRuleRulesTail(MA_RuleRules arg) {
  assert(!MA_isRuleRulesEmpty(arg) && "getTail on an empty list");
  if (MA_isRuleRulesSingle(arg)) {
    return (MA_RuleRules) MA_makeRuleRulesEmpty();
  }
  else {
  
    return (MA_RuleRules)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_Rule of a MA_RuleRules. Note that the precondition is that this MA_RuleRules actually has a head
 * \param[in] arg input MA_RuleRules
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_Rule MA_getRuleRulesHead(MA_RuleRules arg) {
  if (MA_isRuleRulesSingle(arg)) {
    return (MA_Rule)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_Rule)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_RuleRules. Note that the precondition is that this MA_RuleRules actually has a ws-after-head
 * \param[in] arg input MA_RuleRules
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleRulesWsAfterHead(MA_RuleRules arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_RuleRules. Note that the precondition is that this MA_RuleRules actually has a ws-after-sep
 * \param[in] arg input MA_RuleRules
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getRuleRulesWsAfterSep(MA_RuleRules arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_RuleRules. The precondition being that this MA_RuleRules actually has a head
 * \param[in] arg input MA_RuleRules
 * \param[in] head new MA_Rule to set in #arg
 * \return A new MA_RuleRules with head at the right place, or a core dump if #arg did not have a head
 */
MA_RuleRules MA_setRuleRulesHead(MA_RuleRules arg, MA_Rule head) {
  if (MA_isRuleRulesSingle(arg)) {
    return (MA_RuleRules)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isRuleRulesMany(arg)) {
    return (MA_RuleRules)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("RuleRules has no Head: %t\n", arg);
  return (MA_RuleRules)NULL;
}

/**
 * Set the ws-after-head of a MA_RuleRules. The precondition being that this MA_RuleRules actually has a ws-after-head
 * \param[in] arg input MA_RuleRules
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_RuleRules with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_RuleRules MA_setRuleRulesWsAfterHead(MA_RuleRules arg, MA_OptLayout wsAfterHead) {
  if (MA_isRuleRulesMany(arg)) {
    return (MA_RuleRules)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("RuleRules has no WsAfterHead: %t\n", arg);
  return (MA_RuleRules)NULL;
}

/**
 * Set the ws-after-sep of a MA_RuleRules. The precondition being that this MA_RuleRules actually has a ws-after-sep
 * \param[in] arg input MA_RuleRules
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_RuleRules with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_RuleRules MA_setRuleRulesWsAfterSep(MA_RuleRules arg, MA_OptLayout wsAfterSep) {
  if (MA_isRuleRulesMany(arg)) {
    return (MA_RuleRules)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("RuleRules has no WsAfterSep: %t\n", arg);
  return (MA_RuleRules)NULL;
}

/**
 * Set the tail of a MA_RuleRules. The precondition being that this MA_RuleRules actually has a tail
 * \param[in] arg input MA_RuleRules
 * \param[in] tail new MA_RuleRules to set in #arg
 * \return A new MA_RuleRules with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_RuleRules MA_setRuleRulesTail(MA_RuleRules arg, MA_RuleRules tail) {
  if (MA_isRuleRulesMany(arg)) {
    return (MA_RuleRules)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("RuleRules has no Tail: %t\n", arg);
  return (MA_RuleRules)NULL;
}

/**
 * Assert whether a MA_CondConds is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_CondConds
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidCondConds(MA_CondConds arg) {
  if (MA_isCondCondsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isCondCondsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isCondCondsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_CondConds
 * \param[in] arg input MA_CondConds
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isCondCondsEmpty(MA_CondConds arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds is a single by checking against the following ATerm pattern: [<head(Cond)>]. May not be used to assert correctness of the MA_CondConds
 * \param[in] arg input MA_CondConds
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isCondCondsSingle(MA_CondConds arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds is a many by checking against the following ATerm pattern: [<head(Cond)>,<ws-after-head("OptLayout")>,appl(prod([char-class([38])],lit("&"),no-attrs),[38]),<ws-after-sep("OptLayout")>,<[tail(Cond-conds)]>]. May not be used to assert correctness of the MA_CondConds
 * \param[in] arg input MA_CondConds
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isCondCondsMany(MA_CondConds arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATerm arg_head;
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
      arg_list = ATgetNext(arg_list);
      if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
        arg_head = ATgetFirst(arg_list);
        arg_list = ATgetNext(arg_list);
        /* checking for: appl */
        if (ATgetType((ATerm)arg_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head) == MA_afun0) {
          ATerm arg_head_arg0 = ATgetArgument(arg_head, 0);
          /* checking for: prod */
          if (ATgetType((ATerm)arg_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0) == MA_afun1) {
            ATerm arg_head_arg0_arg0 = ATgetArgument(arg_head_arg0, 0);
            if (ATgetType((ATerm)arg_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0) == ATfalse) {
              ATerm arg_head_arg0_arg0_head;
              ATermList arg_head_arg0_arg0_list = (ATermList)arg_head_arg0_arg0;
              arg_head_arg0_arg0_head = ATgetFirst(arg_head_arg0_arg0_list);
              arg_head_arg0_arg0_list = ATgetNext(arg_head_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg0_head) == MA_afun16) {
                ATerm arg_head_arg0_arg0_head_arg0 = ATgetArgument(arg_head_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_head_arg0_arg0_head_arg0_head;
                  ATermList arg_head_arg0_arg0_head_arg0_list = (ATermList)arg_head_arg0_arg0_head_arg0;
                  arg_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_head_arg0_arg0_head_arg0_list);
                  arg_head_arg0_arg0_head_arg0_list = ATgetNext(arg_head_arg0_arg0_head_arg0_list);
                  if (ATgetInt((ATermInt)arg_head_arg0_arg0_head_arg0_head) == 38) {

                    if (ATgetType((ATerm)arg_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_head_arg0_list) == ATtrue) {
                      if (ATgetType((ATerm)arg_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg0_arg0_list) == ATtrue) {
                        ATerm arg_head_arg0_arg1 = ATgetArgument(arg_head_arg0, 1);
                        /* checking for: lit */
                        if (ATgetType((ATerm)arg_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1) == MA_afun9) {
                          ATerm arg_head_arg0_arg1_arg0 = ATgetArgument(arg_head_arg0_arg1, 0);
                          /* checking for: & */
                          if (ATgetType((ATerm)arg_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg1_arg0) == MA_afun98) {
                            ATerm arg_head_arg0_arg2 = ATgetArgument(arg_head_arg0, 2);
                            /* checking for: no-attrs */
                            if (ATgetType((ATerm)arg_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_head_arg0_arg2) == MA_afun5) {
                              ATerm arg_head_arg1 = ATgetArgument(arg_head, 1);
                              if (ATgetType((ATerm)arg_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1) == ATfalse) {
                                ATerm arg_head_arg1_head;
                                ATermList arg_head_arg1_list = (ATermList)arg_head_arg1;
                                arg_head_arg1_head = ATgetFirst(arg_head_arg1_list);
                                arg_head_arg1_list = ATgetNext(arg_head_arg1_list);
                                if (ATgetInt((ATermInt)arg_head_arg1_head) == 38) {

                                  if (ATgetType((ATerm)arg_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_head_arg1_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATfalse) {
                                      return ATtrue;
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds has a head. 
 * \param[in] arg input MA_CondConds
 * \return ATtrue if the MA_CondConds had a head, or ATfalse otherwise
 */
ATbool MA_hasCondCondsHead(MA_CondConds arg) {
  if (MA_isCondCondsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isCondCondsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds has a ws-after-head. 
 * \param[in] arg input MA_CondConds
 * \return ATtrue if the MA_CondConds had a ws-after-head, or ATfalse otherwise
 */
ATbool MA_hasCondCondsWsAfterHead(MA_CondConds arg) {
  if (MA_isCondCondsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds has a ws-after-sep. 
 * \param[in] arg input MA_CondConds
 * \return ATtrue if the MA_CondConds had a ws-after-sep, or ATfalse otherwise
 */
ATbool MA_hasCondCondsWsAfterSep(MA_CondConds arg) {
  if (MA_isCondCondsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_CondConds has a tail. 
 * \param[in] arg input MA_CondConds
 * \return ATtrue if the MA_CondConds had a tail, or ATfalse otherwise
 */
ATbool MA_hasCondCondsTail(MA_CondConds arg) {
  if (MA_isCondCondsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Returns a list of all but the first element of a MA_CondConds. 
 * \param[in] arg input MA_CondConds
 * \return A new MA_CondConds, without the first element and the separator(s) just after it.)
 */
MA_CondConds MA_getCondCondsTail(MA_CondConds arg) {
  assert(!MA_isCondCondsEmpty(arg) && "getTail on an empty list");
  if (MA_isCondCondsSingle(arg)) {
    return (MA_CondConds) MA_makeCondCondsEmpty();
  }
  else {
  
    return (MA_CondConds)ATgetTail((ATermList)arg, 4);
  }
}

/**
 * Get the head MA_Cond of a MA_CondConds. Note that the precondition is that this MA_CondConds actually has a head
 * \param[in] arg input MA_CondConds
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_Cond MA_getCondCondsHead(MA_CondConds arg) {
  if (MA_isCondCondsSingle(arg)) {
    return (MA_Cond)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_Cond)ATgetFirst((ATermList)arg);
}

/**
 * Get the ws-after-head MA_OptLayout of a MA_CondConds. Note that the precondition is that this MA_CondConds actually has a ws-after-head
 * \param[in] arg input MA_CondConds
 * \return the ws-after-head of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondCondsWsAfterHead(MA_CondConds arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 1);
}

/**
 * Get the ws-after-sep MA_OptLayout of a MA_CondConds. Note that the precondition is that this MA_CondConds actually has a ws-after-sep
 * \param[in] arg input MA_CondConds
 * \return the ws-after-sep of #arg, if it exist or an undefined value if it does not
 */
MA_OptLayout MA_getCondCondsWsAfterSep(MA_CondConds arg) {
  
    return (MA_OptLayout)ATelementAt((ATermList)arg, 3);
}

/**
 * Set the head of a MA_CondConds. The precondition being that this MA_CondConds actually has a head
 * \param[in] arg input MA_CondConds
 * \param[in] head new MA_Cond to set in #arg
 * \return A new MA_CondConds with head at the right place, or a core dump if #arg did not have a head
 */
MA_CondConds MA_setCondCondsHead(MA_CondConds arg, MA_Cond head) {
  if (MA_isCondCondsSingle(arg)) {
    return (MA_CondConds)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isCondCondsMany(arg)) {
    return (MA_CondConds)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("CondConds has no Head: %t\n", arg);
  return (MA_CondConds)NULL;
}

/**
 * Set the ws-after-head of a MA_CondConds. The precondition being that this MA_CondConds actually has a ws-after-head
 * \param[in] arg input MA_CondConds
 * \param[in] wsAfterHead new MA_OptLayout to set in #arg
 * \return A new MA_CondConds with wsAfterHead at the right place, or a core dump if #arg did not have a wsAfterHead
 */
MA_CondConds MA_setCondCondsWsAfterHead(MA_CondConds arg, MA_OptLayout wsAfterHead) {
  if (MA_isCondCondsMany(arg)) {
    return (MA_CondConds)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterHead), 1);
  }

  ATabort("CondConds has no WsAfterHead: %t\n", arg);
  return (MA_CondConds)NULL;
}

/**
 * Set the ws-after-sep of a MA_CondConds. The precondition being that this MA_CondConds actually has a ws-after-sep
 * \param[in] arg input MA_CondConds
 * \param[in] wsAfterSep new MA_OptLayout to set in #arg
 * \return A new MA_CondConds with wsAfterSep at the right place, or a core dump if #arg did not have a wsAfterSep
 */
MA_CondConds MA_setCondCondsWsAfterSep(MA_CondConds arg, MA_OptLayout wsAfterSep) {
  if (MA_isCondCondsMany(arg)) {
    return (MA_CondConds)ATreplace((ATermList)arg, (ATerm)((ATerm) wsAfterSep), 3);
  }

  ATabort("CondConds has no WsAfterSep: %t\n", arg);
  return (MA_CondConds)NULL;
}

/**
 * Set the tail of a MA_CondConds. The precondition being that this MA_CondConds actually has a tail
 * \param[in] arg input MA_CondConds
 * \param[in] tail new MA_CondConds to set in #arg
 * \return A new MA_CondConds with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_CondConds MA_setCondCondsTail(MA_CondConds arg, MA_CondConds tail) {
  if (MA_isCondCondsMany(arg)) {
    return (MA_CondConds)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 4);
  }

  ATabort("CondConds has no Tail: %t\n", arg);
  return (MA_CondConds)NULL;
}

/**
 * Assert whether a MA_LexLayout is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexLayout
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexLayout(MA_LexLayout arg) {
  if (MA_isLexLayoutWhitespace(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayout is a whitespace by checking against the following ATerm pattern: appl(prod([char-class([range(9,13),32])],lex(layout),attrs([term(cons("whitespace"))])),[<"ch"(char)>]). Always returns ATtrue
 * \param[in] arg input MA_LexLayout
 * \return ATtrue if #arg corresponds to the signature of a whitespace, or ATfalse otherwise
 */
inline ATbool MA_isLexLayoutWhitespace(MA_LexLayout arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 9) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 13) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 32) {

                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                          /* checking for: lex */
                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                            /* checking for: layout */
                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun4) {
                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                              /* checking for: attrs */
                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                  ATerm arg_arg0_arg2_arg0_head;
                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                  /* checking for: term */
                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                    /* checking for: cons */
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                      /* checking for: whitespace */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun116) {
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                            ATerm arg_arg1_head;
                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                            if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                return ATtrue;
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexLayout has a ch. 
 * \param[in] arg input MA_LexLayout
 * \return ATtrue if the MA_LexLayout had a ch, or ATfalse otherwise
 */
ATbool MA_hasLexLayoutCh(MA_LexLayout arg) {
  if (MA_isLexLayoutWhitespace(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the ch char of a MA_LexLayout. Note that the precondition is that this MA_LexLayout actually has a ch
 * \param[in] arg input MA_LexLayout
 * \return the ch of #arg, if it exist or an undefined value if it does not
 */
char MA_getLexLayoutCh(MA_LexLayout arg) {
  
    return (char)MA_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Set the ch of a MA_LexLayout. The precondition being that this MA_LexLayout actually has a ch
 * \param[in] arg input MA_LexLayout
 * \param[in] ch new char to set in #arg
 * \return A new MA_LexLayout with ch at the right place, or a core dump if #arg did not have a ch
 */
MA_LexLayout MA_setLexLayoutCh(MA_LexLayout arg, char ch) {
  if (MA_isLexLayoutWhitespace(arg)) {
    return (MA_LexLayout)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) MA_byteToChar(ch))), 0), 1);
  }

  ATabort("LexLayout has no Ch: %t\n", arg);
  return (MA_LexLayout)NULL;
}

/**
 * Assert whether a MA_LexStrChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexStrChar(MA_LexStrChar arg) {
  if (MA_isLexStrCharNewline(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharTab(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharQuote(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharBackslash(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharNormal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar is a newline by checking against the following ATerm pattern: appl(prod([lit("\\n")],lex(sort("StrChar")),attrs([term(cons("newline"))])),[appl(prod([char-class([92]),char-class([110])],lit("\\n"),no-attrs),[92,110])]). May not be used to assert correctness of the MA_LexStrChar
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a newline, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharNewline(MA_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \n */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun117) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: newline */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun119) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 110) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \n */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun117) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 110) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar is a tab by checking against the following ATerm pattern: appl(prod([lit("\\t")],lex(sort("StrChar")),attrs([term(cons("tab"))])),[appl(prod([char-class([92]),char-class([116])],lit("\\t"),no-attrs),[92,116])]). May not be used to assert correctness of the MA_LexStrChar
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a tab, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharTab(MA_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \t */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun120) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: tab */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun121) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 116) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \t */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun120) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 116) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar is a quote by checking against the following ATerm pattern: appl(prod([lit("\\\"")],lex(sort("StrChar")),attrs([term(cons("quote"))])),[appl(prod([char-class([92]),char-class([34])],lit("\\\""),no-attrs),[92,34])]). May not be used to assert correctness of the MA_LexStrChar
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a quote, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharQuote(MA_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \" */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun122) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: quote */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun123) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 34) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \" */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun122) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 34) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar is a backslash by checking against the following ATerm pattern: appl(prod([lit("\\\\")],lex(sort("StrChar")),attrs([term(cons("backslash"))])),[appl(prod([char-class([92]),char-class([92])],lit("\\\\"),no-attrs),[92,92])]). May not be used to assert correctness of the MA_LexStrChar
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a backslash, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharBackslash(MA_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \\ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun124) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
              ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
              /* checking for: lex */
              if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                /* checking for: sort */
                if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                  ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                  /* checking for: StrChar */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                    ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                    /* checking for: attrs */
                    if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                      ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                      if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                        ATerm arg_arg0_arg2_arg0_head;
                        ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                        arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                        arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                        /* checking for: term */
                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                          ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                          /* checking for: cons */
                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                            ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                            /* checking for: backslash */
                            if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun125) {
                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                ATerm arg_arg1 = ATgetArgument(arg, 1);
                                if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                  ATerm arg_arg1_head;
                                  ATermList arg_arg1_list = (ATermList)arg_arg1;
                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                  /* checking for: appl */
                                  if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                    ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                    /* checking for: prod */
                                    if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                      ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                        ATerm arg_arg1_head_arg0_arg0_head;
                                        ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                        arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                        arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                        /* checking for: char-class */
                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                          ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                            ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                            ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                            arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATfalse) {
                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                  /* checking for: char-class */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                            /* checking for: lit */
                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                              /* checking for: \\ */
                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun124) {
                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                /* checking for: no-attrs */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                    ATerm arg_arg1_head_arg1_head;
                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATfalse) {
                                                                        arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                        arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                          if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                              return ATtrue;
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar is a decimal by checking against the following ATerm pattern: appl(prod([lit("\\"),char-class([range(48,57)]),char-class([range(48,57)]),char-class([range(48,57)])],lex(sort("StrChar")),attrs([term(cons("decimal"))])),[appl(prod([char-class([92])],lit("\\"),no-attrs),[92]),<"a"(char)>,<"b"(char)>,<"c"(char)>]). May not be used to assert correctness of the MA_LexStrChar
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a decimal, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharDecimal(MA_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lit */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun9) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: \ */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun126) {
            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
              /* checking for: char-class */
              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                  ATerm arg_arg0_arg0_head_arg0_head;
                  ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                  arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                  arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                  /* checking for: range */
                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
                    ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                      ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: char-class */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                ATerm arg_arg0_arg0_head_arg0_head;
                                ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                /* checking for: range */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
                                  ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                                    ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                                          arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                                          arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                                          /* checking for: char-class */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
                                            ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                              ATerm arg_arg0_arg0_head_arg0_head;
                                              ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                              arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                              arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                              /* checking for: range */
                                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
                                                ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 48) {

                                                  ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 57) {

                                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                                      if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                        ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                        /* checking for: lex */
                                                        if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                                                          ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                          /* checking for: sort */
                                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                            ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                            /* checking for: StrChar */
                                                            if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                                                              ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                              /* checking for: attrs */
                                                              if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                  ATerm arg_arg0_arg2_arg0_head;
                                                                  ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                  arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                  arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                  /* checking for: term */
                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                    ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                    /* checking for: cons */
                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                      ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                      /* checking for: decimal */
                                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun127) {
                                                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                          ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                          if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                            ATerm arg_arg1_head;
                                                                            ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                            /* checking for: appl */
                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                              /* checking for: prod */
                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun1) {
                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0) == ATfalse) {
                                                                                  ATerm arg_arg1_head_arg0_arg0_head;
                                                                                  ATermList arg_arg1_head_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0;
                                                                                  arg_arg1_head_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_list);
                                                                                  arg_arg1_head_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_list);
                                                                                  /* checking for: char-class */
                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_head) == MA_afun16) {
                                                                                    ATerm arg_arg1_head_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_head, 0);
                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0) == ATfalse) {
                                                                                      ATerm arg_arg1_head_arg0_arg0_head_arg0_head;
                                                                                      ATermList arg_arg1_head_arg0_arg0_head_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_head_arg0;
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      arg_arg1_head_arg0_arg0_head_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_head_arg0_list);
                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_head_arg0_head) == 92) {

                                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_head_arg0_list) == ATtrue) {
                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_list) == ATtrue) {
                                                                                            ATerm arg_arg1_head_arg0_arg1 = ATgetArgument(arg_arg1_head_arg0, 1);
                                                                                            /* checking for: lit */
                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1) == MA_afun9) {
                                                                                              ATerm arg_arg1_head_arg0_arg1_arg0 = ATgetArgument(arg_arg1_head_arg0_arg1, 0);
                                                                                              /* checking for: \ */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg1_arg0) == MA_afun126) {
                                                                                                ATerm arg_arg1_head_arg0_arg2 = ATgetArgument(arg_arg1_head_arg0, 2);
                                                                                                /* checking for: no-attrs */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg2) == MA_afun5) {
                                                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1) == ATfalse) {
                                                                                                    ATerm arg_arg1_head_arg1_head;
                                                                                                    ATermList arg_arg1_head_arg1_list = (ATermList)arg_arg1_head_arg1;
                                                                                                    arg_arg1_head_arg1_head = ATgetFirst(arg_arg1_head_arg1_list);
                                                                                                    arg_arg1_head_arg1_list = ATgetNext(arg_arg1_head_arg1_list);
                                                                                                    if (ATgetInt((ATermInt)arg_arg1_head_arg1_head) == 92) {

                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg1_list) == ATtrue) {
                                                                                                        if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                                if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                                                  arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                                                  arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                                                  if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                      return ATtrue;
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar is a normal by checking against the following ATerm pattern: appl(prod([char-class([range(32,33),range(35,91),range(93,255)])],lex(sort("StrChar")),attrs([term(cons("normal"))])),[<"ch"(char)>]). May not be used to assert correctness of the MA_LexStrChar
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if #arg corresponds to the signature of a normal, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharNormal(MA_LexStrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 32) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 33) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 35) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 91) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                            /* checking for: range */
                            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
                              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 93) {

                                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 255) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: lex */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: StrChar */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: normal */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun55) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                              return ATtrue;
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar has a a. 
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if the MA_LexStrChar had a a, or ATfalse otherwise
 */
ATbool MA_hasLexStrCharA(MA_LexStrChar arg) {
  if (MA_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar has a b. 
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if the MA_LexStrChar had a b, or ATfalse otherwise
 */
ATbool MA_hasLexStrCharB(MA_LexStrChar arg) {
  if (MA_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar has a c. 
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if the MA_LexStrChar had a c, or ATfalse otherwise
 */
ATbool MA_hasLexStrCharC(MA_LexStrChar arg) {
  if (MA_isLexStrCharDecimal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrChar has a ch. 
 * \param[in] arg input MA_LexStrChar
 * \return ATtrue if the MA_LexStrChar had a ch, or ATfalse otherwise
 */
ATbool MA_hasLexStrCharCh(MA_LexStrChar arg) {
  if (MA_isLexStrCharNormal(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the a char of a MA_LexStrChar. Note that the precondition is that this MA_LexStrChar actually has a a
 * \param[in] arg input MA_LexStrChar
 * \return the a of #arg, if it exist or an undefined value if it does not
 */
char MA_getLexStrCharA(MA_LexStrChar arg) {
  
    return (char)MA_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1));
}

/**
 * Get the b char of a MA_LexStrChar. Note that the precondition is that this MA_LexStrChar actually has a b
 * \param[in] arg input MA_LexStrChar
 * \return the b of #arg, if it exist or an undefined value if it does not
 */
char MA_getLexStrCharB(MA_LexStrChar arg) {
  
    return (char)MA_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 2));
}

/**
 * Get the c char of a MA_LexStrChar. Note that the precondition is that this MA_LexStrChar actually has a c
 * \param[in] arg input MA_LexStrChar
 * \return the c of #arg, if it exist or an undefined value if it does not
 */
char MA_getLexStrCharC(MA_LexStrChar arg) {
  
    return (char)MA_charToByte((ATerm)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 3));
}

/**
 * Get the ch char of a MA_LexStrChar. Note that the precondition is that this MA_LexStrChar actually has a ch
 * \param[in] arg input MA_LexStrChar
 * \return the ch of #arg, if it exist or an undefined value if it does not
 */
char MA_getLexStrCharCh(MA_LexStrChar arg) {
  
    return (char)MA_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Set the a of a MA_LexStrChar. The precondition being that this MA_LexStrChar actually has a a
 * \param[in] arg input MA_LexStrChar
 * \param[in] a new char to set in #arg
 * \return A new MA_LexStrChar with a at the right place, or a core dump if #arg did not have a a
 */
MA_LexStrChar MA_setLexStrCharA(MA_LexStrChar arg, char a) {
  if (MA_isLexStrCharDecimal(arg)) {
    return (MA_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) MA_byteToChar(a))), 1), 1);
  }

  ATabort("LexStrChar has no A: %t\n", arg);
  return (MA_LexStrChar)NULL;
}

/**
 * Set the b of a MA_LexStrChar. The precondition being that this MA_LexStrChar actually has a b
 * \param[in] arg input MA_LexStrChar
 * \param[in] b new char to set in #arg
 * \return A new MA_LexStrChar with b at the right place, or a core dump if #arg did not have a b
 */
MA_LexStrChar MA_setLexStrCharB(MA_LexStrChar arg, char b) {
  if (MA_isLexStrCharDecimal(arg)) {
    return (MA_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) MA_byteToChar(b))), 2), 1);
  }

  ATabort("LexStrChar has no B: %t\n", arg);
  return (MA_LexStrChar)NULL;
}

/**
 * Set the c of a MA_LexStrChar. The precondition being that this MA_LexStrChar actually has a c
 * \param[in] arg input MA_LexStrChar
 * \param[in] c new char to set in #arg
 * \return A new MA_LexStrChar with c at the right place, or a core dump if #arg did not have a c
 */
MA_LexStrChar MA_setLexStrCharC(MA_LexStrChar arg, char c) {
  if (MA_isLexStrCharDecimal(arg)) {
    return (MA_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) MA_byteToChar(c))), 3), 1);
  }

  ATabort("LexStrChar has no C: %t\n", arg);
  return (MA_LexStrChar)NULL;
}

/**
 * Set the ch of a MA_LexStrChar. The precondition being that this MA_LexStrChar actually has a ch
 * \param[in] arg input MA_LexStrChar
 * \param[in] ch new char to set in #arg
 * \return A new MA_LexStrChar with ch at the right place, or a core dump if #arg did not have a ch
 */
MA_LexStrChar MA_setLexStrCharCh(MA_LexStrChar arg, char ch) {
  if (MA_isLexStrCharNormal(arg)) {
    return (MA_LexStrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) MA_byteToChar(ch))), 0), 1);
  }

  ATabort("LexStrChar has no Ch: %t\n", arg);
  return (MA_LexStrChar)NULL;
}

/**
 * Assert whether a MA_StrChar is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_StrChar
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidStrChar(MA_StrChar arg) {
  if (MA_isStrCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_StrChar is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("StrChar"))],cf(sort("StrChar")),no-attrs),[<"StrChar"("Lex-StrChar")>]). Always returns ATtrue
 * \param[in] arg input MA_StrChar
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool MA_isStrCharLexToCf(MA_StrChar arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: StrChar */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun118) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: StrChar */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun118) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_StrChar has a StrChar. 
 * \param[in] arg input MA_StrChar
 * \return ATtrue if the MA_StrChar had a StrChar, or ATfalse otherwise
 */
ATbool MA_hasStrCharStrChar(MA_StrChar arg) {
  if (MA_isStrCharLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the StrChar MA_LexStrChar of a MA_StrChar. Note that the precondition is that this MA_StrChar actually has a StrChar
 * \param[in] arg input MA_StrChar
 * \return the StrChar of #arg, if it exist or an undefined value if it does not
 */
MA_LexStrChar MA_getStrCharStrChar(MA_StrChar arg) {
  
    return (MA_LexStrChar)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the StrChar of a MA_StrChar. The precondition being that this MA_StrChar actually has a StrChar
 * \param[in] arg input MA_StrChar
 * \param[in] StrChar new MA_LexStrChar to set in #arg
 * \return A new MA_StrChar with StrChar at the right place, or a core dump if #arg did not have a StrChar
 */
MA_StrChar MA_setStrCharStrChar(MA_StrChar arg, MA_LexStrChar StrChar) {
  if (MA_isStrCharLexToCf(arg)) {
    return (MA_StrChar)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) StrChar), 0), 1);
  }

  ATabort("StrChar has no StrChar: %t\n", arg);
  return (MA_StrChar)NULL;
}

/**
 * Assert whether a MA_LexStrCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexStrCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexStrCon(MA_LexStrCon arg) {
  if (MA_isLexStrConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCon is a default by checking against the following ATerm pattern: appl(prod([char-class([34]),lex(iter-star(sort("StrChar"))),char-class([34])],lex(sort("StrCon")),attrs([term(cons("default"))])),[34,appl(list(lex(iter-star(sort("StrChar")))),<"chars"("Lex-StrChar-chars")>),34]). Always returns ATtrue
 * \param[in] arg input MA_LexStrCon
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool MA_isLexStrConDefault(MA_LexStrCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                  arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                  arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                  /* checking for: lex */
                  if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
                    ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                    /* checking for: iter-star */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun128) {
                      ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                      /* checking for: sort */
                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun11) {
                        ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                        /* checking for: StrChar */
                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0) == MA_afun118) {
                          if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                            arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                            arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                            /* checking for: char-class */
                            if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
                              ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
                                ATerm arg_arg0_arg0_head_arg0_head;
                                ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
                                arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                                arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head) == 34) {

                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                                    if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                      ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                      /* checking for: lex */
                                      if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                                        ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                        /* checking for: sort */
                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                          ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                          /* checking for: StrCon */
                                          if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun31) {
                                            ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                            /* checking for: attrs */
                                            if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                              ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                ATerm arg_arg0_arg2_arg0_head;
                                                ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                /* checking for: term */
                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                  ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                  /* checking for: cons */
                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                    ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                    /* checking for: default */
                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun129) {
                                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                          ATerm arg_arg1_head;
                                                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                          arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                          arg_arg1_list = ATgetNext(arg_arg1_list);
                                                          if (ATgetInt((ATermInt)arg_arg1_head) == 34) {

                                                            if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                                              /* checking for: appl */
                                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                /* checking for: list */
                                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                  /* checking for: lex */
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun6) {
                                                                    ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                    /* checking for: iter-star */
                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun128) {
                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                      /* checking for: sort */
                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun11) {
                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                        /* checking for: StrChar */
                                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == MA_afun118) {
                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                            if (ATgetInt((ATermInt)arg_arg1_head) == 34) {

                                                                              if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                return ATtrue;
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCon has a chars. 
 * \param[in] arg input MA_LexStrCon
 * \return ATtrue if the MA_LexStrCon had a chars, or ATfalse otherwise
 */
ATbool MA_hasLexStrConChars(MA_LexStrCon arg) {
  if (MA_isLexStrConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the chars MA_LexStrCharChars of a MA_LexStrCon. Note that the precondition is that this MA_LexStrCon actually has a chars
 * \param[in] arg input MA_LexStrCon
 * \return the chars of #arg, if it exist or an undefined value if it does not
 */
MA_LexStrCharChars MA_getLexStrConChars(MA_LexStrCon arg) {
  
    return (MA_LexStrCharChars)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1);
}

/**
 * Set the chars of a MA_LexStrCon. The precondition being that this MA_LexStrCon actually has a chars
 * \param[in] arg input MA_LexStrCon
 * \param[in] chars new MA_LexStrCharChars to set in #arg
 * \return A new MA_LexStrCon with chars at the right place, or a core dump if #arg did not have a chars
 */
MA_LexStrCon MA_setLexStrConChars(MA_LexStrCon arg, MA_LexStrCharChars chars) {
  if (MA_isLexStrConDefault(arg)) {
    return (MA_LexStrCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) chars), 1), 1), 1);
  }

  ATabort("LexStrCon has no Chars: %t\n", arg);
  return (MA_LexStrCon)NULL;
}

/**
 * Assert whether a MA_StrCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_StrCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidStrCon(MA_StrCon arg) {
  if (MA_isStrConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_StrCon is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("StrCon"))],cf(sort("StrCon")),no-attrs),[<"StrCon"("Lex-StrCon")>]). Always returns ATtrue
 * \param[in] arg input MA_StrCon
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool MA_isStrConLexToCf(MA_StrCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: StrCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun31) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: StrCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun31) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_StrCon has a StrCon. 
 * \param[in] arg input MA_StrCon
 * \return ATtrue if the MA_StrCon had a StrCon, or ATfalse otherwise
 */
ATbool MA_hasStrConStrCon(MA_StrCon arg) {
  if (MA_isStrConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the StrCon MA_LexStrCon of a MA_StrCon. Note that the precondition is that this MA_StrCon actually has a StrCon
 * \param[in] arg input MA_StrCon
 * \return the StrCon of #arg, if it exist or an undefined value if it does not
 */
MA_LexStrCon MA_getStrConStrCon(MA_StrCon arg) {
  
    return (MA_LexStrCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the StrCon of a MA_StrCon. The precondition being that this MA_StrCon actually has a StrCon
 * \param[in] arg input MA_StrCon
 * \param[in] StrCon new MA_LexStrCon to set in #arg
 * \return A new MA_StrCon with StrCon at the right place, or a core dump if #arg did not have a StrCon
 */
MA_StrCon MA_setStrConStrCon(MA_StrCon arg, MA_LexStrCon StrCon) {
  if (MA_isStrConLexToCf(arg)) {
    return (MA_StrCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) StrCon), 0), 1);
  }

  ATabort("StrCon has no StrCon: %t\n", arg);
  return (MA_StrCon)NULL;
}

/**
 * Assert whether a MA_LexStrCharChars is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexStrCharChars
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexStrCharChars(MA_LexStrCharChars arg) {
  if (MA_isLexStrCharCharsEmpty(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharCharsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharCharsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCharChars is a empty by checking against the following ATerm pattern: []. May not be used to assert correctness of the MA_LexStrCharChars
 * \param[in] arg input MA_LexStrCharChars
 * \return ATtrue if #arg corresponds to the signature of a empty, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharCharsEmpty(MA_LexStrCharChars arg){
  if (ATisEmpty((ATermList)arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCharChars is a single by checking against the following ATerm pattern: [<head(Lex-StrChar)>]. May not be used to assert correctness of the MA_LexStrCharChars
 * \param[in] arg input MA_LexStrCharChars
 * \return ATtrue if #arg corresponds to the signature of a single, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharCharsSingle(MA_LexStrCharChars arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    ATermList arg_list = (ATermList)arg;
    arg_list = ATgetNext(arg_list);
    if (ATgetType((ATerm)arg_list) == AT_LIST && ATisEmpty((ATermList)arg_list) == ATtrue) {
      return ATtrue;
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCharChars is a many by checking against the following ATerm pattern: [<head(Lex-StrChar)>,<[tail(Lex-StrChar-chars)]>]. May not be used to assert correctness of the MA_LexStrCharChars
 * \param[in] arg input MA_LexStrCharChars
 * \return ATtrue if #arg corresponds to the signature of a many, or ATfalse otherwise
 */
inline ATbool MA_isLexStrCharCharsMany(MA_LexStrCharChars arg){
  if (ATgetType((ATerm)arg) == AT_LIST && ATisEmpty((ATermList)arg) == ATfalse) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCharChars has a head. 
 * \param[in] arg input MA_LexStrCharChars
 * \return ATtrue if the MA_LexStrCharChars had a head, or ATfalse otherwise
 */
ATbool MA_hasLexStrCharCharsHead(MA_LexStrCharChars arg) {
  if (MA_isLexStrCharCharsSingle(arg)) {
    return ATtrue;
  }
  else if (MA_isLexStrCharCharsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexStrCharChars has a tail. 
 * \param[in] arg input MA_LexStrCharChars
 * \return ATtrue if the MA_LexStrCharChars had a tail, or ATfalse otherwise
 */
ATbool MA_hasLexStrCharCharsTail(MA_LexStrCharChars arg) {
  if (MA_isLexStrCharCharsMany(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head MA_LexStrChar of a MA_LexStrCharChars. Note that the precondition is that this MA_LexStrCharChars actually has a head
 * \param[in] arg input MA_LexStrCharChars
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
MA_LexStrChar MA_getLexStrCharCharsHead(MA_LexStrCharChars arg) {
  if (MA_isLexStrCharCharsSingle(arg)) {
    return (MA_LexStrChar)ATgetFirst((ATermList)arg);
  }
  else 
    return (MA_LexStrChar)ATgetFirst((ATermList)arg);
}

/**
 * Get the tail MA_LexStrCharChars of a MA_LexStrCharChars. Note that the precondition is that this MA_LexStrCharChars actually has a tail
 * \param[in] arg input MA_LexStrCharChars
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
MA_LexStrCharChars MA_getLexStrCharCharsTail(MA_LexStrCharChars arg) {
  
    return (MA_LexStrCharChars)ATgetNext((ATermList)arg);
}

/**
 * Set the head of a MA_LexStrCharChars. The precondition being that this MA_LexStrCharChars actually has a head
 * \param[in] arg input MA_LexStrCharChars
 * \param[in] head new MA_LexStrChar to set in #arg
 * \return A new MA_LexStrCharChars with head at the right place, or a core dump if #arg did not have a head
 */
MA_LexStrCharChars MA_setLexStrCharCharsHead(MA_LexStrCharChars arg, MA_LexStrChar head) {
  if (MA_isLexStrCharCharsSingle(arg)) {
    return (MA_LexStrCharChars)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }
  else if (MA_isLexStrCharCharsMany(arg)) {
    return (MA_LexStrCharChars)ATreplace((ATermList)arg, (ATerm)((ATerm) head), 0);
  }

  ATabort("LexStrCharChars has no Head: %t\n", arg);
  return (MA_LexStrCharChars)NULL;
}

/**
 * Set the tail of a MA_LexStrCharChars. The precondition being that this MA_LexStrCharChars actually has a tail
 * \param[in] arg input MA_LexStrCharChars
 * \param[in] tail new MA_LexStrCharChars to set in #arg
 * \return A new MA_LexStrCharChars with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_LexStrCharChars MA_setLexStrCharCharsTail(MA_LexStrCharChars arg, MA_LexStrCharChars tail) {
  if (MA_isLexStrCharCharsMany(arg)) {
    return (MA_LexStrCharChars)ATreplaceTail((ATermList)arg, (ATermList)((ATerm) tail), 1);
  }

  ATabort("LexStrCharChars has no Tail: %t\n", arg);
  return (MA_LexStrCharChars)NULL;
}

/**
 * Assert whether a MA_LexNatCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexNatCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexNatCon(MA_LexNatCon arg) {
  if (MA_isLexNatConDigits(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexNatCon is a digits by checking against the following ATerm pattern: appl(prod([lex(iter(char-class([range(48,57)])))],lex(sort("NatCon")),attrs([term(cons("digits"))])),[appl(list(lex(iter(char-class([range(48,57)])))),<"list"(chars)>)]). Always returns ATtrue
 * \param[in] arg input MA_LexNatCon
 * \return ATtrue if #arg corresponds to the signature of a digits, or ATfalse otherwise
 */
inline ATbool MA_isLexNatConDigits(MA_LexNatCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: iter */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun7) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: char-class */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun16) {
              ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
              if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                /* checking for: range */
                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == MA_afun115) {
                  ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                  if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 48) {

                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 57) {

                      if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                        if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                          ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                          /* checking for: lex */
                          if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                            ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                            /* checking for: sort */
                            if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                              ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                              /* checking for: NatCon */
                              if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun25) {
                                ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                /* checking for: attrs */
                                if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                  ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                    ATerm arg_arg0_arg2_arg0_head;
                                    ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                    arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                    arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                    /* checking for: term */
                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                      ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                      /* checking for: cons */
                                      if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                        ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                        /* checking for: digits */
                                        if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun130) {
                                          if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                            ATerm arg_arg1 = ATgetArgument(arg, 1);
                                            if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                              ATerm arg_arg1_head;
                                              ATermList arg_arg1_list = (ATermList)arg_arg1;
                                              arg_arg1_head = ATgetFirst(arg_arg1_list);
                                              arg_arg1_list = ATgetNext(arg_arg1_list);
                                              /* checking for: appl */
                                              if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                /* checking for: list */
                                                if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                  ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                  /* checking for: lex */
                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun6) {
                                                    ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                    /* checking for: iter */
                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun7) {
                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                      /* checking for: char-class */
                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun16) {
                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                        if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                          ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                          ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                          arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                          arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                          /* checking for: range */
                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == MA_afun115) {
                                                            ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                            if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 48) {

                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 57) {

                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                  ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                  if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                    if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                      return ATtrue;
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexNatCon has a list. 
 * \param[in] arg input MA_LexNatCon
 * \return ATtrue if the MA_LexNatCon had a list, or ATfalse otherwise
 */
ATbool MA_hasLexNatConList(MA_LexNatCon arg) {
  if (MA_isLexNatConDigits(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the list char* of a MA_LexNatCon. Note that the precondition is that this MA_LexNatCon actually has a list
 * \param[in] arg input MA_LexNatCon
 * \return the list of #arg, if it exist or an undefined value if it does not
 */
char* MA_getLexNatConList(MA_LexNatCon arg) {
  
    return (char*)MA_charsToString((ATerm)ATgetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), 1));
}

/**
 * Set the list of a MA_LexNatCon. The precondition being that this MA_LexNatCon actually has a list
 * \param[in] arg input MA_LexNatCon
 * \param[in] list new const char* to set in #arg
 * \return A new MA_LexNatCon with list at the right place, or a core dump if #arg did not have a list
 */
MA_LexNatCon MA_setLexNatConList(MA_LexNatCon arg, const char* list) {
  if (MA_isLexNatConDigits(arg)) {
    return (MA_LexNatCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)), (ATerm)((ATerm) ((ATerm) MA_stringToChars(list))), 1), 0), 1);
  }

  ATabort("LexNatCon has no List: %t\n", arg);
  return (MA_LexNatCon)NULL;
}

/**
 * Assert whether a MA_NatCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_NatCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidNatCon(MA_NatCon arg) {
  if (MA_isNatConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_NatCon is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("NatCon"))],cf(sort("NatCon")),no-attrs),[<"NatCon"("Lex-NatCon")>]). Always returns ATtrue
 * \param[in] arg input MA_NatCon
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool MA_isNatConLexToCf(MA_NatCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: NatCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun25) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: NatCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun25) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_NatCon has a NatCon. 
 * \param[in] arg input MA_NatCon
 * \return ATtrue if the MA_NatCon had a NatCon, or ATfalse otherwise
 */
ATbool MA_hasNatConNatCon(MA_NatCon arg) {
  if (MA_isNatConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the NatCon MA_LexNatCon of a MA_NatCon. Note that the precondition is that this MA_NatCon actually has a NatCon
 * \param[in] arg input MA_NatCon
 * \return the NatCon of #arg, if it exist or an undefined value if it does not
 */
MA_LexNatCon MA_getNatConNatCon(MA_NatCon arg) {
  
    return (MA_LexNatCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the NatCon of a MA_NatCon. The precondition being that this MA_NatCon actually has a NatCon
 * \param[in] arg input MA_NatCon
 * \param[in] NatCon new MA_LexNatCon to set in #arg
 * \return A new MA_NatCon with NatCon at the right place, or a core dump if #arg did not have a NatCon
 */
MA_NatCon MA_setNatConNatCon(MA_NatCon arg, MA_LexNatCon NatCon) {
  if (MA_isNatConLexToCf(arg)) {
    return (MA_NatCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) NatCon), 0), 1);
  }

  ATabort("NatCon has no NatCon: %t\n", arg);
  return (MA_NatCon)NULL;
}

/**
 * Assert whether a MA_LexIdCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_LexIdCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidLexIdCon(MA_LexIdCon arg) {
  if (MA_isLexIdConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexIdCon is a default by checking against the following ATerm pattern: appl(prod([char-class([range(65,90),range(97,122)]),lex(iter-star(char-class([45,range(48,57),range(65,90),range(97,122)])))],lex(sort("IdCon")),attrs([term(cons("default"))])),[<"head"(char)>,appl(list(lex(iter-star(char-class([45,range(48,57),range(65,90),range(97,122)])))),<"tail"(chars)>)]). Always returns ATtrue
 * \param[in] arg input MA_LexIdCon
 * \return ATtrue if #arg corresponds to the signature of a default, or ATfalse otherwise
 */
inline ATbool MA_isLexIdConDefault(MA_LexIdCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: char-class */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun16) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0) == ATfalse) {
            ATerm arg_arg0_arg0_head_arg0_head;
            ATermList arg_arg0_arg0_head_arg0_list = (ATermList)arg_arg0_arg0_head_arg0;
            arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
            arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
            /* checking for: range */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
              ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 65) {

                ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 90) {

                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATfalse) {
                    arg_arg0_arg0_head_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_list);
                    arg_arg0_arg0_head_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_list);
                    /* checking for: range */
                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_head) == MA_afun115) {
                      ATerm arg_arg0_arg0_head_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 0);
                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg0) == 97) {

                        ATerm arg_arg0_arg0_head_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_head, 1);
                        if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_head_arg1) == 122) {

                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_list) == ATtrue) {
                            if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATfalse) {
                              arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
                              arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
                              /* checking for: lex */
                              if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
                                ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
                                /* checking for: iter-star */
                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun128) {
                                  ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
                                  /* checking for: char-class */
                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun16) {
                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0, 0);
                                    if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0) == ATfalse) {
                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head;
                                      ATermList arg_arg0_arg0_head_arg0_arg0_arg0_list = (ATermList)arg_arg0_arg0_head_arg0_arg0_arg0;
                                      arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                      arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head) == 45) {

                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                          /* checking for: range */
                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == MA_afun115) {
                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 48) {

                                              ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 57) {

                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                  arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                  arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                  /* checking for: range */
                                                  if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == MA_afun115) {
                                                    ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                    if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 65) {

                                                      ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                      if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 90) {

                                                        if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATfalse) {
                                                          arg_arg0_arg0_head_arg0_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                          arg_arg0_arg0_head_arg0_arg0_arg0_list = ATgetNext(arg_arg0_arg0_head_arg0_arg0_arg0_list);
                                                          /* checking for: range */
                                                          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0_arg0_head) == MA_afun115) {
                                                            ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 0);
                                                            if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg0) == 97) {

                                                              ATerm arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg0_arg0_head_arg0_arg0_arg0_head, 1);
                                                              if (ATgetInt((ATermInt)arg_arg0_arg0_head_arg0_arg0_arg0_head_arg1) == 122) {

                                                                if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_head_arg0_arg0_arg0_list) == ATtrue) {
                                                                  if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                                                                    ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                                                                    /* checking for: lex */
                                                                    if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun6) {
                                                                      ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                                                                      /* checking for: sort */
                                                                      if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                                                                        ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                                                                        /* checking for: IdCon */
                                                                        if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun28) {
                                                                          ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                                                                          /* checking for: attrs */
                                                                          if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun13) {
                                                                            ATerm arg_arg0_arg2_arg0 = ATgetArgument(arg_arg0_arg2, 0);
                                                                            if (ATgetType((ATerm)arg_arg0_arg2_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0) == ATfalse) {
                                                                              ATerm arg_arg0_arg2_arg0_head;
                                                                              ATermList arg_arg0_arg2_arg0_list = (ATermList)arg_arg0_arg2_arg0;
                                                                              arg_arg0_arg2_arg0_head = ATgetFirst(arg_arg0_arg2_arg0_list);
                                                                              arg_arg0_arg2_arg0_list = ATgetNext(arg_arg0_arg2_arg0_list);
                                                                              /* checking for: term */
                                                                              if (ATgetType((ATerm)arg_arg0_arg2_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head) == MA_afun14) {
                                                                                ATerm arg_arg0_arg2_arg0_head_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head, 0);
                                                                                /* checking for: cons */
                                                                                if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0) == MA_afun15) {
                                                                                  ATerm arg_arg0_arg2_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg2_arg0_head_arg0, 0);
                                                                                  /* checking for: default */
                                                                                  if (ATgetType((ATerm)arg_arg0_arg2_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2_arg0_head_arg0_arg0) == MA_afun129) {
                                                                                    if (ATgetType((ATerm)arg_arg0_arg2_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg2_arg0_list) == ATtrue) {
                                                                                      ATerm arg_arg1 = ATgetArgument(arg, 1);
                                                                                      if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                                                                                        ATerm arg_arg1_head;
                                                                                        ATermList arg_arg1_list = (ATermList)arg_arg1;
                                                                                        arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                        arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                        if (ATgetType((ATerm)arg_arg1_head) == AT_INT) {
                                                                                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATfalse) {
                                                                                            arg_arg1_head = ATgetFirst(arg_arg1_list);
                                                                                            arg_arg1_list = ATgetNext(arg_arg1_list);
                                                                                            /* checking for: appl */
                                                                                            if (ATgetType((ATerm)arg_arg1_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head) == MA_afun0) {
                                                                                              ATerm arg_arg1_head_arg0 = ATgetArgument(arg_arg1_head, 0);
                                                                                              /* checking for: list */
                                                                                              if (ATgetType((ATerm)arg_arg1_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0) == MA_afun8) {
                                                                                                ATerm arg_arg1_head_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0, 0);
                                                                                                /* checking for: lex */
                                                                                                if (ATgetType((ATerm)arg_arg1_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0) == MA_afun6) {
                                                                                                  ATerm arg_arg1_head_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0, 0);
                                                                                                  /* checking for: iter-star */
                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0) == MA_afun128) {
                                                                                                    ATerm arg_arg1_head_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0, 0);
                                                                                                    /* checking for: char-class */
                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0) == MA_afun16) {
                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0, 0);
                                                                                                      if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0) == ATfalse) {
                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head;
                                                                                                        ATermList arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = (ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0;
                                                                                                        arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                        arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == 45) {

                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                            /* checking for: range */
                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == MA_afun115) {
                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 48) {

                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 57) {

                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                    arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                    arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                    /* checking for: range */
                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == MA_afun115) {
                                                                                                                      ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                      if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 65) {

                                                                                                                        ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                        if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 90) {

                                                                                                                          if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATfalse) {
                                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head = ATgetFirst(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                            arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list = ATgetNext(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list);
                                                                                                                            /* checking for: range */
                                                                                                                            if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head) == MA_afun115) {
                                                                                                                              ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 0);
                                                                                                                              if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg0) == 97) {

                                                                                                                                ATerm arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1 = ATgetArgument(arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head, 1);
                                                                                                                                if (ATgetInt((ATermInt)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_head_arg1) == 122) {

                                                                                                                                  if (ATgetType((ATerm)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_head_arg0_arg0_arg0_arg0_arg0_list) == ATtrue) {
                                                                                                                                    ATerm arg_arg1_head_arg1 = ATgetArgument(arg_arg1_head, 1);
                                                                                                                                    if (ATgetType((ATerm)arg_arg1_head_arg1) == AT_LIST) {
                                                                                                                                      if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                                                                                                                                        return ATtrue;
                                                                                                                                      }
                                                                                                                                    }
                                                                                                                                  }
                                                                                                                                }
                                                                                                                              }
                                                                                                                            }
                                                                                                                          }
                                                                                                                        }
                                                                                                                      }
                                                                                                                    }
                                                                                                                  }
                                                                                                                }
                                                                                                              }
                                                                                                            }
                                                                                                          }
                                                                                                        }
                                                                                                      }
                                                                                                    }
                                                                                                  }
                                                                                                }
                                                                                              }
                                                                                            }
                                                                                          }
                                                                                        }
                                                                                      }
                                                                                    }
                                                                                  }
                                                                                }
                                                                              }
                                                                            }
                                                                          }
                                                                        }
                                                                      }
                                                                    }
                                                                  }
                                                                }
                                                              }
                                                            }
                                                          }
                                                        }
                                                      }
                                                    }
                                                  }
                                                }
                                              }
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexIdCon has a head. 
 * \param[in] arg input MA_LexIdCon
 * \return ATtrue if the MA_LexIdCon had a head, or ATfalse otherwise
 */
ATbool MA_hasLexIdConHead(MA_LexIdCon arg) {
  if (MA_isLexIdConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_LexIdCon has a tail. 
 * \param[in] arg input MA_LexIdCon
 * \return ATtrue if the MA_LexIdCon had a tail, or ATfalse otherwise
 */
ATbool MA_hasLexIdConTail(MA_LexIdCon arg) {
  if (MA_isLexIdConDefault(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the head char of a MA_LexIdCon. Note that the precondition is that this MA_LexIdCon actually has a head
 * \param[in] arg input MA_LexIdCon
 * \return the head of #arg, if it exist or an undefined value if it does not
 */
char MA_getLexIdConHead(MA_LexIdCon arg) {
  
    return (char)MA_charToByte((ATerm)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1)));
}

/**
 * Get the tail char* of a MA_LexIdCon. Note that the precondition is that this MA_LexIdCon actually has a tail
 * \param[in] arg input MA_LexIdCon
 * \return the tail of #arg, if it exist or an undefined value if it does not
 */
char* MA_getLexIdConTail(MA_LexIdCon arg) {
  
    return (char*)MA_charsToString((ATerm)ATgetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), 1));
}

/**
 * Set the head of a MA_LexIdCon. The precondition being that this MA_LexIdCon actually has a head
 * \param[in] arg input MA_LexIdCon
 * \param[in] head new char to set in #arg
 * \return A new MA_LexIdCon with head at the right place, or a core dump if #arg did not have a head
 */
MA_LexIdCon MA_setLexIdConHead(MA_LexIdCon arg, char head) {
  if (MA_isLexIdConDefault(arg)) {
    return (MA_LexIdCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) ((ATerm) MA_byteToChar(head))), 0), 1);
  }

  ATabort("LexIdCon has no Head: %t\n", arg);
  return (MA_LexIdCon)NULL;
}

/**
 * Set the tail of a MA_LexIdCon. The precondition being that this MA_LexIdCon actually has a tail
 * \param[in] arg input MA_LexIdCon
 * \param[in] tail new const char* to set in #arg
 * \return A new MA_LexIdCon with tail at the right place, or a core dump if #arg did not have a tail
 */
MA_LexIdCon MA_setLexIdConTail(MA_LexIdCon arg, const char* tail) {
  if (MA_isLexIdConDefault(arg)) {
    return (MA_LexIdCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)ATsetArgument((ATermAppl)ATelementAt((ATermList)ATgetArgument((ATermAppl)arg, 1), 1), (ATerm)((ATerm) ((ATerm) MA_stringToChars(tail))), 1), 1), 1);
  }

  ATabort("LexIdCon has no Tail: %t\n", arg);
  return (MA_LexIdCon)NULL;
}

/**
 * Assert whether a MA_IdCon is any of the valid alternatives, or not. This analysis does not go any deeper than the top level
 * \param[in] arg input MA_IdCon
 * \return ATtrue if #arg corresponds to the expected signature, or ATfalse otherwise
 */
ATbool MA_isValidIdCon(MA_IdCon arg) {
  if (MA_isIdConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Assert whether a MA_IdCon is a Lex-to-cf by checking against the following ATerm pattern: appl(prod([lex(sort("IdCon"))],cf(sort("IdCon")),no-attrs),[<"IdCon"("Lex-IdCon")>]). Always returns ATtrue
 * \param[in] arg input MA_IdCon
 * \return ATtrue if #arg corresponds to the signature of a Lex-to-cf, or ATfalse otherwise
 */
inline ATbool MA_isIdConLexToCf(MA_IdCon arg){
  /* checking for: appl */
  if (ATgetType((ATerm)arg) == AT_APPL && ATgetAFun((ATermAppl)arg) == MA_afun0) {
    ATerm arg_arg0 = ATgetArgument(arg, 0);
    /* checking for: prod */
    if (ATgetType((ATerm)arg_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0) == MA_afun1) {
      ATerm arg_arg0_arg0 = ATgetArgument(arg_arg0, 0);
      if (ATgetType((ATerm)arg_arg0_arg0) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0) == ATfalse) {
        ATerm arg_arg0_arg0_head;
        ATermList arg_arg0_arg0_list = (ATermList)arg_arg0_arg0;
        arg_arg0_arg0_head = ATgetFirst(arg_arg0_arg0_list);
        arg_arg0_arg0_list = ATgetNext(arg_arg0_arg0_list);
        /* checking for: lex */
        if (ATgetType((ATerm)arg_arg0_arg0_head) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head) == MA_afun6) {
          ATerm arg_arg0_arg0_head_arg0 = ATgetArgument(arg_arg0_arg0_head, 0);
          /* checking for: sort */
          if (ATgetType((ATerm)arg_arg0_arg0_head_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0) == MA_afun11) {
            ATerm arg_arg0_arg0_head_arg0_arg0 = ATgetArgument(arg_arg0_arg0_head_arg0, 0);
            /* checking for: IdCon */
            if (ATgetType((ATerm)arg_arg0_arg0_head_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg0_head_arg0_arg0) == MA_afun28) {
              if (ATgetType((ATerm)arg_arg0_arg0_list) == AT_LIST && ATisEmpty((ATermList)arg_arg0_arg0_list) == ATtrue) {
                ATerm arg_arg0_arg1 = ATgetArgument(arg_arg0, 1);
                /* checking for: cf */
                if (ATgetType((ATerm)arg_arg0_arg1) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1) == MA_afun2) {
                  ATerm arg_arg0_arg1_arg0 = ATgetArgument(arg_arg0_arg1, 0);
                  /* checking for: sort */
                  if (ATgetType((ATerm)arg_arg0_arg1_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0) == MA_afun11) {
                    ATerm arg_arg0_arg1_arg0_arg0 = ATgetArgument(arg_arg0_arg1_arg0, 0);
                    /* checking for: IdCon */
                    if (ATgetType((ATerm)arg_arg0_arg1_arg0_arg0) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg1_arg0_arg0) == MA_afun28) {
                      ATerm arg_arg0_arg2 = ATgetArgument(arg_arg0, 2);
                      /* checking for: no-attrs */
                      if (ATgetType((ATerm)arg_arg0_arg2) == AT_APPL && ATgetAFun((ATermAppl)arg_arg0_arg2) == MA_afun5) {
                        ATerm arg_arg1 = ATgetArgument(arg, 1);
                        if (ATgetType((ATerm)arg_arg1) == AT_LIST && ATisEmpty((ATermList)arg_arg1) == ATfalse) {
                          ATermList arg_arg1_list = (ATermList)arg_arg1;
                          arg_arg1_list = ATgetNext(arg_arg1_list);
                          if (ATgetType((ATerm)arg_arg1_list) == AT_LIST && ATisEmpty((ATermList)arg_arg1_list) == ATtrue) {
                            return ATtrue;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return ATfalse;
}

/**
 * Assert whether a MA_IdCon has a IdCon. 
 * \param[in] arg input MA_IdCon
 * \return ATtrue if the MA_IdCon had a IdCon, or ATfalse otherwise
 */
ATbool MA_hasIdConIdCon(MA_IdCon arg) {
  if (MA_isIdConLexToCf(arg)) {
    return ATtrue;
  }
  return ATfalse;
}

/**
 * Get the IdCon MA_LexIdCon of a MA_IdCon. Note that the precondition is that this MA_IdCon actually has a IdCon
 * \param[in] arg input MA_IdCon
 * \return the IdCon of #arg, if it exist or an undefined value if it does not
 */
MA_LexIdCon MA_getIdConIdCon(MA_IdCon arg) {
  
    return (MA_LexIdCon)ATgetFirst((ATermList)ATgetArgument((ATermAppl)arg, 1));
}

/**
 * Set the IdCon of a MA_IdCon. The precondition being that this MA_IdCon actually has a IdCon
 * \param[in] arg input MA_IdCon
 * \param[in] IdCon new MA_LexIdCon to set in #arg
 * \return A new MA_IdCon with IdCon at the right place, or a core dump if #arg did not have a IdCon
 */
MA_IdCon MA_setIdConIdCon(MA_IdCon arg, MA_LexIdCon IdCon) {
  if (MA_isIdConLexToCf(arg)) {
    return (MA_IdCon)ATsetArgument((ATermAppl)arg, (ATerm)ATreplace((ATermList)ATgetArgument((ATermAppl)arg, 1), (ATerm)((ATerm) IdCon), 0), 1);
  }

  ATabort("IdCon has no IdCon: %t\n", arg);
  return (MA_IdCon)NULL;
}

/**
 * Apply functions to the children of a MA_OptLayout. 
 * \return A new MA_OptLayout with new children where the argument functions might have applied
 */
MA_OptLayout MA_visitOptLayout(MA_OptLayout arg, MA_Layout (*acceptLayout)(MA_Layout)) {
  if (MA_isOptLayoutAbsent(arg)) {
    return MA_makeOptLayoutAbsent();
  }
  if (MA_isOptLayoutPresent(arg)) {
    return MA_makeOptLayoutPresent(
        acceptLayout ? acceptLayout(MA_getOptLayoutLayout(arg)) : MA_getOptLayoutLayout(arg));
  }
  ATabort("not a OptLayout: %t\n", arg);
  return (MA_OptLayout)NULL;
}
/**
 * Apply functions to the children of a MA_Layout. 
 * \return A new MA_Layout with new children where the argument functions might have applied
 */
MA_Layout MA_visitLayout(MA_Layout arg, MA_LexLayoutList (*acceptList)(MA_LexLayoutList)) {
  if (MA_isLayoutLexToCf(arg)) {
    return MA_makeLayoutLexToCf(
        acceptList ? acceptList(MA_getLayoutList(arg)) : MA_getLayoutList(arg));
  }
  ATabort("not a Layout: %t\n", arg);
  return (MA_Layout)NULL;
}
/**
 * Apply functions to the children of a MA_LexLayoutList. 
 * \return A new MA_LexLayoutList with new children where the argument functions might have applied
 */
MA_LexLayoutList MA_visitLexLayoutList(MA_LexLayoutList arg, MA_LexLayout (*acceptHead)(MA_LexLayout)) {
  if (MA_isLexLayoutListEmpty(arg)) {
    return MA_makeLexLayoutListEmpty();
  }
  if (MA_isLexLayoutListSingle(arg)) {
    return MA_makeLexLayoutListSingle(
        acceptHead ? acceptHead(MA_getLexLayoutListHead(arg)) : MA_getLexLayoutListHead(arg));
  }
  if (MA_isLexLayoutListMany(arg)) {
    return MA_makeLexLayoutListMany(
        acceptHead ? acceptHead(MA_getLexLayoutListHead(arg)) : MA_getLexLayoutListHead(arg),
        MA_visitLexLayoutList(MA_getLexLayoutListTail(arg), acceptHead));
  }
  ATabort("not a LexLayoutList: %t\n", arg);
  return (MA_LexLayoutList)NULL;
}
/**
 * Apply functions to the children of a MA_TraversalStrategy. 
 * \return A new MA_TraversalStrategy with new children where the argument functions might have applied
 */
MA_TraversalStrategy MA_visitTraversalStrategy(MA_TraversalStrategy arg) {
  if (MA_isTraversalStrategyBottomUp(arg)) {
    return MA_makeTraversalStrategyBottomUp();
  }
  if (MA_isTraversalStrategyTopDown(arg)) {
    return MA_makeTraversalStrategyTopDown();
  }
  ATabort("not a TraversalStrategy: %t\n", arg);
  return (MA_TraversalStrategy)NULL;
}
/**
 * Apply functions to the children of a MA_TraversalType. 
 * \return A new MA_TraversalType with new children where the argument functions might have applied
 */
MA_TraversalType MA_visitTraversalType(MA_TraversalType arg) {
  if (MA_isTraversalTypeTrafo(arg)) {
    return MA_makeTraversalTypeTrafo();
  }
  if (MA_isTraversalTypeAccu(arg)) {
    return MA_makeTraversalTypeAccu();
  }
  if (MA_isTraversalTypeAccutrafo(arg)) {
    return MA_makeTraversalTypeAccutrafo();
  }
  ATabort("not a TraversalType: %t\n", arg);
  return (MA_TraversalType)NULL;
}
/**
 * Apply functions to the children of a MA_TraversalContinuation. 
 * \return A new MA_TraversalContinuation with new children where the argument functions might have applied
 */
MA_TraversalContinuation MA_visitTraversalContinuation(MA_TraversalContinuation arg) {
  if (MA_isTraversalContinuationBreak(arg)) {
    return MA_makeTraversalContinuationBreak();
  }
  if (MA_isTraversalContinuationContinue(arg)) {
    return MA_makeTraversalContinuationContinue();
  }
  ATabort("not a TraversalContinuation: %t\n", arg);
  return (MA_TraversalContinuation)NULL;
}
/**
 * Apply functions to the children of a MA_FunId. 
 * \return A new MA_FunId with new children where the argument functions might have applied
 */
MA_FunId MA_visitFunId(MA_FunId arg, MA_NatCon (*acceptNatCon)(MA_NatCon), MA_IdCon (*acceptIdCon)(MA_IdCon), MA_StrCon (*acceptStrCon)(MA_StrCon), MA_OptLayout (*acceptWsAfterBracketOpen)(MA_OptLayout), MA_OptLayout (*acceptWsAfterFunId)(MA_OptLayout), MA_OptLayout (*acceptWsAfterBraceOpen)(MA_OptLayout), MA_NatCon (*acceptSeps)(MA_NatCon), MA_OptLayout (*acceptWsAfterSeps)(MA_OptLayout), MA_OptLayout (*acceptWsAfterIGNORE)(MA_OptLayout), MA_OptLayout (*acceptWsAfterTRANSLATE)(MA_OptLayout), MA_OptLayout (*acceptWsAfterBar)(MA_OptLayout), MA_TraversalType (*acceptTraversalType)(MA_TraversalType), MA_OptLayout (*acceptWsAfterTraversalType)(MA_OptLayout), MA_TraversalStrategy (*acceptTraversalStrategy)(MA_TraversalStrategy), MA_OptLayout (*acceptWsAfterTraversalStrategy)(MA_OptLayout), MA_TraversalContinuation (*acceptTraversalContinuation)(MA_TraversalContinuation), MA_OptLayout (*acceptWsAfterTraversalContinuation)(MA_OptLayout), MA_OptLayout (*acceptWsAfterLhs)(MA_OptLayout), MA_OptLayout (*acceptWsAfterConc)(MA_OptLayout), MA_OptLayout (*acceptWsAfterConc2)(MA_OptLayout)) {
  if (MA_isFunIdCharacter(arg)) {
    return MA_makeFunIdCharacter(
        acceptNatCon ? acceptNatCon(MA_getFunIdNatCon(arg)) : MA_getFunIdNatCon(arg));
  }
  if (MA_isFunIdUnquoted(arg)) {
    return MA_makeFunIdUnquoted(
        acceptIdCon ? acceptIdCon(MA_getFunIdIdCon(arg)) : MA_getFunIdIdCon(arg));
  }
  if (MA_isFunIdQuoted(arg)) {
    return MA_makeFunIdQuoted(
        acceptStrCon ? acceptStrCon(MA_getFunIdStrCon(arg)) : MA_getFunIdStrCon(arg));
  }
  if (MA_isFunIdReturnsList(arg)) {
    return MA_makeFunIdReturnsList(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(MA_getFunIdWsAfterBracketOpen(arg)) : MA_getFunIdWsAfterBracketOpen(arg),
        MA_visitFunId(MA_getFunIdFunId(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFunIdWsAfterFunId(arg)) : MA_getFunIdWsAfterFunId(arg));
  }
  if (MA_isFunIdList(arg)) {
    return MA_makeFunIdList(
        acceptWsAfterBraceOpen ? acceptWsAfterBraceOpen(MA_getFunIdWsAfterBraceOpen(arg)) : MA_getFunIdWsAfterBraceOpen(arg),
        MA_visitFunId(MA_getFunIdFunId(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFunIdWsAfterFunId(arg)) : MA_getFunIdWsAfterFunId(arg));
  }
  if (MA_isFunIdSepList(arg)) {
    return MA_makeFunIdSepList(
        acceptWsAfterBraceOpen ? acceptWsAfterBraceOpen(MA_getFunIdWsAfterBraceOpen(arg)) : MA_getFunIdWsAfterBraceOpen(arg),
        MA_visitFunId(MA_getFunIdFunId(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFunIdWsAfterFunId(arg)) : MA_getFunIdWsAfterFunId(arg),
        acceptSeps ? acceptSeps(MA_getFunIdSeps(arg)) : MA_getFunIdSeps(arg),
        acceptWsAfterSeps ? acceptWsAfterSeps(MA_getFunIdWsAfterSeps(arg)) : MA_getFunIdWsAfterSeps(arg));
  }
  if (MA_isFunIdIgnored(arg)) {
    return MA_makeFunIdIgnored(
        acceptWsAfterIGNORE ? acceptWsAfterIGNORE(MA_getFunIdWsAfterIGNORE(arg)) : MA_getFunIdWsAfterIGNORE(arg),
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(MA_getFunIdWsAfterBracketOpen(arg)) : MA_getFunIdWsAfterBracketOpen(arg),
        MA_visitFunId(MA_getFunIdFunId(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFunIdWsAfterFunId(arg)) : MA_getFunIdWsAfterFunId(arg));
  }
  if (MA_isFunIdTranslate(arg)) {
    return MA_makeFunIdTranslate(
        acceptWsAfterTRANSLATE ? acceptWsAfterTRANSLATE(MA_getFunIdWsAfterTRANSLATE(arg)) : MA_getFunIdWsAfterTRANSLATE(arg),
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(MA_getFunIdWsAfterBracketOpen(arg)) : MA_getFunIdWsAfterBracketOpen(arg),
        MA_visitFunId(MA_getFunIdFunId(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFunIdWsAfterFunId(arg)) : MA_getFunIdWsAfterFunId(arg));
  }
  if (MA_isFunIdTraversal(arg)) {
    return MA_makeFunIdTraversal(
        acceptWsAfterBar ? acceptWsAfterBar(MA_getFunIdWsAfterBar(arg)) : MA_getFunIdWsAfterBar(arg),
        MA_visitFunId(MA_getFunIdFunId(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFunIdWsAfterFunId(arg)) : MA_getFunIdWsAfterFunId(arg),
        acceptTraversalType ? acceptTraversalType(MA_getFunIdTraversalType(arg)) : MA_getFunIdTraversalType(arg),
        acceptWsAfterTraversalType ? acceptWsAfterTraversalType(MA_getFunIdWsAfterTraversalType(arg)) : MA_getFunIdWsAfterTraversalType(arg),
        acceptTraversalStrategy ? acceptTraversalStrategy(MA_getFunIdTraversalStrategy(arg)) : MA_getFunIdTraversalStrategy(arg),
        acceptWsAfterTraversalStrategy ? acceptWsAfterTraversalStrategy(MA_getFunIdWsAfterTraversalStrategy(arg)) : MA_getFunIdWsAfterTraversalStrategy(arg),
        acceptTraversalContinuation ? acceptTraversalContinuation(MA_getFunIdTraversalContinuation(arg)) : MA_getFunIdTraversalContinuation(arg),
        acceptWsAfterTraversalContinuation ? acceptWsAfterTraversalContinuation(MA_getFunIdWsAfterTraversalContinuation(arg)) : MA_getFunIdWsAfterTraversalContinuation(arg));
  }
  if (MA_isFunIdConcat(arg)) {
    return MA_makeFunIdConcat(
        MA_visitFunId(MA_getFunIdLhs(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getFunIdWsAfterLhs(arg)) : MA_getFunIdWsAfterLhs(arg),
        acceptWsAfterConc ? acceptWsAfterConc(MA_getFunIdWsAfterConc(arg)) : MA_getFunIdWsAfterConc(arg),
        MA_visitFunId(MA_getFunIdRhs(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2));
  }
  if (MA_isFunIdConcatDash(arg)) {
    return MA_makeFunIdConcatDash(
        MA_visitFunId(MA_getFunIdLhs(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getFunIdWsAfterLhs(arg)) : MA_getFunIdWsAfterLhs(arg),
        acceptWsAfterConc2 ? acceptWsAfterConc2(MA_getFunIdWsAfterConc2(arg)) : MA_getFunIdWsAfterConc2(arg),
        MA_visitFunId(MA_getFunIdRhs(arg), acceptNatCon, acceptIdCon, acceptStrCon, acceptWsAfterBracketOpen, acceptWsAfterFunId, acceptWsAfterBraceOpen, acceptSeps, acceptWsAfterSeps, acceptWsAfterIGNORE, acceptWsAfterTRANSLATE, acceptWsAfterBar, acceptTraversalType, acceptWsAfterTraversalType, acceptTraversalStrategy, acceptWsAfterTraversalStrategy, acceptTraversalContinuation, acceptWsAfterTraversalContinuation, acceptWsAfterLhs, acceptWsAfterConc, acceptWsAfterConc2));
  }
  ATabort("not a FunId: %t\n", arg);
  return (MA_FunId)NULL;
}
/**
 * Apply functions to the children of a MA_VarId. 
 * \return A new MA_VarId with new children where the argument functions might have applied
 */
MA_VarId MA_visitVarId(MA_VarId arg, MA_OptLayout (*acceptWsAfterDollar)(MA_OptLayout), MA_FunId (*acceptFunId)(MA_FunId), MA_OptLayout (*acceptWsAfterDollarPlus)(MA_OptLayout), MA_OptLayout (*acceptWsAfterDollarStar)(MA_OptLayout)) {
  if (MA_isVarIdNormal(arg)) {
    return MA_makeVarIdNormal(
        acceptWsAfterDollar ? acceptWsAfterDollar(MA_getVarIdWsAfterDollar(arg)) : MA_getVarIdWsAfterDollar(arg),
        acceptFunId ? acceptFunId(MA_getVarIdFunId(arg)) : MA_getVarIdFunId(arg));
  }
  if (MA_isVarIdPlus(arg)) {
    return MA_makeVarIdPlus(
        acceptWsAfterDollarPlus ? acceptWsAfterDollarPlus(MA_getVarIdWsAfterDollarPlus(arg)) : MA_getVarIdWsAfterDollarPlus(arg),
        acceptFunId ? acceptFunId(MA_getVarIdFunId(arg)) : MA_getVarIdFunId(arg));
  }
  if (MA_isVarIdStar(arg)) {
    return MA_makeVarIdStar(
        acceptWsAfterDollarStar ? acceptWsAfterDollarStar(MA_getVarIdWsAfterDollarStar(arg)) : MA_getVarIdWsAfterDollarStar(arg),
        acceptFunId ? acceptFunId(MA_getVarIdFunId(arg)) : MA_getVarIdFunId(arg));
  }
  ATabort("not a VarId: %t\n", arg);
  return (MA_VarId)NULL;
}
/**
 * Apply functions to the children of a MA_ModId. 
 * \return A new MA_ModId with new children where the argument functions might have applied
 */
MA_ModId MA_visitModId(MA_ModId arg, MA_IdCon (*acceptIdCon)(MA_IdCon)) {
  if (MA_isModIdDefault(arg)) {
    return MA_makeModIdDefault(
        acceptIdCon ? acceptIdCon(MA_getModIdIdCon(arg)) : MA_getModIdIdCon(arg));
  }
  ATabort("not a ModId: %t\n", arg);
  return (MA_ModId)NULL;
}
/**
 * Apply functions to the children of a MA_Term. 
 * \return A new MA_Term with new children where the argument functions might have applied
 */
MA_Term MA_visitTerm(MA_Term arg, MA_VarId (*acceptVarId)(MA_VarId), MA_FunId (*acceptFunId)(MA_FunId), MA_OptLayout (*acceptWsAfterFunId)(MA_OptLayout), MA_OptLayout (*acceptWsAfterParenOpen)(MA_OptLayout), MA_TermArgs (*acceptArgs)(MA_TermArgs), MA_OptLayout (*acceptWsAfterArgs)(MA_OptLayout), MA_OptLayout (*acceptWsAfterBracketOpen)(MA_OptLayout), MA_TermList (*acceptTermList)(MA_TermList), MA_OptLayout (*acceptWsAfterTermList)(MA_OptLayout), MA_OptLayout (*acceptWsAfterTerm)(MA_OptLayout), MA_OptLayout (*acceptWsAfterColon)(MA_OptLayout)) {
  if (MA_isTermVar(arg)) {
    return MA_makeTermVar(
        acceptVarId ? acceptVarId(MA_getTermVarId(arg)) : MA_getTermVarId(arg));
  }
  if (MA_isTermConstant(arg)) {
    return MA_makeTermConstant(
        acceptFunId ? acceptFunId(MA_getTermFunId(arg)) : MA_getTermFunId(arg));
  }
  if (MA_isTermFunc(arg)) {
    return MA_makeTermFunc(
        acceptFunId ? acceptFunId(MA_getTermFunId(arg)) : MA_getTermFunId(arg),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getTermWsAfterFunId(arg)) : MA_getTermWsAfterFunId(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(MA_getTermWsAfterParenOpen(arg)) : MA_getTermWsAfterParenOpen(arg),
        acceptArgs ? acceptArgs(MA_getTermArgs(arg)) : MA_getTermArgs(arg),
        acceptWsAfterArgs ? acceptWsAfterArgs(MA_getTermWsAfterArgs(arg)) : MA_getTermWsAfterArgs(arg));
  }
  if (MA_isTermList(arg)) {
    return MA_makeTermList(
        acceptWsAfterBracketOpen ? acceptWsAfterBracketOpen(MA_getTermWsAfterBracketOpen(arg)) : MA_getTermWsAfterBracketOpen(arg),
        acceptTermList ? acceptTermList(MA_getTermTermList(arg)) : MA_getTermTermList(arg),
        acceptWsAfterTermList ? acceptWsAfterTermList(MA_getTermWsAfterTermList(arg)) : MA_getTermWsAfterTermList(arg));
  }
  if (MA_isTermTyped(arg)) {
    return MA_makeTermTyped(
        MA_visitTerm(MA_getTermTerm(arg), acceptVarId, acceptFunId, acceptWsAfterFunId, acceptWsAfterParenOpen, acceptArgs, acceptWsAfterArgs, acceptWsAfterBracketOpen, acceptTermList, acceptWsAfterTermList, acceptWsAfterTerm, acceptWsAfterColon),
        acceptWsAfterTerm ? acceptWsAfterTerm(MA_getTermWsAfterTerm(arg)) : MA_getTermWsAfterTerm(arg),
        acceptWsAfterColon ? acceptWsAfterColon(MA_getTermWsAfterColon(arg)) : MA_getTermWsAfterColon(arg),
        MA_visitTerm(MA_getTermType(arg), acceptVarId, acceptFunId, acceptWsAfterFunId, acceptWsAfterParenOpen, acceptArgs, acceptWsAfterArgs, acceptWsAfterBracketOpen, acceptTermList, acceptWsAfterTermList, acceptWsAfterTerm, acceptWsAfterColon));
  }
  ATabort("not a Term: %t\n", arg);
  return (MA_Term)NULL;
}
/**
 * Apply functions to the children of a MA_TermList. 
 * \return A new MA_TermList with new children where the argument functions might have applied
 */
MA_TermList MA_visitTermList(MA_TermList arg, MA_TermElems (*acceptElems)(MA_TermElems)) {
  if (MA_isTermListDefault(arg)) {
    return MA_makeTermListDefault(
        acceptElems ? acceptElems(MA_getTermListElems(arg)) : MA_getTermListElems(arg));
  }
  ATabort("not a TermList: %t\n", arg);
  return (MA_TermList)NULL;
}
/**
 * Apply functions to the children of a MA_SigArg. 
 * \return A new MA_SigArg with new children where the argument functions might have applied
 */
MA_SigArg MA_visitSigArg(MA_SigArg arg, MA_OptLayout (*acceptWsAfterUnderscore)(MA_OptLayout)) {
  if (MA_isSigArgNormal(arg)) {
    return MA_makeSigArgNormal();
  }
  if (MA_isSigArgStar(arg)) {
    return MA_makeSigArgStar(
        acceptWsAfterUnderscore ? acceptWsAfterUnderscore(MA_getSigArgWsAfterUnderscore(arg)) : MA_getSigArgWsAfterUnderscore(arg));
  }
  if (MA_isSigArgPlus(arg)) {
    return MA_makeSigArgPlus(
        acceptWsAfterUnderscore ? acceptWsAfterUnderscore(MA_getSigArgWsAfterUnderscore(arg)) : MA_getSigArgWsAfterUnderscore(arg));
  }
  ATabort("not a SigArg: %t\n", arg);
  return (MA_SigArg)NULL;
}
/**
 * Apply functions to the children of a MA_FuncDef. 
 * \return A new MA_FuncDef with new children where the argument functions might have applied
 */
MA_FuncDef MA_visitFuncDef(MA_FuncDef arg, MA_FunId (*acceptFunId)(MA_FunId), MA_OptLayout (*acceptWsAfterFunId)(MA_OptLayout), MA_Annotations (*acceptAnnotations)(MA_Annotations), MA_OptLayout (*acceptWsAfterParenOpen)(MA_OptLayout), MA_SigArgArgs (*acceptArgs)(MA_SigArgArgs), MA_OptLayout (*acceptWsAfterArgs)(MA_OptLayout), MA_OptLayout (*acceptWsAfterParenClose)(MA_OptLayout)) {
  if (MA_isFuncDefConstantNoAnnos(arg)) {
    return MA_makeFuncDefConstantNoAnnos(
        acceptFunId ? acceptFunId(MA_getFuncDefFunId(arg)) : MA_getFuncDefFunId(arg));
  }
  if (MA_isFuncDefConstantWithAnnos(arg)) {
    return MA_makeFuncDefConstantWithAnnos(
        acceptFunId ? acceptFunId(MA_getFuncDefFunId(arg)) : MA_getFuncDefFunId(arg),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFuncDefWsAfterFunId(arg)) : MA_getFuncDefWsAfterFunId(arg),
        acceptAnnotations ? acceptAnnotations(MA_getFuncDefAnnotations(arg)) : MA_getFuncDefAnnotations(arg));
  }
  if (MA_isFuncDefFuncNoAnnos(arg)) {
    return MA_makeFuncDefFuncNoAnnos(
        acceptFunId ? acceptFunId(MA_getFuncDefFunId(arg)) : MA_getFuncDefFunId(arg),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFuncDefWsAfterFunId(arg)) : MA_getFuncDefWsAfterFunId(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(MA_getFuncDefWsAfterParenOpen(arg)) : MA_getFuncDefWsAfterParenOpen(arg),
        acceptArgs ? acceptArgs(MA_getFuncDefArgs(arg)) : MA_getFuncDefArgs(arg),
        acceptWsAfterArgs ? acceptWsAfterArgs(MA_getFuncDefWsAfterArgs(arg)) : MA_getFuncDefWsAfterArgs(arg));
  }
  if (MA_isFuncDefFuncWithAnnos(arg)) {
    return MA_makeFuncDefFuncWithAnnos(
        acceptFunId ? acceptFunId(MA_getFuncDefFunId(arg)) : MA_getFuncDefFunId(arg),
        acceptWsAfterFunId ? acceptWsAfterFunId(MA_getFuncDefWsAfterFunId(arg)) : MA_getFuncDefWsAfterFunId(arg),
        acceptWsAfterParenOpen ? acceptWsAfterParenOpen(MA_getFuncDefWsAfterParenOpen(arg)) : MA_getFuncDefWsAfterParenOpen(arg),
        acceptArgs ? acceptArgs(MA_getFuncDefArgs(arg)) : MA_getFuncDefArgs(arg),
        acceptWsAfterArgs ? acceptWsAfterArgs(MA_getFuncDefWsAfterArgs(arg)) : MA_getFuncDefWsAfterArgs(arg),
        acceptWsAfterParenClose ? acceptWsAfterParenClose(MA_getFuncDefWsAfterParenClose(arg)) : MA_getFuncDefWsAfterParenClose(arg),
        acceptAnnotations ? acceptAnnotations(MA_getFuncDefAnnotations(arg)) : MA_getFuncDefAnnotations(arg));
  }
  ATabort("not a FuncDef: %t\n", arg);
  return (MA_FuncDef)NULL;
}
/**
 * Apply functions to the children of a MA_Annotations. 
 * \return A new MA_Annotations with new children where the argument functions might have applied
 */
MA_Annotations MA_visitAnnotations(MA_Annotations arg, MA_OptLayout (*acceptWsAfterBraceOpen)(MA_OptLayout), MA_TermAttrs (*acceptAttrs)(MA_TermAttrs), MA_OptLayout (*acceptWsAfterAttrs)(MA_OptLayout)) {
  if (MA_isAnnotationsDefault(arg)) {
    return MA_makeAnnotationsDefault(
        acceptWsAfterBraceOpen ? acceptWsAfterBraceOpen(MA_getAnnotationsWsAfterBraceOpen(arg)) : MA_getAnnotationsWsAfterBraceOpen(arg),
        acceptAttrs ? acceptAttrs(MA_getAnnotationsAttrs(arg)) : MA_getAnnotationsAttrs(arg),
        acceptWsAfterAttrs ? acceptWsAfterAttrs(MA_getAnnotationsWsAfterAttrs(arg)) : MA_getAnnotationsWsAfterAttrs(arg));
  }
  ATabort("not a Annotations: %t\n", arg);
  return (MA_Annotations)NULL;
}
/**
 * Apply functions to the children of a MA_SigArgList. 
 * \return A new MA_SigArgList with new children where the argument functions might have applied
 */
MA_SigArgList MA_visitSigArgList(MA_SigArgList arg, MA_SigArgArgs (*acceptArgs)(MA_SigArgArgs)) {
  if (MA_isSigArgListDefault(arg)) {
    return MA_makeSigArgListDefault(
        acceptArgs ? acceptArgs(MA_getSigArgListArgs(arg)) : MA_getSigArgListArgs(arg));
  }
  ATabort("not a SigArgList: %t\n", arg);
  return (MA_SigArgList)NULL;
}
/**
 * Apply functions to the children of a MA_FuncDefList. 
 * \return A new MA_FuncDefList with new children where the argument functions might have applied
 */
MA_FuncDefList MA_visitFuncDefList(MA_FuncDefList arg, MA_FuncDefDefs (*acceptDefs)(MA_FuncDefDefs)) {
  if (MA_isFuncDefListDefault(arg)) {
    return MA_makeFuncDefListDefault(
        acceptDefs ? acceptDefs(MA_getFuncDefListDefs(arg)) : MA_getFuncDefListDefs(arg));
  }
  ATabort("not a FuncDefList: %t\n", arg);
  return (MA_FuncDefList)NULL;
}
/**
 * Apply functions to the children of a MA_Rule. 
 * \return A new MA_Rule with new children where the argument functions might have applied
 */
MA_Rule MA_visitRule(MA_Rule arg, MA_Term (*acceptLhs)(MA_Term), MA_OptLayout (*acceptWsAfterLhs)(MA_OptLayout), MA_OptLayout (*acceptWsAfterIs)(MA_OptLayout), MA_Term (*acceptRhs)(MA_Term), MA_OptLayout (*acceptWsAfterDefaultColon)(MA_OptLayout), MA_CondList (*acceptConds)(MA_CondList), MA_OptLayout (*acceptWsAfterConds)(MA_OptLayout), MA_OptLayout (*acceptWsAfterEqualsEqualsGreaterThan)(MA_OptLayout)) {
  if (MA_isRuleNoConds(arg)) {
    return MA_makeRuleNoConds(
        acceptLhs ? acceptLhs(MA_getRuleLhs(arg)) : MA_getRuleLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getRuleWsAfterLhs(arg)) : MA_getRuleWsAfterLhs(arg),
        acceptWsAfterIs ? acceptWsAfterIs(MA_getRuleWsAfterIs(arg)) : MA_getRuleWsAfterIs(arg),
        acceptRhs ? acceptRhs(MA_getRuleRhs(arg)) : MA_getRuleRhs(arg));
  }
  if (MA_isRuleDefaultNoConds(arg)) {
    return MA_makeRuleDefaultNoConds(
        acceptWsAfterDefaultColon ? acceptWsAfterDefaultColon(MA_getRuleWsAfterDefaultColon(arg)) : MA_getRuleWsAfterDefaultColon(arg),
        acceptLhs ? acceptLhs(MA_getRuleLhs(arg)) : MA_getRuleLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getRuleWsAfterLhs(arg)) : MA_getRuleWsAfterLhs(arg),
        acceptWsAfterIs ? acceptWsAfterIs(MA_getRuleWsAfterIs(arg)) : MA_getRuleWsAfterIs(arg),
        acceptRhs ? acceptRhs(MA_getRuleRhs(arg)) : MA_getRuleRhs(arg));
  }
  if (MA_isRuleWithConds(arg)) {
    return MA_makeRuleWithConds(
        acceptConds ? acceptConds(MA_getRuleConds(arg)) : MA_getRuleConds(arg),
        acceptWsAfterConds ? acceptWsAfterConds(MA_getRuleWsAfterConds(arg)) : MA_getRuleWsAfterConds(arg),
        acceptWsAfterEqualsEqualsGreaterThan ? acceptWsAfterEqualsEqualsGreaterThan(MA_getRuleWsAfterEqualsEqualsGreaterThan(arg)) : MA_getRuleWsAfterEqualsEqualsGreaterThan(arg),
        acceptLhs ? acceptLhs(MA_getRuleLhs(arg)) : MA_getRuleLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getRuleWsAfterLhs(arg)) : MA_getRuleWsAfterLhs(arg),
        acceptWsAfterIs ? acceptWsAfterIs(MA_getRuleWsAfterIs(arg)) : MA_getRuleWsAfterIs(arg),
        acceptRhs ? acceptRhs(MA_getRuleRhs(arg)) : MA_getRuleRhs(arg));
  }
  if (MA_isRuleDefaultWithConds(arg)) {
    return MA_makeRuleDefaultWithConds(
        acceptWsAfterDefaultColon ? acceptWsAfterDefaultColon(MA_getRuleWsAfterDefaultColon(arg)) : MA_getRuleWsAfterDefaultColon(arg),
        acceptConds ? acceptConds(MA_getRuleConds(arg)) : MA_getRuleConds(arg),
        acceptWsAfterConds ? acceptWsAfterConds(MA_getRuleWsAfterConds(arg)) : MA_getRuleWsAfterConds(arg),
        acceptWsAfterEqualsEqualsGreaterThan ? acceptWsAfterEqualsEqualsGreaterThan(MA_getRuleWsAfterEqualsEqualsGreaterThan(arg)) : MA_getRuleWsAfterEqualsEqualsGreaterThan(arg),
        acceptLhs ? acceptLhs(MA_getRuleLhs(arg)) : MA_getRuleLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getRuleWsAfterLhs(arg)) : MA_getRuleWsAfterLhs(arg),
        acceptWsAfterIs ? acceptWsAfterIs(MA_getRuleWsAfterIs(arg)) : MA_getRuleWsAfterIs(arg),
        acceptRhs ? acceptRhs(MA_getRuleRhs(arg)) : MA_getRuleRhs(arg));
  }
  ATabort("not a Rule: %t\n", arg);
  return (MA_Rule)NULL;
}
/**
 * Apply functions to the children of a MA_RuleList. 
 * \return A new MA_RuleList with new children where the argument functions might have applied
 */
MA_RuleList MA_visitRuleList(MA_RuleList arg, MA_RuleRules (*acceptRules)(MA_RuleRules)) {
  if (MA_isRuleListDefault(arg)) {
    return MA_makeRuleListDefault(
        acceptRules ? acceptRules(MA_getRuleListRules(arg)) : MA_getRuleListRules(arg));
  }
  ATabort("not a RuleList: %t\n", arg);
  return (MA_RuleList)NULL;
}
/**
 * Apply functions to the children of a MA_CondList. 
 * \return A new MA_CondList with new children where the argument functions might have applied
 */
MA_CondList MA_visitCondList(MA_CondList arg, MA_CondConds (*acceptConds)(MA_CondConds)) {
  if (MA_isCondListDefault(arg)) {
    return MA_makeCondListDefault(
        acceptConds ? acceptConds(MA_getCondListConds(arg)) : MA_getCondListConds(arg));
  }
  ATabort("not a CondList: %t\n", arg);
  return (MA_CondList)NULL;
}
/**
 * Apply functions to the children of a MA_Cond. 
 * \return A new MA_Cond with new children where the argument functions might have applied
 */
MA_Cond MA_visitCond(MA_Cond arg, MA_Term (*acceptLhs)(MA_Term), MA_OptLayout (*acceptWsAfterLhs)(MA_OptLayout), MA_OptLayout (*acceptWsAfterBecomes)(MA_OptLayout), MA_Term (*acceptRhs)(MA_Term), MA_OptLayout (*acceptWsAfterNotBecomes)(MA_OptLayout), MA_OptLayout (*acceptWsAfterEquals)(MA_OptLayout), MA_OptLayout (*acceptWsAfterNotEquals)(MA_OptLayout)) {
  if (MA_isCondAssign(arg)) {
    return MA_makeCondAssign(
        acceptLhs ? acceptLhs(MA_getCondLhs(arg)) : MA_getCondLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getCondWsAfterLhs(arg)) : MA_getCondWsAfterLhs(arg),
        acceptWsAfterBecomes ? acceptWsAfterBecomes(MA_getCondWsAfterBecomes(arg)) : MA_getCondWsAfterBecomes(arg),
        acceptRhs ? acceptRhs(MA_getCondRhs(arg)) : MA_getCondRhs(arg));
  }
  if (MA_isCondNoAssign(arg)) {
    return MA_makeCondNoAssign(
        acceptLhs ? acceptLhs(MA_getCondLhs(arg)) : MA_getCondLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getCondWsAfterLhs(arg)) : MA_getCondWsAfterLhs(arg),
        acceptWsAfterNotBecomes ? acceptWsAfterNotBecomes(MA_getCondWsAfterNotBecomes(arg)) : MA_getCondWsAfterNotBecomes(arg),
        acceptRhs ? acceptRhs(MA_getCondRhs(arg)) : MA_getCondRhs(arg));
  }
  if (MA_isCondEqual(arg)) {
    return MA_makeCondEqual(
        acceptLhs ? acceptLhs(MA_getCondLhs(arg)) : MA_getCondLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getCondWsAfterLhs(arg)) : MA_getCondWsAfterLhs(arg),
        acceptWsAfterEquals ? acceptWsAfterEquals(MA_getCondWsAfterEquals(arg)) : MA_getCondWsAfterEquals(arg),
        acceptRhs ? acceptRhs(MA_getCondRhs(arg)) : MA_getCondRhs(arg));
  }
  if (MA_isCondUnequal(arg)) {
    return MA_makeCondUnequal(
        acceptLhs ? acceptLhs(MA_getCondLhs(arg)) : MA_getCondLhs(arg),
        acceptWsAfterLhs ? acceptWsAfterLhs(MA_getCondWsAfterLhs(arg)) : MA_getCondWsAfterLhs(arg),
        acceptWsAfterNotEquals ? acceptWsAfterNotEquals(MA_getCondWsAfterNotEquals(arg)) : MA_getCondWsAfterNotEquals(arg),
        acceptRhs ? acceptRhs(MA_getCondRhs(arg)) : MA_getCondRhs(arg));
  }
  ATabort("not a Cond: %t\n", arg);
  return (MA_Cond)NULL;
}
/**
 * Apply functions to the children of a MA_SignatureOpt. 
 * \return A new MA_SignatureOpt with new children where the argument functions might have applied
 */
MA_SignatureOpt MA_visitSignatureOpt(MA_SignatureOpt arg, MA_OptLayout (*acceptWsAfterSignature)(MA_OptLayout), MA_FuncDefList (*acceptFuncDefList)(MA_FuncDefList)) {
  if (MA_isSignatureOptAbsent(arg)) {
    return MA_makeSignatureOptAbsent();
  }
  if (MA_isSignatureOptPresent(arg)) {
    return MA_makeSignatureOptPresent(
        acceptWsAfterSignature ? acceptWsAfterSignature(MA_getSignatureOptWsAfterSignature(arg)) : MA_getSignatureOptWsAfterSignature(arg),
        acceptFuncDefList ? acceptFuncDefList(MA_getSignatureOptFuncDefList(arg)) : MA_getSignatureOptFuncDefList(arg));
  }
  ATabort("not a SignatureOpt: %t\n", arg);
  return (MA_SignatureOpt)NULL;
}
/**
 * Apply functions to the children of a MA_RulesOpt. 
 * \return A new MA_RulesOpt with new children where the argument functions might have applied
 */
MA_RulesOpt MA_visitRulesOpt(MA_RulesOpt arg, MA_OptLayout (*acceptWsAfterRules)(MA_OptLayout), MA_RuleList (*acceptRuleList)(MA_RuleList)) {
  if (MA_isRulesOptAbsent(arg)) {
    return MA_makeRulesOptAbsent();
  }
  if (MA_isRulesOptPresent(arg)) {
    return MA_makeRulesOptPresent(
        acceptWsAfterRules ? acceptWsAfterRules(MA_getRulesOptWsAfterRules(arg)) : MA_getRulesOptWsAfterRules(arg),
        acceptRuleList ? acceptRuleList(MA_getRulesOptRuleList(arg)) : MA_getRulesOptRuleList(arg));
  }
  ATabort("not a RulesOpt: %t\n", arg);
  return (MA_RulesOpt)NULL;
}
/**
 * Apply functions to the children of a MA_Module. 
 * \return A new MA_Module with new children where the argument functions might have applied
 */
MA_Module MA_visitModule(MA_Module arg, MA_OptLayout (*acceptWsAfterModule)(MA_OptLayout), MA_ModId (*acceptModId)(MA_ModId), MA_OptLayout (*acceptWsAfterModId)(MA_OptLayout), MA_SignatureOpt (*acceptSignatureOpt)(MA_SignatureOpt), MA_OptLayout (*acceptWsAfterSignatureOpt)(MA_OptLayout), MA_RulesOpt (*acceptRulesOpt)(MA_RulesOpt)) {
  if (MA_isModuleModule(arg)) {
    return MA_makeModuleModule(
        acceptWsAfterModule ? acceptWsAfterModule(MA_getModuleWsAfterModule(arg)) : MA_getModuleWsAfterModule(arg),
        acceptModId ? acceptModId(MA_getModuleModId(arg)) : MA_getModuleModId(arg),
        acceptWsAfterModId ? acceptWsAfterModId(MA_getModuleWsAfterModId(arg)) : MA_getModuleWsAfterModId(arg),
        acceptSignatureOpt ? acceptSignatureOpt(MA_getModuleSignatureOpt(arg)) : MA_getModuleSignatureOpt(arg),
        acceptWsAfterSignatureOpt ? acceptWsAfterSignatureOpt(MA_getModuleWsAfterSignatureOpt(arg)) : MA_getModuleWsAfterSignatureOpt(arg),
        acceptRulesOpt ? acceptRulesOpt(MA_getModuleRulesOpt(arg)) : MA_getModuleRulesOpt(arg));
  }
  ATabort("not a Module: %t\n", arg);
  return (MA_Module)NULL;
}
/**
 * Apply functions to the children of a MA_TermArgs. 
 * \return A new MA_TermArgs with new children where the argument functions might have applied
 */
MA_TermArgs MA_visitTermArgs(MA_TermArgs arg, MA_Term (*acceptHead)(MA_Term), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isTermArgsEmpty(arg)) {
    return MA_makeTermArgsEmpty();
  }
  if (MA_isTermArgsSingle(arg)) {
    return MA_makeTermArgsSingle(
        acceptHead ? acceptHead(MA_getTermArgsHead(arg)) : MA_getTermArgsHead(arg));
  }
  if (MA_isTermArgsMany(arg)) {
    return MA_makeTermArgsMany(
        acceptHead ? acceptHead(MA_getTermArgsHead(arg)) : MA_getTermArgsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getTermArgsWsAfterHead(arg)) : MA_getTermArgsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getTermArgsWsAfterSep(arg)) : MA_getTermArgsWsAfterSep(arg),
        MA_visitTermArgs(MA_getTermArgsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a TermArgs: %t\n", arg);
  return (MA_TermArgs)NULL;
}
/**
 * Apply functions to the children of a MA_TermElems. 
 * \return A new MA_TermElems with new children where the argument functions might have applied
 */
MA_TermElems MA_visitTermElems(MA_TermElems arg, MA_Term (*acceptHead)(MA_Term), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isTermElemsEmpty(arg)) {
    return MA_makeTermElemsEmpty();
  }
  if (MA_isTermElemsSingle(arg)) {
    return MA_makeTermElemsSingle(
        acceptHead ? acceptHead(MA_getTermElemsHead(arg)) : MA_getTermElemsHead(arg));
  }
  if (MA_isTermElemsMany(arg)) {
    return MA_makeTermElemsMany(
        acceptHead ? acceptHead(MA_getTermElemsHead(arg)) : MA_getTermElemsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getTermElemsWsAfterHead(arg)) : MA_getTermElemsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getTermElemsWsAfterSep(arg)) : MA_getTermElemsWsAfterSep(arg),
        MA_visitTermElems(MA_getTermElemsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a TermElems: %t\n", arg);
  return (MA_TermElems)NULL;
}
/**
 * Apply functions to the children of a MA_SigArgArgs. 
 * \return A new MA_SigArgArgs with new children where the argument functions might have applied
 */
MA_SigArgArgs MA_visitSigArgArgs(MA_SigArgArgs arg, MA_SigArg (*acceptHead)(MA_SigArg), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isSigArgArgsEmpty(arg)) {
    return MA_makeSigArgArgsEmpty();
  }
  if (MA_isSigArgArgsSingle(arg)) {
    return MA_makeSigArgArgsSingle(
        acceptHead ? acceptHead(MA_getSigArgArgsHead(arg)) : MA_getSigArgArgsHead(arg));
  }
  if (MA_isSigArgArgsMany(arg)) {
    return MA_makeSigArgArgsMany(
        acceptHead ? acceptHead(MA_getSigArgArgsHead(arg)) : MA_getSigArgArgsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getSigArgArgsWsAfterHead(arg)) : MA_getSigArgArgsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getSigArgArgsWsAfterSep(arg)) : MA_getSigArgArgsWsAfterSep(arg),
        MA_visitSigArgArgs(MA_getSigArgArgsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a SigArgArgs: %t\n", arg);
  return (MA_SigArgArgs)NULL;
}
/**
 * Apply functions to the children of a MA_TermAttrs. 
 * \return A new MA_TermAttrs with new children where the argument functions might have applied
 */
MA_TermAttrs MA_visitTermAttrs(MA_TermAttrs arg, MA_Term (*acceptHead)(MA_Term), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isTermAttrsEmpty(arg)) {
    return MA_makeTermAttrsEmpty();
  }
  if (MA_isTermAttrsSingle(arg)) {
    return MA_makeTermAttrsSingle(
        acceptHead ? acceptHead(MA_getTermAttrsHead(arg)) : MA_getTermAttrsHead(arg));
  }
  if (MA_isTermAttrsMany(arg)) {
    return MA_makeTermAttrsMany(
        acceptHead ? acceptHead(MA_getTermAttrsHead(arg)) : MA_getTermAttrsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getTermAttrsWsAfterHead(arg)) : MA_getTermAttrsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getTermAttrsWsAfterSep(arg)) : MA_getTermAttrsWsAfterSep(arg),
        MA_visitTermAttrs(MA_getTermAttrsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a TermAttrs: %t\n", arg);
  return (MA_TermAttrs)NULL;
}
/**
 * Apply functions to the children of a MA_FuncDefDefs. 
 * \return A new MA_FuncDefDefs with new children where the argument functions might have applied
 */
MA_FuncDefDefs MA_visitFuncDefDefs(MA_FuncDefDefs arg, MA_FuncDef (*acceptHead)(MA_FuncDef), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isFuncDefDefsEmpty(arg)) {
    return MA_makeFuncDefDefsEmpty();
  }
  if (MA_isFuncDefDefsSingle(arg)) {
    return MA_makeFuncDefDefsSingle(
        acceptHead ? acceptHead(MA_getFuncDefDefsHead(arg)) : MA_getFuncDefDefsHead(arg));
  }
  if (MA_isFuncDefDefsMany(arg)) {
    return MA_makeFuncDefDefsMany(
        acceptHead ? acceptHead(MA_getFuncDefDefsHead(arg)) : MA_getFuncDefDefsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getFuncDefDefsWsAfterHead(arg)) : MA_getFuncDefDefsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getFuncDefDefsWsAfterSep(arg)) : MA_getFuncDefDefsWsAfterSep(arg),
        MA_visitFuncDefDefs(MA_getFuncDefDefsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a FuncDefDefs: %t\n", arg);
  return (MA_FuncDefDefs)NULL;
}
/**
 * Apply functions to the children of a MA_RuleRules. 
 * \return A new MA_RuleRules with new children where the argument functions might have applied
 */
MA_RuleRules MA_visitRuleRules(MA_RuleRules arg, MA_Rule (*acceptHead)(MA_Rule), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isRuleRulesEmpty(arg)) {
    return MA_makeRuleRulesEmpty();
  }
  if (MA_isRuleRulesSingle(arg)) {
    return MA_makeRuleRulesSingle(
        acceptHead ? acceptHead(MA_getRuleRulesHead(arg)) : MA_getRuleRulesHead(arg));
  }
  if (MA_isRuleRulesMany(arg)) {
    return MA_makeRuleRulesMany(
        acceptHead ? acceptHead(MA_getRuleRulesHead(arg)) : MA_getRuleRulesHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getRuleRulesWsAfterHead(arg)) : MA_getRuleRulesWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getRuleRulesWsAfterSep(arg)) : MA_getRuleRulesWsAfterSep(arg),
        MA_visitRuleRules(MA_getRuleRulesTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a RuleRules: %t\n", arg);
  return (MA_RuleRules)NULL;
}
/**
 * Apply functions to the children of a MA_CondConds. 
 * \return A new MA_CondConds with new children where the argument functions might have applied
 */
MA_CondConds MA_visitCondConds(MA_CondConds arg, MA_Cond (*acceptHead)(MA_Cond), MA_OptLayout (*acceptWsAfterHead)(MA_OptLayout), MA_OptLayout (*acceptWsAfterSep)(MA_OptLayout)) {
  if (MA_isCondCondsEmpty(arg)) {
    return MA_makeCondCondsEmpty();
  }
  if (MA_isCondCondsSingle(arg)) {
    return MA_makeCondCondsSingle(
        acceptHead ? acceptHead(MA_getCondCondsHead(arg)) : MA_getCondCondsHead(arg));
  }
  if (MA_isCondCondsMany(arg)) {
    return MA_makeCondCondsMany(
        acceptHead ? acceptHead(MA_getCondCondsHead(arg)) : MA_getCondCondsHead(arg),
        acceptWsAfterHead ? acceptWsAfterHead(MA_getCondCondsWsAfterHead(arg)) : MA_getCondCondsWsAfterHead(arg),
        acceptWsAfterSep ? acceptWsAfterSep(MA_getCondCondsWsAfterSep(arg)) : MA_getCondCondsWsAfterSep(arg),
        MA_visitCondConds(MA_getCondCondsTail(arg), acceptHead, acceptWsAfterHead, acceptWsAfterSep));
  }
  ATabort("not a CondConds: %t\n", arg);
  return (MA_CondConds)NULL;
}
/**
 * Apply functions to the children of a MA_LexLayout. 
 * \return A new MA_LexLayout with new children where the argument functions might have applied
 */
MA_LexLayout MA_visitLexLayout(MA_LexLayout arg, char (*acceptCh)(char)) {
  if (MA_isLexLayoutWhitespace(arg)) {
    return MA_makeLexLayoutWhitespace(
        acceptCh ? acceptCh(MA_getLexLayoutCh(arg)) : MA_getLexLayoutCh(arg));
  }
  ATabort("not a LexLayout: %t\n", arg);
  return (MA_LexLayout)NULL;
}
/**
 * Apply functions to the children of a MA_LexStrChar. 
 * \return A new MA_LexStrChar with new children where the argument functions might have applied
 */
MA_LexStrChar MA_visitLexStrChar(MA_LexStrChar arg, char (*acceptA)(char), char (*acceptB)(char), char (*acceptC)(char), char (*acceptCh)(char)) {
  if (MA_isLexStrCharNewline(arg)) {
    return MA_makeLexStrCharNewline();
  }
  if (MA_isLexStrCharTab(arg)) {
    return MA_makeLexStrCharTab();
  }
  if (MA_isLexStrCharQuote(arg)) {
    return MA_makeLexStrCharQuote();
  }
  if (MA_isLexStrCharBackslash(arg)) {
    return MA_makeLexStrCharBackslash();
  }
  if (MA_isLexStrCharDecimal(arg)) {
    return MA_makeLexStrCharDecimal(
        acceptA ? acceptA(MA_getLexStrCharA(arg)) : MA_getLexStrCharA(arg),
        acceptB ? acceptB(MA_getLexStrCharB(arg)) : MA_getLexStrCharB(arg),
        acceptC ? acceptC(MA_getLexStrCharC(arg)) : MA_getLexStrCharC(arg));
  }
  if (MA_isLexStrCharNormal(arg)) {
    return MA_makeLexStrCharNormal(
        acceptCh ? acceptCh(MA_getLexStrCharCh(arg)) : MA_getLexStrCharCh(arg));
  }
  ATabort("not a LexStrChar: %t\n", arg);
  return (MA_LexStrChar)NULL;
}
/**
 * Apply functions to the children of a MA_StrChar. 
 * \return A new MA_StrChar with new children where the argument functions might have applied
 */
MA_StrChar MA_visitStrChar(MA_StrChar arg, MA_LexStrChar (*acceptStrChar)(MA_LexStrChar)) {
  if (MA_isStrCharLexToCf(arg)) {
    return MA_makeStrCharLexToCf(
        acceptStrChar ? acceptStrChar(MA_getStrCharStrChar(arg)) : MA_getStrCharStrChar(arg));
  }
  ATabort("not a StrChar: %t\n", arg);
  return (MA_StrChar)NULL;
}
/**
 * Apply functions to the children of a MA_LexStrCon. 
 * \return A new MA_LexStrCon with new children where the argument functions might have applied
 */
MA_LexStrCon MA_visitLexStrCon(MA_LexStrCon arg, MA_LexStrCharChars (*acceptChars)(MA_LexStrCharChars)) {
  if (MA_isLexStrConDefault(arg)) {
    return MA_makeLexStrConDefault(
        acceptChars ? acceptChars(MA_getLexStrConChars(arg)) : MA_getLexStrConChars(arg));
  }
  ATabort("not a LexStrCon: %t\n", arg);
  return (MA_LexStrCon)NULL;
}
/**
 * Apply functions to the children of a MA_StrCon. 
 * \return A new MA_StrCon with new children where the argument functions might have applied
 */
MA_StrCon MA_visitStrCon(MA_StrCon arg, MA_LexStrCon (*acceptStrCon)(MA_LexStrCon)) {
  if (MA_isStrConLexToCf(arg)) {
    return MA_makeStrConLexToCf(
        acceptStrCon ? acceptStrCon(MA_getStrConStrCon(arg)) : MA_getStrConStrCon(arg));
  }
  ATabort("not a StrCon: %t\n", arg);
  return (MA_StrCon)NULL;
}
/**
 * Apply functions to the children of a MA_LexStrCharChars. 
 * \return A new MA_LexStrCharChars with new children where the argument functions might have applied
 */
MA_LexStrCharChars MA_visitLexStrCharChars(MA_LexStrCharChars arg, MA_LexStrChar (*acceptHead)(MA_LexStrChar)) {
  if (MA_isLexStrCharCharsEmpty(arg)) {
    return MA_makeLexStrCharCharsEmpty();
  }
  if (MA_isLexStrCharCharsSingle(arg)) {
    return MA_makeLexStrCharCharsSingle(
        acceptHead ? acceptHead(MA_getLexStrCharCharsHead(arg)) : MA_getLexStrCharCharsHead(arg));
  }
  if (MA_isLexStrCharCharsMany(arg)) {
    return MA_makeLexStrCharCharsMany(
        acceptHead ? acceptHead(MA_getLexStrCharCharsHead(arg)) : MA_getLexStrCharCharsHead(arg),
        MA_visitLexStrCharChars(MA_getLexStrCharCharsTail(arg), acceptHead));
  }
  ATabort("not a LexStrCharChars: %t\n", arg);
  return (MA_LexStrCharChars)NULL;
}
/**
 * Apply functions to the children of a MA_LexNatCon. 
 * \return A new MA_LexNatCon with new children where the argument functions might have applied
 */
MA_LexNatCon MA_visitLexNatCon(MA_LexNatCon arg, char* (*acceptList)(char*)) {
  if (MA_isLexNatConDigits(arg)) {
    return MA_makeLexNatConDigits(
        acceptList ? acceptList(MA_getLexNatConList(arg)) : MA_getLexNatConList(arg));
  }
  ATabort("not a LexNatCon: %t\n", arg);
  return (MA_LexNatCon)NULL;
}
/**
 * Apply functions to the children of a MA_NatCon. 
 * \return A new MA_NatCon with new children where the argument functions might have applied
 */
MA_NatCon MA_visitNatCon(MA_NatCon arg, MA_LexNatCon (*acceptNatCon)(MA_LexNatCon)) {
  if (MA_isNatConLexToCf(arg)) {
    return MA_makeNatConLexToCf(
        acceptNatCon ? acceptNatCon(MA_getNatConNatCon(arg)) : MA_getNatConNatCon(arg));
  }
  ATabort("not a NatCon: %t\n", arg);
  return (MA_NatCon)NULL;
}
/**
 * Apply functions to the children of a MA_LexIdCon. 
 * \return A new MA_LexIdCon with new children where the argument functions might have applied
 */
MA_LexIdCon MA_visitLexIdCon(MA_LexIdCon arg, char (*acceptHead)(char), char* (*acceptTail)(char*)) {
  if (MA_isLexIdConDefault(arg)) {
    return MA_makeLexIdConDefault(
        acceptHead ? acceptHead(MA_getLexIdConHead(arg)) : MA_getLexIdConHead(arg),
        acceptTail ? acceptTail(MA_getLexIdConTail(arg)) : MA_getLexIdConTail(arg));
  }
  ATabort("not a LexIdCon: %t\n", arg);
  return (MA_LexIdCon)NULL;
}
/**
 * Apply functions to the children of a MA_IdCon. 
 * \return A new MA_IdCon with new children where the argument functions might have applied
 */
MA_IdCon MA_visitIdCon(MA_IdCon arg, MA_LexIdCon (*acceptIdCon)(MA_LexIdCon)) {
  if (MA_isIdConLexToCf(arg)) {
    return MA_makeIdConLexToCf(
        acceptIdCon ? acceptIdCon(MA_getIdConIdCon(arg)) : MA_getIdConIdCon(arg));
  }
  ATabort("not a IdCon: %t\n", arg);
  return (MA_IdCon)NULL;
}

